@@ -3,12 +3,13 @@ import config.package
 class Configure(config.package.Package):
   def __init__(self, framework):
     config.package.Package.__init__(self, framework)
-    self.version          = '5.5.1-p1'
+    self.version          = '5.6.1'
     self.minversion       = '5.2.1'
     self.versionname      = 'MUMPS_VERSION'
     self.requiresversion  = 1
     self.gitcommit        = 'v'+self.version
-    self.download         = ['http://ftp.mcs.anl.gov/pub/petsc/externalpackages/MUMPS_'+self.version+'.tar.gz']
+    self.download         = ['https://graal.ens-lyon.fr/MUMPS/MUMPS_'+self.version+'.tar.gz',
+                             'https://web.cels.anl.gov/projects/petsc/download/externalpackages/MUMPS_'+self.version+'.tar.gz']
     self.downloaddirnames = ['petsc-pkg-mumps','MUMPS']
     self.buildLanguages   = ['C','FC']
     self.precisions       = ['single','double']
@@ -128,8 +129,6 @@ class Configure(config.package.Package):
     g.write('FC = '+self.getCompiler()+'\n')
     g.write('FL = '+self.getCompiler()+'\n')
     g.write('OPTF    = '+self.updatePackageFFlags(self.getCompilerFlags())+'\n')
-    if self.openmp.found:
-      g.write('OPTF   += -DBLR_MT\n')
     if self.blasLapack.checkForRoutine('dgemmt'):
       g.write('OPTF   += -DGEMMT_AVAILABLE\n')
     g.write('OUTF = -o \n')
@@ -178,7 +177,7 @@ class Configure(config.package.Package):
         self.logPrintBox('Compiling MUMPS; this may take several minutes')
         output2,err2,ret2 = config.package.Package.executeShellCommand(self.make.make_jnp+' prerequisites', cwd=self.packageDir, timeout=2500, log = self.log)
         output3,err3,ret3 = config.package.Package.executeShellCommand(self.make.make_jnp+' all', cwd=os.path.join(self.packageDir,'src'), timeout=2500, log = self.log)
-        libDir     = os.path.join(self.installDir, self.libdir)
+        libDir     = self.libDir
         includeDir = os.path.join(self.installDir, self.includedir)
         self.logPrintBox('Installing MUMPS; this may take several minutes')
         output,err,ret = config.package.Package.executeShellCommandSeq(
