@@ -4,11 +4,11 @@ import os
 class Configure(config.package.GNUPackage):
   def __init__(self, framework):
     config.package.GNUPackage.__init__(self, framework)
-    self.version            = '3.26.2'
+    self.version            = '3.27.6'
     self.download           = ['https://github.com/Kitware/CMake/releases/download/v'+self.version+'/cmake-'+self.version+'.tar.gz',
                               'https://gitlab.kitware.com/cmake/cmake/-/archive/v'+self.version+'/cmake-v'+self.version+'.tar.gz']
     self.download_solaris   = ['https://cmake.org/files/v3.11/cmake-3.11.4.tar.gz',
-                               'http://ftp.mcs.anl.gov/pub/petsc/externalpackages/cmake-3.11.4.tar.gz']
+                               'https://web.cels.anl.gov/projects/petsc/download/externalpackages/cmake-3.11.4.tar.gz']
     self.downloadonWindows  = 1
     self.lookforbydefault   = 1
     self.publicInstall      = 0  # always install in PETSC_DIR/PETSC_ARCH (not --prefix) since this is not used by users
