@@ -3,8 +3,8 @@ import config.package
 class Configure(config.package.Package):
   def __init__(self,framework):
     config.package.Package.__init__(self,framework)
-    # self.version                = '2.2.3'
-    self.gitcommit              = '314f74e8210b02e76fa16ea706641249594ce92f' # main may-05-2023
+    # self.version                = '2.2.5'
+    self.gitcommit              = '201eecd26177f88d7bb6287251877d8013fb64d2' # main jan-01-2024
     self.download               = ['git://https://github.com/hpddm/hpddm','https://github.com/hpddm/hpddm/archive/'+self.gitcommit+'.tar.gz']
     self.minversion             = '2.2.1'
     self.versionname            = 'HPDDM_VERSION'
@@ -50,7 +50,7 @@ class Configure(config.package.Package):
       PETSC_ARCH = self.arch
       prefix     = os.path.join(self.petscdir.dir,self.arch)
     incDir = os.path.join(prefix,'include')
-    libDir = os.path.join(prefix,'lib')
+    libDir = os.path.join(prefix,self.libDirs[0])
     self.addMakeMacro('HPDDM','yes')
     self.include = [incDir]
     if not hasattr(self.framework,'packages'):
