@@ -3,17 +3,18 @@ import config.package
 class Configure(config.package.Package):
   def __init__(self,framework):
     config.package.Package.__init__(self,framework)
-    self.gitcommit              = '34b0a74ea932258034dfb91fa8ee83664cf40a1d' # main may-02-2023
+    self.gitcommit              = '658d8f0c51a18c01543c9a2da23df92784479063' # main sep-07-2023
     self.download               = ['git://https://github.com/htool-ddm/htool','https://github.com/htool-ddm/htool/archive/'+self.gitcommit+'.tar.gz']
     self.minversion             = '0.8.0'
-    self.versionname            = 'HTOOL_VERSION'
-    self.versioninclude         = 'htool/misc/define.hpp'
+    self.versionname            = 'HTOOL_VERSION_MAJOR.HTOOL_VERSION_MINOR.HTOOL_VERSION_SUBMINOR'
+    self.versioninclude         = 'htool/htool_version.hpp'
     self.buildLanguages         = ['Cxx']
     self.functions              = []
     self.includes               = ['htool/misc/define.hpp'] # no C++11 in this header
     self.skippackagewithoptions = 1
     self.precisions             = ['double'] # coordinates are stored in double precision, other scalars are templated, just enforce PetscReal == double during ./configure, for now
     self.usesopenmp             = 'yes'
+    self.requires32bitint       = 1
     return
 
   def setupDependencies(self,framework):
