@@ -15,22 +15,24 @@ class Configure(config.base.Configure):
     return
 
   def __str2__(self):
+    import logger
+
     desc = ['  Using GNU make: ' + self.make.make]
     if self.defines.get('USE_COVERAGE'):
       desc.extend([
         '  Code coverage: yes',
         '  Using code coverage executable: {}'.format(self.getMakeMacro('PETSC_COVERAGE_EXEC'))
       ])
+    banner_ends   = 'xxx'
+    banner_middle = '=' * (logger.get_global_divider_length() - 2 * len(banner_ends))
+    banner_line   = banner_middle.join((banner_ends, banner_ends))
+    desc.append(banner_line)
     if not self.installed:
-      desc.append('xxx=========================================================================xxx')
       desc.append(' Configure stage complete. Now build PETSc libraries with:')
       desc.append('   %s PETSC_DIR=%s PETSC_ARCH=%s all' % (self.make.make_user, self.petscdir.dir, self.arch.arch))
-      desc.append('xxx=========================================================================xxx')
     else:
-      desc.append('xxx=========================================================================xxx')
       desc.append(' Installation complete. You do not need to run make to compile or install the software')
-      desc.append('xxx=========================================================================xxx')
-    desc.append('')
+    desc.extend([banner_line, ''])
     return '\n'.join(desc)
 
   def setupHelp(self, help):
@@ -42,7 +44,7 @@ class Configure(config.base.Configure):
     help.addArgument('PETSc','-with-single-library=<bool>',                  nargs.ArgBool(None, 1,'Put all PETSc code into the single -lpetsc library'))
     help.addArgument('PETSc','-with-fortran-bindings=<bool>',                nargs.ArgBool(None, 1,'Build PETSc fortran bindings in the library and corresponding module files'))
     help.addArgument('PETSc', '-with-ios=<bool>',                            nargs.ArgBool(None, 0, 'Build an iPhone/iPad version of PETSc library'))
-    help.addArgument('PETSc', '-with-display=<x11display>',                  nargs.Arg(None, '', 'Specifiy DISPLAY env variable for use with matlab test)'))
+    help.addArgument('PETSc', '-with-display=<x11display>',                  nargs.Arg(None, '', 'Specifiy DISPLAY environmental variable for use with MATLAB test)'))
     help.addArgument('PETSc', '-with-package-scripts=<pyscripts>',           nargs.ArgFileList(None,None,'Specify configure package scripts for user provided packages'))
     help.addArgument('PETSc', '-with-coverage=<bool>',                       nargs.ArgFuzzyBool(None, value=0, help='Enable or disable code-coverage collection'))
     help.addArgument('PETSc', '-with-coverage-exec=<executable>',            nargs.ArgExecutable(None, value='default-auto', mustExist=0, help='Name of executable to use for post-processing coverage data, e.g. \'gcov\' or \'llvm-cov\'. Pass \'auto\' to let configure infer from compiler'))
@@ -141,7 +143,7 @@ class Configure(config.base.Configure):
                                             'sys/socket','sys/wait','netinet/in','netdb','direct','time','Ws2tcpip','sys/types',
                                             'WindowsX','float','ieeefp','stdint','inttypes','immintrin'])
     functions = ['access','_access','clock','drand48','getcwd','_getcwd','getdomainname','gethostname',
-                 'getwd','posix_memalign','popen','PXFGETARG','rand','getpagesize',
+                 'posix_memalign','popen','PXFGETARG','rand','getpagesize',
                  'readlink','realpath','usleep','sleep','_sleep',
                  'uname','snprintf','_snprintf','lseek','_lseek','time','fork','stricmp',
                  'strcasecmp','bzero','dlopen','dlsym','dlclose','dlerror',
@@ -326,7 +328,7 @@ prepend-path PATH "%s"
       if self.framework.argDB['with-fortran-bindings']:
         if not self.fortran.fortranIsF90:
           raise RuntimeError('Error! Fortran compiler "'+self.compilers.FC+'" does not support F90! PETSc fortran bindings require a F90 compiler')
-        self.addDefine('HAVE_FORTRAN','1')
+        self.addDefine('USE_FORTRAN_BINDINGS','1')
       self.setCompilers.pushLanguage('FC')
       # need FPPFLAGS in config/setCompilers
       self.addMakeMacro('FPP_FLAGS',self.setCompilers.FPPFLAGS)
@@ -644,13 +646,13 @@ prepend-path PATH "%s"
 
       If none of the combos work, defines MACRO_BASE(why) as empty
       '''
-      full_macro_name = macro_base + '(why)'
+      full_macro_name = macro_base + '(string_literal_why)'
       for prefix in ('__attribute__', '__attribute','__declspec'):
         if prefix == '__declspec':
           # declspec does not have an extra set of brackets around the arguments
-          attr_bodies = ('deprecated(why)', 'deprecated')
+          attr_bodies = ('deprecated(string_literal_why)', 'deprecated')
         else:
-          attr_bodies = ('(deprecated(why))', '(deprecated)')
+          attr_bodies = ('(deprecated(string_literal_why))', '(deprecated)')
 
         for attr_body in attr_bodies:
           attr_def = '{}({})'.format(prefix, attr_body)
@@ -673,16 +675,18 @@ prepend-path PATH "%s"
     lang = self.languages.clanguage
     with self.Language(lang):
       is_intel = self.setCompilers.isIntel(self.getCompiler(lang=lang), self.log)
-      checkDeprecated('DEPRECATED_FUNCTION', '{} int myfunc(void) {{ return 1; }}', is_intel)
-      checkDeprecated('DEPRECATED_TYPEDEF', 'typedef int my_int {};', is_intel)
-      checkDeprecated('DEPRECATED_ENUM', 'enum E {{ oldval {}, newval }};', is_intel)
+      checkDeprecated('DEPRECATED_FUNCTION_BASE', '{} int myfunc(void) {{ return 1; }}', is_intel)
+      checkDeprecated('DEPRECATED_TYPEDEF_BASE', 'typedef int my_int {};', is_intel)
+      checkDeprecated('DEPRECATED_ENUM_BASE', 'enum E {{ oldval {}, newval }};', is_intel)
+      checkDeprecated('DEPRECATED_OBJECT_BASE', '{} int x;', is_intel)
       # I was unable to make a CPP macro that takes the old and new values as separate
       # arguments and builds the message needed by _Pragma hence the deprecation message is
       # handled as it is
       if self.checkCompile('#define TEST _Pragma("GCC warning \"Testing _Pragma\"") value'):
-        self.addDefine('DEPRECATED_MACRO(why)', '_Pragma(why)')
+        self.addDefine('DEPRECATED_MACRO_BASE_(why)', '_Pragma(#why)')
+        self.addDefine('DEPRECATED_MACRO_BASE(string_literal_why)', self.substPrefix + '_DEPRECATED_MACRO_BASE_(GCC warning string_literal_why)')
       else:
-        self.addDefine('DEPRECATED_MACRO(why)', ' ')
+        self.addDefine('DEPRECATED_MACRO_BASE(why)', ' ')
 
   def configureAlign(self):
     '''Check if __attribute(aligned) is supported'''
@@ -841,7 +845,6 @@ char assert_aligned[(sizeof(struct mystruct)==16)*2-1];
     if not self.libraries.add('Gdi32.lib','CreateCompatibleDC',prototype='#include <windows.h>',call='CreateCompatibleDC(0);'):
       self.libraries.add('gdi32','CreateCompatibleDC',prototype='#include <windows.h>',call='CreateCompatibleDC(0);')
 
-    self.types.check('int32_t', 'int')
     if not self.checkCompile('#include <sys/types.h>\n','uid_t u;\n(void)u'):
       self.addTypedef('int', 'uid_t')
       self.addTypedef('int', 'gid_t')
