@@ -26,7 +26,7 @@ configure_options = [
   '--download-mumps=1',
   '--download-hdf5',
   '--with-zlib=1',
-  '--download-elemental=1',
+  # '--download-elemental=1', # disabled since its maxCxxVersion is c++14, but Kokkos-4.0's minCxxVersion is c++17
   #'--download-sundials2=1',
   #'--download-hypre=1',
   #'--download-suitesparse=1',
@@ -37,6 +37,7 @@ configure_options = [
   '--download-kokkos=1',
   '--download-kokkos-kernels=1',
   '--with-ssl=1',
+  '--with-strict-petscerrorcode=0',
   ]
 
 if __name__ == '__main__':
