@@ -31,6 +31,7 @@ if __name__ == '__main__':
     '--download-parmetis',
     '--download-triangle',
     '--download-p4est',
+    '--download-mfem',
     '--with-cuda',
     '--with-shared-libraries',
     '--download-magma',
@@ -43,6 +44,9 @@ if __name__ == '__main__':
     '--download-hypre',
     '--download-raja',
     '--download-amgx',
+    '--download-zfp',
+    '--download-butterflypack',
+    '--download-strumpack',
     '--with-strict-petscerrorcode',
   ]
 
