@@ -10,16 +10,19 @@ if __name__ == '__main__':
   import configure
   configure_options = [
     '--package-prefix-hash='+petsc_hash_pkgs,
-    'CC=icc',
-    'CXX=icpc',
-    'FC=ifort',
-    'COPTFLAGS=-g -O',
+    'CC=icx',
+    'CXX=icpx',
+    'FC=ifx',
+    # Intel compilers enable GCC/clangs equivalent of -ffast-math *by default*. This is
+    # bananas, so we make sure they use the same model as everyone else
+    'COPTFLAGS=-g -O -fp-model=precise -Wno-deprecated-non-prototype -Wno-implicit-int -Wno-implicit-function-declaration -Wno-incompatible-pointer-types -Wincompatible-function-pointer-types -Wno-unused-result',
     'FOPTFLAGS=-g -O',
-    'CXXOPTFLAGS=-g -O',
+    'CXXOPTFLAGS=-g -O -fp-model=precise',
     '--with-scalar-type=complex',
     '--with-blaslapack-dir='+os.environ['MKLROOT'],
     '--with-mkl_pardiso-dir='+os.environ['MKLROOT'],
     '--download-mpich',
+    '--download-bamg',
     '--download-chaco',
     '--download-codipack',
     '--download-ctetgen',
@@ -41,5 +44,6 @@ if __name__ == '__main__':
     '--download-tetgen',
     '--download-triangle',
     '--download-zlib',
+    '--with-strict-petscerrorcode',
   ]
   configure.petsc_configure(configure_options)
