@@ -5,12 +5,14 @@ petsc_hash_pkgs=os.path.join(os.getenv('HOME'),'petsc-hash-pkgs')
 
 configure_options = [
   '--package-prefix-hash='+petsc_hash_pkgs,
+  '--with-cudac=0',
   '--with-debugging=0',
   #'--with-cc=mpicc.openmpi',
   #'--with-cxx=mpicxx.openmpi',
   #'--with-fc=mpif90.openmpi',
   #'--with-mpiexec=mpiexec.openmpi',
   '--download-openmpi=1',
+  '--download-mpe=1',
   '--download-fblaslapack=1',
   '--download-hypre=1',
   '--download-cmake=1',
@@ -50,6 +52,8 @@ configure_options = [
   '--download-htool=1',
   '--download-egads=1',
   '--download-opencascade=1',
+  '--with-strict-petscerrorcode',
+  '--with-coverage',
   ]
 
 if __name__ == '__main__':
