@@ -1,6 +1,4 @@
-
-#ifndef PETSCF90_H
-#define PETSCF90_H
+#pragma once
 #include <petsc/private/fortranimpl.h>
 
 /* PGI compilers pass in f90 pointers as 2 arguments */
@@ -30,22 +28,18 @@ typedef struct {
 PETSC_EXTERN PetscErrorCode F90Array1dCreate(void *, MPI_Datatype, PetscInt, PetscInt, F90Array1d *PETSC_F90_2PTR_PROTO_NOVAR);
 PETSC_EXTERN PetscErrorCode F90Array1dAccess(F90Array1d *, MPI_Datatype, void **PETSC_F90_2PTR_PROTO_NOVAR);
 PETSC_EXTERN PetscErrorCode F90Array1dDestroy(F90Array1d *, MPI_Datatype PETSC_F90_2PTR_PROTO_NOVAR);
-PETSC_EXTERN PetscErrorCode F90Array1dGetNextRecord(F90Array1d *, void **PETSC_F90_2PTR_PROTO_NOVAR);
 
 PETSC_EXTERN PetscErrorCode F90Array2dCreate(void *, MPI_Datatype, PetscInt, PetscInt, PetscInt, PetscInt, F90Array2d *PETSC_F90_2PTR_PROTO_NOVAR);
 PETSC_EXTERN PetscErrorCode F90Array2dAccess(F90Array2d *, MPI_Datatype, void **PETSC_F90_2PTR_PROTO_NOVAR);
 PETSC_EXTERN PetscErrorCode F90Array2dDestroy(F90Array2d *, MPI_Datatype PETSC_F90_2PTR_PROTO_NOVAR);
-PETSC_EXTERN PetscErrorCode F90Array2dGetNextRecord(F90Array2d *, void **PETSC_F90_2PTR_PROTO_NOVAR);
 
 PETSC_EXTERN PetscErrorCode F90Array3dCreate(void *, MPI_Datatype, PetscInt, PetscInt, PetscInt, PetscInt, PetscInt, PetscInt, F90Array3d *PETSC_F90_2PTR_PROTO_NOVAR);
 PETSC_EXTERN PetscErrorCode F90Array3dAccess(F90Array3d *, MPI_Datatype, void **PETSC_F90_2PTR_PROTO_NOVAR);
 PETSC_EXTERN PetscErrorCode F90Array3dDestroy(F90Array3d *, MPI_Datatype PETSC_F90_2PTR_PROTO_NOVAR);
-PETSC_EXTERN PetscErrorCode F90Array3dGetNextRecord(F90Array3d *, void **PETSC_F90_2PTR_PROTO_NOVAR);
 
 PETSC_EXTERN PetscErrorCode F90Array4dCreate(void *, MPI_Datatype, PetscInt, PetscInt, PetscInt, PetscInt, PetscInt, PetscInt, PetscInt, PetscInt, F90Array4d *PETSC_F90_2PTR_PROTO_NOVAR);
 PETSC_EXTERN PetscErrorCode F90Array4dAccess(F90Array4d *, MPI_Datatype, void **PETSC_F90_2PTR_PROTO_NOVAR);
 PETSC_EXTERN PetscErrorCode F90Array4dDestroy(F90Array4d *, MPI_Datatype PETSC_F90_2PTR_PROTO_NOVAR);
-PETSC_EXTERN PetscErrorCode F90Array4dGetNextRecord(F90Array4d *, void **PETSC_F90_2PTR_PROTO_NOVAR);
 
 /*
   F90Array1dCreate - Given a C pointer to a one dimensional
@@ -61,5 +55,3 @@ PETSC_EXTERN PetscErrorCode F90Array4dGetNextRecord(F90Array4d *, void **PETSC_F
   Output Parameter:
 .   ptr - Fortran 90 pointer
 */
-
-#endif
