@@ -1,20 +1,13 @@
-/*
-    Index sets for scatter-gather type operations in vectors
-and matrices.
+#pragma once
 
-*/
-
-#ifndef _IS_H
-#define _IS_H
+/* Index sets for scatter-gather type operations in vectors and matrices. */
 
 #include <petscis.h>
 #include <petsc/private/petscimpl.h>
 
-PETSC_EXTERN PetscBool      ISRegisterAllCalled;
-PETSC_EXTERN PetscBool      ISLocalToGlobalMappingRegisterAllCalled;
-PETSC_EXTERN PetscErrorCode ISRegisterAll(void);
+PETSC_INTERN PetscBool ISRegisterAllCalled;
+PETSC_INTERN PetscBool ISLocalToGlobalMappingRegisterAllCalled;
 
-/* events */
 PETSC_EXTERN PetscLogEvent IS_View;
 PETSC_EXTERN PetscLogEvent IS_Load;
 
@@ -63,9 +56,8 @@ struct _p_IS {
   ISInfoBool  info[2][IS_INFO_MAX];           /* local / global properties */
 };
 
-PETSC_EXTERN PetscErrorCode ISView_Binary(IS, PetscViewer);
-PETSC_EXTERN PetscErrorCode ISLoad_Binary(IS, PetscViewer);
-PETSC_EXTERN PetscErrorCode ISLoad_Default(IS, PetscViewer);
+PETSC_INTERN PetscErrorCode ISView_Binary(IS, PetscViewer);
+PETSC_INTERN PetscErrorCode ISLoad_Default(IS, PetscViewer);
 
 struct _ISLocalToGlobalMappingOps {
   PetscErrorCode (*globaltolocalmappingsetup)(ISLocalToGlobalMapping);
@@ -103,5 +95,3 @@ struct _n_ISColoring {
   ISColoringType   ctype;
   PetscBool        allocated;
 };
-
-#endif
