@@ -1,5 +1,4 @@
-#ifndef SFIMPL_H
-#define SFIMPL_H
+#pragma once
 
 #include <petscvec.h>
 #include <petscsf.h>
@@ -102,7 +101,7 @@ struct _p_PetscSF {
   PetscInt       leafstart[2];     /* ... leafstart[0] and leafstart[1] respectively */
   PetscSFPackOpt leafpackopt[2];   /* Optimization plans to (un)pack leaves connected to remote roots, based on index patterns in rmine[]. NULL for no optimization */
   PetscSFPackOpt leafpackopt_d[2]; /* Copy of leafpackopt_d[] on device if needed */
-  PetscBool      leafdups[2];      /* Indices in rmine[] for self(0)/remote(1) communication have dups respectively? TRUE implies theads working on them in parallel may have data race. */
+  PetscBool      leafdups[2];      /* Indices in rmine[] for self(0)/remote(1) communication have dups respectively? TRUE implies threads working on them in parallel may have data race. */
 
   PetscInt       nleafreqs;            /* Number of MPI requests for leaves */
   PetscInt      *rremote;              /* Concatenated array holding remote indices referenced for each remote rank */
@@ -216,5 +215,3 @@ PETSC_EXTERN PetscErrorCode PetscSFFree_Kokkos(PetscMemType, void *);
   #define PetscSFMalloc(sf, mtype, sz, ptr) PetscMalloc(sz, ptr)
   #define PetscSFFree(sf, mtype, ptr)       PetscFree(ptr)
 #endif
-
-#endif
