@@ -1,5 +1,4 @@
-#ifndef PETSCDEVICETYPES_H
-#define PETSCDEVICETYPES_H
+#pragma once
 
 #include <petscsys.h> /*I <petscdevicetypes.h> I*/
 
@@ -18,15 +17,14 @@
 
   Level: intermediate
 
-  Notes:
+  Note:
   `PETSC_MEMTYPE_KOKKOS` depends on the Kokkos backend configuration
 
   Developer Notes:
   This enum uses a function (`PetscMemTypeToString()`) to convert to string representation so
   cannot be used in `PetscOptionsEnum()`.
 
-  Developer Note:
-  Encoding of the bitmask in binary: xxxxyyyz
+  Encoding of the bitmask in binary\: xxxxyyyz
 .vb
  z = 0                - Host memory
  z = 1                - Device memory
@@ -101,8 +99,8 @@ PETSC_NODISCARD static inline PETSC_CONSTEXPR_14 const char *PetscMemTypeToStrin
   static_assert(PETSC_MEMTYPE_CUDA == PETSC_MEMTYPE_DEVICE, "");
 #endif
 #define PETSC_CASE_NAME(v) \
-case v: \
-  return PetscStringize(v)
+  case v: \
+    return PetscStringize(v)
 
   switch (mtype) {
     PETSC_CASE_NAME(PETSC_MEMTYPE_HOST);
@@ -117,7 +115,7 @@ case v: \
 #undef PETSC_CASE_NAME
 }
 
-#define PETSC_OFFLOAD_VECKOKKOS_DEPRECATED PETSC_OFFLOAD_VECKOKKOS PETSC_DEPRECATED_ENUM("Use PETSC_OFFLOAD_KOKKOS (since version 3.17.0)")
+#define PETSC_OFFLOAD_VECKOKKOS_DEPRECATED PETSC_OFFLOAD_VECKOKKOS PETSC_DEPRECATED_ENUM(3, 17, 0, "PETSC_OFFLOAD_KOKKOS", )
 
 /*E
   PetscOffloadMask - indicates which memory (CPU, GPU, or none) contains valid data
@@ -131,7 +129,7 @@ case v: \
 
   Level: developer
 
-  Developer Notes:
+  Developer Note:
   This enum uses a function (`PetscOffloadMaskToString()`) to convert to string representation so
   cannot be used in `PetscOptionsEnum()`.
 
@@ -181,8 +179,8 @@ static_assert(!PetscOffloadBoth(PETSC_OFFLOAD_KOKKOS), "");
 PETSC_NODISCARD static inline PETSC_CONSTEXPR_14 const char *PetscOffloadMaskToString(PetscOffloadMask mask)
 {
 #define PETSC_CASE_RETURN(v) \
-case v: \
-  return PetscStringize(v)
+  case v: \
+    return PetscStringize(v)
 
   switch (mask) {
     PETSC_CASE_RETURN(PETSC_OFFLOAD_UNALLOCATED);
@@ -222,7 +220,7 @@ PETSC_NODISCARD static inline PETSC_CONSTEXPR_14 PetscMemType PetscOffloadMaskTo
 
   Level: beginner
 
-  Notes:
+  Note:
   `PETSC_DEVICE_INIT_NONE` implies that any initialization of `PetscDevice` is disallowed and
   doing so results in an error. Useful to ensure that no accelerator is used in a program.
 
@@ -248,7 +246,7 @@ PETSC_EXTERN const char *const PetscDeviceInitTypes[];
 
   Level: beginner
 
-  Notes:
+  Note:
   One can also use the `PETSC_DEVICE_DEFAULT()` routine to get the current default `PetscDeviceType`.
 
 .seealso: `PetscDevice`, `PetscDeviceInitType`, `PetscDeviceCreate()`, `PETSC_DEVICE_DEFAULT()`
@@ -284,7 +282,7 @@ PETSC_EXTERN const char *const PetscDeviceAttributes[];
 
   Level: beginner
 
-  Notes:
+  Note:
   This object is used to house configuration and state of a device, but does not offer any
   ability to interact with or drive device computation. This functionality is facilitated
   instead by the `PetscDeviceContext` object.
@@ -300,7 +298,7 @@ typedef struct _n_PetscDevice *PetscDevice;
   with the default `NULL` stream, which is usually blocking.
 
   Values:
-+ `PETSC_STREAM_GLOBAL_BLOCKING`    - Alias for `NULL` stream. Any stream of this type will block the host for all other streams to finish work before starting its operations.
++ `PETSC_STREAM_GLOBAL_BLOCKING`    - Alias for `NULL` stream. Block the host for all other streams to finish work before starting its operations.
 . `PETSC_STREAM_DEFAULT_BLOCKING`   - Stream will act independent of other streams, but will still be blocked by actions on the `NULL` stream.
 . `PETSC_STREAM_GLOBAL_NONBLOCKING` - Stream is truly asynchronous, and is blocked by nothing, not even the `NULL` stream.
 - `PETSC_STREAM_MAX`                - Always 1 greater than the largest `PetscStreamType`, do not use
@@ -423,7 +421,7 @@ PETSC_NODISCARD static inline PETSC_CONSTEXPR_14 PetscDeviceCopyMode PetscMemTyp
 + `PetscMemoryAccessRead(mode)` - `true` if `mode` is any kind of read, `false` otherwise
 - `PetscMemoryAccessWrite(mode)` - `true` if `mode` is any kind of write, `false` otherwise
 
-  Developer Notes:
+  Developer Note:
   This enum uses a function (`PetscMemoryAccessModeToString()`) to convert values to string
   representation, so cannot be used in `PetscOptionsEnum()`.
 
@@ -458,8 +456,8 @@ static_assert((PETSC_MEMORY_ACCESS_READ | PETSC_MEMORY_ACCESS_WRITE) == PETSC_ME
 PETSC_NODISCARD static inline PETSC_CONSTEXPR_14 const char *PetscMemoryAccessModeToString(PetscMemoryAccessMode mode)
 {
 #define PETSC_CASE_RETURN(v) \
-case v: \
-  return PetscStringize(v)
+  case v: \
+    return PetscStringize(v)
 
   switch (mode) {
     PETSC_CASE_RETURN(PETSC_MEMORY_ACCESS_READ);
@@ -472,5 +470,3 @@ case v: \
 }
 
 #undef PETSC_SHOULD_SILENCE_GCC_TAUTOLOGICAL_COMPARE_WARNING
-
-#endif /* PETSCDEVICETYPES_H */
