@@ -1,8 +1,7 @@
 /*
   Common tools for constructing discretizations
 */
-#ifndef PETSCDT_H
-#define PETSCDT_H
+#pragma once
 
 #include <petscsys.h>
 #include <petscdmtypes.h>
@@ -26,7 +25,7 @@ typedef struct _p_PetscQuadrature *PetscQuadrature;
 
   Values:
 +  `PETSCGAUSSLOBATTOLEGENDRE_VIA_LINEAR_ALGEBRA` - compute the nodes via linear algebra
--  `PETSCGAUSSLOBATTOLEGENDRE_VIA_NEWTON` - compute the nodes by solving a nonlinear equation with Newton's method
+-  `PETSCGAUSSLOBATTOLEGENDRE_VIA_NEWTON`         - compute the nodes by solving a nonlinear equation with Newton's method
 
   Level: intermediate
 
@@ -41,11 +40,11 @@ typedef enum {
   PetscDTNodeType - A description of strategies for generating nodes (both
   quadrature nodes and nodes for Lagrange polynomials)
 
-   Values:
-+  `PETSCDTNODES_DEFAULT` - Nodes chosen by PETSc
-.  `PETSCDTNODES_GAUSSJACOBI` - Nodes at either Gauss-Jacobi or Gauss-Lobatto-Jacobi quadrature points
-.  `PETSCDTNODES_EQUISPACED` - Nodes equispaced either including the endpoints or excluding them
--  `PETSCDTNODES_TANHSINH` - Nodes at Tanh-Sinh quadrature points
+  Values:
++ `PETSCDTNODES_DEFAULT`     - Nodes chosen by PETSc
+. `PETSCDTNODES_GAUSSJACOBI` - Nodes at either Gauss-Jacobi or Gauss-Lobatto-Jacobi quadrature points
+. `PETSCDTNODES_EQUISPACED`  - Nodes equispaced either including the endpoints or excluding them
+- `PETSCDTNODES_TANHSINH`    - Nodes at Tanh-Sinh quadrature points
 
   Level: intermediate
 
@@ -71,19 +70,19 @@ PETSC_EXTERN const char *const *const PetscDTNodeTypes;
   Values:
 +  `PETSCDTSIMPLEXQUAD_DEFAULT` - Quadrature rule chosen by PETSc
 .  `PETSCDTSIMPLEXQUAD_CONIC`   - Quadrature rules constructed as
-                                conically-warped tensor products of 1D
-                                Gauss-Jacobi quadrature rules.  These are
-                                explicitly computable in any dimension for any
-                                degree, and the tensor-product structure can be
-                                exploited by sum-factorization methods, but
-                                they are not efficient in terms of nodes per
-                                polynomial degree.
+                                  conically-warped tensor products of 1D
+                                  Gauss-Jacobi quadrature rules.  These are
+                                  explicitly computable in any dimension for any
+                                  degree, and the tensor-product structure can be
+                                  exploited by sum-factorization methods, but
+                                  they are not efficient in terms of nodes per
+                                  polynomial degree.
 -  `PETSCDTSIMPLEXQUAD_MINSYM`  - Quadrature rules that are fully symmetric
-                                (symmetries of the simplex preserve the nodes
-                                and weights) with minimal (or near minimal)
-                                number of nodes.  In dimensions higher than 1
-                                these are not simple to compute, so lookup
-                                tables are used.
+                                  (symmetries of the simplex preserve the nodes
+                                  and weights) with minimal (or near minimal)
+                                  number of nodes.  In dimensions higher than 1
+                                  these are not simple to compute, so lookup
+                                  tables are used.
 
   Level: intermediate
 
@@ -148,6 +147,16 @@ PETSC_EXTERN PetscErrorCode PetscGaussLobattoLegendreElementAdvectionDestroy(Pet
 PETSC_EXTERN PetscErrorCode PetscGaussLobattoLegendreElementMassCreate(PetscInt, PetscReal *, PetscReal *, PetscReal ***);
 PETSC_EXTERN PetscErrorCode PetscGaussLobattoLegendreElementMassDestroy(PetscInt, PetscReal *, PetscReal *, PetscReal ***);
 
+/*MC
+  PETSC_FORM_DEGREE_UNDEFINED - Indicates that a field does not have
+  a well-defined form degree in exterior calculus.
+
+  Level: advanced
+
+.seealso: `PetscDTAltV`, `PetscDualSpaceGetFormDegree()`
+M*/
+#define PETSC_FORM_DEGREE_UNDEFINED PETSC_INT_MIN
+
 PETSC_EXTERN PetscErrorCode PetscDTAltVApply(PetscInt, PetscInt, const PetscReal *, const PetscReal *, PetscReal *);
 PETSC_EXTERN PetscErrorCode PetscDTAltVWedge(PetscInt, PetscInt, PetscInt, const PetscReal *, const PetscReal *, PetscReal *);
 PETSC_EXTERN PetscErrorCode PetscDTAltVWedgeMatrix(PetscInt, PetscInt, PetscInt, const PetscReal *, PetscReal *);
@@ -208,7 +217,7 @@ static inline PetscErrorCode PetscDTFactorial(PetscInt n, PetscReal *factorial)
    Level: beginner
 
    Note:
-   This is limited to n such that n! can be represented by `PetscInt`, which is 12 if `PetscInt` is a signed 32-bit integer and 20 if `PetscInt` is a signed 64-bit integer.
+   This is limited to `n` such that n! can be represented by `PetscInt`, which is 12 if `PetscInt` is a signed 32-bit integer and 20 if `PetscInt` is a signed 64-bit integer.
 
 .seealso: `PetscDTFactorial()`, `PetscDTBinomialInt()`, `PetscDTBinomial()`
 M*/
@@ -232,14 +241,14 @@ static inline PetscErrorCode PetscDTFactorialInt(PetscInt n, PetscInt *factorial
 }
 
 /*MC
-   PetscDTBinomial - Approximate the binomial coefficient "n choose k"
+   PetscDTBinomial - Approximate the binomial coefficient `n` choose `k`
 
    Input Parameters:
 +  n - a non-negative integer
--  k - an integer between 0 and n, inclusive
+-  k - an integer between 0 and `n`, inclusive
 
    Output Parameter:
-.  binomial - approximation of the binomial coefficient n choose k
+.  binomial - approximation of the binomial coefficient `n` choose `k`
 
    Level: beginner
 
@@ -270,14 +279,14 @@ static inline PetscErrorCode PetscDTBinomial(PetscInt n, PetscInt k, PetscReal *
 }
 
 /*MC
-   PetscDTBinomialInt - Compute the binomial coefficient "n choose k"
+   PetscDTBinomialInt - Compute the binomial coefficient `n` choose `k`
 
    Input Parameters:
 +  n - a non-negative integer
--  k - an integer between 0 and n, inclusive
+-  k - an integer between 0 and `n`, inclusive
 
    Output Parameter:
-.  binomial - the binomial coefficient n choose k
+.  binomial - the binomial coefficient `n` choose `k`
 
    Level: beginner
 
@@ -324,7 +333,7 @@ static inline PetscErrorCode PetscDTBinomialInt(PetscInt n, PetscInt k, PetscInt
 -  k - an integer in [0, n!)
 
    Output Parameters:
-+  perm - the permuted list of the integers [0, ..., n-1]
++  perm  - the permuted list of the integers [0, ..., n-1]
 -  isOdd - if not `NULL`, returns whether the permutation used an even or odd number of swaps.
 
    Level: intermediate
@@ -372,11 +381,11 @@ static inline PetscErrorCode PetscDTEnumPerm(PetscInt n, PetscInt k, PetscInt *p
    PetscDTPermIndex - Encode a permutation of n into an integer in [0, n!).  This inverts `PetscDTEnumPerm()`.
 
    Input Parameters:
-+  n - a non-negative integer (see note about limits below)
++  n    - a non-negative integer (see note about limits below)
 -  perm - the permuted list of the integers [0, ..., n-1]
 
    Output Parameters:
-+  k - an integer in [0, n!)
++  k     - an integer in [0, n!)
 -  isOdd - if not `NULL`, returns whether the permutation used an even or odd number of swaps.
 
    Level: beginner
@@ -463,8 +472,8 @@ static inline PetscErrorCode PetscDTEnumSubset(PetscInt n, PetscInt k, PetscInt
    This is the inverse of `PetscDTEnumSubset`.
 
    Input Parameters:
-+  n - a non-negative integer (see note about limits below)
-.  k - an integer in [0, n]
++  n      - a non-negative integer (see note about limits below)
+.  k      - an integer in [0, n]
 -  subset - an ordered subset of the integers [0, ..., n - 1]
 
    Output Parameter:
@@ -509,7 +518,7 @@ static inline PetscErrorCode PetscDTSubsetIndex(PetscInt n, PetscInt k, const Pe
 -  j - an index in [0, n choose k)
 
    Output Parameters:
-+  perm - the jth subset of size k of the integers [0, ..., n - 1], followed by its complementary set.
++  perm  - the jth subset of size k of the integers [0, ..., n - 1], followed by its complementary set.
 -  isOdd - if not `NULL`, return whether perm is an even or odd permutation.
 
    Level: beginner
@@ -598,5 +607,3 @@ PETSC_EXTERN PetscErrorCode PetscProbCreateFromOptions(PetscInt, const char[], c
 #include <petscvec.h>
 
 PETSC_EXTERN PetscErrorCode PetscProbComputeKSStatistic(Vec, PetscProbFunc, PetscReal *);
-
-#endif
