@@ -1,31 +1,31 @@
 /*
    Defines the interface functions for the Krylov subspace accelerators.
 */
-#ifndef PETSCKSP_H
-#define PETSCKSP_H
+#pragma once
 
 #include <petscpc.h>
 
 /* SUBMANSEC = KSP */
 
 PETSC_EXTERN PetscErrorCode KSPInitializePackage(void);
+PETSC_EXTERN PetscErrorCode KSPFinalizePackage(void);
 
 /*S
-     KSP - Abstract PETSc object that manages all Krylov methods. This is the object that manages the
+   KSP - Abstract PETSc object that manages all Krylov methods. This is the object that manages the
          linear solves in PETSc (even those such as direct factorization-based solvers that do no use Krylov accelerators).
 
    Level: beginner
 
    Note:
-    When a direct solver is used, but no Krylov solver is used, the `KSP` object is still used but with a
-    `KSPType` of `KSPPREONLY` (or equivalently `KSPNONE`), meaning that only application of the preconditioner is used as the linear solver.
+   When a direct solver is used, but no Krylov solver is used, the `KSP` object is still used but with a
+   `KSPType` of `KSPPREONLY` (or equivalently `KSPNONE`), meaning that only application of the preconditioner is used as the linear solver.
 
 .seealso: [](doc_linsolve), [](ch_ksp), `KSPCreate()`, `KSPSetType()`, `KSPType`, `SNES`, `TS`, `PC`, `KSP`, `KSPDestroy()`, `KSPCG`, `KSPGMRES`
 S*/
 typedef struct _p_KSP *KSP;
 
 /*J
-    KSPType - String with the name of a PETSc Krylov method.
+   KSPType - String with the name of a PETSc Krylov method.
 
    Level: beginner
 
@@ -45,9 +45,9 @@ typedef const char *KSPType;
 #define KSPNASH       "nash"
 #define KSPSTCG       "stcg"
 #define KSPGLTR       "gltr"
-#define KSPCGNASH     PETSC_DEPRECATED_MACRO("GCC warning \"KSPCGNASH macro is deprecated use KSPNASH (since version 3.11)\"") "nash"
-#define KSPCGSTCG     PETSC_DEPRECATED_MACRO("GCC warning \"KSPCGSTCG macro is deprecated use KSPSTCG (since version 3.11)\"") "stcg"
-#define KSPCGGLTR     PETSC_DEPRECATED_MACRO("GCC warning \"KSPCGGLTR macro is deprecated use KSPSGLTR (since version 3.11)\"") "gltr"
+#define KSPCGNASH     PETSC_DEPRECATED_MACRO(3, 11, 0, "KSPNASH", ) "nash"
+#define KSPCGSTCG     PETSC_DEPRECATED_MACRO(3, 11, 0, "KSPSTCG", ) "stcg"
+#define KSPCGGLTR     PETSC_DEPRECATED_MACRO(3, 11, 0, "KSPSGLTR", ) "gltr"
 #define KSPFCG        "fcg"
 #define KSPPIPEFCG    "pipefcg"
 #define KSPGMRES      "gmres"
@@ -100,12 +100,12 @@ PETSC_EXTERN PetscErrorCode KSPSetUseExplicitTranspose(KSP, PetscBool);
 PETSC_EXTERN PetscErrorCode KSPMatSolve(KSP, Mat, Mat);
 PETSC_EXTERN PetscErrorCode KSPMatSolveTranspose(KSP, Mat, Mat);
 PETSC_EXTERN PetscErrorCode KSPSetMatSolveBatchSize(KSP, PetscInt);
-PETSC_DEPRECATED_FUNCTION("Use KSPSetMatSolveBatchSize() (since version 3.15)") static inline PetscErrorCode KSPSetMatSolveBlockSize(KSP ksp, PetscInt n)
+PETSC_DEPRECATED_FUNCTION(3, 15, 0, "KSPSetMatSolveBatchSize()", ) static inline PetscErrorCode KSPSetMatSolveBlockSize(KSP ksp, PetscInt n)
 {
   return KSPSetMatSolveBatchSize(ksp, n);
 }
 PETSC_EXTERN PetscErrorCode KSPGetMatSolveBatchSize(KSP, PetscInt *);
-PETSC_DEPRECATED_FUNCTION("Use KSPGetMatSolveBatchSize() (since version 3.15)") static inline PetscErrorCode KSPGetMatSolveBlockSize(KSP ksp, PetscInt *n)
+PETSC_DEPRECATED_FUNCTION(3, 15, 0, "KSPGetMatSolveBatchSize()", ) static inline PetscErrorCode KSPGetMatSolveBlockSize(KSP ksp, PetscInt *n)
 {
   return KSPGetMatSolveBatchSize(ksp, n);
 }
@@ -129,6 +129,8 @@ PETSC_EXTERN PetscErrorCode KSPSetPCSide(KSP, PCSide);
 PETSC_EXTERN PetscErrorCode KSPGetPCSide(KSP, PCSide *);
 PETSC_EXTERN PetscErrorCode KSPSetTolerances(KSP, PetscReal, PetscReal, PetscReal, PetscInt);
 PETSC_EXTERN PetscErrorCode KSPGetTolerances(KSP, PetscReal *, PetscReal *, PetscReal *, PetscInt *);
+PETSC_EXTERN PetscErrorCode KSPSetMinimumIterations(KSP, PetscInt);
+PETSC_EXTERN PetscErrorCode KSPGetMinimumIterations(KSP, PetscInt *);
 PETSC_EXTERN PetscErrorCode KSPSetInitialGuessNonzero(KSP, PetscBool);
 PETSC_EXTERN PetscErrorCode KSPGetInitialGuessNonzero(KSP, PetscBool *);
 PETSC_EXTERN PetscErrorCode KSPSetErrorIfNotConverged(KSP, PetscBool);
@@ -144,7 +146,7 @@ PETSC_EXTERN PetscErrorCode KSPGetResidualNorm(KSP, PetscReal *);
 PETSC_EXTERN PetscErrorCode KSPGetIterationNumber(KSP, PetscInt *);
 PETSC_EXTERN PetscErrorCode KSPGetTotalIterations(KSP, PetscInt *);
 PETSC_EXTERN PetscErrorCode KSPCreateVecs(KSP, PetscInt, Vec **, PetscInt, Vec **);
-PETSC_DEPRECATED_FUNCTION("Use KSPCreateVecs() (since version 3.6)") static inline PetscErrorCode KSPGetVecs(KSP ksp, PetscInt n, Vec **x, PetscInt m, Vec **y)
+PETSC_DEPRECATED_FUNCTION(3, 6, 0, "KSPCreateVecs()", ) static inline PetscErrorCode KSPGetVecs(KSP ksp, PetscInt n, Vec **x, PetscInt m, Vec **y)
 {
   return KSPCreateVecs(ksp, n, x, m, y);
 }
@@ -154,6 +156,8 @@ PETSC_EXTERN PetscErrorCode KSPSetPostSolve(KSP, PetscErrorCode (*)(KSP, Vec, Ve
 
 PETSC_EXTERN PetscErrorCode KSPSetPC(KSP, PC);
 PETSC_EXTERN PetscErrorCode KSPGetPC(KSP, PC *);
+PETSC_EXTERN PetscErrorCode KSPSetNestLevel(KSP, PetscInt);
+PETSC_EXTERN PetscErrorCode KSPGetNestLevel(KSP, PetscInt *);
 
 PETSC_EXTERN PetscErrorCode KSPMonitor(KSP, PetscInt, PetscReal);
 PETSC_EXTERN PetscErrorCode KSPMonitorSet(KSP, PetscErrorCode (*)(KSP, PetscInt, PetscReal, void *), void *, PetscErrorCode (*)(void **));
@@ -194,7 +198,7 @@ PETSC_EXTERN PetscErrorCode KSPBuildSolution(KSP, Vec, Vec *);
 PETSC_EXTERN PetscErrorCode KSPBuildResidual(KSP, Vec, Vec, Vec *);
 
 /*E
-  KSPChebyshevKind - Which kind of Chebyshev polynomial to use
+  KSPChebyshevKind - Which kind of Chebyshev polynomial to use with `KSPCHEBYSHEV`
 
   Values:
 + `KSP_CHEBYSHEV_FIRST`      - "classic" first-kind Chebyshev polynomial
@@ -230,7 +234,7 @@ PETSC_EXTERN PetscErrorCode KSPComputeRitz(KSP, PetscBool, PetscBool, PetscInt *
 
   Values:
 + `KSP_FCD_TRUNC_TYPE_STANDARD` - uses all (up to mmax) stored directions
-- `KSP_FCD_TRUNC_TYPE_NOTAY` - uses the last max(1,mod(i,mmax)) stored directions at iteration i=0,1..
+- `KSP_FCD_TRUNC_TYPE_NOTAY`    - uses the last max(1,mod(i,mmax)) stored directions at iteration i=0,1..
 
    Level: intermediate
 
@@ -264,6 +268,7 @@ PETSC_EXTERN PetscErrorCode KSPPIPEGCRSetTruncationType(KSP, KSPFCDTruncationTyp
 PETSC_EXTERN PetscErrorCode KSPPIPEGCRGetTruncationType(KSP, KSPFCDTruncationType *);
 PETSC_EXTERN PetscErrorCode KSPPIPEGCRSetUnrollW(KSP, PetscBool);
 PETSC_EXTERN PetscErrorCode KSPPIPEGCRGetUnrollW(KSP, PetscBool *);
+PETSC_EXTERN PetscErrorCode KSPPIPEGCRSetModifyPC(KSP, PetscErrorCode (*)(KSP, PetscInt, PetscReal, void *), void *, PetscErrorCode (*)(void *));
 
 PETSC_EXTERN PetscErrorCode KSPGMRESSetRestart(KSP, PetscInt);
 PETSC_EXTERN PetscErrorCode KSPGMRESGetRestart(KSP, PetscInt *);
@@ -297,16 +302,16 @@ PETSC_EXTERN PetscErrorCode KSPFETIDPSetPressureOperator(KSP, Mat);
 PETSC_EXTERN PetscErrorCode KSPHPDDMSetDeflationMat(KSP, Mat);
 PETSC_EXTERN PetscErrorCode KSPHPDDMGetDeflationMat(KSP, Mat *);
 #if PetscDefined(HAVE_HPDDM)
-PETSC_DEPRECATED_FUNCTION("Use KSPHPDDMSetDeflationMat() (since version 3.18)") static inline PetscErrorCode KSPHPDDMSetDeflationSpace(KSP ksp, Mat U)
+PETSC_DEPRECATED_FUNCTION(3, 18, 0, "KSPHPDDMSetDeflationMat()", ) static inline PetscErrorCode KSPHPDDMSetDeflationSpace(KSP ksp, Mat U)
 {
   return KSPHPDDMSetDeflationMat(ksp, U);
 }
-PETSC_DEPRECATED_FUNCTION("Use KSPHPDDMGetDeflationMat() (since version 3.18)") static inline PetscErrorCode KSPHPDDMGetDeflationSpace(KSP ksp, Mat *U)
+PETSC_DEPRECATED_FUNCTION(3, 18, 0, "KSPHPDDMGetDeflationMat()", ) static inline PetscErrorCode KSPHPDDMGetDeflationSpace(KSP ksp, Mat *U)
 {
   return KSPHPDDMGetDeflationMat(ksp, U);
 }
 #endif
-PETSC_DEPRECATED_FUNCTION("Use KSPMatSolve() (since version 3.14)") static inline PetscErrorCode KSPHPDDMMatSolve(KSP ksp, Mat B, Mat X)
+PETSC_DEPRECATED_FUNCTION(3, 14, 0, "KSPMatSolve()", ) static inline PetscErrorCode KSPHPDDMMatSolve(KSP ksp, Mat B, Mat X)
 {
   return KSPMatSolve(ksp, B, X);
 }
@@ -315,13 +320,13 @@ PETSC_DEPRECATED_FUNCTION("Use KSPMatSolve() (since version 3.14)") static inlin
 
     Values:
 +   `KSP_HPDDM_TYPE_GMRES` (default) - Generalized Minimal Residual method
-.   `KSP_HPDDM_TYPE_BGMRES` - block GMRES
-.   `KSP_HPDDM_TYPE_CG` - Conjugate Gradient
-.   `KSP_HPDDM_TYPE_BCG` - block CG
-.   `KSP_HPDDM_TYPE_GCRODR` - Generalized Conjugate Residual method with inner Orthogonalization and Deflated Restarting
-.   `KSP_HPDDM_TYPE_BGCRODR` - block GCRODR
-.   `KSP_HPDDM_TYPE_BFBCG` - breakdown-free BCG
--   `KSP_HPDDM_TYPE_PREONLY` - apply the preconditioner only
+.   `KSP_HPDDM_TYPE_BGMRES`          - block GMRES
+.   `KSP_HPDDM_TYPE_CG`              - Conjugate Gradient
+.   `KSP_HPDDM_TYPE_BCG`             - block CG
+.   `KSP_HPDDM_TYPE_GCRODR`          - Generalized Conjugate Residual method with inner Orthogonalization and Deflated Restarting
+.   `KSP_HPDDM_TYPE_BGCRODR`         - block GCRODR
+.   `KSP_HPDDM_TYPE_BFBCG`           - breakdown-free BCG
+-   `KSP_HPDDM_TYPE_PREONLY`         - apply the preconditioner only
 
     Level: intermediate
 
@@ -343,9 +348,9 @@ PETSC_EXTERN const char *const KSPHPDDMTypes[];
     KSPHPDDMPrecision - Precision of Krylov bases used by `KSPHPDDM`
 
     Values:
-+   `KSP_HPDDM_PRECISION_HALF` - default when PETSc is configured `--with-precision=__fp16`
-.   `KSP_HPDDM_PRECISION_SINGLE` - default when PETSc is configured `--with-precision=single`
-.   `KSP_HPDDM_PRECISION_DOUBLE` - default when PETSc is configured `--with-precision=double`
++   `KSP_HPDDM_PRECISION_HALF`      - default when PETSc is configured `--with-precision=__fp16`
+.   `KSP_HPDDM_PRECISION_SINGLE`    - default when PETSc is configured `--with-precision=single`
+.   `KSP_HPDDM_PRECISION_DOUBLE`    - default when PETSc is configured `--with-precision=double`
 -   `KSP_HPDDM_PRECISION_QUADRUPLE` - default when PETSc is configured `--with-precision=__float128`
 
     Level: intermediate
@@ -362,16 +367,16 @@ PETSC_EXTERN PetscErrorCode KSPHPDDMSetType(KSP, KSPHPDDMType);
 PETSC_EXTERN PetscErrorCode KSPHPDDMGetType(KSP, KSPHPDDMType *);
 
 /*E
-    KSPGMRESCGSRefinementType - How the classical (unmodified) Gram-Schmidt is performed in the GMRES solvers
+   KSPGMRESCGSRefinementType - How the classical (unmodified) Gram-Schmidt is performed in the GMRES solvers
 
-    Values:
-+   `KSP_GMRES_CGS_REFINE_NEVER` - one step of classical Gram-Schmidt
-.   `KSP_GMRES_CGS_REFINE_IFNEEDED` - a second step is performed if the first step does not satisfy some criteria
--   `KSP_GMRES_CGS_REFINE_ALWAYS` - always perform two steps
+   Values:
++  `KSP_GMRES_CGS_REFINE_NEVER`    - one step of classical Gram-Schmidt
+.  `KSP_GMRES_CGS_REFINE_IFNEEDED` - a second step is performed if the first step does not satisfy some criteria
+-  `KSP_GMRES_CGS_REFINE_ALWAYS`   - always perform two steps
 
    Level: advanced
 
-.seealso: [](ch_ksp), `KSP`, `KSPGMRESClassicalGramSchmidtOrthogonalization()`, `KSPGMRESSetOrthogonalization()`,
+.seealso: [](ch_ksp), `KSP`, `KSPGMRES`, `KSPGMRESClassicalGramSchmidtOrthogonalization()`, `KSPGMRESSetOrthogonalization()`,
           `KSPGMRESGetOrthogonalization()`,
           `KSPGMRESSetCGSRefinementType()`, `KSPGMRESGetCGSRefinementType()`, `KSPGMRESModifiedGramSchmidtOrthogonalization()`
 E*/
@@ -383,14 +388,14 @@ typedef enum {
 PETSC_EXTERN const char *const KSPGMRESCGSRefinementTypes[];
 
 /*MC
-    KSP_GMRES_CGS_REFINE_NEVER - Do the classical (unmodified) Gram-Schmidt process
+   KSP_GMRES_CGS_REFINE_NEVER - Do the classical (unmodified) Gram-Schmidt process
 
    Level: advanced
 
    Note:
    Possibly unstable, but the fastest to compute
 
-.seealso: [](ch_ksp), `KSPGMRESCGSRefinementType`, `KSPGMRESClassicalGramSchmidtOrthogonalization()`, `KSPGMRESSetOrthogonalization()`,
+.seealso: [](ch_ksp), `KSPGMRES`, `KSPGMRESCGSRefinementType`, `KSPGMRESClassicalGramSchmidtOrthogonalization()`, `KSPGMRESSetOrthogonalization()`,
           `KSP`, `KSPGMRESGetOrthogonalization()`,
           `KSPGMRESSetCGSRefinementType()`, `KSPGMRESGetCGSRefinementType()`, `KSP_GMRES_CGS_REFINE_IFNEEDED`, `KSP_GMRES_CGS_REFINE_ALWAYS`,
           `KSPGMRESModifiedGramSchmidtOrthogonalization()`
@@ -407,14 +412,14 @@ M*/
    This is slower than `KSP_GMRES_CGS_REFINE_NEVER` because it requires an extra norm computation to
    estimate the orthogonality but is more stable.
 
-.seealso: [](ch_ksp), `KSPGMRESCGSRefinementType`, `KSPGMRESClassicalGramSchmidtOrthogonalization()`, `KSPGMRESSetOrthogonalization()`,
+.seealso: [](ch_ksp), `KSPGMRES`, `KSPGMRESCGSRefinementType`, `KSPGMRESClassicalGramSchmidtOrthogonalization()`, `KSPGMRESSetOrthogonalization()`,
           `KSP`, `KSPGMRESGetOrthogonalization()`,
           `KSPGMRESSetCGSRefinementType()`, `KSPGMRESGetCGSRefinementType()`, `KSP_GMRES_CGS_REFINE_NEVER`, `KSP_GMRES_CGS_REFINE_ALWAYS`,
           `KSPGMRESModifiedGramSchmidtOrthogonalization()`
 M*/
 
 /*MC
-    KSP_GMRES_CGS_REFINE_ALWAYS - Do two steps of the classical (unmodified) Gram-Schmidt process.
+   KSP_GMRES_CGS_REFINE_ALWAYS - Do two steps of the classical (unmodified) Gram-Schmidt process.
 
    Level: advanced
 
@@ -424,7 +429,7 @@ M*/
 
    You should only use this if you absolutely know that the iterative refinement is needed.
 
-.seealso: [](ch_ksp), `KSPGMRESCGSRefinementType`, `KSPGMRESClassicalGramSchmidtOrthogonalization()`, `KSPGMRESSetOrthogonalization()`,
+.seealso: [](ch_ksp), `KSPGMRES`, `KSPGMRESCGSRefinementType`, `KSPGMRESClassicalGramSchmidtOrthogonalization()`, `KSPGMRESSetOrthogonalization()`,
           `KSP`, `KSPGMRESGetOrthogonalization()`,
           `KSPGMRESSetCGSRefinementType()`, `KSPGMRESGetCGSRefinementType()`, `KSP_GMRES_CGS_REFINE_IFNEEDED`, `KSP_GMRES_CGS_REFINE_ALWAYS`,
           `KSPGMRESModifiedGramSchmidtOrthogonalization()`
@@ -448,7 +453,6 @@ PETSC_EXTERN PetscErrorCode KSPBCGSLSetUsePseudoinverse(KSP, PetscBool);
 
 PETSC_EXTERN PetscErrorCode KSPSetFromOptions(KSP);
 PETSC_EXTERN PetscErrorCode KSPResetFromOptions(KSP);
-PETSC_EXTERN PetscErrorCode KSPAddOptionsChecker(PetscErrorCode (*)(KSP));
 
 PETSC_EXTERN PetscErrorCode KSPMonitorSetFromOptions(KSP, const char[], const char[], void *);
 PETSC_EXTERN PetscErrorCode KSPMonitorLGCreate(MPI_Comm, const char[], const char[], const char[], PetscInt, const char *[], int, int, int, int, PetscDrawLG *);
@@ -473,15 +477,15 @@ PETSC_EXTERN PetscErrorCode KSPMonitorSolutionDrawLG(KSP, PetscInt, PetscReal, P
 PETSC_EXTERN PetscErrorCode KSPMonitorSolutionDrawLGCreate(PetscViewer, PetscViewerFormat, void *, PetscViewerAndFormat **);
 PETSC_EXTERN PetscErrorCode KSPMonitorSingularValue(KSP, PetscInt, PetscReal, PetscViewerAndFormat *);
 PETSC_EXTERN PetscErrorCode KSPMonitorSingularValueCreate(PetscViewer, PetscViewerFormat, void *, PetscViewerAndFormat **);
-PETSC_DEPRECATED_FUNCTION("Use KSPMonitorResidual() (since version 3.15)") static inline PetscErrorCode KSPMonitorDefault(KSP ksp, PetscInt n, PetscReal rnorm, PetscViewerAndFormat *vf)
+PETSC_DEPRECATED_FUNCTION(3, 15, 0, "KSPMonitorResidual()", ) static inline PetscErrorCode KSPMonitorDefault(KSP ksp, PetscInt n, PetscReal rnorm, PetscViewerAndFormat *vf)
 {
   return KSPMonitorResidual(ksp, n, rnorm, vf);
 }
-PETSC_DEPRECATED_FUNCTION("Use KSPMonitorTrueResidual() (since version 3.15)") static inline PetscErrorCode KSPMonitorTrueResidualNorm(KSP ksp, PetscInt n, PetscReal rnorm, PetscViewerAndFormat *vf)
+PETSC_DEPRECATED_FUNCTION(3, 15, 0, "KSPMonitorTrueResidual()", ) static inline PetscErrorCode KSPMonitorTrueResidualNorm(KSP ksp, PetscInt n, PetscReal rnorm, PetscViewerAndFormat *vf)
 {
   return KSPMonitorTrueResidual(ksp, n, rnorm, vf);
 }
-PETSC_DEPRECATED_FUNCTION("Use KSPMonitorTrueResidualMax() (since version 3.15)") static inline PetscErrorCode KSPMonitorTrueResidualMaxNorm(KSP ksp, PetscInt n, PetscReal rnorm, PetscViewerAndFormat *vf)
+PETSC_DEPRECATED_FUNCTION(3, 15, 0, "KSPMonitorTrueResidualMax()", ) static inline PetscErrorCode KSPMonitorTrueResidualMaxNorm(KSP ksp, PetscInt n, PetscReal rnorm, PetscViewerAndFormat *vf)
 {
   return KSPMonitorTrueResidualMax(ksp, n, rnorm, vf);
 }
@@ -519,11 +523,11 @@ PETSC_EXTERN PetscErrorCode KSPConvergedReasonViewFromOptions(KSP);
 PETSC_EXTERN PetscErrorCode KSPConvergedReasonViewCancel(KSP);
 PETSC_EXTERN PetscErrorCode KSPConvergedRateView(KSP, PetscViewer);
 
-PETSC_DEPRECATED_FUNCTION("Use KSPConvergedReasonView() (since version 3.14)") static inline PetscErrorCode KSPReasonView(KSP ksp, PetscViewer v)
+PETSC_DEPRECATED_FUNCTION(3, 14, 0, "KSPConvergedReasonView()", ) static inline PetscErrorCode KSPReasonView(KSP ksp, PetscViewer v)
 {
   return KSPConvergedReasonView(ksp, v);
 }
-PETSC_DEPRECATED_FUNCTION("Use KSPConvergedReasonViewFromOptions() (since version 3.14)") static inline PetscErrorCode KSPReasonViewFromOptions(KSP ksp)
+PETSC_DEPRECATED_FUNCTION(3, 14, 0, "KSPConvergedReasonViewFromOptions()", ) static inline PetscErrorCode KSPReasonViewFromOptions(KSP ksp)
 {
   return KSPConvergedReasonViewFromOptions(ksp);
 }
@@ -543,15 +547,15 @@ PETSC_EXTERN PetscErrorCode PCRedistributeGetKSP(PC, KSP *);
 PETSC_EXTERN PetscErrorCode PCTelescopeGetKSP(PC, KSP *);
 
 /*E
-    KSPNormType - Norm calculated by the `KSP` and passed in the Krylov convergence
+   KSPNormType - Norm calculated by the `KSP` and passed in the Krylov convergence
        test routines.
 
-    Values:
-+   `KSP_NORM_DEFAULT` - use the default for the current `KSPType`
-.   `KSP_NORM_NONE` - use no norm calculation
-.   `KSP_NORM_PRECONDITIONED` - use the preconditioned residual norm
-.   `KSP_NORM_UNPRECONDITIONED` - use the unpreconditioned residual norm
--   `KSP_NORM_NATURAL` - use the natural norm (the norm induced by the linear operator)
+   Values:
++  `KSP_NORM_DEFAULT`          - use the default for the current `KSPType`
+.  `KSP_NORM_NONE`             - use no norm calculation
+.  `KSP_NORM_PRECONDITIONED`   - use the preconditioned residual norm
+.  `KSP_NORM_UNPRECONDITIONED` - use the unpreconditioned residual norm
+-  `KSP_NORM_NATURAL`          - use the natural norm (the norm induced by the linear operator)
 
    Level: advanced
 
@@ -559,11 +563,8 @@ PETSC_EXTERN PetscErrorCode PCTelescopeGetKSP(PC, KSP *);
    Each solver only supports a subset of these and some may support different ones
    depending on whether left or right preconditioning is used, see `KSPSetPCSide()`
 
-   Developer Note:
-   This must match the values in petsc/finclude/petscksp.h
-
 .seealso: [](ch_ksp), `KSP`, `PCSide`, `KSPSolve()`, `KSPGetConvergedReason()`, `KSPSetNormType()`,
-          `KSPSetConvergenceTest()`, `KSPSetPCSide()`
+          `KSPSetConvergenceTest()`, `KSPSetPCSide()`, `KSP_NORM_DEFAULT`, `KSP_NORM_NONE`, `KSP_NORM_PRECONDITIONED`, `KSP_NORM_UNPRECONDITIONED`, `KSP_NORM_NATURAL`
 E*/
 typedef enum {
   KSP_NORM_DEFAULT          = -1,
@@ -576,21 +577,21 @@ typedef enum {
 PETSC_EXTERN const char *const *const KSPNormTypes;
 
 /*MC
-    KSP_NORM_NONE - Do not compute a norm during the Krylov process. This will
-          possibly save some computation but means the convergence test cannot
-          be based on a norm of a residual etc.
+   KSP_NORM_NONE - Do not compute a norm during the Krylov process. This will
+   possibly save some computation but means the convergence test cannot
+   be based on a norm of a residual etc.
 
    Level: advanced
 
-    Note:
-    Some Krylov methods need to compute a residual norm (such as `KPSGMRES`) and then this option is ignored
+   Note:
+   Some Krylov methods need to compute a residual norm (such as `KPSGMRES`) and then this option is ignored
 
 .seealso: [](ch_ksp), `KSPNormType`, `KSP`, `KSPSetNormType()`, `KSP_NORM_PRECONDITIONED`, `KSP_NORM_UNPRECONDITIONED`, `KSP_NORM_NATURAL`
 M*/
 
 /*MC
-    KSP_NORM_PRECONDITIONED - Compute the norm of the preconditioned residual B*(b - A*x), if left preconditioning, and pass that to the
-       convergence test routine.
+   KSP_NORM_PRECONDITIONED - Compute the norm of the preconditioned residual B*(b - A*x), if left preconditioning, and pass that to the
+   convergence test routine.
 
    Level: advanced
 
@@ -598,8 +599,8 @@ M*/
 M*/
 
 /*MC
-    KSP_NORM_UNPRECONDITIONED - Compute the norm of the true residual (b - A*x) and pass that to the
-       convergence test routine.
+   KSP_NORM_UNPRECONDITIONED - Compute the norm of the true residual (b - A*x) and pass that to the
+   convergence test routine.
 
    Level: advanced
 
@@ -607,8 +608,8 @@ M*/
 M*/
 
 /*MC
-    KSP_NORM_NATURAL - Compute the 'natural norm' of residual sqrt((b - A*x)*B*(b - A*x)) and pass that to the
-       convergence test routine. This is only supported by  `KSPCG`, `KSPCR`, `KSPCGNE`, `KSPCGS`, `KSPFCG`, `KSPPIPEFCG`, `KSPPIPEGCR`
+   KSP_NORM_NATURAL - Compute the 'natural norm' of residual sqrt((b - A*x)*B*(b - A*x)) and pass that to the
+   convergence test routine. This is only supported by  `KSPCG`, `KSPCR`, `KSPCGNE`, `KSPCGS`, `KSPFCG`, `KSPPIPEFCG`, `KSPPIPEGCR`
 
    Level: advanced
 
@@ -621,41 +622,39 @@ PETSC_EXTERN PetscErrorCode KSPSetSupportedNorm(KSP ksp, KSPNormType, PCSide, Pe
 PETSC_EXTERN PetscErrorCode KSPSetCheckNormIteration(KSP, PetscInt);
 PETSC_EXTERN PetscErrorCode KSPSetLagNorm(KSP, PetscBool);
 
-#define KSP_CONVERGED_CG_NEG_CURVE_DEPRECATED   KSP_CONVERGED_CG_NEG_CURVE PETSC_DEPRECATED_ENUM("Use KSP_CONVERGED_NEG_CURVE (since version 3.19)")
-#define KSP_CONVERGED_CG_CONSTRAINED_DEPRECATED KSP_CONVERGED_CG_CONSTRAINED PETSC_DEPRECATED_ENUM("Use KSP_CONVERGED_STEP_LENGTH (since version 3.19)")
-#define KSP_DIVERGED_PCSETUP_FAILED_DEPRECATED  KSP_DIVERGED_PCSETUP_FAILED PETSC_DEPRECATED_ENUM("Use KSP_DIVERGED_PC_FAILED (since version 3.11)")
+#define KSP_CONVERGED_CG_NEG_CURVE_DEPRECATED   KSP_CONVERGED_CG_NEG_CURVE PETSC_DEPRECATED_ENUM(3, 19, 0, "KSP_CONVERGED_NEG_CURVE", )
+#define KSP_CONVERGED_CG_CONSTRAINED_DEPRECATED KSP_CONVERGED_CG_CONSTRAINED PETSC_DEPRECATED_ENUM(3, 19, 0, "KSP_CONVERGED_STEP_LENGTH", )
+#define KSP_DIVERGED_PCSETUP_FAILED_DEPRECATED  KSP_DIVERGED_PCSETUP_FAILED PETSC_DEPRECATED_ENUM(3, 11, 0, "KSP_DIVERGED_PC_FAILED", )
 /*E
-    KSPConvergedReason - reason a Krylov method was determined to have converged or diverged
+   KSPConvergedReason - reason a Krylov method was determined to have converged or diverged
 
    Values:
-+  `KSP_CONVERGED_RTOL_NORMAL` - requested decrease in the residual for the normal equations
-.  `KSP_CONVERGED_ATOL_NORMAL` - requested absolute value in the residual for the normal equations
-.  `KSP_CONVERGED_RTOL` - requested decrease in the residual
-.  `KSP_CONVERGED_ATOL` - requested absolute value in the residual
-.  `KSP_CONVERGED_ITS` - requested number of iterations
-.  `KSP_CONVERGED_NEG_CURVE` - see note below
-.  `KSP_CONVERGED_STEP_LENGTH` - see note below
-.  `KSP_CONVERGED_HAPPY_BREAKDOWN` - happy breakdown (meaning early convergence of the `KSPType` occurred.
-.  `KSP_DIVERGED_NULL` - breakdown when solving the Hessenberg system within GMRES
-.  `KSP_DIVERGED_ITS` - requested number of iterations
-.  `KSP_DIVERGED_DTOL` - large increase in the residual norm
-.  `KSP_DIVERGED_BREAKDOWN` - breakdown in the Krylov method
-.  `KSP_DIVERGED_BREAKDOWN_BICG` - breakdown in the `KSPBGCS` Krylov method
-.  `KSP_DIVERGED_NONSYMMETRIC` - the operator or preonditioner was not symmetric for a `KSPType` that requires symmetry
-.  `KSP_DIVERGED_INDEFINITE_PC` - the preconditioner was indefinite for a `KSPType` that requires it be definite
-.  `KSP_DIVERGED_NANORINF` - a not a number of infinity was detected in a vector during the computation
-.  `KSP_DIVERGED_INDEFINITE_MAT` - the operator was indefinite for a `KSPType` that requires it be definite
--  `KSP_DIVERGED_PC_FAILED` - the action of the preconditioner failed for some reason
++  `KSP_CONVERGED_RTOL_NORMAL`     - requested decrease in the residual for the normal equations
+.  `KSP_CONVERGED_ATOL_NORMAL`     - requested absolute value in the residual for the normal equations
+.  `KSP_CONVERGED_RTOL`            - requested decrease in the residual
+.  `KSP_CONVERGED_ATOL`            - requested absolute value in the residual
+.  `KSP_CONVERGED_ITS`             - requested number of iterations
+.  `KSP_CONVERGED_NEG_CURVE`       - see note below
+.  `KSP_CONVERGED_STEP_LENGTH`     - see note below
+.  `KSP_CONVERGED_HAPPY_BREAKDOWN` - happy breakdown (meaning early convergence of the `KSPType` occurred).
+.  `KSP_DIVERGED_NULL`             - breakdown when solving the Hessenberg system within GMRES
+.  `KSP_DIVERGED_ITS`              - requested number of iterations
+.  `KSP_DIVERGED_DTOL`             - large increase in the residual norm
+.  `KSP_DIVERGED_BREAKDOWN`        - breakdown in the Krylov method
+.  `KSP_DIVERGED_BREAKDOWN_BICG`   - breakdown in the `KSPBGCS` Krylov method
+.  `KSP_DIVERGED_NONSYMMETRIC`     - the operator or preonditioner was not symmetric for a `KSPType` that requires symmetry
+.  `KSP_DIVERGED_INDEFINITE_PC`    - the preconditioner was indefinite for a `KSPType` that requires it be definite
+.  `KSP_DIVERGED_NANORINF`         - a not a number of infinity was detected in a vector during the computation
+.  `KSP_DIVERGED_INDEFINITE_MAT`   - the operator was indefinite for a `KSPType` that requires it be definite
+-  `KSP_DIVERGED_PC_FAILED`        - the action of the preconditioner failed for some reason
 
    Level: beginner
 
    Note:
-   The values  `KSP_CONVERGED_NEG_CURVE`, and `KSP_CONVERGED_STEP_LENGTH` are returned only by the special `KSPNASH`,
-   `KSPSTCG`, and `KSPGLTR` solvers which are used by the `SNESNEWTONTR` (trust region) solver.
-
-   Developer Notes:
-   This must match the values in petsc/finclude/petscksp.h
+   The values `KSP_CONVERGED_NEG_CURVE`, and `KSP_CONVERGED_STEP_LENGTH` are returned only by `KSPCG`, `KSPMINRES` and by
+   the special `KSPNASH`, `KSPSTCG`, and `KSPGLTR` solvers which are used by the `SNESNEWTONTR` (trust region) solver.
 
+   Developer Note:
    The string versions of these are `KSPConvergedReasons`; if you change
    any of the values here also change them that array of names.
 
@@ -690,10 +689,11 @@ typedef enum { /* converged */
 PETSC_EXTERN const char *const *KSPConvergedReasons;
 
 /*MC
-     KSP_CONVERGED_RTOL - norm(r) <= rtol*norm(b) or rtol*norm(b - A*x_0) if `KSPConvergedDefaultSetUIRNorm()` was called
+   KSP_CONVERGED_RTOL - $||r|| \le rtol*||b||$ or $rtol*||b - A*x_0||$ if `KSPConvergedDefaultSetUIRNorm()` was called
 
    Level: beginner
 
+   Notes:
    See `KSPNormType` and `KSPSetNormType()` for possible norms that may be used. By default
    for left preconditioning it is the 2-norm of the preconditioned residual, and the
    2-norm of the residual for right preconditioning
@@ -704,13 +704,14 @@ PETSC_EXTERN const char *const *KSPConvergedReasons;
 M*/
 
 /*MC
-     KSP_CONVERGED_ATOL - norm(r) <= atol
+   KSP_CONVERGED_ATOL - $||r|| \le atol$
 
    Level: beginner
 
+   Notes:
    See `KSPNormType` and `KSPSetNormType()` for possible norms that may be used. By default
-       for left preconditioning it is the 2-norm of the preconditioned residual, and the
-       2-norm of the residual for right preconditioning
+   for left preconditioning it is the 2-norm of the preconditioned residual, and the
+   2-norm of the residual for right preconditioning
 
    See also `KSP_CONVERGED_RTOL` which may apply before this tolerance.
 
@@ -718,22 +719,21 @@ M*/
 M*/
 
 /*MC
-     KSP_DIVERGED_DTOL - norm(r) >= dtol*norm(b)
+   KSP_DIVERGED_DTOL - $||r|| \ge dtol*||b||$
 
    Level: beginner
 
+   Note:
    See `KSPNormType` and `KSPSetNormType()` for possible norms that may be used. By default
-       for left preconditioning it is the 2-norm of the preconditioned residual, and the
-       2-norm of the residual for right preconditioning
-
-   Level: beginner
+   for left preconditioning it is the 2-norm of the preconditioned residual, and the
+   2-norm of the residual for right preconditioning
 
 .seealso: [](ch_ksp), `KSPNormType`, `KSP_CONVERGED_ATOL`, `KSP_DIVERGED_RTOL`, `KSPSolve()`, `KSPGetConvergedReason()`, `KSPConvergedReason`, `KSPSetTolerances()`
 M*/
 
 /*MC
-     KSP_DIVERGED_ITS - Ran out of iterations before any convergence criteria was
-      reached
+   KSP_DIVERGED_ITS - Ran out of iterations before any convergence criteria was
+   reached
 
    Level: beginner
 
@@ -741,9 +741,9 @@ M*/
 M*/
 
 /*MC
-     KSP_CONVERGED_ITS - Used by the `KSPPREONLY` solver after the single iteration of
-           the preconditioner is applied. Also used when the `KSPConvergedSkip()` convergence
-           test routine is set in KSP.
+   KSP_CONVERGED_ITS - Used by the `KSPPREONLY` solver after the single iteration of
+   the preconditioner is applied. Also used when the `KSPConvergedSkip()` convergence
+   test routine is set in `KSP`.
 
    Level: beginner
 
@@ -751,10 +751,10 @@ M*/
 M*/
 
 /*MC
-     KSP_DIVERGED_BREAKDOWN - A breakdown in the Krylov method was detected so the
-          method could not continue to enlarge the Krylov space. Could be due to a singular matrix or
-          preconditioner. In `KSPHPDDM`, this is also returned when some search directions within a block
-          are colinear.
+   KSP_DIVERGED_BREAKDOWN - A breakdown in the Krylov method was detected so the
+   method could not continue to enlarge the Krylov space. Could be due to a singular matrix or
+   preconditioner. In `KSPHPDDM`, this is also returned when some search directions within a block
+   are colinear.
 
    Level: beginner
 
@@ -762,8 +762,8 @@ M*/
 M*/
 
 /*MC
-     KSP_DIVERGED_BREAKDOWN_BICG - A breakdown in the `KSPBICG` method was detected so the
-          method could not continue to enlarge the Krylov space.
+   KSP_DIVERGED_BREAKDOWN_BICG - A breakdown in the `KSPBICG` method was detected so the
+   method could not continue to enlarge the Krylov space.
 
    Level: beginner
 
@@ -771,8 +771,8 @@ M*/
 M*/
 
 /*MC
-     KSP_DIVERGED_NONSYMMETRIC - It appears the operator or preconditioner is not
-        symmetric and this Krylov method (`KSPCG`, `KSPMINRES`, `KSPCR`) requires symmetry
+   KSP_DIVERGED_NONSYMMETRIC - It appears the operator or preconditioner is not
+   symmetric and this Krylov method (`KSPCG`, `KSPMINRES`, `KSPCR`) requires symmetry
 
    Level: beginner
 
@@ -780,35 +780,35 @@ M*/
 M*/
 
 /*MC
-     KSP_DIVERGED_INDEFINITE_PC - It appears the preconditioner is indefinite (has both
-        positive and negative eigenvalues) and this Krylov method (`KSPCG`) requires it to
-        be positive definite
+   KSP_DIVERGED_INDEFINITE_PC - It appears the preconditioner is indefinite (has both
+   positive and negative eigenvalues) and this Krylov method (`KSPCG`) requires it to
+   be positive definite
 
    Level: beginner
 
-     Note:
-    This can happen with the `PCICC` preconditioner, use the options database option `-pc_factor_shift_positive_definite` to force
-  the `PCICC` preconditioner to generate a positive definite preconditioner
+   Note:
+   This can happen with the `PCICC` preconditioner, use the options database option `-pc_factor_shift_positive_definite` to force
+   the `PCICC` preconditioner to generate a positive definite preconditioner
 
 .seealso: [](ch_ksp), `KSPSolve()`, `KSPGetConvergedReason()`, `KSPConvergedReason`, `KSPSetTolerances()`
 M*/
 
 /*MC
-     KSP_DIVERGED_PC_FAILED - It was not possible to build or use the requested preconditioner. This is usually due to a
-     zero pivot in a factorization. It can also result from a failure in a subpreconditioner inside a nested preconditioner
-     such as `PCFIELDSPLIT`.
+   KSP_DIVERGED_PC_FAILED - It was not possible to build or use the requested preconditioner. This is usually due to a
+   zero pivot in a factorization. It can also result from a failure in a subpreconditioner inside a nested preconditioner
+   such as `PCFIELDSPLIT`.
 
    Level: beginner
 
-    Note:
-    Run with `-ksp_error_if_not_converged` to stop the program when the error is detected and print an error message with details.
+   Note:
+   Run with `-ksp_error_if_not_converged` to stop the program when the error is detected and print an error message with details.
 
 .seealso: [](ch_ksp), `KSPSolve()`, `KSPGetConvergedReason()`, `KSPConvergedReason`, `KSPSetTolerances()`
 M*/
 
 /*MC
-     KSP_CONVERGED_ITERATING - This flag is returned if `KSPGetConvergedReason()` is called
-        while `KSPSolve()` is still running.
+   KSP_CONVERGED_ITERATING - This flag is returned if `KSPGetConvergedReason()` is called
+   while `KSPSolve()` is still running.
 
    Level: beginner
 
@@ -833,39 +833,39 @@ PETSC_EXTERN PetscErrorCode KSPComputeConvergenceRate(KSP, PetscReal *, PetscRea
 PETSC_EXTERN PetscErrorCode KSPSetConvergedNegativeCurvature(KSP, PetscBool);
 PETSC_EXTERN PetscErrorCode KSPGetConvergedNegativeCurvature(KSP, PetscBool *);
 
-PETSC_DEPRECATED_FUNCTION("Use KSPConvergedDefault() (since version 3.5)") static inline void KSPDefaultConverged(void)
+PETSC_DEPRECATED_FUNCTION(3, 5, 0, "KSPConvergedDefault()", ) static inline void KSPDefaultConverged(void)
 { /* never called */
 }
 #define KSPDefaultConverged (KSPDefaultConverged, KSPConvergedDefault)
-PETSC_DEPRECATED_FUNCTION("Use KSPConvergedDefaultDestroy() (since version 3.5)") static inline void KSPDefaultConvergedDestroy(void)
+PETSC_DEPRECATED_FUNCTION(3, 5, 0, "KSPConvergedDefaultDestroy()", ) static inline void KSPDefaultConvergedDestroy(void)
 { /* never called */
 }
 #define KSPDefaultConvergedDestroy (KSPDefaultConvergedDestroy, KSPConvergedDefaultDestroy)
-PETSC_DEPRECATED_FUNCTION("Use KSPConvergedDefaultCreate() (since version 3.5)") static inline void KSPDefaultConvergedCreate(void)
+PETSC_DEPRECATED_FUNCTION(3, 5, 0, "KSPConvergedDefaultCreate()", ) static inline void KSPDefaultConvergedCreate(void)
 { /* never called */
 }
 #define KSPDefaultConvergedCreate (KSPDefaultConvergedCreate, KSPConvergedDefaultCreate)
-PETSC_DEPRECATED_FUNCTION("Use KSPConvergedDefaultSetUIRNorm() (since version 3.5)") static inline void KSPDefaultConvergedSetUIRNorm(void)
+PETSC_DEPRECATED_FUNCTION(3, 5, 0, "KSPConvergedDefaultSetUIRNorm()", ) static inline void KSPDefaultConvergedSetUIRNorm(void)
 { /* never called */
 }
 #define KSPDefaultConvergedSetUIRNorm (KSPDefaultConvergedSetUIRNorm, KSPConvergedDefaultSetUIRNorm)
-PETSC_DEPRECATED_FUNCTION("Use KSPConvergedDefaultSetUMIRNorm() (since version 3.5)") static inline void KSPDefaultConvergedSetUMIRNorm(void)
+PETSC_DEPRECATED_FUNCTION(3, 5, 0, "KSPConvergedDefaultSetUMIRNorm()", ) static inline void KSPDefaultConvergedSetUMIRNorm(void)
 { /* never called */
 }
 #define KSPDefaultConvergedSetUMIRNorm (KSPDefaultConvergedSetUMIRNorm, KSPConvergedDefaultSetUMIRNorm)
-PETSC_DEPRECATED_FUNCTION("Use KSPConvergedSkip() (since version 3.5)") static inline void KSPSkipConverged(void)
+PETSC_DEPRECATED_FUNCTION(3, 5, 0, "KSPConvergedSkip()", ) static inline void KSPSkipConverged(void)
 { /* never called */
 }
 #define KSPSkipConverged (KSPSkipConverged, KSPConvergedSkip)
 
 PETSC_EXTERN PetscErrorCode KSPComputeOperator(KSP, MatType, Mat *);
-PETSC_DEPRECATED_FUNCTION("Use KSPComputeOperator() (since version 3.12)") static inline PetscErrorCode KSPComputeExplicitOperator(KSP A, Mat *B)
+PETSC_DEPRECATED_FUNCTION(3, 12, 0, "KSPComputeOperator()", ) static inline PetscErrorCode KSPComputeExplicitOperator(KSP A, Mat *B)
 {
   return KSPComputeOperator(A, PETSC_NULLPTR, B);
 }
 
 /*E
-    KSPCGType - Determines what type of `KSPCG` to use
+   KSPCGType - Determines what type of `KSPCG` to use
 
    Values:
  + `KSP_CG_SYMMETRIC` - the matrix is complex symmetric
@@ -891,11 +891,11 @@ PETSC_EXTERN PetscErrorCode KSPCGGetObjFcn(KSP, PetscReal *);
 
 PETSC_EXTERN PetscErrorCode KSPGLTRGetMinEig(KSP, PetscReal *);
 PETSC_EXTERN PetscErrorCode KSPGLTRGetLambda(KSP, PetscReal *);
-PETSC_DEPRECATED_FUNCTION("Use KSPGLTRGetMinEig (since v3.12)") static inline PetscErrorCode KSPCGGLTRGetMinEig(KSP ksp, PetscReal *x)
+PETSC_DEPRECATED_FUNCTION(3, 12, 0, "KSPGLTRGetMinEig()", ) static inline PetscErrorCode KSPCGGLTRGetMinEig(KSP ksp, PetscReal *x)
 {
   return KSPGLTRGetMinEig(ksp, x);
 }
-PETSC_DEPRECATED_FUNCTION("Use KSPGLTRGetLambda (since v3.12)") static inline PetscErrorCode KSPCGGLTRGetLambda(KSP ksp, PetscReal *x)
+PETSC_DEPRECATED_FUNCTION(3, 12, 0, "KSPGLTRGetLambda()", ) static inline PetscErrorCode KSPCGGLTRGetLambda(KSP ksp, PetscReal *x)
 {
   return KSPGLTRGetLambda(ksp, x);
 }
@@ -914,20 +914,20 @@ PETSC_EXTERN PetscErrorCode PCShellSetPreSolve(PC, PetscErrorCode (*)(PC, KSP, V
 PETSC_EXTERN PetscErrorCode PCShellSetPostSolve(PC, PetscErrorCode (*)(PC, KSP, Vec, Vec));
 
 /*S
-     KSPGuess - Abstract PETSc object that manages all initial guess generation methods for Krylov methods.
+   KSPGuess - Abstract PETSc object that manages all initial guess generation methods for Krylov methods.
 
    Level: intermediate
 
-.seealso: [](ch_ksp), `KSPCreate()`, `KSPSetGuessType()`, `KSPGuessType`
+.seealso: [](ch_ksp), `KSPCreate()`, `KSPGuessSetType()`, `KSPGuessType`
 S*/
 typedef struct _p_KSPGuess *KSPGuess;
 
 /*J
-    KSPGuessType - String with the name of a PETSc initial guess approach for Krylov methods.
+   KSPGuessType - String with the name of a PETSc initial guess approach for Krylov methods.
 
    Values:
  + `KSPGUESSFISCHER` - methodology developed by Paul Fischer
- - `KSPGUESSPOD` - methodology based on proper orthogonal decomposition
+ - `KSPGUESSPOD`     - methodology based on proper orthogonal decomposition
 
    Level: intermediate
 
@@ -1040,7 +1040,10 @@ PETSC_EXTERN PetscErrorCode DMKSPGetComputeInitialGuess(DM, PetscErrorCode (**)(
 
 PETSC_EXTERN PetscErrorCode DMGlobalToLocalSolve(DM, Vec, Vec);
 PETSC_EXTERN PetscErrorCode DMProjectField(DM, PetscReal, Vec, void (**)(PetscInt, PetscInt, PetscInt, const PetscInt[], const PetscInt[], const PetscScalar[], const PetscScalar[], const PetscScalar[], const PetscInt[], const PetscInt[], const PetscScalar[], const PetscScalar[], const PetscScalar[], PetscReal, const PetscReal[], PetscInt, const PetscScalar[], PetscScalar[]), InsertMode, Vec);
+PETSC_EXTERN PetscErrorCode DMSwarmProjectFields(DM, PetscInt, const char **, Vec[], ScatterMode mode);
 
 PETSC_EXTERN PetscErrorCode DMAdaptInterpolator(DM, DM, Mat, KSP, Mat, Mat, Mat *, void *);
 PETSC_EXTERN PetscErrorCode DMCheckInterpolator(DM, Mat, Mat, Mat, PetscReal);
-#endif
+
+PETSC_EXTERN PetscErrorCode PCBJKOKKOSSetKSP(PC, KSP);
+PETSC_EXTERN PetscErrorCode PCBJKOKKOSGetKSP(PC, KSP *);
