@@ -1,8 +1,7 @@
 /*
       Preconditioner module.
 */
-#ifndef PETSCPC_H
-#define PETSCPC_H
+#pragma once
 
 #include <petscmat.h>
 #include <petscdmtypes.h>
@@ -11,6 +10,7 @@
 /* SUBMANSEC = PC */
 
 PETSC_EXTERN PetscErrorCode PCInitializePackage(void);
+PETSC_EXTERN PetscErrorCode PCFinalizePackage(void);
 
 /*
     PCList contains the list of preconditioners currently registered
@@ -45,13 +45,17 @@ PETSC_EXTERN PetscErrorCode PCSetType(PC, PCType);
 PETSC_EXTERN PetscErrorCode PCGetType(PC, PCType *);
 PETSC_EXTERN PetscErrorCode PCSetUp(PC);
 
+PETSC_EXTERN PetscErrorCode PCSetKSPNestLevel(PC, PetscInt);
+PETSC_EXTERN PetscErrorCode PCGetKSPNestLevel(PC, PetscInt *);
+
 PETSC_EXTERN PetscErrorCode PCSetFailedReason(PC, PCFailedReason);
 PETSC_EXTERN PetscErrorCode PCGetFailedReason(PC, PCFailedReason *);
-PETSC_DEPRECATED_FUNCTION("Use PCGetFailedReason() (since version 3.11)") static inline PetscErrorCode PCGetSetUpFailedReason(PC pc, PCFailedReason *reason)
+PETSC_DEPRECATED_FUNCTION(3, 11, 0, "PCGetFailedReason()", ) static inline PetscErrorCode PCGetSetUpFailedReason(PC pc, PCFailedReason *reason)
 {
   return PCGetFailedReason(pc, reason);
 }
 PETSC_EXTERN PetscErrorCode PCGetFailedReasonRank(PC, PCFailedReason *);
+PETSC_EXTERN PetscErrorCode PCReduceFailedReason(PC);
 
 PETSC_EXTERN PetscErrorCode PCSetUpOnBlocks(PC);
 PETSC_EXTERN PetscErrorCode PCApply(PC, Vec, Vec);
@@ -96,7 +100,7 @@ PETSC_EXTERN PetscErrorCode PCAppendOptionsPrefix(PC, const char[]);
 PETSC_EXTERN PetscErrorCode PCGetOptionsPrefix(PC, const char *[]);
 
 PETSC_EXTERN PetscErrorCode PCComputeOperator(PC, MatType, Mat *);
-PETSC_DEPRECATED_FUNCTION("Use PCComputeOperator() (since version 3.12)") static inline PetscErrorCode PCComputeExplicitOperator(PC A, Mat *B)
+PETSC_DEPRECATED_FUNCTION(3, 12, 0, "PCComputeOperator()", ) static inline PetscErrorCode PCComputeExplicitOperator(PC A, Mat *B)
 {
   return PCComputeOperator(A, PETSC_NULLPTR, B);
 }
@@ -116,7 +120,7 @@ PETSC_EXTERN PetscErrorCode PCGetDM(PC, DM *);
 PETSC_EXTERN PetscErrorCode PCGetInterpolations(PC, PetscInt *, Mat *[]);
 PETSC_EXTERN PetscErrorCode PCGetCoarseOperators(PC pc, PetscInt *, Mat *[]);
 
-PETSC_EXTERN PetscErrorCode PCSetCoordinates(PC, PetscInt, PetscInt, PetscReal *);
+PETSC_EXTERN PetscErrorCode PCSetCoordinates(PC, PetscInt, PetscInt, PetscReal[]);
 
 PETSC_EXTERN PetscErrorCode PCSetApplicationContext(PC, void *);
 PETSC_EXTERN PetscErrorCode PCGetApplicationContext(PC, void *);
@@ -169,15 +173,15 @@ PETSC_EXTERN PetscErrorCode PCFactorSetShiftAmount(PC, PetscReal);
 PETSC_EXTERN PetscErrorCode PCFactorSetMatSolverType(PC, MatSolverType);
 PETSC_EXTERN PetscErrorCode PCFactorGetMatSolverType(PC, MatSolverType *);
 PETSC_EXTERN PetscErrorCode PCFactorSetUpMatSolverType(PC);
-PETSC_DEPRECATED_FUNCTION("Use PCFactorSetMatSolverType() (since version 3.9)") static inline PetscErrorCode PCFactorSetMatSolverPackage(PC pc, MatSolverType stype)
+PETSC_DEPRECATED_FUNCTION(3, 9, 0, "PCFactorSetMatSolverType()", ) static inline PetscErrorCode PCFactorSetMatSolverPackage(PC pc, MatSolverType stype)
 {
   return PCFactorSetMatSolverType(pc, stype);
 }
-PETSC_DEPRECATED_FUNCTION("Use PCFactorGetMatSolverType() (since version 3.9)") static inline PetscErrorCode PCFactorGetMatSolverPackage(PC pc, MatSolverType *stype)
+PETSC_DEPRECATED_FUNCTION(3, 9, 0, "PCFactorGetMatSolverType()", ) static inline PetscErrorCode PCFactorGetMatSolverPackage(PC pc, MatSolverType *stype)
 {
   return PCFactorGetMatSolverType(pc, stype);
 }
-PETSC_DEPRECATED_FUNCTION("Use PCFactorSetUpMatSolverType() (since version 3.9)") static inline PetscErrorCode PCFactorSetUpMatSolverPackage(PC pc)
+PETSC_DEPRECATED_FUNCTION(3, 9, 0, "PCFactorSetUpMatSolverType()", ) static inline PetscErrorCode PCFactorSetUpMatSolverPackage(PC pc)
 {
   return PCFactorSetUpMatSolverType(pc);
 }
@@ -281,7 +285,7 @@ PETSC_EXTERN PetscErrorCode PCFieldSplitGetDiagUseAmat(PC, PetscBool *);
 PETSC_EXTERN PetscErrorCode PCFieldSplitSetOffDiagUseAmat(PC, PetscBool);
 PETSC_EXTERN PetscErrorCode PCFieldSplitGetOffDiagUseAmat(PC, PetscBool *);
 
-PETSC_EXTERN                PETSC_DEPRECATED_FUNCTION("Use PCFieldSplitSetSchurPre() (since version 3.5)") PetscErrorCode PCFieldSplitSchurPrecondition(PC, PCFieldSplitSchurPreType, Mat);
+PETSC_EXTERN PETSC_DEPRECATED_FUNCTION(3, 5, 0, "PCFieldSplitSetSchurPre()", ) PetscErrorCode PCFieldSplitSchurPrecondition(PC, PCFieldSplitSchurPreType, Mat);
 PETSC_EXTERN PetscErrorCode PCFieldSplitSetSchurPre(PC, PCFieldSplitSchurPreType, Mat);
 PETSC_EXTERN PetscErrorCode PCFieldSplitGetSchurPre(PC, PCFieldSplitSchurPreType *, Mat *);
 PETSC_EXTERN PetscErrorCode PCFieldSplitSetSchurFactType(PC, PCFieldSplitSchurFactType);
@@ -316,9 +320,10 @@ PETSC_EXTERN PetscErrorCode PCGAMGSetProcEqLim(PC, PetscInt);
 
 PETSC_EXTERN PetscErrorCode PCGAMGSetRepartition(PC, PetscBool);
 PETSC_EXTERN PetscErrorCode PCGAMGSetUseSAEstEig(PC, PetscBool);
+PETSC_EXTERN PetscErrorCode PCGAMGSetRecomputeEstEig(PC, PetscBool);
 PETSC_EXTERN PetscErrorCode PCGAMGSetEigenvalues(PC, PetscReal, PetscReal);
 PETSC_EXTERN PetscErrorCode PCGAMGASMSetUseAggs(PC, PetscBool);
-PETSC_EXTERN PetscErrorCode PCGAMGSetUseParallelCoarseGridSolve(PC, PetscBool);
+PETSC_EXTERN PetscErrorCode PCGAMGSetParallelCoarseGridSolve(PC, PetscBool);
 PETSC_EXTERN PetscErrorCode PCGAMGSetCpuPinCoarseGrids(PC, PetscBool);
 PETSC_EXTERN PetscErrorCode PCGAMGSetCoarseGridLayoutType(PC, PCGAMGLayoutType);
 PETSC_EXTERN PetscErrorCode PCGAMGSetThreshold(PC, PetscReal[], PetscInt);
@@ -327,13 +332,15 @@ PETSC_EXTERN PetscErrorCode PCGAMGSetThresholdScale(PC, PetscReal);
 PETSC_EXTERN PetscErrorCode PCGAMGSetCoarseEqLim(PC, PetscInt);
 PETSC_EXTERN PetscErrorCode PCGAMGSetNlevels(PC, PetscInt);
 PETSC_EXTERN PetscErrorCode PCGAMGSetNSmooths(PC, PetscInt);
-PETSC_EXTERN PetscErrorCode PCGAMGSetSquareGraph(PC, PetscInt);
 PETSC_EXTERN PetscErrorCode PCGAMGSetAggressiveLevels(PC, PetscInt);
 PETSC_EXTERN PetscErrorCode PCGAMGSetReuseInterpolation(PC, PetscBool);
 PETSC_EXTERN PetscErrorCode PCGAMGFinalizePackage(void);
 PETSC_EXTERN PetscErrorCode PCGAMGInitializePackage(void);
 PETSC_EXTERN PetscErrorCode PCGAMGRegister(PCGAMGType, PetscErrorCode (*)(PC));
 PETSC_EXTERN PetscErrorCode PCGAMGCreateGraph(PC, Mat, Mat *);
+PETSC_EXTERN PetscErrorCode PCGAMGSetAggressiveSquareGraph(PC, PetscBool);
+PETSC_EXTERN PetscErrorCode PCGAMGMISkSetMinDegreeOrdering(PC, PetscBool);
+PETSC_EXTERN PetscErrorCode PCGAMGMISkSetAggressive(PC, PetscInt);
 
 PETSC_EXTERN PetscErrorCode PCGAMGClassicalSetType(PC, PCGAMGClassicalType);
 PETSC_EXTERN PetscErrorCode PCGAMGClassicalGetType(PC, PCGAMGClassicalType *);
@@ -365,9 +372,15 @@ PETSC_EXTERN PetscErrorCode PCBDDCMatFETIDPGetSolution(Mat, Vec, Vec);
 PETSC_EXTERN PetscErrorCode PCBDDCFinalizePackage(void);
 PETSC_EXTERN PetscErrorCode PCBDDCInitializePackage(void);
 
+PETSC_EXTERN PetscErrorCode PCISInitialize(PC);
+PETSC_EXTERN PetscErrorCode PCISSetUp(PC, PetscBool, PetscBool);
 PETSC_EXTERN PetscErrorCode PCISSetUseStiffnessScaling(PC, PetscBool);
 PETSC_EXTERN PetscErrorCode PCISSetSubdomainScalingFactor(PC, PetscScalar);
 PETSC_EXTERN PetscErrorCode PCISSetSubdomainDiagonalScaling(PC, Vec);
+PETSC_EXTERN PetscErrorCode PCISScatterArrayNToVecB(PC, PetscScalar *, Vec, InsertMode, ScatterMode);
+PETSC_EXTERN PetscErrorCode PCISApplySchur(PC, Vec, Vec, Vec, Vec, Vec);
+PETSC_EXTERN PetscErrorCode PCISApplyInvSchur(PC, Vec, Vec, Vec, Vec);
+PETSC_EXTERN PetscErrorCode PCISReset(PC);
 
 PETSC_EXTERN PetscInt       PetscMGLevelId;
 PETSC_EXTERN PetscErrorCode PCMGSetType(PC, PCMGType);
@@ -379,7 +392,7 @@ PETSC_EXTERN PetscErrorCode PCMGSetDistinctSmoothUp(PC);
 PETSC_EXTERN PetscErrorCode PCMGSetNumberSmooth(PC, PetscInt);
 PETSC_EXTERN PetscErrorCode PCMGSetCycleType(PC, PCMGCycleType);
 PETSC_EXTERN PetscErrorCode PCMGSetCycleTypeOnLevel(PC, PetscInt, PCMGCycleType);
-PETSC_DEPRECATED_FUNCTION("Use PCMGSetCycleTypeOnLevel() (since version 3.5)") static inline PetscErrorCode PCMGSetCyclesOnLevel(PC pc, PetscInt l, PetscInt t)
+PETSC_DEPRECATED_FUNCTION(3, 5, 0, "PCMGSetCycleTypeOnLevel()", ) static inline PetscErrorCode PCMGSetCyclesOnLevel(PC pc, PetscInt l, PetscInt t)
 {
   return PCMGSetCycleTypeOnLevel(pc, l, (PCMGCycleType)t);
 }
@@ -483,4 +496,5 @@ PETSC_EXTERN PetscErrorCode PCHPDDMInitializePackage(void);
 
 PETSC_EXTERN PetscErrorCode PCAmgXGetResources(PC, void *);
 
-#endif /* PETSCPC_H */
+PETSC_EXTERN PetscErrorCode PCMatSetApplyOperation(PC, MatOperation);
+PETSC_EXTERN PetscErrorCode PCMatGetApplyOperation(PC, MatOperation *);
