@@ -1,10 +1,9 @@
-#ifndef PETSCPCTYPES_H
-#define PETSCPCTYPES_H
+#pragma once
 
 /* SUBMANSEC = PC */
 
 /*S
-     PC - Abstract PETSc object that manages all preconditioners including direct solvers such as `PCLU`
+   PC - Abstract PETSc object that manages all preconditioners including direct solvers such as `PCLU`
 
    Level: beginner
 
@@ -13,7 +12,7 @@ S*/
 typedef struct _p_PC *PC;
 
 /*J
-    PCType - String with the name of a PETSc preconditioner
+   PCType - String with the name of a PETSc preconditioner
 
    Level: beginner
 
@@ -80,11 +79,11 @@ typedef const char *PCType;
 
 /*E
     PCSide - If the preconditioner is to be applied to the left, right
-     or symmetrically around the operator.
+             or symmetrically around the operator.
 
    Values:
-+  `PC_LEFT` - applied after the operator is applied
-.  `PC_RIGHT` - applied before the operator is applied
++  `PC_LEFT`      - applied after the operator is applied
+.  `PC_RIGHT`     - applied before the operator is applied
 -  `PC_SYMMETRIC` - a portion of the preconditioner is applied before the operator and the transpose of this portion is applied after the operator is applied.
 
    Level: beginner
@@ -92,7 +91,7 @@ typedef const char *PCType;
    Note:
    Certain `KSPType` support only a subset of `PCSide` values
 
-.seealso: [](sec_pc), `PC`, `KSPSetPCSide()`
+.seealso: [](sec_pc), `PC`, `KSPSetPCSide()`, `KSP`, `KSPType`
 E*/
 typedef enum {
   PC_SIDE_DEFAULT = -1,
@@ -107,9 +106,6 @@ typedef enum {
 
    Level: advanced
 
-   Developer Note:
-  This must match `include/petsc/finclude/petscpc.h` and the `KSPConvergedReason` values in `include/petscksp.h
-
 .seealso: [](sec_pc), `PCRICHARDSON`, `PC`, `PCApplyRichardson()`
 E*/
 typedef enum {
@@ -124,8 +120,8 @@ typedef enum {
 
    Values:
 +  `PC_JACOBI_DIAGONAL` - use the diagonal entry, if it is zero use one
-.  `PC_JACOBI_ROWMAX` - use the maximum absolute value in the row
--  `PC_JACOBI_ROWSUM` - use the sum of the values in the row (not the absolute values)
+.  `PC_JACOBI_ROWMAX`   - use the maximum absolute value in the row
+-  `PC_JACOBI_ROWSUM`   - use the sum of the values in the row (not the absolute values)
 
    Level: intermediate
 
@@ -142,16 +138,14 @@ typedef enum {
 
    Values:
 +  `PC_ASM_BASIC`        - Symmetric version where residuals from the ghost points are used
-                        and computed values in ghost regions are added together.
-                        Classical standard additive Schwarz.
+                           and computed values in ghost regions are added together.
+                           Classical standard additive Schwarz as introduced in {cite}`dryja1987additive`.
 .  `PC_ASM_RESTRICT`     - Residuals from ghost points are used but computed values in ghost
-                        region are discarded.
-                        Default.
+                           region are discarded {cite}`cs99`. Default.
 .  `PC_ASM_INTERPOLATE`  - Residuals from ghost points are not used, computed values in ghost
-                        region are added back in.
+                           region are added back in.
 -  `PC_ASM_NONE`         - Residuals from ghost points are not used, computed ghost values are
-                        discarded.
-                        Not very good.
+                           discarded. Not very good.
 
    Level: beginner
 
@@ -168,29 +162,29 @@ typedef enum {
     PCGASMType - Type of generalized additive Schwarz method to use (differs from `PCASM` in allowing multiple processors per subdomain).
 
    Values:
-+  `PC_GASM_BASIC`      - Symmetric version where the full from the outer subdomain is used, and the resulting correction is applied
-                        over the outer subdomains.  As a result, points in the overlap will receive the sum of the corrections
-                        from neighboring subdomains.
-                        Classical standard additive Schwarz.
++  `PC_GASM_BASIC`       - Symmetric version where the full from the outer subdomain is used, and the resulting correction is applied
+                           over the outer subdomains.  As a result, points in the overlap will receive the sum of the corrections
+                           from neighboring subdomains. Classical standard additive Schwarz {cite}`dryja1987additive`.
 .  `PC_GASM_RESTRICT`    - Residual from the outer subdomain is used but the correction is restricted to the inner subdomain only
-                        (i.e., zeroed out over the overlap portion of the outer subdomain before being applied).  As a result,
-                        each point will receive a correction only from the unique inner subdomain containing it (nonoverlapping covering
-                        assumption).
-                        Default.
+                           (i.e., zeroed out over the overlap portion of the outer subdomain before being applied).  As a result,
+                           each point will receive a correction only from the unique inner subdomain containing it (nonoverlapping covering
+                           assumption) {cite}`cs99`. Default.
 .  `PC_GASM_INTERPOLATE` - Residual is zeroed out over the overlap portion of the outer subdomain, but the resulting correction is
-                        applied over the outer subdomain. As a result, points in the overlap will receive the sum of the corrections
-                        from neighboring subdomains.
--  `PC_GASM_NONE`       - Residuals and corrections are zeroed out outside the local subdomains.
-                        Not very good.
+                           applied over the outer subdomain. As a result, points in the overlap will receive the sum of the corrections
+                           from neighboring subdomains.
+-  `PC_GASM_NONE`        - Residuals and corrections are zeroed out outside the local subdomains. Not very good.
 
    Level: beginner
 
    Note:
-     Each subdomain has nested inner and outer parts.  The inner subdomains are assumed to form a non-overlapping covering of the computational
+   Each subdomain has nested inner and outer parts.  The inner subdomains are assumed to form a non-overlapping covering of the computational
    domain, while the outer subdomains contain the inner subdomains and overlap with each other.  This preconditioner will compute
    a subdomain correction over each *outer* subdomain from a residual computed there, but its different variants will differ in
    (a) how the outer subdomain residual is computed, and (b) how the outer subdomain correction is computed.
 
+   Developer Note:
+   Perhaps better to remove this since it matches `PCASMType`
+
 .seealso: [](sec_pc), `PCGASM`, `PCASM`, `PC`, `PCGASMSetType()`, `PCASMType`
 E*/
 typedef enum {
@@ -204,20 +198,19 @@ typedef enum {
     PCCompositeType - Determines how two or more preconditioner are composed with the `PCType` of `PCCOMPOSITE`
 
   Values:
-+  `PC_COMPOSITE_ADDITIVE` - results from application of all preconditioners are added together
-.  `PC_COMPOSITE_MULTIPLICATIVE` - preconditioners are applied sequentially to the residual freshly
-                                computed after the previous preconditioner application
++  `PC_COMPOSITE_ADDITIVE`                 - results from application of all preconditioners are added together
+.  `PC_COMPOSITE_MULTIPLICATIVE`           - preconditioners are applied sequentially to the residual freshly
+                                             computed after the previous preconditioner application
 .  `PC_COMPOSITE_SYMMETRIC_MULTIPLICATIVE` - preconditioners are applied sequentially to the residual freshly
-                                computed from first preconditioner to last and then back (Use only for symmetric matrices and preconditioners)
-.  `PC_COMPOSITE_SPECIAL` - This is very special for a matrix of the form alpha I + R + S
-                         where first preconditioner is built from alpha I + S and second from
-                         alpha I + R
-.  `PC_COMPOSITE_SCHUR` -  composes the Schur complement of the matrix from two blocks, see `PCFIELDSPLIT`
--  `PC_COMPOSITE_GKB` - the generalized Golub-Kahan bidiagonalization preconditioner, see `PCFIELDSPLIT`
+                                             computed from first preconditioner to last and then back (Use only for symmetric matrices and preconditioners)
+.  `PC_COMPOSITE_SPECIAL`                  - This is very special for a matrix of the form $ \alpha I + R + S$
+                                             where the first preconditioner is built from $\alpha I + S$ and second from $\alpha I + R$
+.  `PC_COMPOSITE_SCHUR`                    - composes the Schur complement of the matrix from two blocks, see `PCFIELDSPLIT`
+-  `PC_COMPOSITE_GKB`                      - the generalized Golub-Kahan bidiagonalization preconditioner, see `PCFIELDSPLIT`
 
    Level: beginner
 
-.seealso: [](sec_pc), `PCCOMPOSITE`, `PCFIELDSPLIT`, `PC`, `PCCompositeSetType()`
+.seealso: [](sec_pc), `PCCOMPOSITE`, `PCFIELDSPLIT`, `PC`, `PCCompositeSetType()`, `SNESCompositeType`, `PCCompositeSpecialSetAlpha()`
 E*/
 typedef enum {
   PC_COMPOSITE_ADDITIVE,
@@ -232,17 +225,17 @@ typedef enum {
     PCFieldSplitSchurPreType - Determines how to precondition a Schur complement
 
     Values:
-+  `PC_FIELDSPLIT_SCHUR_PRE_SELF` - the preconditioner for the Schur complement is generated from the symbolic representation of the Schur complement matrix:
-          The only preconditioner that currently works with this symbolic representation matrix object is `PCLSC`
-.  `PC_FIELDSPLIT_SCHUR_PRE_SELFP` - the preconditioning for the Schur complement is generated from an explicitly-assembled approximation Sp = A11 - A10 inv(diag(A00)) A01
-          This is only a good preconditioner when diag(A00) is a good preconditioner for A00. Optionally, A00 can be
-          lumped before extracting the diagonal using the additional option `-fieldsplit_1_mat_schur_complement_ainv_type lump`
-.  `PC_FIELDSPLIT_SCHUR_PRE_A11` - the preconditioner for the Schur complement is generated from the block diagonal part of the matrix used to define the preconditioner,
-                                 associated with the Schur complement (i.e. A11), not the Schur complement matrix
-.  `PC_FIELDSPLIT_SCHUR_PRE_USER` - the preconditioner for the Schur complement is generated from the user provided matrix (pre argument
-          to this function).
--  `PC_FIELDSPLIT_SCHUR_PRE_FULL` -  the preconditioner for the Schur complement is generated from the exact Schur complement matrix representation
-      computed internally by `PCFIELDSPLIT` (this is expensive) useful mostly as a test that the Schur complement approach can work for your problem
++  `PC_FIELDSPLIT_SCHUR_PRE_SELF`  - the preconditioner for the Schur complement is generated from the symbolic representation of the Schur complement matrix.
+                                     The only preconditioners that currently work with this symbolic representation matrix object are `PCLSC` and `PCHPDDM`
+.  `PC_FIELDSPLIT_SCHUR_PRE_SELFP` - the preconditioning for the Schur complement is generated from an explicitly-assembled approximation Sp = A11 - A10 inv(diag(A00)) A01.
+                                     This is only a good preconditioner when diag(A00) is a good preconditioner for A00. Optionally, A00 can be
+                                     lumped before extracting the diagonal using the additional option `-fieldsplit_1_mat_schur_complement_ainv_type lump`
+.  `PC_FIELDSPLIT_SCHUR_PRE_A11`   - the preconditioner for the Schur complement is generated from the block diagonal part of the matrix used to define the preconditioner,
+                                     associated with the Schur complement (i.e. A11), not the Schur complement matrix
+.  `PC_FIELDSPLIT_SCHUR_PRE_USER`  - the preconditioner for the Schur complement is generated from the user provided matrix (pre argument
+                                     to this function).
+-  `PC_FIELDSPLIT_SCHUR_PRE_FULL`  - the preconditioner for the Schur complement is generated from the exact Schur complement matrix representation
+                                     computed internally by `PCFIELDSPLIT` (this is expensive) useful mostly as a test that the Schur complement approach can work for your problem
 
     Level: intermediate
 
@@ -260,10 +253,10 @@ typedef enum {
     PCFieldSplitSchurFactType - determines which off-diagonal parts of the approximate block factorization to use
 
     Values:
-+   `PC_FIELDSPLIT_SCHUR_FACT_DIAG` - the preconditioner is solving `D`
++   `PC_FIELDSPLIT_SCHUR_FACT_DIAG`  - the preconditioner is solving `D`
 .   `PC_FIELDSPLIT_SCHUR_FACT_LOWER` - the preconditioner is solving `L D`
 .   `PC_FIELDSPLIT_SCHUR_FACT_UPPER` - the preconditioner is solving `D U`
--   `PC_FIELDSPLIT_SCHUR_FACT_FULL` - the preconditioner is solving `L(D U)`
+-   `PC_FIELDSPLIT_SCHUR_FACT_FULL`  - the preconditioner is solving `L(D U)`
 
     where the matrix is factorized as
 .vb
@@ -313,9 +306,9 @@ typedef enum {
     PCGAMGType - type of generalized algebraic multigrid `PCGAMG` method
 
    Values:
-+   `PCGAMGAGG` - (the default) smoothed aggregation algorithm, robust, very well tested
-.   `PCGAMGGEO` - geometric coarsening, uses mesh generator to produce coarser meshes, limited to triangles, not well tested
--   `PCGAMGCLASSICAL` - classical algebraic multigrid preconditioner, incomplete, poorly tested
++   `PCGAMGAGG`       - (the default) smoothed aggregation algorithm, robust, very well tested
+.   `PCGAMGGEO`       - geometric coarsening, uses mesh generator to produce coarser meshes, limited to triangles, not supported, reference implementation (2D)
+-   `PCGAMGCLASSICAL` - classical algebraic multigrid preconditioner, incomplete, not supported, reference implementation
 
      Level: intermediate
 
@@ -331,19 +324,19 @@ typedef const char *PCGAMGClassicalType;
 #define PCGAMGCLASSICALSTANDARD "standard"
 
 /*E
-    PCMGType - Determines the type of multigrid method that is run.
+   PCMGType - Determines the type of multigrid method that is run.
 
    Values:
 +  `PC_MG_MULTIPLICATIVE` (default) - traditional V or W cycle as determined by `PCMGSetCycleType()`
-.  `PC_MG_ADDITIVE` - the additive multigrid preconditioner where all levels are
-                smoothed before updating the residual. This only uses the
-                down smoother, in the preconditioner the upper smoother is ignored
-.  `PC_MG_FULL` - same as multiplicative except one also performs grid sequencing,
-            that is starts on the coarsest grid, performs a cycle, interpolates
-            to the next, performs a cycle etc. This is much like the F-cycle presented in "Multigrid" by Trottenberg, Oosterlee, Schuller page 49, but that
-            algorithm supports smoothing on before the restriction on each level in the initial restriction to the coarsest stage. In addition that algorithm
-            calls the V-cycle only on the coarser level and has a post-smoother instead.
--  `PC_MG_KASKADE` - like full multigrid except one never goes back to a coarser level from a finer
+.  `PC_MG_ADDITIVE`                 - the additive multigrid preconditioner where all levels are
+                                      smoothed before updating the residual. This only uses the
+                                      down smoother, in the preconditioner the upper smoother is ignored
+.  `PC_MG_FULL`                     - same as multiplicative except one also performs grid sequencing,
+                                      that is starts on the coarsest grid, performs a cycle, interpolates
+                                      to the next, performs a cycle etc. This is much like the F-cycle presented in "Multigrid" by Trottenberg, Oosterlee, Schuller page 49, but that
+                                      algorithm supports smoothing on before the restriction on each level in the initial restriction to the coarsest stage. In addition that algorithm
+                                      calls the V-cycle only on the coarser level and has a post-smoother instead.
+-  `PC_MG_KASKADE`                  - like full multigrid except one never goes back to a coarser level from a finer
 
    Level: beginner
 
@@ -358,11 +351,11 @@ typedef enum {
 #define PC_MG_CASCADE PC_MG_KASKADE;
 
 /*E
-    PCMGCycleType - Use V-cycle or W-cycle
+   PCMGCycleType - Use V-cycle or W-cycle
 
    Values:
-+  `PC_MG_V_CYCLE` - use the v cycle
--  `PC_MG_W_CYCLE` - use the w cycle
++  `PC_MG_V_CYCLE` - use the V cycle
+-  `PC_MG_W_CYCLE` - use the W cycle
 
    Level: beginner
 
@@ -414,7 +407,7 @@ typedef enum {
 
    Values:
 +  `PC_BDDC_INTERFACE_EXT_DIRICHLET` - solves Dirichlet interior problem; this is the standard BDDC algorithm
--  `PC_BDDC_INTERFACE_EXT_LUMP` - skips interior solve; sometimes called M_1 and associated with "lumped FETI-DP"
+-  `PC_BDDC_INTERFACE_EXT_LUMP`      - skips interior solve; sometimes called M_1 and associated with "lumped FETI-DP"
 
    Level: intermediate
 
@@ -494,8 +487,8 @@ typedef enum {
 
     Values:
 +   `PC_HPDDM_COARSE_CORRECTION_DEFLATED` (default) - eq. (1) in `PCHPDDMShellApply()`
-.   `PC_HPDDM_COARSE_CORRECTION_ADDITIVE` - eq. (2)
--   `PC_HPDDM_COARSE_CORRECTION_BALANCED` - eq. (3)
+.   `PC_HPDDM_COARSE_CORRECTION_ADDITIVE`           - eq. (2)
+-   `PC_HPDDM_COARSE_CORRECTION_BALANCED`           - eq. (3)
 
     Level: intermediate
 
@@ -507,14 +500,27 @@ typedef enum {
   PC_HPDDM_COARSE_CORRECTION_BALANCED
 } PCHPDDMCoarseCorrectionType;
 
+/*E
+    PCHPDDMSchurPreType - Type of `PCHPDDM` preconditioner for a `MATSCHURCOMPLEMENT` generated by `PCFIELDSPLIT` with `PCFieldSplitSchurPreType` set to `PC_FIELDSPLIT_SCHUR_PRE_SELF`
+
+    Values:
++   `PC_HPDDM_SCHUR_PRE_LEAST_SQUARES` (default) - only with a near-zero A11 block and A10 = A01^T; a preconditioner for solving A01^T A00^-1 A01 x = b is built by approximating the Schur complement with (inv(sqrt(diag(A00))) A01)^T (inv(sqrt(diag(A00))) A01) and by considering the associated linear least squares problem
+-   `PC_HPDDM_SCHUR_PRE_GENEO` - only with A10 = A01^T, `PCHPDDMSetAuxiliaryMat()` called on the `PC` of the A00 block, and if A11 is nonzero, then `PCHPDDMSetAuxiliaryMat()` must be called on the associated `PC` as well (it is built automatically for the user otherwise); the Schur complement `PC` is set internally to `PCKSP`, with the prefix `-fieldsplit_1_pc_hpddm_`; the operator associated to the `PC` is spectrally equivalent to the original Schur complement
+
+    Level: advanced
+
+.seealso: [](sec_pc), `PCHPDDM`, `PC`, `PCFIELDSPLIT`, `PC_FIELDSPLIT_SCHUR_PRE_SELF`, `PCFieldSplitSetSchurPre()`, `PCHPDDMSetAuxiliaryMat()`
+E*/
+typedef enum {
+  PC_HPDDM_SCHUR_PRE_LEAST_SQUARES,
+  PC_HPDDM_SCHUR_PRE_GENEO,
+} PCHPDDMSchurPreType;
+
 /*E
     PCFailedReason - indicates type of `PC` failure
 
     Level: beginner
 
-    Developer Note:
-    Any additions/changes here MUST also be made in `include/petsc/finclude/petscpc.h`
-
 .seealso: [](sec_pc), `PC`
 E*/
 typedef enum {
@@ -533,14 +539,9 @@ typedef enum {
 
     Level: intermediate
 
-    Developer Note:
-    Any additions/changes here MUST also be made in `include/petsc/finclude/petscpc.h`
-
 .seealso: [](sec_pc), `PCGAMG`, `PC`, `PCGAMGSetCoarseGridLayoutType()`
 E*/
 typedef enum {
   PCGAMG_LAYOUT_COMPACT,
   PCGAMG_LAYOUT_SPREAD
 } PCGAMGLayoutType;
-
-#endif
