@@ -1,8 +1,7 @@
 /*
    A star forest (SF) describes a communication pattern
 */
-#ifndef PETSCSF_H
-#define PETSCSF_H
+#pragma once
 
 #include <petscsys.h>
 #include <petscsftypes.h>
@@ -20,9 +19,9 @@ PETSC_EXTERN PetscClassId PETSCSF_CLASSID;
 .  `PETSCSF_PATTERN_ALLGATHER` - A graph that every rank gathers all roots from all ranks (like `MPI_Allgather()`). One sets the graph with `PetscSFSetGraphWithPattern()`.
 .  `PETSCSF_PATTERN_GATHER`    - A graph that rank 0 gathers all roots from all ranks (like `MPI_Gatherv()` with root=0). One sets the graph with `PetscSFSetGraphWithPattern()`.
 -  `PETSCSF_PATTERN_ALLTOALL`  - A graph that every rank gathers different roots from all ranks (like `MPI_Alltoall()`). One sets the graph with `PetscSFSetGraphWithPattern()`.
-                               In an ALLTOALL graph, we assume each process has <size> leaves and <size> roots, with each leaf connecting to a remote root. Here <size> is
-                               the size of the communicator. This does not mean one can not communicate multiple data items between a pair of processes. One just needs to
-                               create a new MPI datatype for the multiple data items, e.g., by `MPI_Type_contiguous`.
+                                 In an ALLTOALL graph, we assume each process has <size> leaves and <size> roots, with each leaf connecting to a remote root. Here <size> is
+                                 the size of the communicator. This does not mean one can not communicate multiple data items between a pair of processes. One just needs to
+                                 create a new MPI datatype for the multiple data items, e.g., by `MPI_Type_contiguous`.
    Level: beginner
 
 .seealso: `PetscSF`, `PetscSFSetGraph()`, `PetscSFSetGraphWithPattern()`
@@ -38,8 +37,8 @@ typedef enum {
     PetscSFWindowSyncType - Type of synchronization for `PETSCSFWINDOW`
 
    Values:
-+  `PETSCSF_WINDOW_SYNC_FENCE` - simplest model, synchronizing across communicator
-.  `PETSCSF_WINDOW_SYNC_LOCK` - passive model, less synchronous, requires less setup than `PETSCSF_WINDOW_SYNC_ACTIVE`, but may require more handshakes
++  `PETSCSF_WINDOW_SYNC_FENCE`  - simplest model, synchronizing across communicator
+.  `PETSCSF_WINDOW_SYNC_LOCK`   - passive model, less synchronous, requires less setup than `PETSCSF_WINDOW_SYNC_ACTIVE`, but may require more handshakes
 -  `PETSCSF_WINDOW_SYNC_ACTIVE` - active model, provides most information to MPI implementation, needs to construct 2-way process groups (more setup than `PETSCSF_WINDOW_SYNC_LOCK`)
 
    Level: advanced
@@ -57,10 +56,10 @@ PETSC_EXTERN const char *const PetscSFWindowSyncTypes[];
     PetscSFWindowFlavorType - Flavor for the creation of MPI windows for `PETSCSFWINDOW`
 
     Values:
-+  `PETSCSF_WINDOW_FLAVOR_CREATE` - Use `MPI_Win_create()`, no reuse
-.  `PETSCSF_WINDOW_FLAVOR_DYNAMIC` - Use `MPI_Win_create_dynamic()` and dynamically attach pointers
++  `PETSCSF_WINDOW_FLAVOR_CREATE`   - Use `MPI_Win_create()`, no reuse
+.  `PETSCSF_WINDOW_FLAVOR_DYNAMIC`  - Use `MPI_Win_create_dynamic()` and dynamically attach pointers
 .  `PETSCSF_WINDOW_FLAVOR_ALLOCATE` - Use `MPI_Win_allocate()`
--  `PETSCSF_WINDOW_FLAVOR_SHARED` - Use `MPI_Win_allocate_shared()`
+-  `PETSCSF_WINDOW_FLAVOR_SHARED`   - Use `MPI_Win_allocate_shared()`
 
    Level: advanced
 
@@ -79,8 +78,8 @@ PETSC_EXTERN const char *const PetscSFWindowFlavorTypes[];
 
    Values:
 +  `PETSCSF_DUPLICATE_CONFONLY` - configuration only, user must call `PetscSFSetGraph()`
-.  `PETSCSF_DUPLICATE_RANKS` - communication ranks preserved, but different graph (allows simpler setup after calling `PetscSFSetGraph()`)
--  `PETSCSF_DUPLICATE_GRAPH` - entire graph duplicated
+.  `PETSCSF_DUPLICATE_RANKS`    - communication ranks preserved, but different graph (allows simpler setup after calling `PetscSFSetGraph()`)
+-  `PETSCSF_DUPLICATE_GRAPH`    - entire graph duplicated
 
    Level: beginner
 
@@ -192,36 +191,34 @@ PETSC_EXTERN PetscErrorCode PetscSFScatterEnd(PetscSF, MPI_Datatype, const void
 PETSC_EXTERN PetscErrorCode PetscSFCompose(PetscSF, PetscSF, PetscSF *);
 PETSC_EXTERN PetscErrorCode PetscSFComposeInverse(PetscSF, PetscSF, PetscSF *);
 
-#define MPIU_REPLACE MPI_REPLACE PETSC_DEPRECATED_MACRO("GCC warning \"MPIU_REPLACE macro is deprecated use MPI_REPLACE (since version 3.15)\"")
+#define MPIU_REPLACE MPI_REPLACE PETSC_DEPRECATED_MACRO(3, 15, 0, "MPI_REPLACE", )
 
-PETSC_DEPRECATED_FUNCTION("Use PetscSFGetRootRanks (since v3.12)")
+PETSC_DEPRECATED_FUNCTION(3, 12, 0, "PetscSFGetRootRanks()", )
 static inline PetscErrorCode PetscSFGetRanks(PetscSF sf, PetscInt *nranks, const PetscMPIInt **ranks, const PetscInt **roffset, const PetscInt **rmine, const PetscInt **rremote)
 {
   return PetscSFGetRootRanks(sf, nranks, ranks, roffset, rmine, rremote);
 }
 
-PETSC_DEPRECATED_FUNCTION("Use PetscSFCreateEmbeddedRootSF (since v3.15)")
+PETSC_DEPRECATED_FUNCTION(3, 15, 0, "PetscSFCreateEmbeddedRootSF()", )
 static inline PetscErrorCode PetscSFCreateEmbeddedSF(PetscSF sf, PetscInt nselected, const PetscInt *selected, PetscSF *esf)
 {
   return PetscSFCreateEmbeddedRootSF(sf, nselected, selected, esf);
 }
 
-PETSC_DEPRECATED_FUNCTION("Use PetscSFBcastBegin (since v3.15)")
+PETSC_DEPRECATED_FUNCTION(3, 15, 0, "PetscSFBcastBegin()", )
 static inline PetscErrorCode PetscSFBcastAndOpBegin(PetscSF sf, MPI_Datatype unit, const void *rootdata, void *leafdata, MPI_Op op)
 {
   return PetscSFBcastBegin(sf, unit, rootdata, leafdata, op);
 }
 
-PETSC_DEPRECATED_FUNCTION("Use PetscSFBcastEnd (since v3.15)")
+PETSC_DEPRECATED_FUNCTION(3, 15, 0, "PetscSFBcastEnd()", )
 static inline PetscErrorCode PetscSFBcastAndOpEnd(PetscSF sf, MPI_Datatype unit, const void *rootdata, void *leafdata, MPI_Op op)
 {
   return PetscSFBcastEnd(sf, unit, rootdata, leafdata, op);
 }
 
-PETSC_DEPRECATED_FUNCTION("Use PetscSFBcastWithMemTypeBegin (since v3.15)")
+PETSC_DEPRECATED_FUNCTION(3, 15, 0, "PetscSFBcastWithMemTypeBegin()", )
 static inline PetscErrorCode PetscSFBcastAndOpWithMemtypeBegin(PetscSF sf, MPI_Datatype unit, PetscMemType rootmtype, const void *rootdata, PetscMemType leafmtype, void *leafdata, MPI_Op op)
 {
   return PetscSFBcastWithMemTypeBegin(sf, unit, rootmtype, rootdata, leafmtype, leafdata, op);
 }
-
-#endif
