@@ -1,5 +1,4 @@
-#ifndef PETSCTAO_H
-#define PETSCTAO_H
+#pragma once
 
 #include <petscsnes.h>
 
@@ -12,17 +11,19 @@ PETSC_EXTERN PetscErrorCode MatDSFischer(Mat, Vec, Vec, Vec, Vec, PetscReal, Vec
 PETSC_EXTERN PetscErrorCode TaoSoftThreshold(Vec, PetscReal, PetscReal, Vec);
 
 /*E
-  TaoSubsetType - Type representing the way Tao handles active sets
+  TaoSubsetType - Type representing the way TAO handles active sets
 
-+ `TAO_SUBSET_SUBVEC` - Tao uses `MatCreateSubMatrix()` and `VecGetSubVector()`
-. `TAO_SUBSET_MASK` - Matrices are zeroed out corresponding to active set entries
+  Values:
++ `TAO_SUBSET_SUBVEC`     - Tao uses `MatCreateSubMatrix()` and `VecGetSubVector()`
+. `TAO_SUBSET_MASK`       - Matrices are zeroed out corresponding to active set entries
 - `TAO_SUBSET_MATRIXFREE` - Same as `TAO_SUBSET_MASK` but it can be applied to matrix-free operators
 
-  Options database keys:
-. -different_hessian - Tao will use a copy of the hessian operator for masking.  By default
-                       Tao will directly alter the hessian operator.
+  Options database Key:
+. -different_hessian - Tao will use a copy of the Hessian operator for masking.  By default TAO will directly alter the Hessian operator.
+
   Level: intermediate
 
+.seealso: [](ch_tao), `TaoVecGetSubVec()`, `TaoMatGetSubMat()`, `Tao`, `TaoCreate()`, `TaoDestroy()`, `TaoSetType()`, `TaoType`
 E*/
 typedef enum {
   TAO_SUBSET_SUBVEC,
@@ -32,20 +33,20 @@ typedef enum {
 PETSC_EXTERN const char *const TaoSubsetTypes[];
 
 /*S
-     Tao - Abstract PETSc object that manages nonlinear optimization solves
+   Tao - Abstract PETSc object that manages nonlinear optimization solves
 
    Level: advanced
 
-.seealso: `TaoCreate()`, `TaoDestroy()`, `TaoSetType()`, `TaoType`
+.seealso: [](doc_taosolve), [](ch_tao), `TaoCreate()`, `TaoDestroy()`, `TaoSetType()`, `TaoType`
 S*/
 typedef struct _p_Tao *Tao;
 
 /*E
-     TaoADMMUpdateType - Determine spectral penalty update routine for Lagrange augmented term for `TAOADMM`.
+  TaoADMMUpdateType - Determine spectral penalty update routine for Lagrange augmented term for `TAOADMM`.
 
   Level: advanced
 
-.seealso: `Tao`, `TAOADMM`, `TaoADMMSetUpdateType()`
+.seealso: [](ch_tao), `Tao`, `TAOADMM`, `TaoADMMSetUpdateType()`
 E*/
 typedef enum {
   TAO_ADMM_UPDATE_BASIC,
@@ -55,44 +56,44 @@ typedef enum {
 PETSC_EXTERN const char *const TaoADMMUpdateTypes[];
 
 /*MC
-     TAO_ADMM_UPDATE_BASIC - Use same spectral penalty set at the beginning. No update
+  TAO_ADMM_UPDATE_BASIC - Use same spectral penalty set at the beginning. No update
 
   Level: advanced
 
   Note:
-  Most basic implementation. Generally slower than adaptive or adaptive relaxed version.
+  Most basic implementation of `TAOADMM`. Generally slower than adaptive or adaptive relaxed version.
 
-.seealso: `TaoADMMSetUpdateType()`, `TAO_ADMM_UPDATE_ADAPTIVE`, `TAO_ADMM_UPDATE_ADAPTIVE_RELAXED`
+.seealso: [](ch_tao), `Tao`, `TAOADMM`, `TaoADMMSetUpdateType()`, `TAO_ADMM_UPDATE_ADAPTIVE`, `TAO_ADMM_UPDATE_ADAPTIVE_RELAXED`
 M*/
 
 /*MC
-     TAO_ADMM_UPDATE_ADAPTIVE - Adaptively update spectral penalty
+  TAO_ADMM_UPDATE_ADAPTIVE - Adaptively update spectral penalty
 
   Level: advanced
 
   Note:
-  Adaptively updates spectral penalty by using both steepest descent and minimum gradient.
+  Adaptively updates spectral penalty of `TAOADMM` by using both steepest descent and minimum gradient.
 
-.seealso: `TaoADMMSetUpdateType()`, `TAO_ADMM_UPDATE_BASIC`, `TAO_ADMM_UPDATE_ADAPTIVE_RELAXED`
+.seealso: [](ch_tao), `Tao`, `TAOADMM`, `TaoADMMSetUpdateType()`, `TAO_ADMM_UPDATE_BASIC`, `TAO_ADMM_UPDATE_ADAPTIVE_RELAXED`
 M*/
 
 /*MC
-     ADMM_UPDATE_ADAPTIVE_RELAXED - Adaptively update spectral penalty, and relaxes parameter update
+  ADMM_UPDATE_ADAPTIVE_RELAXED - Adaptively update spectral penalty, and relaxes parameter update
 
   Level: advanced
 
   Note:
   With adaptive spectral penalty update, it also relaxes x vector update by a factor.
 
-.seealso: `TaoADMMSetUpdateType()`, `TAO_ADMM_UPDATE_BASIC`, `TAO_ADMM_UPDATE_ADAPTIVE`
+.seealso: [](ch_tao), `Tao`, `TaoADMMSetUpdateType()`, `TAO_ADMM_UPDATE_BASIC`, `TAO_ADMM_UPDATE_ADAPTIVE`
 M*/
 
 /*E
-     TaoADMMRegularizerType - Determine regularizer routine - either user provided or soft threshold
+  TaoADMMRegularizerType - Determine regularizer routine - either user provided or soft threshold for `TAOADMM`
 
   Level: advanced
 
-.seealso: `Tao`, `TAOADMM`, `TaoADMMSetRegularizerType()`
+.seealso: [](ch_tao), `Tao`, `TAOADMM`, `TaoADMMSetRegularizerType()`
 E*/
 typedef enum {
   TAO_ADMM_REGULARIZER_USER,
@@ -108,7 +109,7 @@ PETSC_EXTERN const char *const TaoADMMRegularizerTypes[];
   Note:
   User needs to provided appropriate routines and type for regularizer solver
 
-.seealso: `TaoADMMSetRegularizerType()`, `TAO_ADMM_REGULARIZER_SOFT_THRESH`
+.seealso: [](ch_tao), `Tao`, `TAOADMM`, `TaoADMMSetRegularizerType()`, `TAO_ADMM_REGULARIZER_SOFT_THRESH`
 M*/
 
 /*MC
@@ -119,12 +120,12 @@ M*/
   Note:
   Utilizes built-in SoftThreshold routines
 
-.seealso: `TaoSoftThreshold()`, `TaoADMMSetRegularizerObjectiveAndGradientRoutine()`,
+.seealso: [](ch_tao), `Tao`, `TAOADMM`, `TaoSoftThreshold()`, `TaoADMMSetRegularizerObjectiveAndGradientRoutine()`,
           `TaoADMMSetRegularizerHessianRoutine()`, `TaoADMMSetRegularizerType()`, `TAO_ADMM_REGULARIZER_USER`
 M*/
 
 /*E
-     TaoALMMType - Determine the augmented Lagrangian formulation used in the `TAOALMM` subproblem.
+   TaoALMMType - Determine the augmented Lagrangian formulation used in the `TAOALMM` subproblem.
 
    Values:
 +  `TAO_ALMM_CLASSIC` - classic augmented Lagrangian definition including slack variables for inequality constraints
@@ -132,7 +133,7 @@ M*/
 
   Level: advanced
 
-.seealso: `Tao`, `TAOALMM`, `TaoALMMSetType()`, `TaoALMMGetType()`
+.seealso: [](ch_tao), `Tao`, `TAOALMM`, `TaoALMMSetType()`, `TaoALMMGetType()`
 E*/
 typedef enum {
   TAO_ALMM_CLASSIC,
@@ -140,12 +141,65 @@ typedef enum {
 } TaoALMMType;
 PETSC_EXTERN const char *const TaoALMMTypes[];
 
+/*E
+  TaoBNCGType - Determine the conjugate gradient update formula used in the TAOBNCG algorithm.
+
+  Values:
++  TAO_BNCG_GD         - basic gradient descent, no CG update
+.  TAO_BNCG_PCGD       - preconditioned/scaled gradient descent
+.  TAO_BNCG_HS         - Hestenes-Stiefel
+.  TAO_BNCG_FR         - Fletcher-Reeves
+.  TAO_BNCG_PRP        - Polak-Ribiere-Polyak (PRP)
+.  TAO_BNCG_PRP_PLUS   - Polak-Ribiere-Polyak "plus" (PRP+)
+.  TAO_BNCG_DY         - Dai-Yuan
+.  TAO_BNCG_HZ         - Hager-Zhang (CG_DESCENT 5.3)
+.  TAO_BNCG_DK         - Dai-Kou (2013)
+.  TAO_BNCG_KD         - Kou-Dai (2015)
+.  TAO_BNCG_SSML_BFGS  - Self-Scaling Memoryless BFGS (Perry-Shanno)
+.  TAO_BNCG_SSML_DFP   - Self-Scaling Memoryless DFP
+-  TAO_BNCG_SSML_BRDN  - Self-Scaling Memoryless (Symmetric) Broyden
+
+  Level: advanced
+
+.seealso: `Tao`, `TAOBNCG`, `TaoBNCGSetType()`, `TaoBNCGGetType()`
+E*/
+
+typedef enum {
+  TAO_BNCG_GD,
+  TAO_BNCG_PCGD,
+  TAO_BNCG_HS,
+  TAO_BNCG_FR,
+  TAO_BNCG_PRP,
+  TAO_BNCG_PRP_PLUS,
+  TAO_BNCG_DY,
+  TAO_BNCG_HZ,
+  TAO_BNCG_DK,
+  TAO_BNCG_KD,
+  TAO_BNCG_SSML_BFGS,
+  TAO_BNCG_SSML_DFP,
+  TAO_BNCG_SSML_BRDN
+} TaoBNCGType;
+PETSC_EXTERN const char *const TaoBNCGTypes[];
+
 /*J
-        TaoType - String with the name of a `Tao` method
+  TaoType - String with the name of a `Tao` method
 
-       Level: beginner
+  Values:
++ `TAONLS`      - nls Newton's method with line search for unconstrained minimization
+. `TAONTR`      - ntr Newton's method with trust region for unconstrained minimization
+. `TAONTL`      - ntl Newton's method with trust region, line search for unconstrained minimization
+. `TAOLMVM`     - lmvm Limited memory variable metric method for unconstrained minimization
+. `TAOCG`       - cg Nonlinear conjugate gradient method for unconstrained minimization
+. `TAONM`       - nm Nelder-Mead algorithm for derivate-free unconstrained minimization
+. `TAOTRON`     - tron Newton Trust Region method for bound constrained minimization
+. `TAOGPCG`     - gpcg Newton Trust Region method for quadratic bound constrained minimization
+. `TAOBLMVM`    - blmvm Limited memory variable metric method for bound constrained minimization
+. `TAOLCL`      - lcl Linearly constrained Lagrangian method for pde-constrained minimization
+- `TAOPOUNDERS` - Pounders Model-based algorithm for nonlinear least squares
 
-.seealso: `Tao`, `TaoCreate()`, `TaoSetType()`
+  Level: beginner
+
+.seealso: [](doc_taosolve), [](ch_tao), `Tao`, `TaoCreate()`, `TaoSetType()`
 J*/
 typedef const char *TaoType;
 #define TAOLMVM     "lmvm"
@@ -181,27 +235,50 @@ typedef const char *TaoType;
 #define TAOADMM     "admm"
 #define TAOALMM     "almm"
 #define TAOPYTHON   "python"
+#define TAOSNES     "snes"
 
 PETSC_EXTERN PetscClassId      TAO_CLASSID;
 PETSC_EXTERN PetscFunctionList TaoList;
 
 /*E
-    TaoConvergedReason - reason a Tao method was said to have converged or diverged
+    TaoConvergedReason - reason a `Tao` optimizer was said to have converged or diverged
+
+   Values:
++  `TAO_CONVERGED_GATOL`       - $||g(X)|| < gatol$
+.  `TAO_CONVERGED_GRTOL`       - $||g(X)|| / f(X)  < grtol$
+.  `TAO_CONVERGED_GTTOL`       - $||g(X)|| / ||g(X0)|| < gttol$
+.  `TAO_CONVERGED_STEPTOL`     - step size smaller than tolerance
+.  `TAO_CONVERGED_MINF`        - $F < F_min$
+.  `TAO_CONVERGED_USER`        - the user indicates the optimization has succeeded
+.  `TAO_DIVERGED_MAXITS`       - the maximum number of iterations allowed has been achieved
+.  `TAO_DIVERGED_NAN`          - not a number appeared in the computations
+.  `TAO_DIVERGED_MAXFCN`       - the maximum number of function evaluations has been computed
+.  `TAO_DIVERGED_LS_FAILURE`   - a linesearch failed
+.  `TAO_DIVERGED_TR_REDUCTION` - trust region failure
+.  `TAO_DIVERGED_USER`         - the user has indicated the optimization has failed
+-  `TAO_CONTINUE_ITERATING`    - the optimization is still running, `TaoSolve()`
+
+   where
++  X            - current solution
+.  X0           - initial guess
+.  f(X)         - current function value
+.  f(X*)        - true solution (estimated)
+.  g(X)         - current gradient
+.  its          - current iterate number
+.  maxits       - maximum number of iterates
+.  fevals       - number of function evaluations
+-  max_funcsals - maximum number of function evaluations
 
    Level: beginner
 
-   The two most common reasons for divergence are
-$   1) an incorrectly coded or computed gradient or Hessian
-$   2) failure or lack of convergence in the linear system (in this case we recommend
-$      testing with -pc_type lu to eliminate the linear solver as the cause of the problem).
+   Note:
+   The two most common reasons for divergence are  an incorrectly coded or computed gradient or Hessian failure or lack of convergence
+   in the linear system solve (in this case we recommend testing with `-pc_type lu` to eliminate the linear solver as the cause of the problem).
 
-   Developer Notes:
-    This must match petsc/finclude/petsctao.h
+   Developer Note:
+   The names in `KSPConvergedReason`, `SNESConvergedReason`, and `TaoConvergedReason` should be uniformized
 
-       The string versions of these are in `TAOConvergedReasons`, if you change any value here you must
-     also adjust that array.
-
-.seealso: `Tao`, `TaoSolve()`, `TaoGetConvergedReason()`, `KSPConvergedReason`, `SNESConvergedReason`, `TSConvergedReason`
+.seealso: [](ch_tao), `Tao`, `TaoSolve()`, `TaoGetConvergedReason()`, `KSPConvergedReason`, `SNESConvergedReason`
 E*/
 typedef enum {               /* converged */
   TAO_CONVERGED_GATOL   = 3, /* ||g(X)|| < gatol */
@@ -248,11 +325,11 @@ PETSC_EXTERN PetscErrorCode TaoGetSolutionStatus(Tao, PetscInt *, PetscReal *, P
 PETSC_EXTERN PetscErrorCode TaoSetConvergedReason(Tao, TaoConvergedReason);
 PETSC_EXTERN PetscErrorCode TaoSetSolution(Tao, Vec);
 PETSC_EXTERN PetscErrorCode TaoGetSolution(Tao, Vec *);
-PETSC_DEPRECATED_FUNCTION("Use TaoSetSolution() (since version 3.17)") static inline PetscErrorCode TaoSetInitialVector(Tao t, Vec v)
+PETSC_DEPRECATED_FUNCTION(3, 17, 0, "TaoSetSolution()", ) static inline PetscErrorCode TaoSetInitialVector(Tao t, Vec v)
 {
   return TaoSetSolution(t, v);
 }
-PETSC_DEPRECATED_FUNCTION("Use TaoGetSolution() (since version 3.17)") static inline PetscErrorCode TaoGetInitialVector(Tao t, Vec *v)
+PETSC_DEPRECATED_FUNCTION(3, 17, 0, "TaoGetSolution()", ) static inline PetscErrorCode TaoGetInitialVector(Tao t, Vec *v)
 {
   return TaoGetSolution(t, v);
 }
@@ -265,23 +342,23 @@ PETSC_EXTERN PetscErrorCode TaoSetObjectiveAndGradient(Tao, Vec, PetscErrorCode
 PETSC_EXTERN PetscErrorCode TaoGetObjectiveAndGradient(Tao, Vec *, PetscErrorCode (**)(Tao, Vec, PetscReal *, Vec, void *), void **);
 PETSC_EXTERN PetscErrorCode TaoSetHessian(Tao, Mat, Mat, PetscErrorCode (*)(Tao, Vec, Mat, Mat, void *), void *);
 PETSC_EXTERN PetscErrorCode TaoGetHessian(Tao, Mat *, Mat *, PetscErrorCode (**)(Tao, Vec, Mat, Mat, void *), void **);
-PETSC_DEPRECATED_FUNCTION("Use TaoSetObjective() (since version 3.17)") static inline PetscErrorCode TaoSetObjectiveRoutine(Tao t, PetscErrorCode (*f)(Tao, Vec, PetscReal *, void *), void *c)
+PETSC_DEPRECATED_FUNCTION(3, 17, 0, "TaoSetObjective()", ) static inline PetscErrorCode TaoSetObjectiveRoutine(Tao t, PetscErrorCode (*f)(Tao, Vec, PetscReal *, void *), void *c)
 {
   return TaoSetObjective(t, f, c);
 }
-PETSC_DEPRECATED_FUNCTION("Use TaoGetGradient() (since version 3.17)") static inline PetscErrorCode TaoGetGradientVector(Tao t, Vec *v)
+PETSC_DEPRECATED_FUNCTION(3, 17, 0, "TaoGetGradient()", ) static inline PetscErrorCode TaoGetGradientVector(Tao t, Vec *v)
 {
-  return TaoGetGradient(t, v, NULL, NULL);
+  return TaoGetGradient(t, v, PETSC_NULLPTR, PETSC_NULLPTR);
 }
-PETSC_DEPRECATED_FUNCTION("Use TaoSetGradient() (since version 3.17)") static inline PetscErrorCode TaoSetGradientRoutine(Tao t, PetscErrorCode (*f)(Tao, Vec, Vec, void *), void *c)
+PETSC_DEPRECATED_FUNCTION(3, 17, 0, "TaoSetGradient()", ) static inline PetscErrorCode TaoSetGradientRoutine(Tao t, PetscErrorCode (*f)(Tao, Vec, Vec, void *), void *c)
 {
-  return TaoSetGradient(t, NULL, f, c);
+  return TaoSetGradient(t, PETSC_NULLPTR, f, c);
 }
-PETSC_DEPRECATED_FUNCTION("Use TaoSetObjectiveAndGradient() (since version 3.17)") static inline PetscErrorCode TaoSetObjectiveAndGradientRoutine(Tao t, PetscErrorCode (*f)(Tao, Vec, PetscReal *, Vec, void *), void *c)
+PETSC_DEPRECATED_FUNCTION(3, 17, 0, "TaoSetObjectiveAndGradient()", ) static inline PetscErrorCode TaoSetObjectiveAndGradientRoutine(Tao t, PetscErrorCode (*f)(Tao, Vec, PetscReal *, Vec, void *), void *c)
 {
-  return TaoSetObjectiveAndGradient(t, NULL, f, c);
+  return TaoSetObjectiveAndGradient(t, PETSC_NULLPTR, f, c);
 }
-PETSC_DEPRECATED_FUNCTION("Use TaoSetHessian() (since version 3.17)") static inline PetscErrorCode TaoSetHessianRoutine(Tao t, Mat H, Mat P, PetscErrorCode (*f)(Tao, Vec, Mat, Mat, void *), void *c)
+PETSC_DEPRECATED_FUNCTION(3, 17, 0, "TaoSetHessian()", ) static inline PetscErrorCode TaoSetHessianRoutine(Tao t, Mat H, Mat P, PetscErrorCode (*f)(Tao, Vec, Mat, Mat, void *), void *c)
 {
   return TaoSetHessian(t, H, P, f, c);
 }
@@ -315,11 +392,11 @@ PETSC_EXTERN PetscErrorCode TaoShellSetSolve(Tao, PetscErrorCode (*)(Tao));
 PETSC_EXTERN PetscErrorCode TaoShellSetContext(Tao, void *);
 PETSC_EXTERN PetscErrorCode TaoShellGetContext(Tao, void *);
 
-PETSC_DEPRECATED_FUNCTION("Use TaoSetResidualRoutine() (since version 3.11)") static inline PetscErrorCode TaoSetSeparableObjectiveRoutine(Tao tao, Vec res, PetscErrorCode (*func)(Tao, Vec, Vec, void *), void *ctx)
+PETSC_DEPRECATED_FUNCTION(3, 11, 0, "TaoSetResidualRoutine()", ) static inline PetscErrorCode TaoSetSeparableObjectiveRoutine(Tao tao, Vec res, PetscErrorCode (*func)(Tao, Vec, Vec, void *), void *ctx)
 {
   return TaoSetResidualRoutine(tao, res, func, ctx);
 }
-PETSC_DEPRECATED_FUNCTION("Use TaoSetResidualWeights() (since version 3.11)") static inline PetscErrorCode TaoSetSeparableObjectiveWeights(Tao tao, Vec sigma_v, PetscInt n, PetscInt *rows, PetscInt *cols, PetscReal *vals)
+PETSC_DEPRECATED_FUNCTION(3, 11, 0, "TaoSetResidualWeights()", ) static inline PetscErrorCode TaoSetSeparableObjectiveWeights(Tao tao, Vec sigma_v, PetscInt n, PetscInt *rows, PetscInt *cols, PetscReal *vals)
 {
   return TaoSetResidualWeights(tao, sigma_v, n, rows, cols, vals);
 }
@@ -339,7 +416,7 @@ PETSC_EXTERN PetscErrorCode TaoIsObjectiveDefined(Tao, PetscBool *);
 PETSC_EXTERN PetscErrorCode TaoIsGradientDefined(Tao, PetscBool *);
 PETSC_EXTERN PetscErrorCode TaoIsObjectiveAndGradientDefined(Tao, PetscBool *);
 
-PETSC_DEPRECATED_FUNCTION("Use TaoComputeResidual() (since version 3.11)") static inline PetscErrorCode TaoComputeSeparableObjective(Tao tao, Vec X, Vec F)
+PETSC_DEPRECATED_FUNCTION(3, 11, 0, "TaoComputeResidual()", ) static inline PetscErrorCode TaoComputeSeparableObjective(Tao tao, Vec X, Vec F)
 {
   return TaoComputeResidual(tao, X, F);
 }
@@ -403,7 +480,7 @@ PETSC_EXTERN PetscErrorCode TaoGetConvergenceHistory(Tao, PetscReal **, PetscRea
 PETSC_EXTERN PetscErrorCode TaoSetMonitor(Tao, PetscErrorCode (*)(Tao, void *), void *, PetscErrorCode (*)(void **));
 PETSC_EXTERN PetscErrorCode TaoCancelMonitors(Tao);
 PETSC_EXTERN PetscErrorCode TaoMonitorDefault(Tao, void *);
-PETSC_DEPRECATED_FUNCTION("Use TaoMonitorDefault() (since version 3.9)") static inline PetscErrorCode TaoDefaultMonitor(Tao tao, void *ctx)
+PETSC_DEPRECATED_FUNCTION(3, 9, 0, "TaoMonitorDefault()", ) static inline PetscErrorCode TaoDefaultMonitor(Tao tao, void *ctx)
 {
   return TaoMonitorDefault(tao, ctx);
 }
@@ -435,6 +512,8 @@ PETSC_EXTERN PetscErrorCode TaoBRGNSetRegularizerWeight(Tao, PetscReal);
 PETSC_EXTERN PetscErrorCode TaoBRGNSetL1SmoothEpsilon(Tao, PetscReal);
 PETSC_EXTERN PetscErrorCode TaoBRGNSetDictionaryMatrix(Tao, Mat);
 PETSC_EXTERN PetscErrorCode TaoBRGNGetDampingVector(Tao, Vec *);
+PETSC_EXTERN PetscErrorCode TaoBNCGSetType(Tao, TaoBNCGType);
+PETSC_EXTERN PetscErrorCode TaoBNCGGetType(Tao, TaoBNCGType *);
 
 PETSC_EXTERN PetscErrorCode TaoADMMGetMisfitSubsolver(Tao, Tao *);
 PETSC_EXTERN PetscErrorCode TaoADMMGetRegularizationSubsolver(Tao, Tao *);
@@ -444,6 +523,7 @@ PETSC_EXTERN PetscErrorCode TaoADMMSetSpectralPenalty(Tao, PetscReal);
 PETSC_EXTERN PetscErrorCode TaoGetADMMParentTao(Tao, Tao *);
 PETSC_EXTERN PetscErrorCode TaoADMMSetConstraintVectorRHS(Tao, Vec);
 PETSC_EXTERN PetscErrorCode TaoADMMSetRegularizerCoefficient(Tao, PetscReal);
+PETSC_EXTERN PetscErrorCode TaoADMMGetRegularizerCoefficient(Tao, PetscReal *);
 PETSC_EXTERN PetscErrorCode TaoADMMSetMisfitConstraintJacobian(Tao, Mat, Mat, PetscErrorCode (*)(Tao, Vec, Mat, Mat, void *), void *);
 PETSC_EXTERN PetscErrorCode TaoADMMSetRegularizerConstraintJacobian(Tao, Mat, Mat, PetscErrorCode (*)(Tao, Vec, Mat, Mat, void *), void *);
 PETSC_EXTERN PetscErrorCode TaoADMMSetRegularizerHessianRoutine(Tao, Mat, Mat, PetscErrorCode (*)(Tao, Vec, Mat, Mat, void *), void *);
@@ -466,4 +546,10 @@ PETSC_EXTERN PetscErrorCode TaoALMMGetMultipliers(Tao, Vec *);
 PETSC_EXTERN PetscErrorCode TaoALMMSetMultipliers(Tao, Vec);
 PETSC_EXTERN PetscErrorCode TaoALMMGetPrimalIS(Tao, IS *, IS *);
 PETSC_EXTERN PetscErrorCode TaoALMMGetDualIS(Tao, IS *, IS *);
-#endif
+
+PETSC_EXTERN PetscErrorCode TaoVecGetSubVec(Vec, IS, TaoSubsetType, PetscReal, Vec *);
+PETSC_EXTERN PetscErrorCode TaoMatGetSubMat(Mat, IS, Vec, TaoSubsetType, Mat *);
+PETSC_EXTERN PetscErrorCode TaoGradientNorm(Tao, Vec, NormType, PetscReal *);
+PETSC_EXTERN PetscErrorCode TaoEstimateActiveBounds(Vec, Vec, Vec, Vec, Vec, Vec, PetscReal, PetscReal *, IS *, IS *, IS *, IS *, IS *);
+PETSC_EXTERN PetscErrorCode TaoBoundStep(Vec, Vec, Vec, IS, IS, IS, PetscReal, Vec);
+PETSC_EXTERN PetscErrorCode TaoBoundSolution(Vec, Vec, Vec, PetscReal, PetscInt *, Vec);
