@@ -3,8 +3,7 @@
   degrees of freedom for finite element/finite difference functions
   on a grid. They have more mathematical structure then simple arrays.
 */
-#ifndef PETSCVEC_H
-#define PETSCVEC_H
+#pragma once
 
 #include <petscsys.h>
 #include <petscsftypes.h> /* for VecScatter, VecScatterType */
@@ -15,10 +14,13 @@
 /* SUBMANSEC = Vec */
 
 /*S
-     Vec - Abstract PETSc vector object
+   Vec - Abstract PETSc vector object. Used for holding solutions and right-hand sides for (non) linear systems and integrators
 
    Level: beginner
 
+   Note:
+   Internally the actual vector representation is generally a simple array but most PETSc code can work on other representations through this abstraction
+
 .seealso: [](doc_vector), [](ch_vectors), `VecCreate()`, `VecType`, `VecSetType()`
 S*/
 typedef struct _p_Vec *Vec;
@@ -27,8 +29,8 @@ typedef struct _p_Vec *Vec;
   ScatterMode - Determines the direction of a scatter
 
   Values:
-+  `SCATTER_FORWARD` - Scatters the values as dictated by the `VecScatterCreate()` call
-.  `SCATTER_REVERSE` - Moves the values in the opposite direction than the directions indicated in the `VecScatterCreate()` call
++  `SCATTER_FORWARD`       - Scatters the values as dictated by the `VecScatterCreate()` call
+.  `SCATTER_REVERSE`       - Moves the values in the opposite direction than the directions indicated in the `VecScatterCreate()` call
 .  `SCATTER_FORWARD_LOCAL` - Scatters the values as dictated by the `VecScatterCreate()` call except NO MPI communication is done
 -  `SCATTER_REVERSE_LOCAL` - Moves the values in the opposite direction than the directions indicated in the `VecScatterCreate()` call
                              except NO MPI communication is done
@@ -55,7 +57,7 @@ M*/
 
 /*MC
     SCATTER_REVERSE - Moves the values in the opposite direction then the directions indicated in
-         in the `VecScatterCreate()`
+                      in the `VecScatterCreate()`
 
     Level: beginner
 
@@ -65,7 +67,7 @@ M*/
 
 /*MC
     SCATTER_FORWARD_LOCAL - Scatters the values as dictated by the `VecScatterCreate()` call except NO parallel communication
-       is done. Any variables that have be moved between processes are ignored
+                            is done. Any variables that have be moved between processes are ignored
 
     Level: developer
 
@@ -75,8 +77,8 @@ M*/
 
 /*MC
     SCATTER_REVERSE_LOCAL - Moves the values in the opposite direction then the directions indicated in
-         in the `VecScatterCreate()`  except NO parallel communication
-       is done. Any variables that have be moved between processes are ignored
+                           in the `VecScatterCreate()`  except NO parallel communication
+                           is done. Any variables that have be moved between processes are ignored
 
     Level: developer
 
@@ -85,7 +87,7 @@ M*/
 M*/
 
 /*J
-    VecType - String with the name of a PETSc vector
+   VecType - String with the name of a PETSc vector type
 
    Level: beginner
 
@@ -94,21 +96,21 @@ J*/
 typedef const char *VecType;
 #define VECSEQ         "seq"
 #define VECMPI         "mpi"
-#define VECSTANDARD    "standard" /* seq on one process and mpi on several */
+#define VECSTANDARD    "standard" /* seq on one process and mpi on multiple */
 #define VECSHARED      "shared"
 #define VECSEQVIENNACL "seqviennacl"
 #define VECMPIVIENNACL "mpiviennacl"
-#define VECVIENNACL    "viennacl" /* seqviennacl on one process and mpiviennacl on several */
+#define VECVIENNACL    "viennacl" /* seqviennacl on one process and mpiviennacl on multiple */
 #define VECSEQCUDA     "seqcuda"
 #define VECMPICUDA     "mpicuda"
-#define VECCUDA        "cuda" /* seqcuda on one process and mpicuda on several */
+#define VECCUDA        "cuda" /* seqcuda on one process and mpicuda on multiple */
 #define VECSEQHIP      "seqhip"
 #define VECMPIHIP      "mpihip"
-#define VECHIP         "hip" /* seqcuda on one process and mpicuda on several */
+#define VECHIP         "hip" /* seqhip on one process and mpihip on multiple */
 #define VECNEST        "nest"
 #define VECSEQKOKKOS   "seqkokkos"
 #define VECMPIKOKKOS   "mpikokkos"
-#define VECKOKKOS      "kokkos" /* seqkokkos on one process and mpikokkos on several */
+#define VECKOKKOS      "kokkos" /* seqkokkos on one process and mpikokkos on multiple */
 
 /* Dynamic creation and loading functions */
 PETSC_EXTERN PetscErrorCode VecScatterSetType(VecScatter, VecScatterType);
@@ -127,12 +129,12 @@ PETSC_EXTERN PetscErrorCode VecInitializePackage(void);
 PETSC_EXTERN PetscErrorCode VecFinalizePackage(void);
 
 PETSC_EXTERN PetscErrorCode VecCreate(MPI_Comm, Vec *);
+PETSC_EXTERN PetscErrorCode VecCreateFromOptions(MPI_Comm, const char *, PetscInt, PetscInt, PetscInt, Vec *);
 PETSC_EXTERN PetscErrorCode VecCreateSeq(MPI_Comm, PetscInt, Vec *);
 PETSC_EXTERN PetscErrorCode VecCreateMPI(MPI_Comm, PetscInt, PetscInt, Vec *);
 PETSC_EXTERN PetscErrorCode VecCreateSeqWithArray(MPI_Comm, PetscInt, PetscInt, const PetscScalar[], Vec *);
 PETSC_EXTERN PetscErrorCode VecCreateMPIWithArray(MPI_Comm, PetscInt, PetscInt, PetscInt, const PetscScalar[], Vec *);
 PETSC_EXTERN PetscErrorCode VecCreateShared(MPI_Comm, PetscInt, PetscInt, Vec *);
-PETSC_EXTERN PetscErrorCode VecCreateNode(MPI_Comm, PetscInt, PetscInt, Vec *);
 
 PETSC_EXTERN PetscErrorCode VecSetFromOptions(Vec);
 PETSC_EXTERN PetscErrorCode VecViewFromOptions(Vec, PetscObject, const char[]);
@@ -160,16 +162,16 @@ PETSC_EXTERN PetscErrorCode VecConcatenate(PetscInt, const Vec[], Vec *, IS *[])
     NormType - determines what type of norm to compute
 
     Values:
-+    `NORM_1` - the one norm, ||v|| = sum_i | v_i |. ||A|| = max_j || v_*j ||, maximum column sum
-.    `NORM_2` - the two norm, ||v|| = sqrt(sum_i |v_i|^2) (vectors only)
-.    `NORM_FROBENIUS` - ||A|| = sqrt(sum_ij |A_ij|^2), same as `NORM_2` for vectors
-.    `NORM_INFINITY` - ||v|| = max_i |v_i|. ||A|| = max_i || v_i* ||, maximum row sum
--    `NORM_1_AND_2` - computes both the 1 and 2 norm of a vector
++    `NORM_1`         - the one norm, $||v|| = \sum_i | v_i |$. $||A|| = \max_j || v_*j ||$, maximum column sum
+.    `NORM_2`         - the two norm, $||v|| = sqrt(\sum_i |v_i|^2)$ (vectors only)
+.    `NORM_FROBENIUS` - $||A|| = sqrt(\sum_ij |A_ij|^2)$, same as `NORM_2` for vectors
+.    `NORM_INFINITY`  - $||v|| = \max_i |v_i|$. $||A|| = \max_i || v_i* ||$, maximum row sum
+-    `NORM_1_AND_2`   - computes both the 1 and 2 norm of a vector. The values are stored in two adjacent `PetscReal` memory locations
 
     Level: beginner
 
-  Note:
-  The `v` above represents a `Vec` while the `A` represents a `Mat`
+    Note:
+    The `v` above represents a `Vec` while the `A` represents a `Mat`
 
 .seealso: [](ch_vectors), `Vec`, `Mat`, `VecNorm()`, `VecNormBegin()`, `VecNormEnd()`, `MatNorm()`, `NORM_1`,
           `NORM_2`, `NORM_FROBENIUS`, `NORM_INFINITY`, `NORM_1_AND_2`
@@ -185,7 +187,7 @@ PETSC_EXTERN const char *const NormTypes[];
 #define NORM_MAX NORM_INFINITY
 
 /*MC
-     NORM_1 - the one norm, ||v|| = sum_i | v_i |. ||A|| = max_j || v_*j ||, maximum column sum
+   NORM_1 - the one norm, $||v|| = \sum_i | v_i |$. $||A|| = \max_j || v_{*,j} ||$, maximum column sum
 
    Level: beginner
 
@@ -194,7 +196,7 @@ PETSC_EXTERN const char *const NormTypes[];
 M*/
 
 /*MC
-     NORM_2 - the two norm, ||v|| = sqrt(sum_i |v_i|^2) (vectors only)
+   NORM_2 - the two norm, $||v|| = \sqrt{\sum_i |v_i|^2}$ (vectors only)
 
    Level: beginner
 
@@ -203,7 +205,7 @@ M*/
 M*/
 
 /*MC
-     NORM_FROBENIUS - ||A|| = sqrt(sum_ij |A_ij|^2), same as `NORM_2` for vectors
+   NORM_FROBENIUS - $||A|| = \sqrt{\sum_{i,j} |A_{i,j}|^2}$, same as `NORM_2` for vectors
 
    Level: beginner
 
@@ -212,7 +214,7 @@ M*/
 M*/
 
 /*MC
-     NORM_INFINITY - ||v|| = max_i |v_i|. ||A|| = max_i || v_i* ||, maximum row sum
+   NORM_INFINITY - $||v|| = \max_i |v_i|$. $||A|| = \max_i || v_{i,*} ||$, maximum row sum
 
    Level: beginner
 
@@ -221,7 +223,7 @@ M*/
 M*/
 
 /*MC
-     NORM_1_AND_2 - computes both the 1 and 2 norm of a vector. The values are stored in two adjacent `PetscReal` memory locations
+   NORM_1_AND_2 - computes both the 1 and 2 norm of a vector. The values are stored in two adjacent `PetscReal` memory locations
 
    Level: beginner
 
@@ -230,7 +232,7 @@ M*/
 M*/
 
 /*MC
-     NORM_MAX - see `NORM_INFINITY`
+   NORM_MAX - see `NORM_INFINITY`
 
    Level: beginner
 M*/
@@ -239,17 +241,17 @@ M*/
     ReductionType - determines what type of column reduction (one that is not a type of norm defined in `NormType`) to compute
 
     Values:
-+  `REDUCTION_SUM_REALPART` - sum of real part of each matrix column
-.  `REDUCTION_SUM_IMAGINARYPART` - sum of imaginary part of each matrix column
-.  `REDUCTION_MEAN_REALPART` - arithmetic mean of real part of each matrix column
++  `REDUCTION_SUM_REALPART`       - sum of real part of each matrix column
+.  `REDUCTION_SUM_IMAGINARYPART`  - sum of imaginary part of each matrix column
+.  `REDUCTION_MEAN_REALPART`      - arithmetic mean of real part of each matrix column
 -  `REDUCTION_MEAN_IMAGINARYPART` - arithmetic mean of imaginary part of each matrix column
 
     Level: beginner
 
     Developer Note:
-  The constants defined in `ReductionType` MUST BE DISTINCT from those defined in `NormType`.
-  This is because `MatGetColumnReductions()` is used to compute both norms and other types of reductions,
-  and the constants defined in both `NormType` and `ReductionType` are used to designate the desired operation.
+    The constants defined in `ReductionType` MUST BE DISTINCT from those defined in `NormType`.
+   This is because `MatGetColumnReductions()` is used to compute both norms and other types of reductions,
+   and the constants defined in both `NormType` and `ReductionType` are used to designate the desired operation.
 
 .seealso: [](ch_vectors), `MatGetColumnReductions()`, `MatGetColumnNorms()`, `NormType`, `REDUCTION_SUM_REALPART`,
           `REDUCTION_SUM_IMAGINARYPART`, `REDUCTION_MEAN_REALPART`, `REDUCTION_NORM_1`, `REDUCTION_NORM_2`, `REDUCTION_NORM_FROBENIUS`, `REDUCTION_NORM_INFINITY`
@@ -262,7 +264,7 @@ typedef enum {
 } ReductionType;
 
 /*MC
-     REDUCTION_SUM_REALPART - sum of real part of matrix column
+   REDUCTION_SUM_REALPART - sum of real part of matrix column
 
    Level: beginner
 
@@ -271,7 +273,7 @@ typedef enum {
 M*/
 
 /*MC
-     REDUCTION_SUM_IMAGINARYPART - sum of imaginary part of matrix column
+   REDUCTION_SUM_IMAGINARYPART - sum of imaginary part of matrix column
 
    Level: beginner
 
@@ -280,7 +282,7 @@ M*/
 M*/
 
 /*MC
-     REDUCTION_MEAN_REALPART - arithmetic mean of real part of matrix column
+   REDUCTION_MEAN_REALPART - arithmetic mean of real part of matrix column
 
    Level: beginner
 
@@ -289,7 +291,7 @@ M*/
 M*/
 
 /*MC
-     REDUCTION_MEAN_IMAGINARYPART - arithmetic mean of imaginary part of matrix column
+   REDUCTION_MEAN_IMAGINARYPART - arithmetic mean of imaginary part of matrix column
 
    Level: beginner
 
@@ -313,6 +315,7 @@ PETSC_EXTERN PetscErrorCode VecSwap(Vec, Vec);
 PETSC_EXTERN PetscErrorCode VecAXPY(Vec, PetscScalar, Vec);
 PETSC_EXTERN PetscErrorCode VecAXPBY(Vec, PetscScalar, PetscScalar, Vec);
 PETSC_EXTERN PetscErrorCode VecMAXPY(Vec, PetscInt, const PetscScalar[], Vec[]);
+PETSC_EXTERN PetscErrorCode VecMAXPBY(Vec, PetscInt, const PetscScalar[], PetscScalar, Vec[]);
 PETSC_EXTERN PetscErrorCode VecAYPX(Vec, PetscScalar, Vec);
 PETSC_EXTERN PetscErrorCode VecWAXPY(Vec, PetscScalar, Vec, Vec);
 PETSC_EXTERN PetscErrorCode VecAXPBYPCZ(Vec, PetscScalar, PetscScalar, PetscScalar, Vec, Vec);
@@ -377,10 +380,10 @@ PETSC_EXTERN PetscErrorCode VecSetValuesCOO(Vec, const PetscScalar[], InsertMode
    Not Collective
 
    Input Parameters:
-+  v - the vector
-.  row - the row location of the entry
++  v     - the vector
+.  row   - the row location of the entry
 .  value - the value to insert
--  mode - either `INSERT_VALUES` or `ADD_VALUES`
+-  mode  - either `INSERT_VALUES` or `ADD_VALUES`
 
    Level: beginner
 
@@ -409,6 +412,7 @@ PETSC_EXTERN PetscFunctionList VecList;
 PETSC_EXTERN PetscErrorCode    VecSetType(Vec, VecType);
 PETSC_EXTERN PetscErrorCode    VecGetType(Vec, VecType *);
 PETSC_EXTERN PetscErrorCode    VecRegister(const char[], PetscErrorCode (*)(Vec));
+PETSC_EXTERN PetscErrorCode    VecRegisterAll(void);
 
 PETSC_EXTERN PetscErrorCode VecScatterBegin(VecScatter, Vec, Vec, InsertMode, ScatterMode);
 PETSC_EXTERN PetscErrorCode VecScatterEnd(VecScatter, Vec, Vec, InsertMode, ScatterMode);
@@ -486,10 +490,10 @@ PETSC_EXTERN PetscErrorCode VecViennaCLRestoreCLMem(Vec);
    Not Collective
 
    Input Parameters:
-+  v - the vector
-.  row - the row location of the entry
++  v     - the vector
+.  row   - the row location of the entry
 .  value - the value to insert
--  mode - either `INSERT_VALUES` or `ADD_VALUES`
+-  mode  - either `INSERT_VALUES` or `ADD_VALUES`
 
    Level: beginner
 
@@ -528,7 +532,7 @@ static inline PetscErrorCode VecSetValueLocal(Vec v, PetscInt i, PetscScalar va,
 
 .seealso: [](ch_vectors), `Vec`, `VecSetValues()`, `VecAssemblyBegin()`, `VecAssemblyEnd()`, `MatAssemblyBegin()`, `MatAssemblyEnd()`
 M*/
-#define VecCheckAssembled(v) PetscCheck(v->stash.insertmode == NOT_SET_VALUES, PETSC_COMM_SELF, PETSC_ERR_ARG_WRONGSTATE, "Not for unassembled vector, did you call VecAssemblyBegin()/VecAssemblyEnd()?");
+#define VecCheckAssembled(v) PetscCheck(v->stash.insertmode == NOT_SET_VALUES, PETSC_COMM_SELF, PETSC_ERR_ARG_WRONGSTATE, "Not for unassembled vector, did you call VecAssemblyBegin()/VecAssemblyEnd()?")
 
 PETSC_EXTERN PetscErrorCode VecSetValuesBlockedLocal(Vec, PetscInt, const PetscInt[], const PetscScalar[], InsertMode);
 PETSC_EXTERN PetscErrorCode VecGetLocalToGlobalMapping(Vec, ISLocalToGlobalMapping *);
@@ -539,6 +543,7 @@ PETSC_EXTERN PetscErrorCode VecTDotBegin(Vec, Vec, PetscScalar *);
 PETSC_EXTERN PetscErrorCode VecTDotEnd(Vec, Vec, PetscScalar *);
 PETSC_EXTERN PetscErrorCode VecNormBegin(Vec, NormType, PetscReal *);
 PETSC_EXTERN PetscErrorCode VecNormEnd(Vec, NormType, PetscReal *);
+PETSC_EXTERN PetscErrorCode VecErrorWeightedNorms(Vec, Vec, Vec, NormType, PetscReal, Vec, PetscReal, Vec, PetscReal, PetscReal *, PetscInt *, PetscReal *, PetscInt *, PetscReal *, PetscInt *);
 
 PETSC_EXTERN PetscErrorCode VecMDotBegin(Vec, PetscInt, const Vec[], PetscScalar[]);
 PETSC_EXTERN PetscErrorCode VecMDotEnd(Vec, PetscInt, const Vec[], PetscScalar[]);
@@ -547,7 +552,7 @@ PETSC_EXTERN PetscErrorCode VecMTDotEnd(Vec, PetscInt, const Vec[], PetscScalar[
 PETSC_EXTERN PetscErrorCode PetscCommSplitReductionBegin(MPI_Comm);
 
 PETSC_EXTERN PetscErrorCode VecBindToCPU(Vec, PetscBool);
-PETSC_DEPRECATED_FUNCTION("Use VecBindToCPU (since v3.13)") static inline PetscErrorCode VecPinToCPU(Vec v, PetscBool flg)
+PETSC_DEPRECATED_FUNCTION(3, 13, 0, "VecBindToCPU()", ) static inline PetscErrorCode VecPinToCPU(Vec v, PetscBool flg)
 {
   return VecBindToCPU(v, flg);
 }
@@ -585,7 +590,7 @@ PETSC_EXTERN PetscErrorCode VecGetArrayWriteAndMemType(Vec, PetscScalar **, Pets
 PETSC_EXTERN PetscErrorCode VecRestoreArrayWriteAndMemType(Vec, PetscScalar **);
 
 /*@C
-   VecGetArrayPair - Accesses a pair of pointers for two vectors that may be common. When not common the first pointer is read only
+   VecGetArrayPair - Accesses a pair of pointers for two vectors that may be common. When the vectors are not the same the first pointer is read only
 
    Logically Collective; No Fortran Support
 
@@ -616,8 +621,8 @@ static inline PetscErrorCode VecGetArrayPair(Vec x, Vec y, PetscScalar **xv, Pet
    Logically Collective; No Fortran Support
 
    Input Parameters:
-+  x - the vector
-.  y - the second vector
++  x  - the vector
+.  y  - the second vector
 .  xv - location to put pointer to the first array
 -  yv - location to put pointer to the second array
 
@@ -633,7 +638,7 @@ static inline PetscErrorCode VecRestoreArrayPair(Vec x, Vec y, PetscScalar **xv,
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-#if defined(PETSC_USE_DEBUG)
+#if PetscDefined(USE_DEBUG)
 PETSC_EXTERN PetscErrorCode  VecLockReadPush(Vec);
 PETSC_EXTERN PetscErrorCode  VecLockReadPop(Vec);
 PETSC_EXTERN PetscErrorCode  VecLockWriteSet(Vec, PetscBool);
@@ -656,9 +661,9 @@ static inline PetscErrorCode VecSetErrorIfLocked(Vec x, PetscInt arg)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 /* The three are deprecated */
-PETSC_EXTERN PETSC_DEPRECATED_FUNCTION("Use VecLockReadPush() (since version 3.11)") PetscErrorCode VecLockPush(Vec);
-PETSC_EXTERN PETSC_DEPRECATED_FUNCTION("Use VecLockReadPop() (since version 3.11)") PetscErrorCode VecLockPop(Vec);
-  #define VecLocked(x, arg) VecSetErrorIfLocked(x, arg) PETSC_DEPRECATED_MACRO("GCC warning \"Use VecSetErrorIfLocked() (since version 3.11)\"")
+PETSC_EXTERN PETSC_DEPRECATED_FUNCTION(3, 11, 0, "VecLockReadPush()", ) PetscErrorCode VecLockPush(Vec);
+PETSC_EXTERN PETSC_DEPRECATED_FUNCTION(3, 11, 0, "VecLockReadPop()", ) PetscErrorCode VecLockPop(Vec);
+  #define VecLocked(x, arg) VecSetErrorIfLocked(x, arg) PETSC_DEPRECATED_MACRO(3, 11, 0, "VecSetErrorIfLocked()", )
 #else
   #define VecLockReadPush(x)          PETSC_SUCCESS
   #define VecLockReadPop(x)           PETSC_SUCCESS
@@ -747,16 +752,16 @@ PETSC_EXTERN PetscErrorCode PetscViewerMathematicaGetVector(PetscViewer, Vec);
 PETSC_EXTERN PetscErrorCode PetscViewerMathematicaPutVector(PetscViewer, Vec);
 
 /*S
-     Vecs - Collection of vectors where the data for the vectors is stored in
-            one contiguous memory
+   Vecs - Collection of vectors where the data for the vectors is stored in
+          one contiguous memory
 
    Level: advanced
 
    Notes:
-    Temporary construct for handling multiply right hand side solves
+   Temporary construct for handling multiply right hand side solves
 
-    This is faked by storing a single vector that has enough array space for
-    n vectors
+   This is faked by storing a single vector that has enough array space for
+   n vectors
 
 S*/
 struct _n_Vecs {
@@ -769,20 +774,18 @@ PETSC_EXTERN PetscErrorCode VecsCreateSeq(MPI_Comm, PetscInt, PetscInt, Vecs *);
 PETSC_EXTERN PetscErrorCode VecsCreateSeqWithArray(MPI_Comm, PetscInt, PetscInt, PetscScalar *, Vecs *);
 PETSC_EXTERN PetscErrorCode VecsDuplicate(Vecs, Vecs *);
 
-#if defined(PETSC_HAVE_VIENNACL)
+#if PetscDefined(HAVE_VIENNACL)
 typedef struct _p_PetscViennaCLIndices *PetscViennaCLIndices;
-PETSC_EXTERN PetscErrorCode             PetscViennaCLIndicesCreate(PetscInt, PetscInt *, PetscInt, PetscInt *, PetscViennaCLIndices *);
-PETSC_EXTERN PetscErrorCode             PetscViennaCLIndicesDestroy(PetscViennaCLIndices *);
 PETSC_EXTERN PetscErrorCode             VecViennaCLCopyToGPUSome_Public(Vec, PetscViennaCLIndices);
 PETSC_EXTERN PetscErrorCode             VecViennaCLCopyFromGPUSome_Public(Vec, PetscViennaCLIndices);
 PETSC_EXTERN PetscErrorCode             VecCreateSeqViennaCL(MPI_Comm, PetscInt, Vec *);
 PETSC_EXTERN PetscErrorCode             VecCreateMPIViennaCL(MPI_Comm, PetscInt, PetscInt, Vec *);
 #endif
-#if defined(PETSC_HAVE_CUDA) || defined(PETSC_HAVE_HIP)
+#if PetscDefined(HAVE_CUDA) || PetscDefined(HAVE_HIP)
 PETSC_EXTERN PetscErrorCode VecScatterInitializeForGPU(VecScatter, Vec);
 PETSC_EXTERN PetscErrorCode VecScatterFinalizeForGPU(VecScatter);
 #endif
-#if defined(PETSC_HAVE_KOKKOS_KERNELS)
+#if PetscDefined(HAVE_KOKKOS_KERNELS)
 PETSC_EXTERN PetscErrorCode VecCreateSeqKokkos(MPI_Comm, PetscInt, Vec *);
 PETSC_EXTERN PetscErrorCode VecCreateSeqKokkosWithArray(MPI_Comm, PetscInt, PetscInt, const PetscScalar *, Vec *);
 PETSC_EXTERN PetscErrorCode VecCreateMPIKokkos(MPI_Comm, PetscInt, PetscInt, Vec *);
@@ -797,14 +800,18 @@ PETSC_EXTERN PetscErrorCode VecCreateNest(MPI_Comm, PetscInt, IS *, Vec *, Vec *
 PETSC_EXTERN PetscErrorCode VecNestGetSize(Vec, PetscInt *);
 
 PETSC_EXTERN PetscErrorCode PetscOptionsGetVec(PetscOptions, const char[], const char[], Vec, PetscBool *);
-PETSC_EXTERN PetscErrorCode VecChop(Vec, PetscReal);
+PETSC_EXTERN PetscErrorCode VecFilter(Vec, PetscReal);
+PETSC_DEPRECATED_FUNCTION(3, 20, 0, "VecFilter()", ) static inline PetscErrorCode VecChop(Vec v, PetscReal tol)
+{
+  return VecFilter(v, tol);
+}
 
 PETSC_EXTERN PetscErrorCode VecGetLayout(Vec, PetscLayout *);
 PETSC_EXTERN PetscErrorCode VecSetLayout(Vec, PetscLayout);
 
 PETSC_EXTERN PetscErrorCode PetscSectionVecView(PetscSection, Vec, PetscViewer);
 PETSC_EXTERN PetscErrorCode VecGetValuesSection(Vec, PetscSection, PetscInt, PetscScalar **);
-PETSC_EXTERN PetscErrorCode VecSetValuesSection(Vec, PetscSection, PetscInt, PetscScalar[], InsertMode);
+PETSC_EXTERN PetscErrorCode VecSetValuesSection(Vec, PetscSection, PetscInt, const PetscScalar[], InsertMode);
 PETSC_EXTERN PetscErrorCode PetscSectionVecNorm(PetscSection, PetscSection, Vec, NormType, PetscReal[]);
 
 /*S
@@ -815,9 +822,9 @@ PETSC_EXTERN PetscErrorCode PetscSectionVecNorm(PetscSection, PetscSection, Vec,
   Values:
 +  `VECTAGGERABSOLUTE` - "absolute" values are in a interval (box for complex values) of explicitly defined values
 .  `VECTAGGERRELATIVE` - "relative" values are in a interval (box for complex values) of values relative to the set of all values in the vector
-.  `VECTAGGERCDF` - "cdf" values are in a relative range of the *cumulative distribution* of values in the vector
-.  `VECTAGGEROR` - "or" values are in the union of other tags
--  `VECTAGGERAND` - "and" values are in the intersection of other tags
+.  `VECTAGGERCDF`      - "cdf" values are in a relative range of the *cumulative distribution* of values in the vector
+.  `VECTAGGEROR`       - "or" values are in the union of other tags
+-  `VECTAGGERAND`      - "and" values are in the intersection of other tags
 
   Level: advanced
 
@@ -845,6 +852,7 @@ typedef const char *VecTaggerType;
 PETSC_EXTERN PetscClassId      VEC_TAGGER_CLASSID;
 PETSC_EXTERN PetscFunctionList VecTaggerList;
 PETSC_EXTERN PetscErrorCode    VecTaggerRegister(const char[], PetscErrorCode (*)(VecTagger));
+PETSC_EXTERN PetscErrorCode    VecTaggerRegisterAll(void);
 
 PETSC_EXTERN PetscErrorCode VecTaggerCreate(MPI_Comm, VecTagger *);
 PETSC_EXTERN PetscErrorCode VecTaggerSetBlockSize(VecTagger, PetscInt);
@@ -886,7 +894,7 @@ PETSC_EXTERN PetscErrorCode VecTaggerCDFGetBox(VecTagger, const VecTaggerBox **)
   VecTaggerCDFMethod - Determines what method is used to compute absolute values from cumulative distribution values (e.g., what value is the preimage of .95 in the cdf).
 
    Values:
-+  `VECTAGGER_CDF_GATHER` - gather results to rank 0, perform the computation and broadcast the result
++  `VECTAGGER_CDF_GATHER`    - gather results to MPI rank 0, perform the computation and broadcast the result
 -  `VECTAGGER_CDF_ITERATIVE` - compute the results on all ranks iteratively using `MPI_Allreduce()`
 
   Level: advanced
@@ -997,5 +1005,3 @@ VEC_HIP__DECL_OR_STUB(PetscErrorCode VecHIPResetArray(Vec a), (void)a)
 #undef VEC_CUPM_NOT_CONFIGURED
 #undef VEC_CUDA_DECL_OR_STUB
 #undef VEC_HIP__DECL_OR_STUB
-
-#endif
