@@ -11,11 +11,12 @@ const char *const DTProbDensityTypes[] = {"constant", "gaussian", "maxwell_boltz
 
   Not Collective
 
-  Input Parameter:
-. x - Speed in [0, \infty]
+  Input Parameters:
++ x     - Speed in $[0, \infty]$
+- dummy - Unused
 
   Output Parameter:
-. p - The probability density at x
+. p - The probability density at `x`
 
   Level: beginner
 
@@ -32,11 +33,12 @@ PetscErrorCode PetscPDFMaxwellBoltzmann1D(const PetscReal x[], const PetscReal d
 
   Not Collective
 
-  Input Parameter:
-. x - Speed in [0, \infty]
+  Input Parameters:
++ x     - Speed in $[0, \infty]$
+- dummy - Unused
 
   Output Parameter:
-. p - The probability density at x
+. p - The probability density at `x`
 
   Level: beginner
 
@@ -53,11 +55,12 @@ PetscErrorCode PetscCDFMaxwellBoltzmann1D(const PetscReal x[], const PetscReal d
 
   Not Collective
 
-  Input Parameter:
-. x - Speed in [0, \infty]
+  Input Parameters:
++ x     - Speed in $[0, \infty]$
+- dummy - Unused
 
   Output Parameter:
-. p - The probability density at x
+. p - The probability density at `x`
 
   Level: beginner
 
@@ -74,11 +77,12 @@ PetscErrorCode PetscPDFMaxwellBoltzmann2D(const PetscReal x[], const PetscReal d
 
   Not Collective
 
-  Input Parameter:
-. x - Speed in [0, \infty]
+  Input Parameters:
++ x     - Speed in $[0, \infty]$
+- dummy - Unused
 
   Output Parameter:
-. p - The probability density at x
+. p - The probability density at `x`
 
   Level: beginner
 
@@ -95,11 +99,12 @@ PetscErrorCode PetscCDFMaxwellBoltzmann2D(const PetscReal x[], const PetscReal d
 
   Not Collective
 
-  Input Parameter:
-. x - Speed in [0, \infty]
+  Input Parameters:
++ x     - Speed in $[0, \infty]$
+- dummy - Unused
 
   Output Parameter:
-. p - The probability density at x
+. p - The probability density at `x`
 
   Level: beginner
 
@@ -116,11 +121,12 @@ PetscErrorCode PetscPDFMaxwellBoltzmann3D(const PetscReal x[], const PetscReal d
 
   Not Collective
 
-  Input Parameter:
-. x - Speed in [0, \infty]
+  Input Parameters:
++ x     - Speed in $[0, \infty]$
+- dummy - Unused
 
   Output Parameter:
-. p - The probability density at x
+. p - The probability density at `x`
 
   Level: beginner
 
@@ -137,11 +143,12 @@ PetscErrorCode PetscCDFMaxwellBoltzmann3D(const PetscReal x[], const PetscReal d
 
   Not Collective
 
-  Input Parameter:
-. x - Coordinate in [-\infty, \infty]
+  Input Parameters:
++ x     - Coordinate in $[-\infty, \infty]$
+- scale - Scaling value
 
   Output Parameter:
-. p - The probability density at x
+. p - The probability density at `x`
 
   Level: beginner
 
@@ -167,16 +174,19 @@ PetscErrorCode PetscCDFGaussian1D(const PetscReal x[], const PetscReal scale[],
   Not Collective
 
   Input Parameters:
-+ p - A uniform variable on [0, 1]
++ p     - A uniform variable on $[0, 1]$
 - dummy - ignored
 
   Output Parameter:
-. x - Coordinate in [-\infty, \infty]
+. x - Coordinate in $[-\infty, \infty]$
 
   Level: beginner
 
-  Note: http://www.mimirgames.com/articles/programming/approximations-of-the-inverse-error-function/
-  https://stackoverflow.com/questions/27229371/inverse-error-function-in-c
+  Note:
+  See <http://www.mimirgames.com/articles/programming/approximations-of-the-inverse-error-function> and
+  <https://stackoverflow.com/questions/27229371/inverse-error-function-in-c>
+
+.seealso: `PetscPDFGaussian2D()`
 @*/
 PetscErrorCode PetscPDFSampleGaussian1D(const PetscReal p[], const PetscReal dummy[], PetscReal x[])
 {
@@ -211,11 +221,11 @@ PetscErrorCode PetscPDFSampleGaussian1D(const PetscReal p[], const PetscReal dum
   Not Collective
 
   Input Parameters:
-+ x - Coordinate in [-\infty, \infty]^2
++ x     - Coordinate in $[-\infty, \infty]^2$
 - dummy - ignored
 
   Output Parameter:
-. p - The probability density at x
+. p - The probability density at `x`
 
   Level: beginner
 
@@ -229,20 +239,19 @@ PetscErrorCode PetscPDFGaussian2D(const PetscReal x[], const PetscReal dummy[],
 
 /*@
   PetscPDFSampleGaussian2D - Sample uniformly from a Gaussian distribution in 2D
+  <https://en.wikipedia.org/wiki/Box%E2%80%93Muller_transform>
 
   Not Collective
 
   Input Parameters:
-+ p - A uniform variable on [0, 1]^2
++ p     - A uniform variable on $[0, 1]^2$
 - dummy - ignored
 
   Output Parameter:
-. x - Coordinate in [-\infty, \infty]^2
+. x - Coordinate in $[-\infty, \infty]^2 $
 
   Level: beginner
 
-  Note: https://en.wikipedia.org/wiki/Box%E2%80%93Muller_transform
-
 .seealso: `PetscPDFGaussian2D()`, `PetscPDFMaxwellBoltzmann3D()`
 @*/
 PetscErrorCode PetscPDFSampleGaussian2D(const PetscReal p[], const PetscReal dummy[], PetscReal x[])
@@ -259,11 +268,11 @@ PetscErrorCode PetscPDFSampleGaussian2D(const PetscReal p[], const PetscReal dum
   Not Collective
 
   Input Parameters:
-+ x - Coordinate in [-\infty, \infty]^3
++ x     - Coordinate in $[-\infty, \infty]^3$
 - dummy - ignored
 
   Output Parameter:
-. p - The probability density at x
+. p - The probability density at `x`
 
   Level: beginner
 
@@ -277,21 +286,19 @@ PetscErrorCode PetscPDFGaussian3D(const PetscReal x[], const PetscReal dummy[],
 
 /*@
   PetscPDFSampleGaussian3D - Sample uniformly from a Gaussian distribution in 3D
+  <https://en.wikipedia.org/wiki/Box%E2%80%93Muller_transform>
 
   Not Collective
 
   Input Parameters:
-+ p - A uniform variable on [0, 1]^3
++ p     - A uniform variable on $[0, 1]^3$
 - dummy - ignored
 
   Output Parameter:
-. x - Coordinate in [-\infty, \infty]^3
+. x - Coordinate in $[-\infty, \infty]^3$
 
   Level: beginner
 
-  Reference:
-  https://en.wikipedia.org/wiki/Box%E2%80%93Muller_transform
-
 .seealso: `PetscPDFGaussian3D()`, `PetscPDFMaxwellBoltzmann3D()`
 @*/
 PetscErrorCode PetscPDFSampleGaussian3D(const PetscReal p[], const PetscReal dummy[], PetscReal x[])
@@ -306,11 +313,12 @@ PetscErrorCode PetscPDFSampleGaussian3D(const PetscReal p[], const PetscReal dum
 
   Not Collective
 
-  Input Parameter:
-. x - Coordinate in [-1, 1]
+  Input Parameters:
++ x     - Coordinate in $[-1, 1]$
+- dummy - Unused
 
   Output Parameter:
-. p - The probability density at x
+. p - The probability density at `x`
 
   Level: beginner
 
@@ -327,11 +335,12 @@ PetscErrorCode PetscPDFConstant1D(const PetscReal x[], const PetscReal dummy[],
 
   Not Collective
 
-  Input Parameter:
-. x - Coordinate in [-1, 1]
+  Input Parameters:
++ x     - Coordinate in $[-1, 1]$
+- dummy - Unused
 
   Output Parameter:
-. p - The cumulative probability at x
+. p - The cumulative probability at `x`
 
   Level: beginner
 
@@ -348,11 +357,12 @@ PetscErrorCode PetscCDFConstant1D(const PetscReal x[], const PetscReal dummy[],
 
   Not Collective
 
-  Input Parameter:
-. p - A uniform variable on [0, 1]
+  Input Parameters:
++ p     - A uniform variable on $[0, 1]$
+- dummy - Unused
 
   Output Parameter:
-. x - Coordinate in [-1, 1]
+. x - Coordinate in $[-1, 1]$
 
   Level: beginner
 
@@ -369,11 +379,12 @@ PetscErrorCode PetscPDFSampleConstant1D(const PetscReal p[], const PetscReal dum
 
   Not Collective
 
-  Input Parameter:
-. x - Coordinate in [-1, 1] x [-1, 1]
+  Input Parameters:
++ x     - Coordinate in $[-1, 1]^2$
+- dummy - Unused
 
   Output Parameter:
-. p - The probability density at x
+. p - The probability density at `x`
 
   Level: beginner
 
@@ -390,11 +401,12 @@ PetscErrorCode PetscPDFConstant2D(const PetscReal x[], const PetscReal dummy[],
 
   Not Collective
 
-  Input Parameter:
-. x - Coordinate in [-1, 1] x [-1, 1]
+  Input Parameters:
++ x     - Coordinate in $[-1, 1]^2$
+- dummy - Unused
 
   Output Parameter:
-. p - The cumulative probability at x
+. p - The cumulative probability at `x`
 
   Level: beginner
 
@@ -407,15 +419,16 @@ PetscErrorCode PetscCDFConstant2D(const PetscReal x[], const PetscReal dummy[],
 }
 
 /*@
-  PetscPDFSampleConstant2D - Sample uniformly from a uniform distribution on [-1, 1] x [-1, 1] in 2D
+  PetscPDFSampleConstant2D - Sample uniformly from a uniform distribution on $[-1, 1]^2$ in 2D
 
   Not Collective
 
-  Input Parameter:
-. p - Two uniform variables on [0, 1]
+  Input Parameters:
++ p     - Two uniform variables on $[0, 1]$
+- dummy - Unused
 
   Output Parameter:
-. x - Coordinate in [-1, 1] x [-1, 1]
+. x - Coordinate in $[-1, 1]^2$
 
   Level: beginner
 
@@ -433,11 +446,12 @@ PetscErrorCode PetscPDFSampleConstant2D(const PetscReal p[], const PetscReal dum
 
   Not Collective
 
-  Input Parameter:
-. x - Coordinate in [-1, 1] x [-1, 1] x [-1, 1]
+  Input Parameters:
++ x     - Coordinate in $[-1, 1]^3$
+- dummy - Unused
 
   Output Parameter:
-. p - The probability density at x
+. p - The probability density at `x`
 
   Level: beginner
 
@@ -454,11 +468,12 @@ PetscErrorCode PetscPDFConstant3D(const PetscReal x[], const PetscReal dummy[],
 
   Not Collective
 
-  Input Parameter:
-. x - Coordinate in [-1, 1] x [-1, 1] x [-1, 1]
+  Input Parameters:
++ x     - Coordinate in $[-1, 1]^3$
+- dummy - Unused
 
   Output Parameter:
-. p - The cumulative probability at x
+. p - The cumulative probability at `x`
 
   Level: beginner
 
@@ -471,15 +486,16 @@ PetscErrorCode PetscCDFConstant3D(const PetscReal x[], const PetscReal dummy[],
 }
 
 /*@
-  PetscPDFSampleConstant3D - Sample uniformly from a uniform distribution on [-1, 1] x [-1, 1] in 3D
+  PetscPDFSampleConstant3D - Sample uniformly from a uniform distribution on $[-1, 1]^3$ in 3D
 
   Not Collective
 
-  Input Parameter:
-. p - Three uniform variables on [0, 1]
+  Input Parameters:
++ p     - Three uniform variables on $[0, 1]$
+- dummy - Unused
 
   Output Parameter:
-. x - Coordinate in [-1, 1] x [-1, 1] x [-1, 1]
+. x - Coordinate in $[-1, 1]^3$
 
   Level: beginner
 
@@ -500,12 +516,12 @@ PetscErrorCode PetscPDFSampleConstant3D(const PetscReal p[], const PetscReal dum
 
   Input Parameters:
 + dim    - The dimension of sample points
-. prefix - The options prefix, or NULL
-- name   - The option name for the probility distribution type
+. prefix - The options prefix, or `NULL`
+- name   - The option name for the probability distribution type
 
   Output Parameters:
-+ pdf - The PDF of this type
-. cdf - The CDF of this type
++ pdf     - The PDF of this type
+. cdf     - The CDF of this type
 - sampler - The PDF sampler of this type
 
   Level: intermediate
@@ -522,15 +538,15 @@ PetscErrorCode PetscProbCreateFromOptions(PetscInt dim, const char prefix[], con
   PetscOptionsEnd();
 
   if (pdf) {
-    PetscValidPointer(pdf, 4);
+    PetscAssertPointer(pdf, 4);
     *pdf = NULL;
   }
   if (cdf) {
-    PetscValidPointer(cdf, 5);
+    PetscAssertPointer(cdf, 5);
     *cdf = NULL;
   }
   if (sampler) {
-    PetscValidPointer(sampler, 6);
+    PetscAssertPointer(sampler, 6);
     *sampler = NULL;
   }
   switch (den) {
@@ -620,13 +636,16 @@ EXTERN_C_END
 
   Notes:
   The Kolmogorov-Smirnov statistic for a given cumulative distribution function $F(x)$ is
-.vb
-    D_n = \sup_x \left| F_n(x) - F(x) \right|
+
+  $$
+  D_n = \sup_x \left| F_n(x) - F(x) \right|
+  $$
 
   where $\sup_x$ is the supremum of the set of distances, and the empirical distribution function $F_n(x)$ is discrete, and given by
 
-    F_n =  # of samples <= x / n
-.ve
+  $$
+  F_n =  # of samples <= x / n
+  $$
 
   The empirical distribution function $F_n(x)$ is discrete, and thus had a ``stairstep''
   cumulative distribution, making $n$ the number of stairs. Intuitively, the statistic takes
