@@ -1,7 +1,6 @@
-
 #include <petsc/private/dmdaimpl.h> /*I   "petscdmda.h"   I*/
 
-PetscErrorCode DMSetFromOptions_DA(DM da, PetscOptionItems *PetscOptionsObject)
+static PetscErrorCode DMSetFromOptions_DA(DM da, PetscOptionItems *PetscOptionsObject)
 {
   DM_DA    *dd     = (DM_DA *)da->data;
   PetscInt  refine = 0, dim = da->dim, maxnlevels = 100, refx[100], refy[100], refz[100], n, i;
@@ -111,31 +110,7 @@ PetscErrorCode DMSetFromOptions_DA(DM da, PetscOptionItems *PetscOptionsObject)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-extern PetscErrorCode       DMCreateGlobalVector_DA(DM, Vec *);
-extern PetscErrorCode       DMCreateLocalVector_DA(DM, Vec *);
-extern PetscErrorCode       DMGlobalToLocalBegin_DA(DM, Vec, InsertMode, Vec);
-extern PetscErrorCode       DMGlobalToLocalEnd_DA(DM, Vec, InsertMode, Vec);
-extern PetscErrorCode       DMLocalToGlobalBegin_DA(DM, Vec, InsertMode, Vec);
-extern PetscErrorCode       DMLocalToGlobalEnd_DA(DM, Vec, InsertMode, Vec);
-extern PetscErrorCode       DMLocalToLocalBegin_DA(DM, Vec, InsertMode, Vec);
-extern PetscErrorCode       DMLocalToLocalEnd_DA(DM, Vec, InsertMode, Vec);
-extern PetscErrorCode       DMCreateInterpolation_DA(DM, DM, Mat *, Vec *);
-extern PetscErrorCode       DMCreateColoring_DA(DM, ISColoringType, ISColoring *);
-extern PetscErrorCode       DMCreateMatrix_DA(DM, Mat *);
-extern PetscErrorCode       DMCreateCoordinateDM_DA(DM, DM *);
-extern PetscErrorCode       DMRefine_DA(DM, MPI_Comm, DM *);
-extern PetscErrorCode       DMCoarsen_DA(DM, MPI_Comm, DM *);
-extern PetscErrorCode       DMRefineHierarchy_DA(DM, PetscInt, DM[]);
-extern PetscErrorCode       DMCoarsenHierarchy_DA(DM, PetscInt, DM[]);
-extern PetscErrorCode       DMCreateInjection_DA(DM, DM, Mat *);
-extern PetscErrorCode       DMView_DA(DM, PetscViewer);
-extern PetscErrorCode       DMSetUp_DA(DM);
-extern PetscErrorCode       DMDestroy_DA(DM);
-extern PetscErrorCode       DMCreateDomainDecomposition_DA(DM, PetscInt *, char ***, IS **, IS **, DM **);
-extern PetscErrorCode       DMCreateDomainDecompositionScatters_DA(DM, PetscInt, DM *, VecScatter **, VecScatter **, VecScatter **);
-PETSC_INTERN PetscErrorCode DMGetCompatibility_DA(DM, DM, PetscBool *, PetscBool *);
-
-PetscErrorCode DMLoad_DA(DM da, PetscViewer viewer)
+static PetscErrorCode DMLoad_DA(DM da, PetscViewer viewer)
 {
   PetscInt        dim, m, n, p, dof, swidth;
   DMDAStencilType stencil;
@@ -174,7 +149,7 @@ PetscErrorCode DMLoad_DA(DM da, PetscViewer viewer)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode DMCreateSubDM_DA(DM dm, PetscInt numFields, const PetscInt fields[], IS *is, DM *subdm)
+static PetscErrorCode DMCreateSubDM_DA(DM dm, PetscInt numFields, const PetscInt fields[], IS *is, DM *subdm)
 {
   DM_DA *da = (DM_DA *)dm->data;
 
@@ -221,7 +196,7 @@ PetscErrorCode DMCreateSubDM_DA(DM dm, PetscInt numFields, const PetscInt fields
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode DMCreateFieldDecomposition_DA(DM dm, PetscInt *len, char ***namelist, IS **islist, DM **dmlist)
+static PetscErrorCode DMCreateFieldDecomposition_DA(DM dm, PetscInt *len, char ***namelist, IS **islist, DM **dmlist)
 {
   PetscInt i;
   DM_DA   *dd  = (DM_DA *)dm->data;
@@ -265,7 +240,7 @@ PetscErrorCode DMCreateFieldDecomposition_DA(DM dm, PetscInt *len, char ***namel
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode DMClone_DA(DM dm, DM *newdm)
+static PetscErrorCode DMClone_DA(DM dm, DM *newdm)
 {
   DM_DA *da = (DM_DA *)dm->data;
 
@@ -289,7 +264,7 @@ static PetscErrorCode DMHasCreateInjection_DA(DM dm, PetscBool *flg)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(dm, DM_CLASSID, 1);
-  PetscValidBoolPointer(flg, 2);
+  PetscAssertPointer(flg, 2);
   *flg = da->interptype == DMDA_Q1 ? PETSC_TRUE : PETSC_FALSE;
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -332,25 +307,23 @@ static PetscErrorCode DMGetNeighbors_DA(DM dm, PetscInt *nranks, const PetscMPII
 /*MC
    DMDA = "da" - A `DM` object that is used to manage data for a structured grid in 1, 2, or 3 dimensions.
          In the global representation of the vector each process stores a non-overlapping rectangular (or slab in 3d) portion of the grid points.
-         In the local representation these rectangular regions (slabs) are extended in all directions by a stencil width.
+         In the local representation these rectangular regions (slabs) are extended in all directions by a stencil width set with `DMDASetStencilWidth()`.
 
          The vectors can be thought of as either cell centered or vertex centered on the mesh. But some variables cannot be cell centered and others
-         vertex centered; see the documentation for `DMSTAG`, a similar DM implementation which supports these staggered grids.
+         vertex centered; see the documentation for `DMSTAG`, a similar `DM` implementation which supports more general staggered grids.
 
   Level: intermediate
 
-.seealso: `DMType`, `DMCOMPOSITE`, `DMSTAG`, `DMDACreate()`, `DMCreate()`, `DMSetType()`
+.seealso: [](sec_struct), `DMType`, `DMCOMPOSITE`, `DMSTAG`, `DMDACreate()`, `DMCreate()`, `DMSetType()`, `DMDASetStencilWidth()`, `DMDASetStencilType()`,
+          `DMDAStencilType`
 M*/
 
-extern PetscErrorCode       DMLocatePoints_DA_Regular(DM, Vec, DMPointLocationType, PetscSF);
-PETSC_INTERN PetscErrorCode DMSetUpGLVisViewer_DMDA(PetscObject, PetscViewer);
-
 PETSC_EXTERN PetscErrorCode DMCreate_DA(DM da)
 {
   DM_DA *dd;
 
   PetscFunctionBegin;
-  PetscValidPointer(da, 1);
+  PetscAssertPointer(da, 1);
   PetscCall(PetscNew(&dd));
   da->data = dd;
 
@@ -451,27 +424,27 @@ PETSC_EXTERN PetscErrorCode DMCreate_DA(DM da)
 }
 
 /*@
-  DMDACreate - Creates a DMDA object.
+  DMDACreate - Creates a `DMDA` object for managing structured grids.
 
   Collective
 
   Input Parameter:
-. comm - The communicator for the DMDA object
+. comm - The communicator for the `DMDA` object
 
   Output Parameter:
-. da  - The DMDA object
+. da - The DMDA object
 
   Level: advanced
 
-  Developers Note:
+  Developer Note:
   Since there exists DMDACreate1/2/3d() should this routine even exist?
 
-.seealso: `DMDASetSizes()`, `DMClone()`, `DMDACreate1d()`, `DMDACreate2d()`, `DMDACreate3d()`
+.seealso: [](sec_struct), `DMDASetSizes()`, `DMClone()`, `DMDACreate1d()`, `DMDACreate2d()`, `DMDACreate3d()`
 @*/
 PetscErrorCode DMDACreate(MPI_Comm comm, DM *da)
 {
   PetscFunctionBegin;
-  PetscValidPointer(da, 2);
+  PetscAssertPointer(da, 2);
   PetscCall(DMCreate(comm, da));
   PetscCall(DMSetType(*da, DMDA));
   PetscFunctionReturn(PETSC_SUCCESS);
