@@ -1,38 +1,37 @@
-
 #include <petsc/private/dmdaimpl.h> /*I   "petscdmda.h"   I*/
 
 /*MC
-  DMDAVecGetArrayF90 - check Fortran Notes at `DMDAVecGetArray()`
+  DMDAVecGetArrayF90 - see Fortran Notes at `DMDAVecGetArray()`
 
   Level: intermediate
 M*/
 
 /*@C
-   DMDAVecGetArray - Returns a multiple dimension array that shares data with
-      the underlying vector and is indexed using the global dimensions.
+  DMDAVecGetArray - Returns a multiple dimension array that shares data with
+  the underlying vector and is indexed using the global or local dimensions of a `DMDA`.
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameters:
-+  da - the distributed array
--  vec - a vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
+  Input Parameters:
++ da  - the distributed array
+- vec - a vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
 
-   Output Parameter:
-.  array - the array
+  Output Parameter:
+. array - the array
 
   Level: intermediate
 
-   Notes:
-    Call `DMDAVecRestoreArray()` once you have finished accessing the vector entries.
+  Notes:
+  Call `DMDAVecRestoreArray()` once you have finished accessing the vector entries.
 
-    In C, the indexing is "backwards" from what expects: array[k][j][i] NOT array[i][j][k]!
+  In C, the indexing is "backwards" from what expects: array[k][j][i] NOT array[i][j][k]!
 
-    If `vec` is a local vector (obtained with DMCreateLocalVector() etc) then the ghost point locations are accessible. If it is
-    a global vector then the ghost points are not accessible. Of course, with a local vector you will have had to do the
-    appropriate `DMGlobalToLocalBegin()` and `DMGlobalToLocalEnd()` to have correct values in the ghost locations.
+  If `vec` is a local vector (obtained with DMCreateLocalVector() etc) then the ghost point locations are accessible. If it is
+  a global vector then the ghost points are not accessible. Of course, with a local vector you will have had to do the
+  appropriate `DMGlobalToLocalBegin()` and `DMGlobalToLocalEnd()` to have correct values in the ghost locations.
 
-    The accessible indices are `array[zs:zs+zm-1][ys:ys+ym-1][xs:xs+xm-1]` where the values are obtained from
-   `DMDAGetCorners()` for a global vector or `DMDAGetGhostCorners()` for a local vector.
+  The accessible indices are `array[zs:zs+zm-1][ys:ys+ym-1][xs:xs+xm-1]` where the values are obtained from
+  `DMDAGetCorners()` for a global vector or `DMDAGetGhostCorners()` for a local vector.
 
   Fortran Notes:
   Use `DMDAVecGetArrayF90()` and pass for the array type `PetscScalar`,pointer :: array(:,...,:) of the appropriate
@@ -43,7 +42,7 @@ M*/
   `array(0:dof-1,xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1)` where the values are obtained from
   `DMDAGetCorners()` for a global vector or `DMDAGetGhostCorners()` for a local vector.
 
-.seealso: `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecRestoreArray()`, `DMDAVecRestoreArrayDOF()`
+.seealso: [](sec_struct), [](sec_struct_set), `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecRestoreArray()`, `DMDAVecRestoreArrayDOF()`
           `DMDAVecGetArrayDOF()`, `DMDAVecGetArrayWrite()`, `DMDAVecRestoreArrayWrite()`, `DMDAVecGetArrayRead()`, `DMDAVecRestoreArrayRead()`,
           `DMStagVecGetArray()`
 @*/
@@ -54,7 +53,7 @@ PetscErrorCode DMDAVecGetArray(DM da, Vec vec, void *array)
   PetscFunctionBegin;
   PetscValidHeaderSpecificType(da, DM_CLASSID, 1, DMDA);
   PetscValidHeaderSpecific(vec, VEC_CLASSID, 2);
-  PetscValidPointer(array, 3);
+  PetscAssertPointer(array, 3);
   PetscCall(DMDAGetCorners(da, &xs, &ys, &zs, &xm, &ym, &zm));
   PetscCall(DMDAGetGhostCorners(da, &gxs, &gys, &gzs, &gxm, &gym, &gzm));
   PetscCall(DMDAGetInfo(da, &dim, NULL, NULL, NULL, NULL, NULL, NULL, &dof, NULL, NULL, NULL, NULL, NULL));
@@ -81,27 +80,27 @@ PetscErrorCode DMDAVecGetArray(DM da, Vec vec, void *array)
 }
 
 /*MC
-  DMDAVecRestoreArrayF90 - check Fortran Notes at `DMDAVecRestoreArray()`
+  DMDAVecRestoreArrayF90 - see Fortran Notes at `DMDAVecRestoreArray()`
 
   Level: intermediate
 M*/
 
 /*@
-   DMDAVecRestoreArray - Restores a multiple dimension array obtained with `DMDAVecGetArray()`
+  DMDAVecRestoreArray - Restores a multiple dimension array obtained with `DMDAVecGetArray()`
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameters:
-+  da - the distributed array
-.  vec - a vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
--  array - the `array` pointer is zeroed
+  Input Parameters:
++ da    - the distributed array
+. vec   - a vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
+- array - the `array` pointer
 
   Level: intermediate
 
   Fortran Note:
   Use `DMDAVecRestoreArayF90()`
 
-.seealso: `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `DMDAVecRestoreArayF90()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecGetArray()`,
+.seealso: [](sec_struct), [](sec_struct_set), `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `DMDAVecRestoreArayF90()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecGetArray()`,
           `DMDAVecGetArrayWrite()`, `DMDAVecRestoreArrayWrite()`, `DMDAVecGetArrayRead()`, `DMDAVecRestoreArrayRead()`,
           `DMDStagVecRestoreArray()`
 @*/
@@ -112,7 +111,7 @@ PetscErrorCode DMDAVecRestoreArray(DM da, Vec vec, void *array)
   PetscFunctionBegin;
   PetscValidHeaderSpecificType(da, DM_CLASSID, 1, DMDA);
   PetscValidHeaderSpecific(vec, VEC_CLASSID, 2);
-  PetscValidPointer(array, 3);
+  PetscAssertPointer(array, 3);
   PetscCall(DMDAGetCorners(da, &xs, &ys, &zs, &xm, &ym, &zm));
   PetscCall(DMDAGetGhostCorners(da, &gxs, &gys, &gzs, &gxm, &gym, &gzm));
   PetscCall(DMDAGetInfo(da, &dim, NULL, NULL, NULL, NULL, NULL, NULL, &dof, NULL, NULL, NULL, NULL, NULL));
@@ -139,51 +138,51 @@ PetscErrorCode DMDAVecRestoreArray(DM da, Vec vec, void *array)
 }
 
 /*MC
-  DMDAVecGetArrayWriteF90 - check Fortran Notes at `DMDAVecGetArrayWrite()`
+  DMDAVecGetArrayWriteF90 - see Fortran Notes at `DMDAVecGetArrayWrite()`
 
   Level: intermediate
 M*/
 
 /*@C
-   DMDAVecGetArrayWrite - Returns a multiple dimension array that shares data with
-      the underlying vector and is indexed using the global dimensions.
+  DMDAVecGetArrayWrite - Returns a multiple dimension array that shares data with
+  the underlying vector and is indexed using the global or local dimensions of a `DMDA`.
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameters:
-+  da - the distributed array
--  vec - a vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
+  Input Parameters:
++ da  - the distributed array
+- vec - a vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
 
-   Output Parameter:
-.  array - the array
+  Output Parameter:
+. array - the array
 
   Level: intermediate
 
-   Notes:
-    Call `DMDAVecRestoreArray()` once you have finished accessing the vector entries.
+  Notes:
+  Call `DMDAVecRestoreArray()` once you have finished accessing the vector entries.
 
-    In C, the indexing is "backwards" from what expects: array[k][j][i] NOT array[i][j][k]!
+  In C, the indexing is "backwards" from what expects: array[k][j][i] NOT array[i][j][k]!
 
-    if `vec` is a local vector (obtained with `DMCreateLocalVector()` etc) then the ghost point locations are accessible. If it is
-    a global vector then the ghost points are not accessible. Of course with the local vector you will have had to do the
-    appropriate `DMGlobalToLocalBegin()` and `DMGlobalToLocalEnd()` to have correct values in the ghost locations.
+  if `vec` is a local vector (obtained with `DMCreateLocalVector()` etc) then the ghost point locations are accessible. If it is
+  a global vector then the ghost points are not accessible. Of course with the local vector you will have had to do the
+  appropriate `DMGlobalToLocalBegin()` and `DMGlobalToLocalEnd()` to have correct values in the ghost locations.
 
-     The accessible indices are `array[zs:zs+zm-1][ys:ys+ym-1][xs:xs+xm-1]` where the values are obtained from
-   `DMDAGetCorners()` for a global vector or `DMDAGetGhostCorners()` for a local vector.
+  The accessible indices are `array[zs:zs+zm-1][ys:ys+ym-1][xs:xs+xm-1]` where the values are obtained from
+  `DMDAGetCorners()` for a global vector or `DMDAGetGhostCorners()` for a local vector.
 
-   Fortran Notes:
-   From Fortran use `DMDAVecGetArrayWriteF90()` and pass for the array type PetscScalar,pointer :: array(:,...,:) of the appropriate
-   dimension. For a `DMDA` created with a dof of 1 use the dimension of the `DMDA`, for a `DMDA` created with a dof greater than 1 use one more than the
-   dimension of the `DMDA`.
+  Fortran Notes:
+  Use `DMDAVecGetArrayWriteF90()` and pass for the array type PetscScalar,pointer :: array(:,...,:) of the appropriate
+  dimension. For a `DMDA` created with a dof of 1 use the dimension of the `DMDA`, for a `DMDA` created with a dof greater than 1 use one more than the
+  dimension of the `DMDA`.
 
-   The order of the indices is `array(xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1)` (when dof is 1) otherwise
-   `array(0:dof-1,xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1)` where the values are obtained from
-   `DMDAGetCorners()` for a global vector or `DMDAGetGhostCorners()` for a local vector.
+  The order of the indices is `array(xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1)` (when dof is 1) otherwise
+  `array(0:dof-1,xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1)` where the values are obtained from
+  `DMDAGetCorners()` for a global vector or `DMDAGetGhostCorners()` for a local vector.
 
   Developer Note:
   This has code duplication with `DMDAVecGetArray()` and `DMDAVecGetArrayRead()`
 
-.seealso: `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecRestoreArrayWrite()`, `DMDAVecRestoreArrayDOF()`
+.seealso: [](sec_struct), [](sec_struct_set), `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecRestoreArrayWrite()`, `DMDAVecRestoreArrayDOF()`
           `DMDAVecGetArrayDOF()`, `DMDAVecGetArray()`, `DMDAVecRestoreArray()`, `DMDAVecGetArrayRead()`, `DMDAVecRestoreArrayRead()`
 @*/
 PetscErrorCode DMDAVecGetArrayWrite(DM da, Vec vec, void *array)
@@ -193,7 +192,7 @@ PetscErrorCode DMDAVecGetArrayWrite(DM da, Vec vec, void *array)
   PetscFunctionBegin;
   PetscValidHeaderSpecificType(da, DM_CLASSID, 1, DMDA);
   PetscValidHeaderSpecific(vec, VEC_CLASSID, 2);
-  PetscValidPointer(array, 3);
+  PetscAssertPointer(array, 3);
   if (da->localSection) {
     PetscCall(VecGetArrayWrite(vec, (PetscScalar **)array));
     PetscFunctionReturn(PETSC_SUCCESS);
@@ -224,27 +223,27 @@ PetscErrorCode DMDAVecGetArrayWrite(DM da, Vec vec, void *array)
 }
 
 /*MC
-  DMDAVecRestoreArrayWriteF90 - check Fortran Notes at `DMDAVecRestoreArrayWrite()`
+  DMDAVecRestoreArrayWriteF90 - see Fortran Notes at `DMDAVecRestoreArrayWrite()`
 
   Level: intermediate
 M*/
 
 /*@
-   DMDAVecRestoreArrayWrite - Restores a multiple dimension array obtained with `DMDAVecGetArrayWrite()`
+  DMDAVecRestoreArrayWrite - Restores a multiple dimension array obtained with `DMDAVecGetArrayWrite()`
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameters:
-+  da - the distributed array
-.  vec - a vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
--  array - the `array` pointer is zeroed
+  Input Parameters:
++ da    - the distributed array
+. vec   - a vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
+- array - the `array` pointer
 
   Level: intermediate
 
   Fortran Note:
   Use `DMDAVecRestoreArayWriteF90()`
 
-.seealso: `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecGetArrayWrite()`,
+.seealso: [](sec_struct), [](sec_struct_set), `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecGetArrayWrite()`,
           `DMDAVecGetArray()`, `DMDAVecRestoreArray()`, `DMDAVecGetArrayRead()`, `DMDAVecRestoreArrayRead()`
 @*/
 PetscErrorCode DMDAVecRestoreArrayWrite(DM da, Vec vec, void *array)
@@ -254,7 +253,7 @@ PetscErrorCode DMDAVecRestoreArrayWrite(DM da, Vec vec, void *array)
   PetscFunctionBegin;
   PetscValidHeaderSpecificType(da, DM_CLASSID, 1, DMDA);
   PetscValidHeaderSpecific(vec, VEC_CLASSID, 2);
-  PetscValidPointer(array, 3);
+  PetscAssertPointer(array, 3);
   if (da->localSection) {
     PetscCall(VecRestoreArray(vec, (PetscScalar **)array));
     PetscFunctionReturn(PETSC_SUCCESS);
@@ -285,38 +284,38 @@ PetscErrorCode DMDAVecRestoreArrayWrite(DM da, Vec vec, void *array)
 }
 
 /*@C
-   DMDAVecGetArrayDOF - Returns a multiple dimension array that shares data with
-      the underlying vector and is indexed using the global dimensions.
+  DMDAVecGetArrayDOF - Returns a multiple dimension array that shares data with
+  the underlying vector and is indexed using the global or local dimensions of a `DMDA`
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameters:
-+  da - the distributed array
--  vec - a vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
+  Input Parameters:
++ da  - the distributed array
+- vec - a vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
 
-   Output Parameter:
-.  array - the `array` pointer is zeroed
+  Output Parameter:
+. array - the `array` pointer
 
   Level: intermediate
 
-   Notes:
-    Call `DMDAVecRestoreArrayDOF()` once you have finished accessing the vector entries.
+  Notes:
+  Call `DMDAVecRestoreArrayDOF()` once you have finished accessing the vector entries.
 
-    In C, the indexing is "backwards" from what expects: array[k][j][i][DOF] NOT array[i][j][k][DOF]
+  In C, the indexing is "backwards" from what expects: array[k][j][i][DOF] NOT array[i][j][k][DOF]
 
-    The accessible indices are `array[zs:zs+zm-1][ys:ys+ym-1][xs:xs+xm-1][0:ndof-1]` where the values are obtained from
-   `DMDAGetCorners()` for a global vector or `DMDAGetGhostCorners()` for a local vector.
+  The accessible indices are `array[zs:zs+zm-1][ys:ys+ym-1][xs:xs+xm-1][0:ndof-1]` where the values are obtained from
+  `DMDAGetCorners()` for a global vector or `DMDAGetGhostCorners()` for a local vector.
 
-   Fortran Notes:
-    Use `DMDAVecGetArrayF90()` and pass for the array type PetscScalar,pointer :: array(:,...,:) of the appropriate
-   dimension. For a `DMDA` created with a dof of 1 use the dimension of the `DMDA`, for a `DMDA` created with a dof greater than 1 use one more than the
-   dimension of the `DMDA`.
+  Fortran Notes:
+  Use `DMDAVecGetArrayF90()` and pass for the array type PetscScalar,pointer :: array(:,...,:) of the appropriate
+  dimension. For a `DMDA` created with a dof of 1 use the dimension of the `DMDA`, for a `DMDA` created with a dof greater than 1 use one more than the
+  dimension of the `DMDA`.
 
-   The order of the indices is `array(xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1)` (when ndof is 1) otherwise
-   `array(0:dof-1,xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1)` where the values are obtained from
-   `DMDAGetCorners()` for a global vector or `DMDAGetGhostCorners()` for a local vector.
+  The order of the indices is `array(xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1)` (when ndof is 1) otherwise
+  `array(0:dof-1,xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1)` where the values are obtained from
+  `DMDAGetCorners()` for a global vector or `DMDAGetGhostCorners()` for a local vector.
 
-.seealso: `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecRestoreArray()`, `DMDAVecGetArray()`, `DMDAVecRestoreArrayDOF()`,
+.seealso: [](sec_struct), [](sec_struct_set), `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecRestoreArray()`, `DMDAVecGetArray()`, `DMDAVecRestoreArrayDOF()`,
           `DMDAVecGetArrayWrite()`, `DMDAVecRestoreArrayWrite()`, `DMDAVecGetArrayRead()`, `DMDAVecRestoreArrayRead()`, `DMDAVecGetArrayDOFRead()`
 @*/
 PetscErrorCode DMDAVecGetArrayDOF(DM da, Vec vec, void *array)
@@ -350,21 +349,21 @@ PetscErrorCode DMDAVecGetArrayDOF(DM da, Vec vec, void *array)
 }
 
 /*@
-   DMDAVecRestoreArrayDOF - Restores a multiple dimension array obtained with `DMDAVecGetArrayDOF()`
+  DMDAVecRestoreArrayDOF - Restores a multiple dimension array obtained with `DMDAVecGetArrayDOF()`
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameters:
-+  da - the distributed array
-.  vec - vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
--  array - the `array` point is zeroed
+  Input Parameters:
++ da    - the distributed array
+. vec   - vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
+- array - the `array` point
 
   Level: intermediate
 
   Fortran Note:
   Use `DMDAVecRestoreArayF90()`
 
-.seealso: `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecGetArray()`, `DMDAVecGetArrayDOF()`, `DMDAVecRestoreArrayDOF()`,
+.seealso: [](sec_struct), [](sec_struct_set), `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecGetArray()`, `DMDAVecGetArrayDOF()`,
           `DMDAVecGetArrayWrite()`, `DMDAVecRestoreArrayWrite()`, `DMDAVecGetArrayRead()`, `DMDAVecRestoreArrayRead()`
 @*/
 PetscErrorCode DMDAVecRestoreArrayDOF(DM da, Vec vec, void *array)
@@ -398,37 +397,37 @@ PetscErrorCode DMDAVecRestoreArrayDOF(DM da, Vec vec, void *array)
 }
 
 /*MC
-  DMDAVecGetArrayReadF90 - check Fortran Notes at `DMDAVecGetArrayRead()`
+  DMDAVecGetArrayReadF90 - see Fortran Notes at `DMDAVecGetArrayRead()`
 
   Level: intermediate
 M*/
 
 /*@C
-   DMDAVecGetArrayRead - Returns a multiple dimension array that shares data with
-      the underlying vector and is indexed using the global dimensions.
+  DMDAVecGetArrayRead - Returns a multiple dimension array that shares data with
+  the underlying vector and is indexed using the global or local dimensions of a `DMDA`.
 
-   Not Collective
+  Not Collective
 
-   Input Parameters:
-+  da - the distributed array
--  vec - a vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
+  Input Parameters:
++ da  - the distributed array
+- vec - a vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
 
-   Output Parameter:
-.  array - the array
+  Output Parameter:
+. array - the array
 
   Level: intermediate
 
-   Notes:
-    Call `DMDAVecRestoreArrayRead()` once you have finished accessing the vector entries.
+  Notes:
+  Call `DMDAVecRestoreArrayRead()` once you have finished accessing the vector entries.
 
-    In C, the indexing is "backwards" from what expects: array[k][j][i] NOT array[i][j][k]!
+  In C, the indexing is "backwards" from what expects: array[k][j][i] NOT array[i][j][k]!
 
-    If `vec` is a local vector (obtained with `DMCreateLocalVector()` etc) then the ghost point locations are accessible. If it is
-    a global vector then the ghost points are not accessible. Of course with the local vector you will have had to do the
-    appropriate `DMGlobalToLocalBegin()` and `DMGlobalToLocalEnd()` to have correct values in the ghost locations.
+  If `vec` is a local vector (obtained with `DMCreateLocalVector()` etc) then the ghost point locations are accessible. If it is
+  a global vector then the ghost points are not accessible. Of course with the local vector you will have had to do the
+  appropriate `DMGlobalToLocalBegin()` and `DMGlobalToLocalEnd()` to have correct values in the ghost locations.
 
-    The accessible indices are `array[zs:zs+zm-1][ys:ys+ym-1][xs:xs+xm-1]` where the values are obtained from
-    `DMDAGetCorners()` for a global vector or `DMDAGetGhostCorners()` for a local vector.
+  The accessible indices are `array[zs:zs+zm-1][ys:ys+ym-1][xs:xs+xm-1]` where the values are obtained from
+  `DMDAGetCorners()` for a global vector or `DMDAGetGhostCorners()` for a local vector.
 
   Fortran Notes:
   Use `DMDAVecGetArrayReadF90()` and pass for the array type `PetscScalar`,pointer :: array(:,...,:) of the appropriate
@@ -439,9 +438,10 @@ M*/
   `array(0:dof-1,xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1)` where the values are obtained from
   `DMDAGetCorners()` for a global vector or `DMDAGetGhostCorners()` for a local vector.
 
-.seealso: `DM`, `DMDA`, `DMDAVecGetArrayReadF90()`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecRestoreArrayRead()`, `DMDAVecRestoreArrayDOF()`
-          `DMDAVecGetArrayDOF()`, `DMDAVecGetArray()`, `DMDAVecRestoreArray()`, `DMDAVecGetArrayRead()`, `DMDAVecRestoreArrayRead()`,
-          `DMStagVecGetArrayRead()`
+.seealso: [](sec_struct), [](sec_struct_set), `DM`, `DMDA`, `DMDAVecGetArrayReadF90()`, `DMDAGetGhostCorners()`,
+`DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecRestoreArrayRead()`,
+`DMDAVecRestoreArrayDOF()`, `DMDAVecGetArrayDOF()`, `DMDAVecGetArray()`,
+`DMDAVecRestoreArray()`, `DMStagVecGetArrayRead()`
 @*/
 PetscErrorCode DMDAVecGetArrayRead(DM da, Vec vec, void *array)
 {
@@ -450,7 +450,7 @@ PetscErrorCode DMDAVecGetArrayRead(DM da, Vec vec, void *array)
   PetscFunctionBegin;
   PetscValidHeaderSpecificType(da, DM_CLASSID, 1, DMDA);
   PetscValidHeaderSpecific(vec, VEC_CLASSID, 2);
-  PetscValidPointer(array, 3);
+  PetscAssertPointer(array, 3);
   PetscCall(DMDAGetCorners(da, &xs, &ys, &zs, &xm, &ym, &zm));
   PetscCall(DMDAGetGhostCorners(da, &gxs, &gys, &gzs, &gxm, &gym, &gzm));
   PetscCall(DMDAGetInfo(da, &dim, NULL, NULL, NULL, NULL, NULL, NULL, &dof, NULL, NULL, NULL, NULL, NULL));
@@ -477,27 +477,27 @@ PetscErrorCode DMDAVecGetArrayRead(DM da, Vec vec, void *array)
 }
 
 /*MC
-  DMDAVecRestoreArrayReadF90 - check Fortran Notes at `DMDAVecRestoreArrayRead()`
+  DMDAVecRestoreArrayReadF90 - see Fortran Notes at `DMDAVecRestoreArrayRead()`
 
   Level: intermediate
 M*/
 
 /*@
-   DMDAVecRestoreArrayRead - Restores a multiple dimension array obtained with `DMDAVecGetArrayRead()`
+  DMDAVecRestoreArrayRead - Restores a multiple dimension array obtained with `DMDAVecGetArrayRead()`
 
-   Not Collective
+  Not Collective
 
-   Input Parameters:
-+  da - the distributed array
-.  vec - vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
--  array - the `array` pointer is zeroed
+  Input Parameters:
++ da    - the distributed array
+. vec   - vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
+- array - the `array` pointer
 
   Level: intermediate
 
   Fortran Note:
   Use `DMDAVecRestoreArrayReadF90()`
 
-.seealso: `DM`, `DMDA`, `DMDAVecRestoreArrayReadF90()`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecGetArrayRead()`,
+.seealso: [](sec_struct), [](sec_struct_set), `DM`, `DMDA`, `DMDAVecRestoreArrayReadF90()`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecGetArrayRead()`,
           `DMDAVecGetArray()`, `DMDAVecRestoreArray()`, `DMDAVecGetArrayWrite()`, `DMDAVecRestoreArrayWrite()`,
           `DMStagVecRestoreArrayRead()`
 @*/
@@ -508,7 +508,7 @@ PetscErrorCode DMDAVecRestoreArrayRead(DM da, Vec vec, void *array)
   PetscFunctionBegin;
   PetscValidHeaderSpecificType(da, DM_CLASSID, 1, DMDA);
   PetscValidHeaderSpecific(vec, VEC_CLASSID, 2);
-  PetscValidPointer(array, 3);
+  PetscAssertPointer(array, 3);
   PetscCall(DMDAGetCorners(da, &xs, &ys, &zs, &xm, &ym, &zm));
   PetscCall(DMDAGetGhostCorners(da, &gxs, &gys, &gzs, &gxm, &gym, &gzm));
   PetscCall(DMDAGetInfo(da, &dim, NULL, NULL, NULL, NULL, NULL, NULL, &dof, NULL, NULL, NULL, NULL, NULL));
@@ -535,38 +535,38 @@ PetscErrorCode DMDAVecRestoreArrayRead(DM da, Vec vec, void *array)
 }
 
 /*@C
-   DMDAVecGetArrayDOFRead - Returns a multiple dimension array that shares data with
-      the underlying vector and is indexed using the global dimensions.
+  DMDAVecGetArrayDOFRead - Returns a multiple dimension array that shares data with
+  the underlying vector and is indexed using the global or local dimensions of a `DMDA`
 
-   Not Collective
+  Not Collective
 
-   Input Parameters:
-+  da - the distributed array
--  vec - a vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
+  Input Parameters:
++ da  - the distributed array
+- vec - a vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
 
-   Output Parameter:
-.  array - the array
+  Output Parameter:
+. array - the array
 
   Level: intermediate
 
-   Notes:
-   Call `DMDAVecRestoreArrayDOFRead()` once you have finished accessing the vector entries.
+  Notes:
+  Call `DMDAVecRestoreArrayDOFRead()` once you have finished accessing the vector entries.
 
-   In C, the indexing is "backwards" from what expects: array[k][j][i][DOF] NOT array[i][j][k][DOF]!
+  In C, the indexing is "backwards" from what expects: array[k][j][i][DOF] NOT array[i][j][k][DOF]!
 
-   The accessible indices are `array[zs:zs+zm-1][ys:ys+ym-1][xs:xs+xm-1]` where the values are obtained from
-   `DMDAGetCorners()` for a global vector or `DMDAGetGhostCorners()` for a local vector.
+  The accessible indices are `array[zs:zs+zm-1][ys:ys+ym-1][xs:xs+xm-1]` where the values are obtained from
+  `DMDAGetCorners()` for a global vector or `DMDAGetGhostCorners()` for a local vector.
 
-   Fortran Note:
-   Use  `DMDAVecGetArrayReadF90()` and pass for the array type PetscScalar,pointer :: array(:,...,:) of the appropriate
-   dimension. For a `DMDA` created with a dof of 1 use the dimension of the `DMDA`, for a `DMDA` created with a dof greater than 1 use one more than the
-   dimension of the `DMDA`.
+  Fortran Notes:
+  Use  `DMDAVecGetArrayReadF90()` and pass for the array type PetscScalar,pointer :: array(:,...,:) of the appropriate
+  dimension. For a `DMDA` created with a dof of 1 use the dimension of the `DMDA`, for a `DMDA` created with a dof greater than 1 use one more than the
+  dimension of the `DMDA`.
 
-   The order of the indices is `array(xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1)` (when dof is 1) otherwise
-   `array(0:dof-1,xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1)` where the values are obtained from
-   `DMDAGetCorners()` for a global vector or `DMDAGetGhostCorners()` for a local vector.
+  The order of the indices is `array(xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1)` (when dof is 1) otherwise
+  `array(0:dof-1,xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1)` where the values are obtained from
+  `DMDAGetCorners()` for a global vector or `DMDAGetGhostCorners()` for a local vector.
 
-.seealso: `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecRestoreArray()`, `DMDAVecGetArray()`, `DMDAVecGetArrayDOF()`,
+.seealso: [](sec_struct), [](sec_struct_set), `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecRestoreArray()`, `DMDAVecGetArray()`, `DMDAVecGetArrayDOF()`,
           `DMDAVecGetArrayWrite()`, `DMDAVecRestoreArrayWrite()`, `DMDAVecGetArrayRead()`, `DMDAVecRestoreArrayRead()`
 @*/
 PetscErrorCode DMDAVecGetArrayDOFRead(DM da, Vec vec, void *array)
@@ -600,21 +600,21 @@ PetscErrorCode DMDAVecGetArrayDOFRead(DM da, Vec vec, void *array)
 }
 
 /*@
-   DMDAVecRestoreArrayDOFRead - Restores a multiple dimension array obtained with `DMDAVecGetArrayDOFRead()`
+  DMDAVecRestoreArrayDOFRead - Restores a multiple dimension array obtained with `DMDAVecGetArrayDOFRead()`
 
-   Not Collective
+  Not Collective
 
-   Input Parameters:
-+  da - the distributed array
-.  vec - a vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
--  array - the `array` pointer is zeroed
+  Input Parameters:
++ da    - the distributed array
+. vec   - a vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
+- array - the `array` pointer
 
   Level: intermediate
 
   Fortran Note:
   Use `DMDAVecRestoreArrayReadF90()`
 
-.seealso: `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecGetArray()`, `DMDAVecGetArrayDOF()`, `DMDAVecRestoreArrayDOF()`,
+.seealso: [](sec_struct), [](sec_struct_set), `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecGetArray()`, `DMDAVecGetArrayDOF()`, `DMDAVecRestoreArrayDOF()`,
           `DMDAVecGetArrayWrite()`, `DMDAVecRestoreArrayWrite()`, `DMDAVecGetArrayRead()`, `DMDAVecRestoreArrayRead()`
 @*/
 PetscErrorCode DMDAVecRestoreArrayDOFRead(DM da, Vec vec, void *array)
@@ -648,39 +648,39 @@ PetscErrorCode DMDAVecRestoreArrayDOFRead(DM da, Vec vec, void *array)
 }
 
 /*@C
-   DMDAVecGetArrayDOFWrite - Returns a multiple dimension array that shares data with
-      the underlying vector and is indexed using the global dimensions.
+  DMDAVecGetArrayDOFWrite - Returns a multiple dimension array that shares data with
+  the underlying vector and is indexed using the global or local dimensions of a `DMDA`
 
-   Not Collective
+  Not Collective
 
-   Input Parameters:
-+  da - the distributed array
--  vec - a vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
+  Input Parameters:
++ da  - the distributed array
+- vec - a vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
 
-   Output Parameter:
-.  array - the array
+  Output Parameter:
+. array - the array
 
-   Level: intermediate
+  Level: intermediate
 
-   Notes:
-    Call `DMDAVecRestoreArrayDOFWrite()` once you have finished accessing the vector entries.
+  Notes:
+  Call `DMDAVecRestoreArrayDOFWrite()` once you have finished accessing the vector entries.
 
-    In C, the indexing is "backwards" from what expects: array[k][j][i][DOF] NOT array[i][j][k][DOF]!
+  In C, the indexing is "backwards" from what expects: array[k][j][i][DOF] NOT array[i][j][k][DOF]!
 
-   The accessible indices are `array[zs:zs+zm-1][ys:ys+ym-1][xs:xs+xm-1][0:dof-1]` where the values are obtained from
-   `DMDAGetCorners()` for a global vector or `DMDAGetGhostCorners()` for a local vector.
+  The accessible indices are `array[zs:zs+zm-1][ys:ys+ym-1][xs:xs+xm-1][0:dof-1]` where the values are obtained from
+  `DMDAGetCorners()` for a global vector or `DMDAGetGhostCorners()` for a local vector.
 
-   Fortran Note:
-   Use  `DMDAVecGetArrayWriteF90()` and pass for the array type PetscScalar,pointer :: array(:,...,:) of the appropriate
-   dimension. For a `DMDA` created with a dof of 1 use the dimension of the `DMDA`, for a `DMDA` created with a dof greater than 1 use one more than the
-   dimension of the `DMDA`.
+  Fortran Notes:
+  Use  `DMDAVecGetArrayWriteF90()` and pass for the array type PetscScalar,pointer :: array(:,...,:) of the appropriate
+  dimension. For a `DMDA` created with a dof of 1 use the dimension of the `DMDA`, for a `DMDA` created with a dof greater than 1 use one more than the
+  dimension of the `DMDA`.
 
-   The order of the indices is `array(xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1)` (when dof is 1) otherwise
-   `array(0:dof-1,xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1)` where the values are obtained from
-   `DMDAGetCorners()` for a global vector or `DMDAGetGhostCorners()` for a local vector.
+  The order of the indices is `array(xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1)` (when dof is 1) otherwise
+  `array(0:dof-1,xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1)` where the values are obtained from
+  `DMDAGetCorners()` for a global vector or `DMDAGetGhostCorners()` for a local vector.
 
-.seealso: `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `DMDAVecRestoreArrayWriteF90()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecRestoreArray()`, `DMDAVecGetArray()`, `DMDAVecGetArrayDOF()`,
-          `DMDAVecGetArrayWrite()`, `DMDAVecRestoreArrayWrite()`, `DMDAVecGetArrayWrite()`, `DMDAVecRestoreArrayWrite()`
+.seealso: [](sec_struct), [](sec_struct_set), `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `DMDAVecRestoreArrayWriteF90()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecRestoreArray()`, `DMDAVecGetArray()`, `DMDAVecGetArrayDOF()`,
+          `DMDAVecGetArrayWrite()`, `DMDAVecRestoreArrayWrite()`
 @*/
 PetscErrorCode DMDAVecGetArrayDOFWrite(DM da, Vec vec, void *array)
 {
@@ -713,22 +713,22 @@ PetscErrorCode DMDAVecGetArrayDOFWrite(DM da, Vec vec, void *array)
 }
 
 /*@
-   DMDAVecRestoreArrayDOFWrite - Restores a multiple dimension array obtained with `DMDAVecGetArrayDOFWrite()`
+  DMDAVecRestoreArrayDOFWrite - Restores a multiple dimension array obtained with `DMDAVecGetArrayDOFWrite()`
 
-   Not Collective
+  Not Collective
 
-   Input Parameters:
-+  da - the distributed array
-.  vec - a vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
--  array - the `array` pointer is zeroed
+  Input Parameters:
++ da    - the distributed array
+. vec   - a vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
+- array - the `array` pointer
 
   Level: intermediate
 
   Fortran Note:
   Use `DMDAVecRestoreArrayWriteF90()`
 
-.seealso: `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecGetArray()`, `DMDAVecGetArrayDOF()`, `DMDAVecRestoreArrayDOF()`,
-          `DMDAVecGetArrayWrite()`, `DMDAVecRestoreArrayWrite()`, `DMDAVecGetArrayWrite()`, `DMDAVecRestoreArrayWrite()`
+.seealso: [](sec_struct), [](sec_struct_set), `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecGetArray()`, `DMDAVecGetArrayDOF()`, `DMDAVecRestoreArrayDOF()`,
+          `DMDAVecGetArrayWrite()`, `DMDAVecRestoreArrayWrite()`
 @*/
 PetscErrorCode DMDAVecRestoreArrayDOFWrite(DM da, Vec vec, void *array)
 {
