@@ -6,7 +6,7 @@
 #include <moab/Skinner.hpp>
 
 /*MC
-  DMMOAB = "moab" - A DM object that encapsulates an unstructured mesh described by the MOAB mesh database.
+  DMMOAB = "moab" - A `DM` object that encapsulates an unstructured mesh described by the MOAB mesh database {cite}`moabwebsite`.
                     Direct access to the MOAB Interface and other mesh manipulation related objects are available
                     through public API. Ability to create global and local representation of Vecs containing all
                     unknowns in the interior and shared boundary via a transparent tag-data wrapper is provided
@@ -14,11 +14,9 @@
                     field-based/blocked Vec(Get/Set) methods. Input from and output to different formats are
                     available.
 
-  Reference: https://www.mcs.anl.gov/~fathom/moab-docs/html/contents.html
-
   Level: intermediate
 
-.seealso: `DMType`, `DMMoabCreate()`, `DMCreate()`, `DMSetType()`, `DMMoabCreateMoab()`
+.seealso: `DMMOAB`, `DMType`, `DMMoabCreate()`, `DMCreate()`, `DMSetType()`, `DMMoabCreateMoab()`
 M*/
 
 /* External function declarations here */
@@ -50,45 +48,47 @@ PETSC_EXTERN PetscErrorCode DMLocatePoints_Moab(DM dm, Vec v, IS *cellIS);
 */
 
 /*@C
-  DMMoabCreate - Creates a DMMoab object, which encapsulates a moab instance
+  DMMoabCreate - Creates a `DMMOAB` object, which encapsulates a moab instance
 
   Collective
 
   Input Parameter:
-. comm - The communicator for the DMMoab object
+. comm - The communicator for the `DMMOAB` object
 
   Output Parameter:
-. dmb  - The DMMoab object
+. dmb - The `DMMOAB` object
 
   Level: beginner
 
+.seealso: `DMMOAB`, `DMMoabCreateMoab()`
 @*/
 PetscErrorCode DMMoabCreate(MPI_Comm comm, DM *dmb)
 {
   PetscFunctionBegin;
-  PetscValidPointer(dmb, 2);
+  PetscAssertPointer(dmb, 2);
   PetscCall(DMCreate(comm, dmb));
   PetscCall(DMSetType(*dmb, DMMOAB));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-  DMMoabCreateMoab - Creates a DMMoab object, optionally from an instance and other data
+  DMMoabCreateMoab - Creates a `DMMOAB` object, optionally from an instance and other data
 
   Collective
 
   Input Parameters:
-+ comm - The communicator for the DMMoab object
-. mbiface - (ptr to) the MOAB Instance; if passed in NULL, MOAB instance is created inside PETSc, and destroyed
-         along with the DMMoab
++ comm     - The communicator for the `DMMOAB` object
+. mbiface  - (ptr to) the `DMMOAB` Instance; if passed in `NULL`, MOAB instance is created inside PETSc, and destroyed
+         along with the `DMMOAB`
 . ltog_tag - A tag to use to retrieve global id for an entity; if 0, will use GLOBAL_ID_TAG_NAME/tag
-- range - If non-NULL, contains range of entities to which DOFs will be assigned
+- range    - If non-`NULL`, contains range of entities to which DOFs will be assigned
 
   Output Parameter:
-. dmb  - The DMMoab object
+. dmb - The `DMMOAB` object
 
   Level: intermediate
 
+.seealso: `DMMOAB`, `DMMoabCreate()`
 @*/
 PetscErrorCode DMMoabCreateMoab(MPI_Comm comm, moab::Interface *mbiface, moab::Tag *ltog_tag, moab::Range *range, DM *dmb)
 {
@@ -97,7 +97,7 @@ PetscErrorCode DMMoabCreateMoab(MPI_Comm comm, moab::Interface *mbiface, moab::T
   DM_Moab        *dmmoab;
 
   PetscFunctionBegin;
-  PetscValidPointer(dmb, 6);
+  PetscAssertPointer(dmb, 6);
 
   PetscCall(DMMoabCreate(comm, &dmmb));
   dmmoab = (DM_Moab *)(dmmb)->data;
@@ -160,18 +160,19 @@ PetscErrorCode DMMoabCreateMoab(MPI_Comm comm, moab::Interface *mbiface, moab::T
 #ifdef MOAB_HAVE_MPI
 
 /*@C
-  DMMoabGetParallelComm - Get the ParallelComm used with this DMMoab
+  DMMoabGetParallelComm - Get the ParallelComm used with this `DMMOAB`
 
   Collective
 
   Input Parameter:
-. dm    - The DMMoab object being set
+. dm    - The `DMMOAB` object being set
 
   Output Parameter:
-. pcomm - The ParallelComm for the DMMoab
+. pcomm - The ParallelComm for the `DMMOAB`
 
   Level: beginner
 
+.seealso: `DMMOAB`, `DMMoabSetInterface()`
 @*/
 PetscErrorCode DMMoabGetParallelComm(DM dm, moab::ParallelComm **pcomm)
 {
@@ -184,16 +185,17 @@ PetscErrorCode DMMoabGetParallelComm(DM dm, moab::ParallelComm **pcomm)
 #endif /* MOAB_HAVE_MPI */
 
 /*@C
-  DMMoabSetInterface - Set the MOAB instance used with this DMMoab
+  DMMoabSetInterface - Set the MOAB instance used with this `DMMOAB`
 
   Collective
 
   Input Parameters:
-+ dm      - The DMMoab object being set
-- mbiface - The MOAB instance being set on this DMMoab
++ dm      - The `DMMOAB` object being set
+- mbiface - The MOAB instance being set on this `DMMOAB`
 
   Level: beginner
 
+.seealso: `DMMOAB`, `DMMoabGetInterface()`
 @*/
 PetscErrorCode DMMoabSetInterface(DM dm, moab::Interface *mbiface)
 {
@@ -201,7 +203,7 @@ PetscErrorCode DMMoabSetInterface(DM dm, moab::Interface *mbiface)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(dm, DM_CLASSID, 1);
-  PetscValidPointer(mbiface, 2);
+  PetscAssertPointer(mbiface, 2);
 #ifdef MOAB_HAVE_MPI
   dmmoab->pcomm = NULL;
 #endif
@@ -211,18 +213,19 @@ PetscErrorCode DMMoabSetInterface(DM dm, moab::Interface *mbiface)
 }
 
 /*@C
-  DMMoabGetInterface - Get the MOAB instance used with this DMMoab
+  DMMoabGetInterface - Get the MOAB instance used with this `DMMOAB`
 
   Collective
 
   Input Parameter:
-. dm      - The DMMoab object being set
+. dm - The `DMMOAB` object being set
 
   Output Parameter:
-. mbiface - The MOAB instance set on this DMMoab
+. mbiface - The MOAB instance set on this `DMMOAB`
 
   Level: beginner
 
+.seealso: `DMMOAB`, `DMMoabSetInterface()`
 @*/
 PetscErrorCode DMMoabGetInterface(DM dm, moab::Interface **mbiface)
 {
@@ -238,16 +241,17 @@ PetscErrorCode DMMoabGetInterface(DM dm, moab::Interface **mbiface)
 }
 
 /*@C
-  DMMoabSetLocalVertices - Set the entities having DOFs on this DMMoab
+  DMMoabSetLocalVertices - Set the entities having DOFs on this `DMMOAB`
 
   Collective
 
   Input Parameters:
-+ dm    - The DMMoab object being set
-- range - The entities treated by this DMMoab
++ dm    - The `DMMOAB` object being set
+- range - The entities treated by this `DMMOAB`
 
   Level: beginner
 
+.seealso: `DMMOAB`, `DMMoabGetAllVertices()`
 @*/
 PetscErrorCode DMMoabSetLocalVertices(DM dm, moab::Range *range)
 {
@@ -289,18 +293,19 @@ PetscErrorCode DMMoabSetLocalVertices(DM dm, moab::Range *range)
 }
 
 /*@C
-  DMMoabGetAllVertices - Get the entities having DOFs on this DMMoab
+  DMMoabGetAllVertices - Get the entities having DOFs on this `DMMOAB`
 
   Collective
 
   Input Parameter:
-. dm    - The DMMoab object being set
+. dm - The `DMMOAB` object being set
 
   Output Parameter:
-. owned - The local vertex entities in this DMMoab = (owned+ghosted)
+. local - The local vertex entities in this `DMMOAB` = (owned+ghosted)
 
   Level: beginner
 
+.seealso: `DMMOAB`, `DMMoabGetLocalVertices()`
 @*/
 PetscErrorCode DMMoabGetAllVertices(DM dm, moab::Range *local)
 {
@@ -311,19 +316,20 @@ PetscErrorCode DMMoabGetAllVertices(DM dm, moab::Range *local)
 }
 
 /*@C
-  DMMoabGetLocalVertices - Get the entities having DOFs on this DMMoab
+  DMMoabGetLocalVertices - Get the entities having DOFs on this `DMMOAB`
 
   Collective
 
   Input Parameter:
-. dm    - The DMMoab object being set
+. dm - The `DMMOAB` object being set
 
   Output Parameters:
-+ owned - The owned vertex entities in this DMMoab
++ owned - The owned vertex entities in this `DMMOAB`
 - ghost - The ghosted entities (non-owned) stored locally in this partition
 
   Level: beginner
 
+.seealso: `DMMOAB`, `DMMoabGetAllVertices()`
 @*/
 PetscErrorCode DMMoabGetLocalVertices(DM dm, const moab::Range **owned, const moab::Range **ghost)
 {
@@ -340,13 +346,14 @@ PetscErrorCode DMMoabGetLocalVertices(DM dm, const moab::Range **owned, const mo
   Collective
 
   Input Parameter:
-. dm    - The DMMoab object being set
+. dm - The `DMMOAB` object being set
 
   Output Parameter:
 . range - The entities owned locally
 
   Level: beginner
 
+.seealso: `DMMOAB`, `DMMoabSetLocalElements()`
 @*/
 PetscErrorCode DMMoabGetLocalElements(DM dm, const moab::Range **range)
 {
@@ -357,16 +364,17 @@ PetscErrorCode DMMoabGetLocalElements(DM dm, const moab::Range **range)
 }
 
 /*@C
-  DMMoabSetLocalElements - Set the entities having DOFs on this DMMoab
+  DMMoabSetLocalElements - Set the entities having DOFs on this `DMMOAB`
 
   Collective
 
   Input Parameters:
-+ dm    - The DMMoab object being set
-- range - The entities treated by this DMMoab
++ dm    - The `DMMOAB` object being set
+- range - The entities treated by this `DMMOAB`
 
   Level: beginner
 
+.seealso: `DMMOAB`, `DMMoabGetLocalElements()`
 @*/
 PetscErrorCode DMMoabSetLocalElements(DM dm, moab::Range *range)
 {
@@ -400,11 +408,12 @@ PetscErrorCode DMMoabSetLocalElements(DM dm, moab::Range *range)
   Collective
 
   Input Parameters:
-+ dm      - The DMMoab object being set
-- ltogtag - The MOAB tag used for local to global ids
++ dm      - The `DMMOAB` object being set
+- ltogtag - The `DMMOAB` tag used for local to global ids
 
   Level: beginner
 
+.seealso: `DMMOAB`, `DMMoabGetLocalToGlobalTag()`
 @*/
 PetscErrorCode DMMoabSetLocalToGlobalTag(DM dm, moab::Tag ltogtag)
 {
@@ -420,13 +429,14 @@ PetscErrorCode DMMoabSetLocalToGlobalTag(DM dm, moab::Tag ltogtag)
   Collective
 
   Input Parameter:
-. dm      - The DMMoab object being set
+. dm - The `DMMOAB` object being set
 
   Output Parameter:
-. ltogtag - The MOAB tag used for local to global ids
+. ltog_tag - The MOAB tag used for local to global ids
 
   Level: beginner
 
+.seealso: `DMMOAB`, `DMMoabSetLocalToGlobalTag()`
 @*/
 PetscErrorCode DMMoabGetLocalToGlobalTag(DM dm, moab::Tag *ltog_tag)
 {
@@ -437,16 +447,17 @@ PetscErrorCode DMMoabGetLocalToGlobalTag(DM dm, moab::Tag *ltog_tag)
 }
 
 /*@C
-  DMMoabSetBlockSize - Set the block size used with this DMMoab
+  DMMoabSetBlockSize - Set the block size used with this `DMMOAB`
 
   Collective
 
   Input Parameters:
-+ dm - The DMMoab object being set
-- bs - The block size used with this DMMoab
++ dm - The `DMMOAB` object being set
+- bs - The block size used with this `DMMOAB`
 
   Level: beginner
 
+.seealso: `DMMOAB`, `DMMoabGetBlockSize()`
 @*/
 PetscErrorCode DMMoabSetBlockSize(DM dm, PetscInt bs)
 {
@@ -457,18 +468,19 @@ PetscErrorCode DMMoabSetBlockSize(DM dm, PetscInt bs)
 }
 
 /*@C
-  DMMoabGetBlockSize - Get the block size used with this DMMoab
+  DMMoabGetBlockSize - Get the block size used with this `DMMOAB`
 
   Collective
 
   Input Parameter:
-. dm - The DMMoab object being set
+. dm - The `DMMOAB` object being set
 
   Output Parameter:
-. bs - The block size used with this DMMoab
+. bs - The block size used with this `DMMOAB`
 
   Level: beginner
 
+.seealso: `DMMOAB`, `DMMoabSetBlockSize()`
 @*/
 PetscErrorCode DMMoabGetBlockSize(DM dm, PetscInt *bs)
 {
@@ -479,19 +491,20 @@ PetscErrorCode DMMoabGetBlockSize(DM dm, PetscInt *bs)
 }
 
 /*@C
-  DMMoabGetSize - Get the global vertex size used with this DMMoab
+  DMMoabGetSize - Get the global vertex size used with this `DMMOAB`
 
-  Collective on dm
+  Collective
 
   Input Parameter:
-. dm - The DMMoab object being set
+. dm - The `DMMOAB` object being set
 
   Output Parameters:
-+ neg - The number of global elements in the DMMoab instance
-- nvg - The number of global vertices in the DMMoab instance
++ neg - The number of global elements in the `DMMOAB` instance
+- nvg - The number of global vertices in the `DMMOAB` instance
 
   Level: beginner
 
+.seealso: `DMMOAB`, `DMMoabGetLocalSize()`
 @*/
 PetscErrorCode DMMoabGetSize(DM dm, PetscInt *neg, PetscInt *nvg)
 {
@@ -503,12 +516,12 @@ PetscErrorCode DMMoabGetSize(DM dm, PetscInt *neg, PetscInt *nvg)
 }
 
 /*@C
-  DMMoabGetLocalSize - Get the local and ghosted vertex size used with this DMMoab
+  DMMoabGetLocalSize - Get the local and ghosted vertex size used with this `DMMOAB`
 
-  Collective on dm
+  Collective
 
   Input Parameter:
-. dm - The DMMoab object being set
+. dm - The `DMMOAB` object being set
 
   Output Parameters:
 + nel - The number of owned elements in this processor
@@ -518,6 +531,7 @@ PetscErrorCode DMMoabGetSize(DM dm, PetscInt *neg, PetscInt *nvg)
 
   Level: beginner
 
+.seealso: `DMMOAB`, `DMMoabGetSize()`
 @*/
 PetscErrorCode DMMoabGetLocalSize(DM dm, PetscInt *nel, PetscInt *neg, PetscInt *nvl, PetscInt *nvg)
 {
@@ -536,13 +550,14 @@ PetscErrorCode DMMoabGetLocalSize(DM dm, PetscInt *nel, PetscInt *neg, PetscInt
   Collective
 
   Input Parameter:
-. dm - The DMMoab object being set
+. dm - The `DMMOAB` object being set
 
   Output Parameter:
 . offset - The local offset for the global vector
 
   Level: beginner
 
+.seealso: `DMMOAB`, `DMMoabGetDimension()`
 @*/
 PetscErrorCode DMMoabGetOffset(DM dm, PetscInt *offset)
 {
@@ -553,18 +568,19 @@ PetscErrorCode DMMoabGetOffset(DM dm, PetscInt *offset)
 }
 
 /*@C
-  DMMoabGetDimension - Get the dimension of the DM Mesh
+  DMMoabGetDimension - Get the dimension of the `DM` Mesh
 
   Collective
 
   Input Parameter:
-. dm - The DMMoab object
+. dm - The `DMMOAB` object
 
   Output Parameter:
-. dim - The dimension of DM
+. dim - The dimension of `DM`
 
   Level: beginner
 
+.seealso: `DMMOAB`, `DMMoabGetOffset()`
 @*/
 PetscErrorCode DMMoabGetDimension(DM dm, PetscInt *dim)
 {
@@ -578,16 +594,17 @@ PetscErrorCode DMMoabGetDimension(DM dm, PetscInt *dim)
   DMMoabGetHierarchyLevel - Get the current level of the mesh hierarchy
   generated through uniform refinement.
 
-  Collective on dm
+  Collective
 
   Input Parameter:
-. dm - The DMMoab object being set
+. dm - The `DMMOAB` object being set
 
   Output Parameter:
-. nvg - The current mesh hierarchy level
+. nlevel - The current mesh hierarchy level
 
   Level: beginner
 
+.seealso: `DMMOAB`, `DMMoabGetMaterialBlock()`
 @*/
 PetscErrorCode DMMoabGetHierarchyLevel(DM dm, PetscInt *nlevel)
 {
@@ -603,7 +620,7 @@ PetscErrorCode DMMoabGetHierarchyLevel(DM dm, PetscInt *nlevel)
   Collective
 
   Input Parameters:
-+ dm - The DMMoab object
++ dm      - The `DMMOAB` object
 - ehandle - The element entity handle
 
   Output Parameter:
@@ -611,6 +628,7 @@ PetscErrorCode DMMoabGetHierarchyLevel(DM dm, PetscInt *nlevel)
 
   Level: beginner
 
+.seealso: `DMMOAB`, `DMMoabGetHierarchyLevel()`
 @*/
 PetscErrorCode DMMoabGetMaterialBlock(DM dm, const moab::EntityHandle ehandle, PetscInt *mat)
 {
@@ -631,16 +649,16 @@ PetscErrorCode DMMoabGetMaterialBlock(DM dm, const moab::EntityHandle ehandle, P
   Collective
 
   Input Parameters:
-+ dm - The DMMoab object
++ dm    - The `DMMOAB` object
 . nconn - Number of entities whose coordinates are needed
-- conn - The vertex entity handles
+- conn  - The vertex entity handles
 
   Output Parameter:
 . vpos - The coordinates of the requested vertex entities
 
   Level: beginner
 
-.seealso: `DMMoabGetVertexConnectivity()`
+.seealso: `DMMOAB`, `DMMoabGetVertexConnectivity()`
 @*/
 PetscErrorCode DMMoabGetVertexCoordinates(DM dm, PetscInt nconn, const moab::EntityHandle *conn, PetscReal *vpos)
 {
@@ -649,8 +667,8 @@ PetscErrorCode DMMoabGetVertexCoordinates(DM dm, PetscInt nconn, const moab::Ent
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(dm, DM_CLASSID, 1);
-  PetscValidPointer(conn, 3);
-  PetscValidPointer(vpos, 4);
+  PetscAssertPointer(conn, 3);
+  PetscAssertPointer(vpos, 4);
   dmmoab = (DM_Moab *)(dm)->data;
 
   /* Get connectivity information in MOAB canonical ordering */
@@ -670,16 +688,16 @@ PetscErrorCode DMMoabGetVertexCoordinates(DM dm, PetscInt nconn, const moab::Ent
   Collective
 
   Input Parameters:
-+ dm - The DMMoab object
++ dm      - The `DMMOAB` object
 - vhandle - Vertex entity handle
 
   Output Parameters:
 + nconn - Number of entities whose coordinates are needed
-- conn - The vertex entity handles
+- conn  - The vertex entity handles
 
   Level: beginner
 
-.seealso: `DMMoabGetVertexCoordinates()`, `DMMoabRestoreVertexConnectivity()`
+.seealso: `DMMOAB`, `DMMoabGetVertexCoordinates()`, `DMMoabRestoreVertexConnectivity()`
 @*/
 PetscErrorCode DMMoabGetVertexConnectivity(DM dm, moab::EntityHandle vhandle, PetscInt *nconn, moab::EntityHandle **conn)
 {
@@ -689,7 +707,7 @@ PetscErrorCode DMMoabGetVertexConnectivity(DM dm, moab::EntityHandle vhandle, Pe
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(dm, DM_CLASSID, 1);
-  PetscValidPointer(conn, 4);
+  PetscAssertPointer(conn, 4);
   dmmoab = (DM_Moab *)(dm)->data;
 
   /* Get connectivity information in MOAB canonical ordering */
@@ -712,20 +730,20 @@ PetscErrorCode DMMoabGetVertexConnectivity(DM dm, moab::EntityHandle vhandle, Pe
   Collective
 
   Input Parameters:
-+ dm - The DMMoab object
-. vhandle - Vertex entity handle
-. nconn - Number of entities whose coordinates are needed
-- conn - The vertex entity handles
++ dm      - The `DMMOAB` object
+. ehandle - Vertex entity handle
+. nconn   - Number of entities whose coordinates are needed
+- conn    - The vertex entity handles
 
   Level: beginner
 
-.seealso: `DMMoabGetVertexCoordinates()`, `DMMoabGetVertexConnectivity()`
+.seealso: `DMMOAB`, `DMMoabGetVertexCoordinates()`, `DMMoabGetVertexConnectivity()`
 @*/
 PetscErrorCode DMMoabRestoreVertexConnectivity(DM dm, moab::EntityHandle ehandle, PetscInt *nconn, moab::EntityHandle **conn)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(dm, DM_CLASSID, 1);
-  PetscValidPointer(conn, 4);
+  PetscAssertPointer(conn, 4);
 
   if (conn) PetscCall(PetscFree(*conn));
   if (nconn) *nconn = 0;
@@ -738,16 +756,16 @@ PetscErrorCode DMMoabRestoreVertexConnectivity(DM dm, moab::EntityHandle ehandle
   Collective
 
   Input Parameters:
-+ dm - The DMMoab object
++ dm      - The `DMMOAB` object
 - ehandle - Vertex entity handle
 
   Output Parameters:
 + nconn - Number of entities whose coordinates are needed
-- conn - The vertex entity handles
+- conn  - The vertex entity handles
 
   Level: beginner
 
-.seealso: `DMMoabGetVertexCoordinates()`, `DMMoabGetVertexConnectivity()`, `DMMoabRestoreVertexConnectivity()`
+.seealso: `DMMOAB`, `DMMoabGetVertexCoordinates()`, `DMMoabGetVertexConnectivity()`, `DMMoabRestoreVertexConnectivity()`
 @*/
 PetscErrorCode DMMoabGetElementConnectivity(DM dm, moab::EntityHandle ehandle, PetscInt *nconn, const moab::EntityHandle **conn)
 {
@@ -759,7 +777,7 @@ PetscErrorCode DMMoabGetElementConnectivity(DM dm, moab::EntityHandle ehandle, P
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(dm, DM_CLASSID, 1);
-  PetscValidPointer(conn, 4);
+  PetscAssertPointer(conn, 4);
   dmmoab = (DM_Moab *)(dm)->data;
 
   /* Get connectivity information in MOAB canonical ordering */
@@ -776,15 +794,15 @@ PetscErrorCode DMMoabGetElementConnectivity(DM dm, moab::EntityHandle ehandle, P
   Collective
 
   Input Parameters:
-+ dm - The DMMoab object
++ dm  - The `DMMOAB` object
 - ent - Entity handle
 
   Output Parameter:
-. ent_on_boundary - PETSC_TRUE if entity on boundary; PETSC_FALSE otherwise
+. ent_on_boundary - `PETSC_TRUE` if entity on boundary; `PETSC_FALSE` otherwise
 
   Level: beginner
 
-.seealso: `DMMoabCheckBoundaryVertices()`
+.seealso: `DMMOAB`, `DMMoabCheckBoundaryVertices()`
 @*/
 PetscErrorCode DMMoabIsEntityOnBoundary(DM dm, const moab::EntityHandle ent, PetscBool *ent_on_boundary)
 {
@@ -794,7 +812,7 @@ PetscErrorCode DMMoabIsEntityOnBoundary(DM dm, const moab::EntityHandle ent, Pet
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(dm, DM_CLASSID, 1);
-  PetscValidPointer(ent_on_boundary, 3);
+  PetscAssertPointer(ent_on_boundary, 3);
   dmmoab = (DM_Moab *)(dm)->data;
 
   /* get the entity type and handle accordingly */
@@ -821,16 +839,16 @@ PetscErrorCode DMMoabIsEntityOnBoundary(DM dm, const moab::EntityHandle ent, Pet
   DMMoabCheckBoundaryVertices - Check whether a given entity is on the boundary (vertex, edge, face, element)
 
   Input Parameters:
-+ dm - The DMMoab object
++ dm    - The `DMMOAB` object
 . nconn - Number of handles
-- cnt - Array of entity handles
+- cnt   - Array of entity handles
 
   Output Parameter:
-. isbdvtx - Array of boundary markers - PETSC_TRUE if entity on boundary; PETSC_FALSE otherwise
+. isbdvtx - Array of boundary markers - `PETSC_TRUE` if entity on boundary; `PETSC_FALSE` otherwise
 
   Level: beginner
 
-.seealso: `DMMoabIsEntityOnBoundary()`
+.seealso: `DMMOAB`, `DMMoabIsEntityOnBoundary()`
 @*/
 PetscErrorCode DMMoabCheckBoundaryVertices(DM dm, PetscInt nconn, const moab::EntityHandle *cnt, PetscBool *isbdvtx)
 {
@@ -839,8 +857,8 @@ PetscErrorCode DMMoabCheckBoundaryVertices(DM dm, PetscInt nconn, const moab::En
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(dm, DM_CLASSID, 1);
-  PetscValidPointer(cnt, 3);
-  PetscValidPointer(isbdvtx, 4);
+  PetscAssertPointer(cnt, 3);
+  PetscAssertPointer(isbdvtx, 4);
   dmmoab = (DM_Moab *)(dm)->data;
 
   for (i = 0; i < nconn; ++i) isbdvtx[i] = (dmmoab->bndyvtx->index(cnt[i]) >= 0 ? PETSC_TRUE : PETSC_FALSE);
@@ -851,16 +869,16 @@ PetscErrorCode DMMoabCheckBoundaryVertices(DM dm, PetscInt nconn, const moab::En
   DMMoabGetBoundaryMarkers - Return references to the vertices, faces, elements on the boundary
 
   Input Parameter:
-. dm - The DMMoab object
+. dm - The `DMMOAB` object
 
   Output Parameters:
-+ bdvtx - Boundary vertices
++ bdvtx   - Boundary vertices
 . bdelems - Boundary elements
 - bdfaces - Boundary faces
 
   Level: beginner
 
-.seealso: `DMMoabCheckBoundaryVertices()`, `DMMoabIsEntityOnBoundary()`
+.seealso: `DMMOAB`, `DMMoabCheckBoundaryVertices()`, `DMMoabIsEntityOnBoundary()`
 @*/
 PetscErrorCode DMMoabGetBoundaryMarkers(DM dm, const moab::Range **bdvtx, const moab::Range **bdelems, const moab::Range **bdfaces)
 {
@@ -1204,7 +1222,7 @@ PETSC_EXTERN PetscErrorCode DMSetUp_Moab(DM dm)
     moab::Range msets;
     merr = dmmoab->mbiface->get_entities_by_type_and_tag(dmmoab->fileset, moab::MBENTITYSET, &dmmoab->material_tag, NULL, 1, msets, moab::Interface::UNION);
     MBERRNM(merr);
-    if (msets.size() == 0) PetscCall(PetscInfo(NULL, "No material sets found in the fileset."));
+    if (msets.size() == 0) PetscCall(PetscInfo(NULL, "No material sets found in the fileset.\n"));
 
     for (unsigned i = 0; i < msets.size(); ++i) {
       moab::Range msetelems;
@@ -1234,17 +1252,16 @@ PETSC_EXTERN PetscErrorCode DMSetUp_Moab(DM dm)
   Collective
 
   Input Parameters:
-+ dm - The DM object
-. type - The type of element to create and add (Edge/Tri/Quad/Tet/Hex/Prism/Pyramid/Polygon/Polyhedra)
-. conn - The connectivity of the element
++ dm     - The `DM` object
+. coords - The connectivity of the element
 - nverts - The number of vertices that form the element
 
   Output Parameter:
-. overts  - The list of vertices that were created (can be NULL)
+. overts - The list of vertices that were created (can be `NULL`)
 
   Level: beginner
 
-.seealso: `DMMoabCreateSubmesh()`, `DMMoabCreateElement()`
+.seealso: `DMMOAB`, `DMMoabCreateSubmesh()`, `DMMoabCreateElement()`
 @*/
 PetscErrorCode DMMoabCreateVertices(DM dm, const PetscReal *coords, PetscInt nverts, moab::Range *overts)
 {
@@ -1254,7 +1271,7 @@ PetscErrorCode DMMoabCreateVertices(DM dm, const PetscReal *coords, PetscInt nve
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(dm, DM_CLASSID, 1);
-  PetscValidPointer(coords, 2);
+  PetscAssertPointer(coords, 2);
 
   dmmoab = (DM_Moab *)dm->data;
 
@@ -1274,17 +1291,17 @@ PetscErrorCode DMMoabCreateVertices(DM dm, const PetscReal *coords, PetscInt nve
   Collective
 
   Input Parameters:
-+ dm - The DM object
-. type - The type of element to create and add (Edge/Tri/Quad/Tet/Hex/Prism/Pyramid/Polygon/Polyhedra)
-. conn - The connectivity of the element
++ dm     - The DM object
+. type   - The type of element to create and add (Edge/Tri/Quad/Tet/Hex/Prism/Pyramid/Polygon/Polyhedra)
+. conn   - The connectivity of the element
 - nverts - The number of vertices that form the element
 
   Output Parameter:
-. oelem  - The handle to the element created and added to the DM object
+. oelem - The handle to the element created and added to the `DM` object
 
   Level: beginner
 
-.seealso: `DMMoabCreateSubmesh()`, `DMMoabCreateVertices()`
+.seealso: `DMMOAB`, `DMMoabCreateSubmesh()`, `DMMoabCreateVertices()`
 @*/
 PetscErrorCode DMMoabCreateElement(DM dm, const moab::EntityType type, const moab::EntityHandle *conn, PetscInt nverts, moab::EntityHandle *oelem)
 {
@@ -1294,7 +1311,7 @@ PetscErrorCode DMMoabCreateElement(DM dm, const moab::EntityType type, const moa
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(dm, DM_CLASSID, 1);
-  PetscValidPointer(conn, 3);
+  PetscAssertPointer(conn, 3);
 
   dmmoab = (DM_Moab *)dm->data;
 
@@ -1309,21 +1326,21 @@ PetscErrorCode DMMoabCreateElement(DM dm, const moab::EntityType type, const moa
 }
 
 /*@C
-  DMMoabCreateSubmesh - Creates a sub-DM object with a set that contains all vertices/elements of the parent
+  DMMoabCreateSubmesh - Creates a sub-`DM` object with a set that contains all vertices/elements of the parent
   in addition to providing support for dynamic mesh modifications. This is useful for AMR calculations to
   create a DM object on a refined level.
 
   Collective
 
   Input Parameters:
-. dm - The DM object
+. dm - The `DM` object
 
   Output Parameter:
-. newdm  - The sub DM object with updated set information
+. newdm - The sub `DM` object with updated set information
 
   Level: advanced
 
-.seealso: `DMCreate()`, `DMMoabCreateVertices()`, `DMMoabCreateElement()`
+.seealso: `DMMOAB`, `DMCreate()`, `DMMoabCreateVertices()`, `DMMoabCreateElement()`
 @*/
 PetscErrorCode DMMoabCreateSubmesh(DM dm, DM *newdm)
 {
@@ -1336,7 +1353,7 @@ PetscErrorCode DMMoabCreateSubmesh(DM dm, DM *newdm)
 
   dmmoab = (DM_Moab *)dm->data;
 
-  /* Create the basic DMMoab object and keep the default parameters created by DM impls */
+  /* Create the basic DMMOAB object and keep the default parameters created by DM impls */
   PetscCall(DMMoabCreateMoab(((PetscObject)dm)->comm, dmmoab->mbiface, &dmmoab->ltog_tag, NULL, newdm));
 
   /* get all the necessary handles from the private DM object */
