@@ -13,7 +13,7 @@
 - interpolate - Create faces and edges in the mesh
 
   Output Parameter:
-. dm  - The `DM` object representing the mesh
+. dm - The `DM` object representing the mesh
 
   Level: beginner
 
@@ -220,20 +220,17 @@ static PetscErrorCode DMPlexCreateFluent_ReadSection(PetscViewer viewer, FluentS
 }
 
 /*@C
-  DMPlexCreateFluent - Create a `DMPLEX` mesh from a Fluent mesh file.
+  DMPlexCreateFluent - Create a `DMPLEX` mesh from a Fluent mesh file <http://aerojet.engr.ucdavis.edu/fluenthelp/html/ug/node1490.htm>.
 
   Collective
 
   Input Parameters:
-+ comm  - The MPI communicator
-. viewer - The `PetscViewer` associated with a Fluent mesh file
++ comm        - The MPI communicator
+. viewer      - The `PetscViewer` associated with a Fluent mesh file
 - interpolate - Create faces and edges in the mesh
 
   Output Parameter:
-. dm  - The `DM` object representing the mesh
-
-  Note:
-  http://aerojet.engr.ucdavis.edu/fluenthelp/html/ug/node1490.htm
+. dm - The `DM` object representing the mesh
 
   Level: beginner
 
