@@ -1,4 +1,3 @@
-
 #include <petscao.h>
 #include <petsc/private/dmlabelimpl.h>
 #include <petsc/private/dmfieldimpl.h>
@@ -12,8 +11,8 @@
 
 static PetscBool DMPackageInitialized = PETSC_FALSE;
 /*@C
-  DMFinalizePackage - This function finalizes everything in the DM package. It is called
-  from PetscFinalize().
+  DMFinalizePackage - This function finalizes everything in the `DM` package. It is called
+  from `PetscFinalize()`.
 
   Level: developer
 
@@ -34,9 +33,9 @@ PETSC_EXTERN PetscErrorCode MatCreate_HYPRESStruct(Mat);
 #endif
 
 /*@C
-  DMInitializePackage - This function initializes everything in the DM package. It is called
-  from PetscDLLibraryRegister_petscdm() when using dynamic libraries, and on the first call to AOCreate()
-  or DMDACreate() when using shared or static libraries.
+  DMInitializePackage - This function initializes everything in the `DM` package. It is called
+  from `PetscDLLibraryRegister_petscdm()` when using dynamic libraries, and on the first call to `DMCreate()`
+  or `DMDACreate()` when using shared or static libraries.
 
   Level: developer
 
@@ -79,11 +78,13 @@ PetscErrorCode DMInitializePackage(void)
   PetscCall(PetscLogEventRegister("DMCreateMassMat", DM_CLASSID, &DM_CreateMassMatrix));
   PetscCall(PetscLogEventRegister("DMLoad", DM_CLASSID, &DM_Load));
   PetscCall(PetscLogEventRegister("DMAdaptInterp", DM_CLASSID, &DM_AdaptInterpolator));
+  PetscCall(PetscLogEventRegister("DMProjectFunc", DM_CLASSID, &DM_ProjectFunction));
 
   PetscCall(PetscLogEventRegister("DMPlexBuFrCeLi", DM_CLASSID, &DMPLEX_BuildFromCellList));
   PetscCall(PetscLogEventRegister("DMPlexBuCoFrCeLi", DM_CLASSID, &DMPLEX_BuildCoordinatesFromCellList));
   PetscCall(PetscLogEventRegister("DMPlexCreateGmsh", DM_CLASSID, &DMPLEX_CreateGmsh));
   PetscCall(PetscLogEventRegister("DMPlexCrFromFile", DM_CLASSID, &DMPLEX_CreateFromFile));
+  PetscCall(PetscLogEventRegister("DMPlexCrFromOpts", DM_CLASSID, &DMPLEX_CreateFromOptions));
   PetscCall(PetscLogEventRegister("Mesh Partition", DM_CLASSID, &DMPLEX_Partition));
   PetscCall(PetscLogEventRegister("Mesh Migration", DM_CLASSID, &DMPLEX_Migrate));
   PetscCall(PetscLogEventRegister("DMPlexPartSelf", DM_CLASSID, &DMPLEX_PartSelf));
@@ -133,12 +134,15 @@ PetscErrorCode DMInitializePackage(void)
   PetscCall(PetscLogEventRegister("DMPlexMetricAverage", DM_CLASSID, &DMPLEX_MetricAverage));
   PetscCall(PetscLogEventRegister("DMPlexMetricIntersect", DM_CLASSID, &DMPLEX_MetricIntersection));
   PetscCall(PetscLogEventRegister("DMPlexGenerate", DM_CLASSID, &DMPLEX_Generate));
+  PetscCall(PetscLogEventRegister("DMPlexTransform", DM_CLASSID, &DMPLEX_Transform));
+  PetscCall(PetscLogEventRegister("DMPlexGetLocOff", DM_CLASSID, &DMPLEX_GetLocalOffsets));
 
   PetscCall(PetscLogEventRegister("RebalBuildGraph", DM_CLASSID, &DMPLEX_RebalBuildGraph));
   PetscCall(PetscLogEventRegister("RebalGatherGraph", DM_CLASSID, &DMPLEX_RebalGatherGraph));
   PetscCall(PetscLogEventRegister("RebalPartition", DM_CLASSID, &DMPLEX_RebalPartition));
   PetscCall(PetscLogEventRegister("RebalScatterPart", DM_CLASSID, &DMPLEX_RebalScatterPart));
   PetscCall(PetscLogEventRegister("RebalRewriteSF", DM_CLASSID, &DMPLEX_RebalRewriteSF));
+  PetscCall(PetscLogEventRegister("DMPlexUninterp", DM_CLASSID, &DMPLEX_Uninterpolate));
 
   PetscCall(PetscLogEventRegister("DMSwarmMigrate", DM_CLASSID, &DMSWARM_Migrate));
   PetscCall(PetscLogEventRegister("DMSwarmDETSetup", DM_CLASSID, &DMSWARM_DataExchangerTopologySetup));
@@ -181,9 +185,10 @@ PetscErrorCode DMInitializePackage(void)
 #include <petscfe.h>
 
 static PetscBool PetscFEPackageInitialized = PETSC_FALSE;
+
 /*@C
-  PetscFEFinalizePackage - This function finalizes everything in the PetscFE package. It is called
-  from PetscFinalize().
+  PetscFEFinalizePackage - This function finalizes everything in the `PetscFE` package. It is called
+  from `PetscFinalize()`.
 
   Level: developer
 
@@ -203,8 +208,8 @@ PetscErrorCode PetscFEFinalizePackage(void)
 }
 
 /*@C
-  PetscFEInitializePackage - This function initializes everything in the FE package. It is called
-  from PetscDLLibraryRegister() when using dynamic libraries, and on the first call to PetscSpaceCreate()
+  PetscFEInitializePackage - This function initializes everything in the `PetscFE` package. It is called
+  from `PetscDLLibraryRegister()` when using dynamic libraries, and on the first call to `PetscSpaceCreate()`
   when using static libraries.
 
   Level: developer
@@ -255,9 +260,10 @@ PetscErrorCode PetscFEInitializePackage(void)
 #include <petscfv.h>
 
 static PetscBool PetscFVPackageInitialized = PETSC_FALSE;
+
 /*@C
-  PetscFVFinalizePackage - This function finalizes everything in the PetscFV package. It is called
-  from PetscFinalize().
+  PetscFVFinalizePackage - This function finalizes everything in the `PetscFV` package. It is called
+  from `PetscFinalize()`.
 
   Level: developer
 
@@ -275,8 +281,8 @@ PetscErrorCode PetscFVFinalizePackage(void)
 }
 
 /*@C
-  PetscFVInitializePackage - This function initializes everything in the FV package. It is called
-  from PetscDLLibraryRegister() when using dynamic libraries, and on the first call to PetscFVCreate()
+  PetscFVInitializePackage - This function initializes everything in the `PetscFV` package. It is called
+  from `PetscDLLibraryRegister()` when using dynamic libraries, and on the first call to `PetscFVCreate()`
   when using static libraries.
 
   Level: developer
@@ -322,6 +328,7 @@ PetscErrorCode PetscFVInitializePackage(void)
 #include <petscds.h>
 
 static PetscBool PetscDSPackageInitialized = PETSC_FALSE;
+
 /*@C
   PetscDSFinalizePackage - This function finalizes everything in the PetscDS package. It is called
   from PetscFinalize().
@@ -340,8 +347,8 @@ PetscErrorCode PetscDSFinalizePackage(void)
 }
 
 /*@C
-  PetscDSInitializePackage - This function initializes everything in the DS package. It is called
-  from PetscDLLibraryRegister() when using dynamic libraries, and on the first call to PetscDSCreate()
+  PetscDSInitializePackage - This function initializes everything in the `PetscDS` package. It is called
+  from `PetscDLLibraryRegister()` when using dynamic libraries, and on the first call to `PetscDSCreate()`
   when using static libraries.
 
   Level: developer
