@@ -1,41 +1,41 @@
 #include <petsc/private/dmimpl.h> /*I "petscdm.h" I*/
 
 /*@
-   DMGetLocalVector - Gets a PETSc vector that may be used with the DM local routines. This vector has spaces for the ghost values.
+  DMGetLocalVector - Gets a PETSc vector that may be used with the `DM` local routines. This vector has spaces for the ghost values.
 
-   Not Collective
+  Not Collective
 
-   Input Parameter:
-.  dm - the dm
+  Input Parameter:
+. dm - the `DM`
 
-   Output Parameter:
-.  g - the local vector
+  Output Parameter:
+. g - the local vector
 
-   Level: beginner
+  Level: beginner
 
-   Note:
-   The vector values are NOT initialized and may have garbage in them, so you may need
-   to zero them.
+  Note:
+  The vector values are NOT initialized and may have garbage in them, so you may need
+  to zero them.
 
-   The output parameter, g, is a regular PETSc vector that should be returned with
-   DMRestoreLocalVector() DO NOT call VecDestroy() on it.
+  The output parameter, `g`, is a regular PETSc vector that should be returned with
+  `DMRestoreLocalVector()` DO NOT call `VecDestroy()` on it.
 
-   This is intended to be used for vectors you need for a short time, like within a single function call.
-   For vectors that you intend to keep around (for example in a C struct) or pass around large parts of your
-   code you should use DMCreateLocalVector().
+  This is intended to be used for vectors you need for a short time, like within a single function call.
+  For vectors that you intend to keep around (for example in a C struct) or pass around large parts of your
+  code you should use `DMCreateLocalVector()`.
 
-   VecStride*() operations can be useful when using DM with dof > 1
+  VecStride*() operations can be useful when using `DM` with dof > 1
 
-.seealso: `DMCreateGlobalVector()`, `VecDuplicate()`, `VecDuplicateVecs()`,
+.seealso: `DM`, `DMCreateGlobalVector()`, `VecDuplicate()`, `VecDuplicateVecs()`,
           `DMDACreate1d()`, `DMDACreate2d()`, `DMDACreate3d()`, `DMGlobalToLocalBegin()`,
           `DMGlobalToLocalEnd()`, `DMLocalToGlobalBegin()`, `DMCreateLocalVector()`, `DMRestoreLocalVector()`,
-          `VecStrideMax()`, `VecStrideMin()`, `VecStrideNorm()`
+          `VecStrideMax()`, `VecStrideMin()`, `VecStrideNorm()`, `DMClearLocalVectors()`, `DMGetNamedGlobalVector()`, `DMGetNamedLocalVector()`
 @*/
 PetscErrorCode DMGetLocalVector(DM dm, Vec *g)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(dm, DM_CLASSID, 1);
-  PetscValidPointer(g, 2);
+  PetscAssertPointer(g, 2);
   for (PetscInt i = 0; i < DM_MAX_WORK_VECTORS; i++) {
     if (dm->localin[i]) {
       DM vdm;
@@ -58,25 +58,25 @@ alldone:
       break;
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-   DMRestoreLocalVector - Returns a PETSc vector that was
-     obtained from `DMGetLocalVector()`. Do not use with vector obtained via
-     `DMCreateLocalVector()`.
+  DMRestoreLocalVector - Returns a PETSc vector that was
+  obtained from `DMGetLocalVector()`. Do not use with vector obtained via
+  `DMCreateLocalVector()`.
 
-   Not Collective
+  Not Collective
 
-   Input Parameters:
-+  dm - the dm
--  g - the local vector
+  Input Parameters:
++ dm - the `DM`
+- g  - the local vector
 
-   Level: beginner
+  Level: beginner
 
 .seealso: `DM`, `DMCreateGlobalVector()`, `VecDuplicate()`, `VecDuplicateVecs()`,
           `DMDACreate1d()`, `DMDACreate2d()`, `DMDACreate3d()`, `DMGlobalToLocalBegin()`,
-          `DMGlobalToLocalEnd()`, `DMLocalToGlobalBegin()`, `DMCreateLocalVector()`, `DMGetLocalVector()`
+          `DMGlobalToLocalEnd()`, `DMLocalToGlobalBegin()`, `DMCreateLocalVector()`, `DMGetLocalVector()`, `DMClearLocalVectors()`
 @*/
 PetscErrorCode DMRestoreLocalVector(DM dm, Vec *g)
 {
@@ -84,7 +84,7 @@ PetscErrorCode DMRestoreLocalVector(DM dm, Vec *g)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(dm, DM_CLASSID, 1);
-  PetscValidPointer(g, 2);
+  PetscAssertPointer(g, 2);
   for (j = 0; j < DM_MAX_WORK_VECTORS; j++) {
     if (*g == dm->localout[j]) {
       DM vdm;
@@ -104,39 +104,39 @@ PetscErrorCode DMRestoreLocalVector(DM dm, Vec *g)
   PetscCall(VecDestroy(g));
 alldone:
   *g = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-   DMGetGlobalVector - Gets a PETSc vector that may be used with the `DM` global routines.
+  DMGetGlobalVector - Gets a PETSc vector that may be used with the `DM` global routines.
 
-   Collective on dm
+  Collective
 
-   Input Parameter:
-.  dm - the dm
+  Input Parameter:
+. dm - the `DM`
 
-   Output Parameter:
-.  g - the global vector
+  Output Parameter:
+. g - the global vector
 
-   Level: beginner
+  Level: beginner
 
-   Note:
-   The vector values are NOT initialized and may have garbage in them, so you may need
-   to zero them.
+  Note:
+  The vector values are NOT initialized and may have garbage in them, so you may need
+  to zero them.
 
-   The output parameter, g, is a regular PETSc vector that should be returned with
-   `DMRestoreGlobalVector()` DO NOT call `VecDestroy()` on it.
+  The output parameter, `g`, is a regular PETSc vector that should be returned with
+  `DMRestoreGlobalVector()` DO NOT call `VecDestroy()` on it.
 
-   This is intended to be used for vectors you need for a short time, like within a single function call.
-   For vectors that you intend to keep around (for example in a C struct) or pass around large parts of your
-   code you should use `DMCreateGlobalVector()`.
+  This is intended to be used for vectors you need for a short time, like within a single function call.
+  For vectors that you intend to keep around (for example in a C struct) or pass around large parts of your
+  code you should use `DMCreateGlobalVector()`.
 
-   VecStride*() operations can be useful when using `DM` with dof > 1
+  VecStride*() operations can be useful when using `DM` with dof > 1
 
 .seealso: `DM`, `DMCreateGlobalVector()`, `VecDuplicate()`, `VecDuplicateVecs()`,
           `DMDACreate1d()`, `DMDACreate2d()`, `DMDACreate3d()`, `DMGlobalToLocalBegin()`,
           `DMGlobalToLocalEnd()`, `DMLocalToGlobalBegin()`, `DMCreateLocalVector()`, `DMRestoreLocalVector()`
-          `VecStrideMax()`, `VecStrideMin()`, `VecStrideNorm()`
+          `VecStrideMax()`, `VecStrideMin()`, `VecStrideNorm()`, `DMClearGlobalVectors()`, `DMGetNamedGlobalVector()`, `DMGetNamedLocalVector()`
 @*/
 PetscErrorCode DMGetGlobalVector(DM dm, Vec *g)
 {
@@ -144,7 +144,7 @@ PetscErrorCode DMGetGlobalVector(DM dm, Vec *g)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(dm, DM_CLASSID, 1);
-  PetscValidPointer(g, 2);
+  PetscAssertPointer(g, 2);
   for (i = 0; i < DM_MAX_WORK_VECTORS; i++) {
     if (dm->globalin[i]) {
       DM vdm;
@@ -167,23 +167,23 @@ alldone:
       break;
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-   DMClearGlobalVectors - Destroys all the global vectors that have been stashed in this DM
+  DMClearGlobalVectors - Destroys all the global vectors that have been created for `DMGetGlobalVector()` calls in this `DM`
 
-   Collective on dm
+  Collective
 
-   Input Parameter:
-.  dm - the dm
+  Input Parameter:
+. dm - the `DM`
 
-   Level: developer
+  Level: developer
 
-.seealso: `DMCreateGlobalVector()`, `VecDuplicate()`, `VecDuplicateVecs()`,
+.seealso: `DM`, `DMCreateGlobalVector()`, `VecDuplicate()`, `VecDuplicateVecs()`,
           `DMDACreate1d()`, `DMDACreate2d()`, `DMDACreate3d()`, `DMGlobalToLocalBegin()`,
           `DMGlobalToLocalEnd()`, `DMLocalToGlobalBegin()`, `DMCreateLocalVector()`, `DMRestoreLocalVector()`
-          `VecStrideMax()`, `VecStrideMin()`, `VecStrideNorm()`
+          `VecStrideMax()`, `VecStrideMin()`, `VecStrideNorm()`, `DMClearLocalVectors()`
 @*/
 PetscErrorCode DMClearGlobalVectors(DM dm)
 {
@@ -205,23 +205,23 @@ PetscErrorCode DMClearGlobalVectors(DM dm)
     }
     PetscCall(VecDestroy(&g));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-   DMClearLocalVectors - Destroys all the local vectors that have been stashed in this DM
+  DMClearLocalVectors - Destroys all the local vectors that have been created for `DMGetLocalVector()` calls in this `DM`
 
-   Collective on dm
+  Collective
 
-   Input Parameter:
-.  dm - the dm
+  Input Parameter:
+. dm - the `DM`
 
-   Level: developer
+  Level: developer
 
-.seealso: `DMCreateLocalVector()`, `VecDuplicate()`, `VecDuplicateVecs()`,
+.seealso: `DM`, `DMCreateLocalVector()`, `VecDuplicate()`, `VecDuplicateVecs()`,
           `DMDACreate1d()`, `DMDACreate2d()`, `DMDACreate3d()`, `DMLocalToLocalBegin()`,
-          `DMLocalToLocalEnd()`, `DMLocalToLocalBegin()`, `DMCreateLocalVector()`, `DMRestoreLocalVector()`
-          `VecStrideMax()`, `VecStrideMin()`, `VecStrideNorm()`
+          `DMLocalToLocalEnd()`, `DMRestoreLocalVector()`
+          `VecStrideMax()`, `VecStrideMin()`, `VecStrideNorm()`, `DMClearGlobalVectors()`
 @*/
 PetscErrorCode DMClearLocalVectors(DM dm)
 {
@@ -232,36 +232,36 @@ PetscErrorCode DMClearLocalVectors(DM dm)
   for (i = 0; i < DM_MAX_WORK_VECTORS; i++) {
     Vec g;
 
-    PetscCheck(!dm->localout[i], PetscObjectComm((PetscObject)dm), PETSC_ERR_ARG_WRONGSTATE, "Clearing DM of local vectors that has a local vector obtained with DMGetLocalVector()");
+    PetscCheck(!dm->localout[i], PETSC_COMM_SELF, PETSC_ERR_ARG_WRONGSTATE, "Clearing DM of local vectors that has a local vector obtained with DMGetLocalVector()");
     g              = dm->localin[i];
     dm->localin[i] = NULL;
     if (g) {
       DM vdm;
 
       PetscCall(VecGetDM(g, &vdm));
-      PetscCheck(!vdm, PetscObjectComm((PetscObject)dm), PETSC_ERR_ARG_WRONGSTATE, "Clearing local vector that has a DM attached");
+      PetscCheck(!vdm, PETSC_COMM_SELF, PETSC_ERR_ARG_WRONGSTATE, "Clearing local vector that has a DM attached");
     }
     PetscCall(VecDestroy(&g));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-   DMRestoreGlobalVector - Returns a PETSc vector that
-     obtained from DMGetGlobalVector(). Do not use with vector obtained via
-     DMCreateGlobalVector().
+  DMRestoreGlobalVector - Returns a PETSc vector that
+  obtained from `DMGetGlobalVector()`. Do not use with vector obtained via
+  `DMCreateGlobalVector()`.
 
-   Not Collective
+  Not Collective
 
-   Input Parameters:
-+  dm - the dm
--  g - the global vector
+  Input Parameters:
++ dm - the `DM`
+- g  - the global vector
 
-   Level: beginner
+  Level: beginner
 
-.seealso: `DMCreateGlobalVector()`, `VecDuplicate()`, `VecDuplicateVecs()`,
+.seealso: `DM`, `DMCreateGlobalVector()`, `VecDuplicate()`, `VecDuplicateVecs()`,
           `DMDACreate1d()`, `DMDACreate2d()`, `DMDACreate3d()`, `DMGlobalToGlobalBegin()`,
-          `DMGlobalToGlobalEnd()`, `DMGlobalToGlobal()`, `DMCreateLocalVector()`, `DMGetGlobalVector()`
+          `DMGlobalToGlobalEnd()`, `DMGlobalToGlobal()`, `DMCreateLocalVector()`, `DMGetGlobalVector()`, `DMClearGlobalVectors()`
 @*/
 PetscErrorCode DMRestoreGlobalVector(DM dm, Vec *g)
 {
@@ -269,7 +269,7 @@ PetscErrorCode DMRestoreGlobalVector(DM dm, Vec *g)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(dm, DM_CLASSID, 1);
-  PetscValidPointer(g, 2);
+  PetscAssertPointer(g, 2);
   PetscCall(VecSetErrorIfLocked(*g, 2));
   for (j = 0; j < DM_MAX_WORK_VECTORS; j++) {
     if (*g == dm->globalout[j]) {
@@ -290,26 +290,84 @@ PetscErrorCode DMRestoreGlobalVector(DM dm, Vec *g)
   PetscCall(VecDestroy(g));
 alldone:
   *g = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+/*@
+  DMClearNamedGlobalVectors - Destroys all the named global vectors that have been created with `DMGetNamedGlobalVector()` in this `DM`
+
+  Collective
+
+  Input Parameter:
+. dm - the `DM`
+
+  Level: developer
+
+.seealso: `DM`, `DMGetNamedGlobalVector()`, `DMGetNamedLocalVector()`, `DMClearNamedLocalVectors()`
+@*/
+PetscErrorCode DMClearNamedGlobalVectors(DM dm)
+{
+  DMNamedVecLink nnext;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(dm, DM_CLASSID, 1);
+  nnext           = dm->namedglobal;
+  dm->namedglobal = NULL;
+  for (DMNamedVecLink nlink = nnext; nlink; nlink = nnext) { /* Destroy the named vectors */
+    nnext = nlink->next;
+    PetscCheck(nlink->status == DMVEC_STATUS_IN, ((PetscObject)dm)->comm, PETSC_ERR_ARG_WRONGSTATE, "DM still has global Vec named '%s' checked out", nlink->name);
+    PetscCall(PetscFree(nlink->name));
+    PetscCall(VecDestroy(&nlink->X));
+    PetscCall(PetscFree(nlink));
+  }
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+/*@
+  DMClearNamedLocalVectors - Destroys all the named local vectors that have been created with `DMGetNamedLocalVector()` in this `DM`
+
+  Collective
+
+  Input Parameter:
+. dm - the `DM`
+
+  Level: developer
+
+.seealso: `DM`, `DMGetNamedGlobalVector()`, `DMGetNamedLocalVector()`, `DMClearNamedGlobalVectors()`
+@*/
+PetscErrorCode DMClearNamedLocalVectors(DM dm)
+{
+  DMNamedVecLink nnext;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(dm, DM_CLASSID, 1);
+  nnext          = dm->namedlocal;
+  dm->namedlocal = NULL;
+  for (DMNamedVecLink nlink = nnext; nlink; nlink = nnext) { /* Destroy the named vectors */
+    nnext = nlink->next;
+    PetscCheck(nlink->status == DMVEC_STATUS_IN, PETSC_COMM_SELF, PETSC_ERR_ARG_WRONGSTATE, "DM still has local Vec named '%s' checked out", nlink->name);
+    PetscCall(PetscFree(nlink->name));
+    PetscCall(VecDestroy(&nlink->X));
+    PetscCall(PetscFree(nlink));
+  }
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   DMHasNamedGlobalVector - check for a named, persistent global vector
+  DMHasNamedGlobalVector - check for a named, persistent global vector created with `DMGetNamedGlobalVector()`
 
-   Not Collective
+  Not Collective
 
-   Input Parameters:
-+  dm - DM to hold named vectors
--  name - unique name for Vec
+  Input Parameters:
++ dm   - `DM` to hold named vectors
+- name - unique name for `Vec`
 
-   Output Parameter:
-.  exists - true if the vector was previously created
+  Output Parameter:
+. exists - true if the vector was previously created
 
-   Level: developer
+  Level: developer
 
-   Note: If a Vec with the given name does not exist, it is created.
-
-.seealso: `DMGetNamedGlobalVector()`, `DMRestoreNamedLocalVector()`
+.seealso: `DM`, `DMGetNamedGlobalVector()`, `DMRestoreNamedLocalVector()`, `DMClearNamedGlobalVectors()`
 @*/
 PetscErrorCode DMHasNamedGlobalVector(DM dm, const char *name, PetscBool *exists)
 {
@@ -317,8 +375,8 @@ PetscErrorCode DMHasNamedGlobalVector(DM dm, const char *name, PetscBool *exists
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(dm, DM_CLASSID, 1);
-  PetscValidCharPointer(name, 2);
-  PetscValidBoolPointer(exists, 3);
+  PetscAssertPointer(name, 2);
+  PetscAssertPointer(exists, 3);
   *exists = PETSC_FALSE;
   for (link = dm->namedglobal; link; link = link->next) {
     PetscBool match;
@@ -328,26 +386,27 @@ PetscErrorCode DMHasNamedGlobalVector(DM dm, const char *name, PetscBool *exists
       break;
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   DMGetNamedGlobalVector - get access to a named, persistent global vector
+  DMGetNamedGlobalVector - get access to a named, persistent global vector
 
-   Collective on dm
+  Collective
 
-   Input Parameters:
-+  dm - DM to hold named vectors
--  name - unique name for Vec
+  Input Parameters:
++ dm   - `DM` to hold named vectors
+- name - unique name for `X`
 
-   Output Parameter:
-.  X - named Vec
+  Output Parameter:
+. X - named `Vec`
 
-   Level: developer
+  Level: developer
 
-   Note: If a Vec with the given name does not exist, it is created.
+  Note:
+  If a `Vec` with the given name does not exist, it is created.
 
-.seealso: `DMRestoreNamedGlobalVector()`
+.seealso: `DM`, `DMRestoreNamedGlobalVector()`, `DMHasNamedGlobalVector()`, `DMClearNamedGlobalVectors()`, `DMGetGlobalVector()`, `DMGetLocalVector()`
 @*/
 PetscErrorCode DMGetNamedGlobalVector(DM dm, const char *name, Vec *X)
 {
@@ -355,8 +414,8 @@ PetscErrorCode DMGetNamedGlobalVector(DM dm, const char *name, Vec *X)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(dm, DM_CLASSID, 1);
-  PetscValidCharPointer(name, 2);
-  PetscValidPointer(X, 3);
+  PetscAssertPointer(name, 2);
+  PetscAssertPointer(X, 3);
   for (link = dm->namedglobal; link; link = link->next) {
     PetscBool match;
 
@@ -382,22 +441,22 @@ PetscErrorCode DMGetNamedGlobalVector(DM dm, const char *name, Vec *X)
 found:
   *X           = link->X;
   link->status = DMVEC_STATUS_OUT;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   DMRestoreNamedGlobalVector - restore access to a named, persistent global vector
+  DMRestoreNamedGlobalVector - restore access to a named, persistent global vector
 
-   Collective on dm
+  Collective
 
-   Input Parameters:
-+  dm - DM on which the vector was gotten
-.  name - name under which the vector was gotten
--  X - Vec to restore
+  Input Parameters:
++ dm   - `DM` on which `X` was gotten
+. name - name under which `X` was gotten
+- X    - `Vec` to restore
 
-   Level: developer
+  Level: developer
 
-.seealso: `DMGetNamedGlobalVector()`
+.seealso: `DM`, `DMGetNamedGlobalVector()`, `DMClearNamedGlobalVectors()`
 @*/
 PetscErrorCode DMRestoreNamedGlobalVector(DM dm, const char *name, Vec *X)
 {
@@ -405,8 +464,8 @@ PetscErrorCode DMRestoreNamedGlobalVector(DM dm, const char *name, Vec *X)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(dm, DM_CLASSID, 1);
-  PetscValidCharPointer(name, 2);
-  PetscValidPointer(X, 3);
+  PetscAssertPointer(name, 2);
+  PetscAssertPointer(X, 3);
   PetscValidHeaderSpecific(*X, VEC_CLASSID, 3);
   for (link = dm->namedglobal; link; link = link->next) {
     PetscBool match;
@@ -423,29 +482,30 @@ PetscErrorCode DMRestoreNamedGlobalVector(DM dm, const char *name, Vec *X)
       link->status = DMVEC_STATUS_IN;
       PetscCall(VecSetDM(link->X, NULL));
       *X = NULL;
-      PetscFunctionReturn(0);
+      PetscFunctionReturn(PETSC_SUCCESS);
     }
   }
   SETERRQ(PetscObjectComm((PetscObject)dm), PETSC_ERR_ARG_INCOMP, "Could not find Vec name '%s' to restore", name);
 }
 
 /*@C
-   DMHasNamedLocalVector - check for a named, persistent local vector
+  DMHasNamedLocalVector - check for a named, persistent local vector created with `DMGetNamedLocalVector()`
 
-   Not Collective
+  Not Collective
 
-   Input Parameters:
-+  dm - DM to hold named vectors
--  name - unique name for Vec
+  Input Parameters:
++ dm   - `DM` to hold named vectors
+- name - unique name for `Vec`
 
-   Output Parameter:
-.  exists - true if the vector was previously created
+  Output Parameter:
+. exists - true if the vector was previously created
 
-   Level: developer
+  Level: developer
 
-   Note: If a Vec with the given name does not exist, it is created.
+  Note:
+  If a `Vec` with the given name does not exist, it is created.
 
-.seealso: `DMGetNamedGlobalVector()`, `DMRestoreNamedLocalVector()`
+.seealso: `DM`, `DMGetNamedGlobalVector()`, `DMRestoreNamedLocalVector()`, `DMClearNamedLocalVectors()`
 @*/
 PetscErrorCode DMHasNamedLocalVector(DM dm, const char *name, PetscBool *exists)
 {
@@ -453,8 +513,8 @@ PetscErrorCode DMHasNamedLocalVector(DM dm, const char *name, PetscBool *exists)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(dm, DM_CLASSID, 1);
-  PetscValidCharPointer(name, 2);
-  PetscValidBoolPointer(exists, 3);
+  PetscAssertPointer(name, 2);
+  PetscAssertPointer(exists, 3);
   *exists = PETSC_FALSE;
   for (link = dm->namedlocal; link; link = link->next) {
     PetscBool match;
@@ -464,26 +524,27 @@ PetscErrorCode DMHasNamedLocalVector(DM dm, const char *name, PetscBool *exists)
       break;
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   DMGetNamedLocalVector - get access to a named, persistent local vector
+  DMGetNamedLocalVector - get access to a named, persistent local vector
 
-   Not Collective
+  Not Collective
 
-   Input Parameters:
-+  dm - DM to hold named vectors
--  name - unique name for Vec
+  Input Parameters:
++ dm   - `DM` to hold named vectors
+- name - unique name for `X`
 
-   Output Parameter:
-.  X - named Vec
+  Output Parameter:
+. X - named `Vec`
 
-   Level: developer
+  Level: developer
 
-   Note: If a Vec with the given name does not exist, it is created.
+  Note:
+  If a `Vec` with the given name does not exist, it is created.
 
-.seealso: `DMGetNamedGlobalVector()`, `DMRestoreNamedLocalVector()`
+.seealso: `DM`, `DMGetNamedGlobalVector()`, `DMRestoreNamedLocalVector()`, `DMHasNamedLocalVector()`, `DMClearNamedLocalVectors()`, `DMGetGlobalVector()`, `DMGetLocalVector()`
 @*/
 PetscErrorCode DMGetNamedLocalVector(DM dm, const char *name, Vec *X)
 {
@@ -491,8 +552,8 @@ PetscErrorCode DMGetNamedLocalVector(DM dm, const char *name, Vec *X)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(dm, DM_CLASSID, 1);
-  PetscValidCharPointer(name, 2);
-  PetscValidPointer(X, 3);
+  PetscAssertPointer(name, 2);
+  PetscAssertPointer(X, 3);
   for (link = dm->namedlocal; link; link = link->next) {
     PetscBool match;
 
@@ -518,22 +579,22 @@ PetscErrorCode DMGetNamedLocalVector(DM dm, const char *name, Vec *X)
 found:
   *X           = link->X;
   link->status = DMVEC_STATUS_OUT;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   DMRestoreNamedLocalVector - restore access to a named, persistent local vector
+  DMRestoreNamedLocalVector - restore access to a named, persistent local vector obtained with `DMGetNamedLocalVector()`
 
-   Not Collective
+  Not Collective
 
-   Input Parameters:
-+  dm - DM on which the vector was gotten
-.  name - name under which the vector was gotten
--  X - Vec to restore
+  Input Parameters:
++ dm   - `DM` on which `X` was gotten
+. name - name under which `X` was gotten
+- X    - `Vec` to restore
 
-   Level: developer
+  Level: developer
 
-.seealso: `DMRestoreNamedGlobalVector()`, `DMGetNamedLocalVector()`
+.seealso: `DM`, `DMRestoreNamedGlobalVector()`, `DMGetNamedLocalVector()`, `DMClearNamedLocalVectors()`
 @*/
 PetscErrorCode DMRestoreNamedLocalVector(DM dm, const char *name, Vec *X)
 {
@@ -541,8 +602,8 @@ PetscErrorCode DMRestoreNamedLocalVector(DM dm, const char *name, Vec *X)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(dm, DM_CLASSID, 1);
-  PetscValidCharPointer(name, 2);
-  PetscValidPointer(X, 3);
+  PetscAssertPointer(name, 2);
+  PetscAssertPointer(X, 3);
   PetscValidHeaderSpecific(*X, VEC_CLASSID, 3);
   for (link = dm->namedlocal; link; link = link->next) {
     PetscBool match;
@@ -559,7 +620,7 @@ PetscErrorCode DMRestoreNamedLocalVector(DM dm, const char *name, Vec *X)
       link->status = DMVEC_STATUS_IN;
       PetscCall(VecSetDM(link->X, NULL));
       *X = NULL;
-      PetscFunctionReturn(0);
+      PetscFunctionReturn(PETSC_SUCCESS);
     }
   }
   SETERRQ(PetscObjectComm((PetscObject)dm), PETSC_ERR_ARG_INCOMP, "Could not find Vec name '%s' to restore", name);
