@@ -1,4 +1,3 @@
-
 /*
     This file implements the conjugate gradient method in PETSc as part of
     KSP. You can use this as a starting point for implementing your own
@@ -188,7 +187,7 @@ static PetscErrorCode KSPSolve_CG(KSP ksp)
   PetscCall(VecXDot(B, X, &a));
   cg->obj -= 0.5 * PetscRealPart(a);
 
-  PetscCall(PetscInfo(ksp, "it %" PetscInt_FMT " obj %g\n", ksp->its, (double)cg->obj));
+  if (testobj) PetscCall(PetscInfo(ksp, "it %" PetscInt_FMT " obj %g\n", ksp->its, (double)cg->obj));
   PetscCall(KSPLogResidualHistory(ksp, dp));
   PetscCall(KSPMonitor(ksp, ksp->its, dp));
   ksp->rnorm = dp;
@@ -267,7 +266,7 @@ static PetscErrorCode KSPSolve_CG(KSP ksp)
         PetscCall(VecAXPY(X, a, P)); /*     x <- x + ap                      */
         cg->obj += PetscRealPart(a * (0.5 * a * dpi - betaold));
       }
-      PetscCall(PetscInfo(ksp, "it %" PetscInt_FMT " N obj %g\n", i + 1, (double)cg->obj));
+      if (testobj) PetscCall(PetscInfo(ksp, "it %" PetscInt_FMT " N obj %g\n", i + 1, (double)cg->obj));
       if (ksp->converged_neg_curve) {
         PetscCall(PetscInfo(ksp, "converged due to negative curvature: %g\n", (double)(PetscRealPart(dpi))));
         ksp->reason = KSP_CONVERGED_NEG_CURVE;
@@ -290,7 +289,7 @@ static PetscErrorCode KSPSolve_CG(KSP ksp)
           PetscCall(VecAXPY(X, dp, P)); /*     x <- x + ap                      */
           cg->obj += PetscRealPart(dp * (0.5 * dp * dpi - beta));
         }
-        PetscCall(PetscInfo(ksp, "it %" PetscInt_FMT " R obj %g\n", i + 1, (double)cg->obj));
+        if (testobj) PetscCall(PetscInfo(ksp, "it %" PetscInt_FMT " R obj %g\n", i + 1, (double)cg->obj));
         break;
       }
     }
@@ -312,7 +311,7 @@ static PetscErrorCode KSPSolve_CG(KSP ksp)
       dp = 0.0;
     }
     cg->obj -= PetscRealPart(0.5 * a * betaold);
-    PetscCall(PetscInfo(ksp, "it %" PetscInt_FMT " obj %g\n", i + 1, (double)cg->obj));
+    if (testobj) PetscCall(PetscInfo(ksp, "it %" PetscInt_FMT " obj %g\n", i + 1, (double)cg->obj));
 
     ksp->rnorm = dp;
     PetscCall(KSPLogResidualHistory(ksp, dp));
@@ -630,7 +629,7 @@ PETSC_INTERN PetscErrorCode KSPBuildResidual_CG(KSP ksp, Vec t, Vec v, Vec *V)
 }
 
 /*MC
-     KSPCG - The Preconditioned Conjugate Gradient (PCG) iterative method
+   KSPCG - The Preconditioned Conjugate Gradient (PCG) iterative method {cite}`hs:52` and {cite}`malek2014preconditioning`
 
    Options Database Keys:
 +   -ksp_cg_type Hermitian - (for complex matrices only) indicates the matrix is Hermitian, see `KSPCGSetType()`
@@ -640,31 +639,27 @@ PETSC_INTERN PetscErrorCode KSPBuildResidual_CG(KSP ksp, Vec t, Vec v, Vec *V)
    Level: beginner
 
    Notes:
-    The PCG method requires both the matrix and preconditioner to be symmetric positive (or negative) (semi) definite.
+   The PCG method requires both the matrix and preconditioner to be symmetric positive (or negative) (semi) definite.
 
    Only left preconditioning is supported; there are several ways to motivate preconditioned CG, but they all produce the same algorithm.
    One can interpret preconditioning A with B to mean any of the following\:
-.n  (1) Solve a left-preconditioned system BAx = Bb, using inv(B) to define an inner product in the algorithm.
-.n  (2) Solve a right-preconditioned system ABy = b, x = By, using B to define an inner product in the algorithm.
-.n  (3) Solve a symmetrically-preconditioned system, E^TAEy = E^Tb, x = Ey, where B = EE^T.
-.n  (4) Solve Ax=b with CG, but use the inner product defined by B to define the method [2].
-.n  In all cases, the resulting algorithm only requires application of B to vectors.
+.vb
+   (1) Solve a left-preconditioned system BAx = Bb, using inv(B) to define an inner product in the algorithm.
+   (2) Solve a right-preconditioned system ABy = b, x = By, using B to define an inner product in the algorithm.
+   (3) Solve a symmetrically-preconditioned system, E^TAEy = E^Tb, x = Ey, where B = EE^T.
+   (4) Solve Ax=b with CG, but use the inner product defined by B to define the method [2].
+   In all cases, the resulting algorithm only requires application of B to vectors.
+.ve
 
    For complex numbers there are two different CG methods, one for Hermitian symmetric matrices and one for non-Hermitian symmetric matrices. Use
    `KSPCGSetType()` to indicate which type you are using.
 
    One can use `KSPSetComputeEigenvalues()` and `KSPComputeEigenvalues()` to compute the eigenvalues of the (preconditioned) operator
 
-   Developer Notes:
+   Developer Note:
     KSPSolve_CG() should actually query the matrix to determine if it is Hermitian symmetric or not and NOT require the user to
    indicate it to the `KSP` object.
 
-   References:
-+  * - Magnus R. Hestenes and Eduard Stiefel, Methods of Conjugate Gradients for Solving Linear Systems,
-   Journal of Research of the National Bureau of Standards Vol. 49, No. 6, December 1952 Research Paper 2379
--  * - Josef Malek and Zdenek Strakos, Preconditioning and the Conjugate Gradient Method in the Context of Solving PDEs,
-    SIAM, 2014.
-
 .seealso: [](ch_ksp), `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`, `KSPSetComputeEigenvalues()`, `KSPComputeEigenvalues()`
           `KSPCGSetType()`, `KSPCGUseSingleReduction()`, `KSPPIPECG`, `KSPGROPPCG`
 M*/
