@@ -1,4 +1,3 @@
-
 #include <petsc/private/kspimpl.h> /*I "petscksp.h" I*/
 
 typedef struct {
@@ -206,40 +205,39 @@ static PetscErrorCode KSPGCRSetModifyPC_GCR(KSP ksp, KSPGCRModifyPCFunction func
 }
 
 /*@C
- KSPGCRSetModifyPC - Sets the routine used by `KSPGCR` to modify the preconditioner for each iteration
+  KSPGCRSetModifyPC - Sets the routine used by `KSPGCR` to modify the preconditioner for each iteration
 
- Logically Collective
+  Logically Collective
 
- Input Parameters:
- +  ksp      - iterative context obtained from KSPCreate()
- .  function - user defined function to modify the preconditioner
- .  ctx      - user provided context for the modify preconditioner function
- -  destroy  - the function to use to destroy the user provided application context.
+  Input Parameters:
++ ksp      - iterative context obtained from `KSPCreate()`
+. function - user defined function to modify the preconditioner
+. ctx      - user provided context for the modify preconditioner function
+- destroy  - the function to use to destroy the user provided application context.
 
- Calling Sequence of `function`:
-$  PetscErrorCode function(KSP ksp, PetscInt n, PetscReal rnorm, void *ctx)
-+  ksp   - iterative context
-.  n     - the total number of GCR iterations that have occurred
-.  rnorm - 2-norm residual value
--  ctx   - the user provided application context
+  Calling sequence of `function`:
++ ksp   - iterative context
+. n     - the total number of `PCGCR` iterations that have occurred
+. rnorm - 2-norm residual value
+- ctx   - the user provided application context
 
- Calling Sequence of `destroy`:
-$ PetscErrorCode destroy(void *ctx)
+  Calling sequence of `destroy`:
+. ctx - the user provided application context
 
- Level: intermediate
+  Level: intermediate
 
- Note:
- The default modifypc routine is `KSPGCRModifyPCNoChange()`
+  Note:
+  The default modifypc routine is `KSPGCRModifyPCNoChange()`
 
- Developer Note:
- The API should make uniform for all flexible types, [](sec_flexibleksp), and not have separate function calls for each type.
+  Developer Note:
+  The API should make uniform for all flexible types, [](sec_flexibleksp), and not have separate function calls for each type.
 
 .seealso: [](ch_ksp), `KSP`, `KSPGCR`, `KSPGCRModifyPCNoChange()`, [](sec_flexibleksp)
  @*/
-PetscErrorCode KSPGCRSetModifyPC(KSP ksp, PetscErrorCode (*function)(KSP, PetscInt, PetscReal, void *), void *data, PetscErrorCode (*destroy)(void *))
+PetscErrorCode KSPGCRSetModifyPC(KSP ksp, PetscErrorCode (*function)(KSP ksp, PetscInt n, PetscReal rnorm, void *ctx), void *ctx, PetscErrorCode (*destroy)(void *ctx))
 {
   PetscFunctionBegin;
-  PetscUseMethod(ksp, "KSPGCRSetModifyPC_C", (KSP, PetscErrorCode(*)(KSP, PetscInt, PetscReal, void *), void *data, PetscErrorCode (*)(void *)), (ksp, function, data, destroy));
+  PetscUseMethod(ksp, "KSPGCRSetModifyPC_C", (KSP, PetscErrorCode(*)(KSP, PetscInt, PetscReal, void *), void *data, PetscErrorCode (*)(void *)), (ksp, function, ctx, destroy));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
@@ -264,24 +262,24 @@ static PetscErrorCode KSPGCRGetRestart_GCR(KSP ksp, PetscInt *restart)
 }
 
 /*@
-   KSPGCRSetRestart - Sets number of iterations at which `KSPGCR` restarts.
+  KSPGCRSetRestart - Sets number of iterations at which `KSPGCR` restarts.
 
-   Not Collective
+  Not Collective
 
-   Input Parameters:
-+  ksp - the Krylov space context
--  restart - integer restart value
+  Input Parameters:
++ ksp     - the Krylov space context
+- restart - integer restart value
 
-   Options Database Key:
-.   -ksp_gcr_restart <restart> - the number of stored vectors to orthogonalize against
+  Options Database Key:
+. -ksp_gcr_restart <restart> - the number of stored vectors to orthogonalize against
 
-   Level: intermediate
+  Level: intermediate
 
-   Note:
-   The default value is 30.
+  Note:
+  The default value is 30.
 
-   Developer Note:
-   The API could be made uniform for all `KSP` methods have have a restart.
+  Developer Note:
+  The API could be made uniform for all `KSP` methods that have have a restart.
 
 .seealso: [](ch_ksp), `KSPGCR`, `KSPSetTolerances()`, `KSPGCRGetRestart()`, `KSPGMRESSetRestart()`
 @*/
@@ -293,17 +291,17 @@ PetscErrorCode KSPGCRSetRestart(KSP ksp, PetscInt restart)
 }
 
 /*@
-   KSPGCRGetRestart - Gets number of iterations at which `KSPGCR` restarts.
+  KSPGCRGetRestart - Gets number of iterations at which `KSPGCR` restarts.
 
-   Not Collective
+  Not Collective
 
-   Input Parameter:
-.  ksp - the Krylov space context
+  Input Parameter:
+. ksp - the Krylov space context
 
-   Output Parameter:
-.   restart - integer restart value
+  Output Parameter:
+. restart - integer restart value
 
-   Level: intermediate
+  Level: intermediate
 
 .seealso: [](ch_ksp), `KSPGCR`, `KSPSetTolerances()`, `KSPGCRSetRestart()`, `KSPGMRESGetRestart()`
 @*/
@@ -345,7 +343,7 @@ static PetscErrorCode KSPBuildResidual_GCR(KSP ksp, Vec t, Vec v, Vec *V)
 }
 
 /*MC
-     KSPGCR - Implements the preconditioned flexible Generalized Conjugate Residual method. [](sec_flexibleksp),
+     KSPGCR - Implements the preconditioned flexible Generalized Conjugate Residual method {cite}`eisenstat1983variational`. [](sec_flexibleksp),
 
    Options Database Key:
 .   -ksp_gcr_restart <restart> - the number of stored vectors to orthogonalize against
@@ -357,30 +355,26 @@ static PetscErrorCode KSPBuildResidual_GCR(KSP ksp, Vec t, Vec v, Vec *V)
     which may vary from one iteration to the next.
 
     Users can can define a method to vary the
-           preconditioner between iterates via `KSPGCRSetModifyPC()`.
+    preconditioner between iterates via `KSPGCRSetModifyPC()`.
 
-           Restarts are solves with x0 not equal to zero. When a restart occurs, the initial starting
-           solution is given by the current estimate for x which was obtained by the last restart
-           iterations of the GCR algorithm.
+    Restarts are solves with x0 not equal to zero. When a restart occurs, the initial starting
+    solution is given by the current estimate for x which was obtained by the last restart
+    iterations of the GCR algorithm.
 
-           Unlike `KSPGMRES` and `KSPFGMRES`, when using GCR, the solution and residual vector can be directly accessed at any iterate,
-           with zero computational cost, via a call to `KSPBuildSolution()` and `KSPBuildResidual()` respectively.
+    Unlike `KSPGMRES` and `KSPFGMRES`, when using GCR, the solution and residual vector can be directly accessed at any iterate,
+    with zero computational cost, via a call to `KSPBuildSolution()` and `KSPBuildResidual()` respectively.
 
-           This implementation of GCR will only apply the stopping condition test whenever ksp->its > ksp->chknorm,
-           where ksp->chknorm is specified via the command line argument -ksp_check_norm_iteration or via
-           the function `KSPSetCheckNormIteration()`. Hence the residual norm reported by the monitor and stored
-           in the residual history will be listed as 0.0 before this iteration. It is actually not 0.0; just not calculated.
+    This implementation of GCR will only apply the stopping condition test whenever ksp->its > ksp->chknorm,
+    where ksp->chknorm is specified via the command line argument -ksp_check_norm_iteration or via
+    the function `KSPSetCheckNormIteration()`. Hence the residual norm reported by the monitor and stored
+    in the residual history will be listed as 0.0 before this iteration. It is actually not 0.0; just not calculated.
 
-           The method implemented requires the storage of 2 x restart + 1 vectors, twice as much as `KSPGMRES`.
-           Support only for right preconditioning.
+    The method implemented requires the storage of 2 x restart + 1 vectors, twice as much as `KSPGMRES`.
+    Support only for right preconditioning.
 
     Contributed by:
     Dave May
 
-    References:
-.   * - S. C. Eisenstat, H. C. Elman, and H. C. Schultz. Variational iterative methods for
-           nonsymmetric systems of linear equations. SIAM J. Numer. Anal., 20, 1983
-
 .seealso: [](ch_ksp), [](sec_flexibleksp), `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`, `KSPGCRSetRestart()`, `KSPGCRGetRestart()`,
           `KSPGCRSetRestart()`, `KSPGCRSetModifyPC()`, `KSPGMRES`, `KSPFGMRES`
 M*/
