@@ -1,4 +1,3 @@
-
 /*
     This file contains an implementation of Tony Chan's transpose-free QMR.
 
@@ -158,20 +157,16 @@ static PetscErrorCode KSPSetUp_TCQMR(KSP ksp)
 }
 
 /*MC
-     KSPTCQMR - A variant of QMR (quasi minimal residual) [1]
+   KSPTCQMR - A variant of QMR (quasi minimal residual) {cite}`chan1998transpose`
 
    Level: beginner
 
-  Notes:
-  Supports either left or right preconditioning, but not symmetric
+   Notes:
+   Supports either left or right preconditioning, but not symmetric
 
-  The "residual norm" computed in this algorithm is actually just an upper bound on the actual residual norm.
-  That is for left preconditioning it is a bound on the preconditioned residual and for right preconditioning
-  it is a bound on the true residual.
-
-  References:
-. [1] - Tony F. Chan, Lisette de Pillis, and Henk van der Vorst, Transpose free formulations of Lanczos type methods for nonsymmetric linear systems,
-  Numerical Algorithms, Volume 17, 1998.
+   The "residual norm" computed in this algorithm is actually just an upper bound on the actual residual norm.
+   That is for left preconditioning it is a bound on the preconditioned residual and for right preconditioning
+   it is a bound on the true residual.
 
 .seealso: [](ch_ksp), `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`, `KSPTFQMR`
 M*/
