@@ -3,29 +3,31 @@
 PetscFunctionList KSPGuessList = NULL;
 static PetscBool  KSPGuessRegisterAllCalled;
 
-/*
-  KSPGuessRegister -  Adds a method for initial guess computation in Krylov subspace solver package.
+/*@C
+  KSPGuessRegister -  Registers a method for initial guess computation in Krylov subspace solver package.
 
-   Not Collective
+  Not Collective
 
-   Input Parameters:
-+  name_solver - name of a new user-defined solver
--  routine_create - routine to create method context
+  Input Parameters:
++ sname    - name of a new user-defined solver
+- function - routine to create method context
 
-   Notes:
-   KSPGuessRegister() may be called multiple times to add several user-defined solvers.
-
-   Sample usage:
+  Example Usage:
 .vb
    KSPGuessRegister("my_initial_guess", MyInitialGuessCreate);
 .ve
 
-   Then, it can be chosen with the procedural interface via
-$     KSPSetGuessType(ksp, "my_initial_guess")
-   or at runtime via the option
-$     -ksp_guess_type my_initial_guess
+  Then, it can be chosen with the procedural interface via
+.vb
+  KSPGetGuess(ksp, &guess);
+  KSPGuessSetType(guess, "my_initial_guess");
+.ve
+  or at runtime via the option `-ksp_guess_type my_initial_guess`
 
-   Level: developer
+  Level: developer
+
+  Note:
+  `KSPGuessRegister()` may be called multiple times to add several user-defined solvers.
 
 .seealso: [](ch_ksp), `KSPGuess`, `KSPGuessRegisterAll()`
 @*/
@@ -57,16 +59,27 @@ PetscErrorCode KSPGuessRegisterAll(void)
 }
 
 /*@
-    KSPGuessSetFromOptions - Sets the options for a `KSPGuess` from the options database
+  KSPGuessSetFromOptions - Sets the options for a `KSPGuess` from the options database
 
-    Collective
+  Collective
 
-    Input Parameter:
-.    guess - `KSPGuess` object
+  Input Parameter:
+. guess - `KSPGuess` object
 
-   Level: developer
+  Options Database Keys:
++ -ksp_guess_type <method>       - Turns on generation of initial guesses and sets the method; use -help for a list of available methods
+. -ksp_guess_view <viewer>       - view the `KSPGuess` object
+. -ksp_guess_fischer_model <a,b> - set details for the Fischer models
+. -ksp_guess_fischer_monitor     - monitor the Fischer models
+. -ksp_guess_fischer_tol <tol>   - set the tolerance for the Fischer models
+. -ksp_guess_pod_size <size>     - Number of snapshots
+. -ksp_guess_pod_monitor true    - monitor the pod initial guess processing
+. -ksp_guess_pod_tol <tol>       - Tolerance to retain eigenvectors
+- -ksp_guess_pod_Ainner true     - Use the operator as inner product (must be SPD)
 
-.seealso: [](ch_ksp), `KSPGuess`, `KSPGetGuess()`, `KSPSetGuessType()`, `KSPGuessType`
+  Level: developer
+
+.seealso: [](ch_ksp), `KSPGuess`, `KSPGetGuess()`, `KSPGuessSetType()`, `KSPGuessType`
 @*/
 PetscErrorCode KSPGuessSetFromOptions(KSPGuess guess)
 {
@@ -77,15 +90,22 @@ PetscErrorCode KSPGuessSetFromOptions(KSPGuess guess)
 }
 
 /*@
-    KSPGuessSetTolerance - Sets the relative tolerance used in either eigenvalue (POD) or singular value (Fischer type 3) calculations.
-    Ignored by the first and second Fischer types.
+  KSPGuessSetTolerance - Sets the relative tolerance used in either eigenvalue (POD) or singular value (Fischer type 3) calculations.
 
-    Collective
+  Collective
 
-    Input Parameter:
-.    guess - `KSPGuess` object
+  Input Parameters:
++ guess - `KSPGuess` object
+- tol   - the tolerance
 
-   Level: developer
+  Options Database Key:
++ -ksp_guess_fischer_tol <tol> - set the tolerance for the Fischer models
+- -ksp_guess_pod_tol <tol>     - set the tolerance for the Pod models
+
+  Level: developer
+
+  Note:
+  Ignored by the first and second Fischer guess types
 
 .seealso: [](ch_ksp), `KSPGuess`, `KSPGuessType`, `KSPGuessSetFromOptions()`
 @*/
@@ -98,14 +118,14 @@ PetscErrorCode KSPGuessSetTolerance(KSPGuess guess, PetscReal tol)
 }
 
 /*@
-   KSPGuessDestroy - Destroys `KSPGuess` context.
+  KSPGuessDestroy - Destroys `KSPGuess` context.
 
-   Collective
+  Collective
 
-   Input Parameter:
-.  guess - initial guess object
+  Input Parameter:
+. guess - initial guess object
 
-   Level: developer
+  Level: developer
 
 .seealso: [](ch_ksp), `KSPGuessCreate()`, `KSPGuess`, `KSPGuessType`
 @*/
@@ -125,13 +145,16 @@ PetscErrorCode KSPGuessDestroy(KSPGuess *guess)
 }
 
 /*@C
-   KSPGuessView - View the `KSPGuess` object
+  KSPGuessView - View the `KSPGuess` object
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameters:
-+  guess  - the initial guess object for the Krylov method
--  viewer - the viewer object
+  Input Parameters:
++ guess - the initial guess object for the Krylov method
+- view  - the viewer object
+
+  Options Database Key:
+. -ksp_guess_view viewer - view the `KSPGuess` object
 
   Level: developer
 
@@ -157,17 +180,33 @@ PetscErrorCode KSPGuessView(KSPGuess guess, PetscViewer view)
 }
 
 /*@
-   KSPGuessCreate - Creates the default `KSPGuess` context.
+  KSPGuessCreate - Creates a `KSPGuess` context.
 
-   Collective
+  Collective
 
-   Input Parameter:
-.  comm - MPI communicator
+  Input Parameter:
+. comm - MPI communicator
 
-   Output Parameter:
-.  guess - location to put the `KSPGuess` context
+  Output Parameter:
+. guess - location to put the `KSPGuess` context
 
-   Level: developer
+  Options Database Keys:
++ -ksp_guess_type  <method>      - Turns on generation of initial guesses and sets the method; use -help for a list of available methods
+. -ksp_guess_view <viewer>       - view the `KSPGuess` object
+. -ksp_guess_fischer_model <a,b> - set details for the Fischer models
+. -ksp_guess_fischer_monitor     - monitor the fischer models
+. -ksp_guess_fischer_tol <tol>   - set the tolerance for the Fischer models
+. -ksp_guess_pod_size <size>     - Number of snapshots
+. -ksp_guess_pod_monitor true    - monitor the pod initial guess processing
+. -ksp_guess_pod_tol <tol>       - Tolerance to retain eigenvectors
+- -ksp_guess_pod_Ainner true     - Use the operator as inner product (must be SPD)
+
+  Level: developer
+
+  Note:
+  These are generally created automatically by using the option `-ksp_guess_type type` and controlled from the options database
+
+  There are two families of methods `KSPGUESSFISCHER`, developed by Paul Fischer and `KSPGUESSPOD`
 
 .seealso: [](ch_ksp), `KSPSolve()`, `KSPGuessDestroy()`, `KSPGuess`, `KSPGuessType`, `KSP`
 @*/
@@ -176,7 +215,7 @@ PetscErrorCode KSPGuessCreate(MPI_Comm comm, KSPGuess *guess)
   KSPGuess tguess;
 
   PetscFunctionBegin;
-  PetscValidPointer(guess, 2);
+  PetscAssertPointer(guess, 2);
   *guess = NULL;
   PetscCall(KSPInitializePackage());
   PetscCall(PetscHeaderCreate(tguess, KSPGUESS_CLASSID, "KSPGuess", "Initial guess for Krylov Method", "KSPGuess", comm, KSPGuessDestroy, KSPGuessView));
@@ -186,16 +225,16 @@ PetscErrorCode KSPGuessCreate(MPI_Comm comm, KSPGuess *guess)
 }
 
 /*@C
-   KSPGuessSetType - Sets the type of a `KSPGuess`
+  KSPGuessSetType - Sets the type of a `KSPGuess`
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameters:
-+  guess - the initial guess object for the Krylov method
--  type  - a known `KSPGuessType`
+  Input Parameters:
++ guess - the initial guess object for the Krylov method
+- type  - a known `KSPGuessType`
 
-   Options Database Key:
-.  -ksp_guess_type  <method> - Sets the method; use -help for a list of available methods
+  Options Database Key:
+. -ksp_guess_type  <method> - Turns on generation of initial guesses and sets the method; use -help for a list of available methods
 
   Level: developer
 
@@ -208,7 +247,7 @@ PetscErrorCode KSPGuessSetType(KSPGuess guess, KSPGuessType type)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(guess, KSPGUESS_CLASSID, 1);
-  PetscValidCharPointer(type, 2);
+  PetscAssertPointer(type, 2);
 
   PetscCall(PetscObjectTypeCompare((PetscObject)guess, type, &match));
   if (match) PetscFunctionReturn(PETSC_SUCCESS);
@@ -225,17 +264,17 @@ PetscErrorCode KSPGuessSetType(KSPGuess guess, KSPGuessType type)
 }
 
 /*@C
-   KSPGuessGetType - Gets the `KSPGuessType` as a string from the `KSPGuess` object.
+  KSPGuessGetType - Gets the `KSPGuessType` as a string from the `KSPGuess` object.
 
-   Not Collective
+  Not Collective
 
-   Input Parameter:
-.  guess - the initial guess context
+  Input Parameter:
+. guess - the initial guess context
 
-   Output Parameter:
-.  name - type of `KSPGuess` method
+  Output Parameter:
+. type - type of `KSPGuess` method
 
-   Level: developer
+  Level: developer
 
 .seealso: [](ch_ksp), `KSPGuess`, `KSPGuessSetType()`
 @*/
@@ -243,22 +282,22 @@ PetscErrorCode KSPGuessGetType(KSPGuess guess, KSPGuessType *type)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(guess, KSPGUESS_CLASSID, 1);
-  PetscValidPointer(type, 2);
+  PetscAssertPointer(type, 2);
   *type = ((PetscObject)guess)->type_name;
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-    KSPGuessUpdate - Updates the guess object with the current solution and rhs vector
+  KSPGuessUpdate - Updates the guess object with the current solution and rhs vector
 
-   Collective
+  Collective
 
-   Input Parameters:
-+  guess - the initial guess context
-.  rhs   - the corresponding rhs
--  sol   - the computed solution
+  Input Parameters:
++ guess - the initial guess context
+. rhs   - the corresponding rhs
+- sol   - the computed solution
 
-   Level: developer
+  Level: developer
 
 .seealso: [](ch_ksp), `KSPGuessCreate()`, `KSPGuess`
 @*/
@@ -273,16 +312,16 @@ PetscErrorCode KSPGuessUpdate(KSPGuess guess, Vec rhs, Vec sol)
 }
 
 /*@
-    KSPGuessFormGuess - Form the initial guess
+  KSPGuessFormGuess - Form the initial guess
 
-   Collective
+  Collective
 
-   Input Parameters:
-+  guess - the initial guess context
-.  rhs   - the current rhs vector
--  sol   - the initial guess vector
+  Input Parameters:
++ guess - the initial guess context
+. rhs   - the current right hand side vector
+- sol   - the initial guess vector
 
-   Level: developer
+  Level: developer
 
 .seealso: [](ch_ksp), `KSPGuessCreate()`, `KSPGuess`
 @*/
@@ -297,14 +336,14 @@ PetscErrorCode KSPGuessFormGuess(KSPGuess guess, Vec rhs, Vec sol)
 }
 
 /*@
-    KSPGuessSetUp - Setup the initial guess object
+  KSPGuessSetUp - Setup the initial guess object
 
-   Collective
+  Collective
 
-   Input Parameter:
--  guess - the initial guess context
+  Input Parameter:
+. guess - the initial guess context
 
-   Level: developer
+  Level: developer
 
 .seealso: [](ch_ksp), `KSPGuessCreate()`, `KSPGuess`
 @*/
