@@ -1,4 +1,3 @@
-
 /*
     Code for setting KSP options from the options database.
 */
@@ -7,30 +6,30 @@
 #include <petscdraw.h>
 
 /*@C
-   KSPSetOptionsPrefix - Sets the prefix used for searching for all
-   `KSP` options in the database.
+  KSPSetOptionsPrefix - Sets the prefix used for searching for all
+  `KSP` options in the database.
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameters:
-+  ksp - the Krylov context
--  prefix - the prefix string to prepend to all `KSP` option requests
+  Input Parameters:
++ ksp    - the Krylov context
+- prefix - the prefix string to prepend to all `KSP` option requests
 
-   Level: advanced
+  Level: intermediate
 
-   Notes:
-   A hyphen (-) must NOT be given at the beginning of the prefix name.
-   The first character of all runtime options is AUTOMATICALLY the
-   hyphen.
+  Notes:
+  A hyphen (-) must NOT be given at the beginning of the prefix name.
+  The first character of all runtime options is AUTOMATICALLY the
+  hyphen.
 
-   For example, to distinguish between the runtime options for two
-   different `KSP` contexts, one could call
+  For example, to distinguish between the runtime options for two
+  different `KSP` contexts, one could call
 .vb
       KSPSetOptionsPrefix(ksp1,"sys1_")
       KSPSetOptionsPrefix(ksp2,"sys2_")
 .ve
 
-   This would enable use of different options for each system, such as
+  This would enable use of different options for each system, such as
 .vb
       -sys1_ksp_type gmres -sys1_ksp_rtol 1.e-3
       -sys2_ksp_type bcgs  -sys2_ksp_rtol 1.e-4
@@ -40,29 +39,46 @@
 @*/
 PetscErrorCode KSPSetOptionsPrefix(KSP ksp, const char prefix[])
 {
+  PetscBool ispcmpi;
+
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ksp, KSP_CLASSID, 1);
   if (!ksp->pc) PetscCall(KSPGetPC(ksp, &ksp->pc));
-  PetscCall(PCSetOptionsPrefix(ksp->pc, prefix));
-  PetscCall(PetscObjectSetOptionsPrefix((PetscObject)ksp, prefix));
+  PetscCall(PetscObjectTypeCompare((PetscObject)ksp->pc, PCMPI, &ispcmpi));
+  if (ispcmpi) {
+    size_t     len;
+    const char suffix[] = "mpi_linear_solver_server_";
+    char      *newprefix;
+
+    PetscCall(PetscStrlen(prefix, &len));
+    PetscCall(PetscMalloc1(len + sizeof(suffix) + 1, &newprefix));
+    PetscCall(PetscStrncpy(newprefix, prefix, len + sizeof(suffix)));
+    PetscCall(PetscStrlcat(newprefix, suffix, len + sizeof(suffix)));
+    PetscCall(PCSetOptionsPrefix(ksp->pc, newprefix));
+    PetscCall(PetscObjectSetOptionsPrefix((PetscObject)ksp, newprefix));
+    PetscCall(PetscFree(newprefix));
+  } else {
+    PetscCall(PCSetOptionsPrefix(ksp->pc, prefix));
+    PetscCall(PetscObjectSetOptionsPrefix((PetscObject)ksp, prefix));
+  }
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   KSPAppendOptionsPrefix - Appends to the prefix used for searching for all
-   `KSP` options in the database.
+  KSPAppendOptionsPrefix - Appends to the prefix used for searching for all
+  `KSP` options in the database.
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameters:
-+  ksp - the Krylov context
--  prefix - the prefix string to prepend to all `KSP` option requests
+  Input Parameters:
++ ksp    - the Krylov context
+- prefix - the prefix string to prepend to all `KSP` option requests
 
-   Notes:
-   A hyphen (-) must NOT be given at the beginning of the prefix name.
-   The first character of all runtime options is AUTOMATICALLY the hyphen.
+  Level: intermediate
 
-   Level: advanced
+  Note:
+  A hyphen (-) must NOT be given at the beginning of the prefix name.
+  The first character of all runtime options is AUTOMATICALLY the hyphen.
 
 .seealso: [](ch_ksp), `KSP`, `KSPSetOptionsPrefix()`, `KSPGetOptionsPrefix()`, `KSPSetFromOptions()`
 @*/
@@ -77,21 +93,21 @@ PetscErrorCode KSPAppendOptionsPrefix(KSP ksp, const char prefix[])
 }
 
 /*@
-   KSPSetUseFischerGuess - Use the Paul Fischer algorithm or its variants to compute initial guesses for a set of solves with related right hand sides
+  KSPSetUseFischerGuess - Use the Paul Fischer algorithm or its variants to compute initial guesses for a set of solves with related right hand sides
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameters:
-+  ksp - the Krylov context
-.  model - use model 1, model 2, model 3, or any other number to turn it off
--  size - size of subspace used to generate initial guess
+  Input Parameters:
++ ksp   - the Krylov context
+. model - use model 1, model 2, model 3, or any other number to turn it off
+- size  - size of subspace used to generate initial guess
 
-    Options Database Key:
-.   -ksp_fischer_guess <model,size> - uses the Fischer initial guess generator for repeated linear solves
+  Options Database Key:
+. -ksp_fischer_guess <model,size> - uses the Fischer initial guess generator for repeated linear solves
 
-   Level: advanced
+  Level: advanced
 
-.seealso: [](ch_ksp), `KSP`, `KSPSetOptionsPrefix()`, `KSPAppendOptionsPrefix()`, `KSPSetUseFischerGuess()`, `KSPSetGuess()`, `KSPGetGuess()`, `KSPGuess`
+.seealso: [](ch_ksp), `KSP`, `KSPSetOptionsPrefix()`, `KSPAppendOptionsPrefix()`, `KSPSetGuess()`, `KSPGetGuess()`, `KSPGuess`
 @*/
 PetscErrorCode KSPSetUseFischerGuess(KSP ksp, PetscInt model, PetscInt size)
 {
@@ -108,22 +124,22 @@ PetscErrorCode KSPSetUseFischerGuess(KSP ksp, PetscInt model, PetscInt size)
 }
 
 /*@
-   KSPSetGuess - Set the initial guess object
+  KSPSetGuess - Set the initial guess object
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameters:
-+  ksp - the Krylov context
--  guess - the object created with `KSPGuessCreate()`
+  Input Parameters:
++ ksp   - the Krylov context
+- guess - the object created with `KSPGuessCreate()`
 
-   Level: advanced
+  Level: advanced
 
-   Notes:
-    this allows a single `KSP` to be used with several different initial guess generators (likely for different linear
-          solvers, see `KSPSetPC()`).
+  Notes:
+  this allows a single `KSP` to be used with several different initial guess generators (likely for different linear
+  solvers, see `KSPSetPC()`).
 
-          This increases the reference count of the guess object, you must destroy the object with `KSPGuessDestroy()`
-          before the end of the program.
+  This increases the reference count of the guess object, you must destroy the object with `KSPGuessDestroy()`
+  before the end of the program.
 
 .seealso: [](ch_ksp), `KSP`, `KSPGuess`, `KSPSetOptionsPrefix()`, `KSPAppendOptionsPrefix()`, `KSPSetUseFischerGuess()`, `KSPGetGuess()`
 @*/
@@ -140,17 +156,17 @@ PetscErrorCode KSPSetGuess(KSP ksp, KSPGuess guess)
 }
 
 /*@
-   KSPGetGuess - Gets the initial guess generator for the `KSP`.
+  KSPGetGuess - Gets the initial guess generator for the `KSP`.
 
-   Not Collective
+  Not Collective
 
-   Input Parameter:
-.  ksp - the Krylov context
+  Input Parameter:
+. ksp - the Krylov context
 
-   Output Parameter:
-.   guess - the object
+  Output Parameter:
+. guess - the object
 
-   Level: developer
+  Level: developer
 
 .seealso: [](ch_ksp), `KSPGuess`, `KSP`, `KSPSetOptionsPrefix()`, `KSPAppendOptionsPrefix()`, `KSPSetUseFischerGuess()`, `KSPSetGuess()`
 @*/
@@ -158,7 +174,7 @@ PetscErrorCode KSPGetGuess(KSP ksp, KSPGuess *guess)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ksp, KSP_CLASSID, 1);
-  PetscValidPointer(guess, 2);
+  PetscAssertPointer(guess, 2);
   if (!ksp->guess) {
     const char *prefix;
 
@@ -172,22 +188,22 @@ PetscErrorCode KSPGetGuess(KSP ksp, KSPGuess *guess)
 }
 
 /*@C
-   KSPGetOptionsPrefix - Gets the prefix used for searching for all
-   `KSP` options in the database.
+  KSPGetOptionsPrefix - Gets the prefix used for searching for all
+  `KSP` options in the database.
 
-   Not Collective
+  Not Collective
 
-   Input Parameter:
-.  ksp - the Krylov context
+  Input Parameter:
+. ksp - the Krylov context
 
-   Output Parameter:
-.  prefix - pointer to the prefix string used is returned
+  Output Parameter:
+. prefix - pointer to the prefix string used is returned
 
-   Notes:
-    On the fortran side, the user should pass in a string 'prefix' of
-   sufficient length to hold the prefix.
+  Level: advanced
 
-   Level: advanced
+  Fortran Note:
+  Pass in a string 'prefix' of
+  sufficient length to hold the prefix.
 
 .seealso: [](ch_ksp), `KSP`, `KSPSetFromOptions()`, `KSPSetOptionsPrefix()`, `KSPAppendOptionsPrefix()`
 @*/
@@ -208,21 +224,21 @@ static PetscErrorCode PetscViewerAndFormatCreate_Internal(PetscViewer viewer, Pe
 }
 
 /*@C
-   KSPMonitorSetFromOptions - Sets a monitor function and viewer appropriate for the type indicated by the user in the options database
+  KSPMonitorSetFromOptions - Sets a monitor function and viewer appropriate for the type indicated by the user in the options database
 
-   Collective
+  Collective
 
-   Input Parameters:
-+  ksp  - `KSP` object you wish to monitor
-.  opt  - the command line option for this monitor
-.  name - the monitor type one is seeking
--  ctx  - An optional user context for the monitor, or NULL
+  Input Parameters:
++ ksp  - `KSP` object you wish to monitor
+. opt  - the command line option for this monitor
+. name - the monitor type one is seeking
+- ctx  - An optional user context for the monitor, or `NULL`
 
-   Level: developer
+  Level: developer
 
 .seealso: [](ch_ksp), `KSPMonitorRegister()`, `KSPMonitorSet()`, `PetscOptionsGetViewer()`, `PetscOptionsGetReal()`, `PetscOptionsHasName()`, `PetscOptionsGetString()`,
           `PetscOptionsGetIntArray()`, `PetscOptionsGetRealArray()`, `PetscOptionsBool()`
-          `PetscOptionsInt()`, `PetscOptionsString()`, `PetscOptionsReal()`, `PetscOptionsBool()`,
+          `PetscOptionsInt()`, `PetscOptionsString()`, `PetscOptionsReal()`,
           `PetscOptionsName()`, `PetscOptionsBegin()`, `PetscOptionsEnd()`, `PetscOptionsHeadBegin()`,
           `PetscOptionsStringArray()`, `PetscOptionsRealArray()`, `PetscOptionsScalar()`,
           `PetscOptionsBoolGroupBegin()`, `PetscOptionsBoolGroup()`, `PetscOptionsBoolGroupEnd()`,
@@ -261,60 +277,60 @@ PetscErrorCode KSPMonitorSetFromOptions(KSP ksp, const char opt[], const char na
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+PETSC_INTERN PetscErrorCode KSPCheckPCMPI(KSP);
+
 /*@
-   KSPSetFromOptions - Sets `KSP` options from the options database.
-   This routine must be called before `KSPSetUp()` if the user is to be
-   allowed to set the Krylov type.
+  KSPSetFromOptions - Sets `KSP` options from the options database.
+  This routine must be called before `KSPSetUp()` if the user is to be
+  allowed to set the Krylov type.
 
-   Collective
+  Collective
 
-   Input Parameter:
-.  ksp - the Krylov space context
+  Input Parameter:
+. ksp - the Krylov space context
 
-   Options Database Keys:
-+   -ksp_max_it - maximum number of linear iterations
-.   -ksp_rtol rtol - relative tolerance used in default determination of convergence, i.e.
-                if residual norm decreases by this factor than convergence is declared
-.   -ksp_atol abstol - absolute tolerance used in default convergence test, i.e. if residual
-                norm is less than this then convergence is declared
-.   -ksp_divtol tol - if residual norm increases by this factor than divergence is declared
-.   -ksp_converged_use_initial_residual_norm - see `KSPConvergedDefaultSetUIRNorm()`
-.   -ksp_converged_use_min_initial_residual_norm - see `KSPConvergedDefaultSetUMIRNorm()`
-.   -ksp_converged_maxits - see `KSPConvergedDefaultSetConvergedMaxits()`
-.   -ksp_norm_type - none - skip norms used in convergence tests (useful only when not using
-                       convergence test (say you always want to run with 5 iterations) to
-                       save on communication overhead
-                    preconditioned - default for left preconditioning
-                    unpreconditioned - see `KSPSetNormType()`
-                    natural - see `KSPSetNormType()`
-.   -ksp_check_norm_iteration it - do not compute residual norm until iteration number it (does compute at 0th iteration)
-       works only for `KSPBCGS`, `KSPIBCGS` and and `KSPCG`
-.   -ksp_lag_norm - compute the norm of the residual for the ith iteration on the i+1 iteration; this means that one can use
-       the norm of the residual for convergence test WITHOUT an extra `MPI_Allreduce()` limiting global synchronizations.
-       This will require 1 more iteration of the solver than usual.
-.   -ksp_guess_type - Type of initial guess generator for repeated linear solves
-.   -ksp_fischer_guess <model,size> - uses the Fischer initial guess generator for repeated linear solves
-.   -ksp_constant_null_space - assume the operator (matrix) has the constant vector in its null space
-.   -ksp_test_null_space - tests the null space set with `MatSetNullSpace()` to see if it truly is a null space
-.   -ksp_knoll - compute initial guess by applying the preconditioner to the right hand side
-.   -ksp_monitor_cancel - cancel all previous convergene monitor routines set
-.   -ksp_monitor - print residual norm at each iteration
-.   -ksp_monitor draw::draw_lg - plot residual norm at each iteration
-.   -ksp_monitor_true_residual - print true residual norm at each iteration
-.   -all_ksp_monitor <optional filename> - print residual norm at each iteration for ALL KSP solves, regardless of their prefix. This is
-                                           useful for `PCFIELDSPLIT`, `PCMG`, etc that have inner solvers and you wish to track the convergence of all the solvers
-.   -ksp_monitor_solution [ascii binary or draw][:filename][:format option] - plot solution at each iteration
-.   -ksp_monitor_singular_value - monitor extreme singular values at each iteration
-.   -ksp_converged_reason - view the convergence state at the end of the solve
-.   -ksp_use_explicittranspose - transpose the system explicitly in KSPSolveTranspose
-.   -ksp_error_if_not_converged - stop the program as soon as an error is detected in a `KSPSolve()`, `KSP_DIVERGED_ITS` is not treated as an error on inner solves
--   -ksp_converged_rate - view the convergence rate at the end of the solve
+  Options Database Keys:
++ -ksp_max_it                                                             - maximum number of linear iterations
+. -ksp_min_it                                                             - minimum number of linear iterations to use, defaults to zero
+. -ksp_rtol rtol                                                          - relative tolerance used in default determination of convergence, i.e.
+                                                                            if residual norm decreases by this factor than convergence is declared
+. -ksp_atol abstol                                                        - absolute tolerance used in default convergence test, i.e. if residual
+                                                                            norm is less than this then convergence is declared
+. -ksp_divtol tol                                                         - if residual norm increases by this factor than divergence is declared
+. -ksp_converged_use_initial_residual_norm                                - see `KSPConvergedDefaultSetUIRNorm()`
+. -ksp_converged_use_min_initial_residual_norm                            - see `KSPConvergedDefaultSetUMIRNorm()`
+. -ksp_converged_maxits                                                   - see `KSPConvergedDefaultSetConvergedMaxits()`
+. -ksp_norm_type <none,preconditioned,unpreconditioned,natural>           - see `KSPSetNormType()`
+. -ksp_check_norm_iteration it                                            - do not compute residual norm until iteration number it (does compute at 0th iteration)
+                                                                            works only for `KSPBCGS`, `KSPIBCGS`, and `KSPCG`
+. -ksp_lag_norm                                                           - compute the norm of the residual for the ith iteration on the i+1 iteration;
+                                                                            this means that one can use the norm of the residual for convergence test WITHOUT
+                                                                            an extra `MPI_Allreduce()` limiting global synchronizations.
+                                                                            This will require 1 more iteration of the solver than usual.
+. -ksp_guess_type                                                         - Type of initial guess generator for repeated linear solves
+. -ksp_fischer_guess <model,size>                                         - uses the Fischer initial guess generator for repeated linear solves
+. -ksp_constant_null_space                                                - assume the operator (matrix) has the constant vector in its null space
+. -ksp_test_null_space                                                    - tests the null space set with `MatSetNullSpace()` to see if it truly is a null space
+. -ksp_knoll                                                              - compute initial guess by applying the preconditioner to the right hand side
+. -ksp_monitor_cancel                                                     - cancel all previous convergene monitor routines set
+. -ksp_monitor                                                            - print residual norm at each iteration
+. -ksp_monitor draw::draw_lg                                              - plot residual norm at each iteration
+. -ksp_monitor_true_residual                                              - print true residual norm at each iteration
+. -all_ksp_monitor <optional filename>                                    - print residual norm at each iteration for ALL KSP solves, regardless of their prefix. This is
+                                                                            useful for `PCFIELDSPLIT`, `PCMG`, etc that have inner solvers and
+                                                                            you wish to track the convergence of all the solvers
+. -ksp_monitor_solution [ascii binary or draw][:filename][:format option] - plot solution at each iteration
+. -ksp_monitor_singular_value                                             - monitor extreme singular values at each iteration
+. -ksp_converged_reason                                                   - view the convergence state at the end of the solve
+. -ksp_use_explicittranspose                                              - transpose the system explicitly in KSPSolveTranspose
+. -ksp_error_if_not_converged                                             - stop the program as soon as an error is detected in a `KSPSolve()`, `KSP_DIVERGED_ITS`
+                                                                            is not treated as an error on inner solves
+- -ksp_converged_rate                                                     - view the convergence rate at the end of the solve
 
-   Notes:
-   To see all options, run your program with the -help option
-   or consult [](ch_ksp)
+  Level: beginner
 
-   Level: beginner
+  Note:
+  To see all options, run your program with the `-help` option or consult [](ch_ksp)
 
 .seealso: [](ch_ksp), `KSP`, `KSPSetOptionsPrefix()`, `KSPResetFromOptions()`, `KSPSetUseFischerGuess()`
 @*/
@@ -331,6 +347,8 @@ PetscErrorCode KSPSetFromOptions(KSP ksp)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ksp, KSP_CLASSID, 1);
+  PetscCall(KSPCheckPCMPI(ksp));
+
   PetscCall(PetscObjectGetComm((PetscObject)ksp, &comm));
   PetscCall(PetscObjectGetOptionsPrefix((PetscObject)ksp, &prefix));
   if (!ksp->skippcsetfromoptions) {
@@ -397,7 +415,8 @@ PetscErrorCode KSPSetFromOptions(KSP ksp)
     goto skipoptions;
   }
 
-  PetscCall(PetscOptionsInt("-ksp_max_it", "Maximum number of iterations", "KSPSetTolerances", ksp->max_it, &ksp->max_it, NULL));
+  PetscCall(PetscOptionsBoundedInt("-ksp_max_it", "Maximum number of iterations", "KSPSetTolerances", ksp->max_it, &ksp->max_it, NULL, 0));
+  PetscCall(PetscOptionsRangeInt("-ksp_min_it", "Minimum number of iterations", "KSPSetMinimumIterations", ksp->min_it, &ksp->min_it, NULL, 0, ksp->max_it));
   PetscCall(PetscOptionsReal("-ksp_rtol", "Relative decrease in residual norm", "KSPSetTolerances", ksp->rtol, &ksp->rtol, NULL));
   PetscCall(PetscOptionsReal("-ksp_atol", "Absolute value of residual norm", "KSPSetTolerances", ksp->abstol, &ksp->abstol, NULL));
   PetscCall(PetscOptionsReal("-ksp_divtol", "Residual norm increase cause divergence", "KSPSetTolerances", ksp->divtol, &ksp->divtol, NULL));
@@ -534,19 +553,20 @@ PetscErrorCode KSPSetFromOptions(KSP ksp)
   PetscCall(PetscOptionsGetViewer(comm, ((PetscObject)ksp)->options, prefix, "-ksp_view_rhs", &ksp->viewerRhs, &ksp->formatRhs, &ksp->viewRhs));
   PetscCall(PetscOptionsGetViewer(comm, ((PetscObject)ksp)->options, prefix, "-ksp_view_solution", &ksp->viewerSol, &ksp->formatSol, &ksp->viewSol));
   PetscCall(PetscOptionsGetViewer(comm, ((PetscObject)ksp)->options, prefix, "-ksp_view_mat_explicit", &ksp->viewerMatExp, &ksp->formatMatExp, &ksp->viewMatExp));
+  PetscCall(PetscOptionsDeprecated("-ksp_compute_eigenvalues", "-ksp_view_eigenvalues", "3.9", NULL));
   PetscCall(PetscOptionsGetViewer(comm, ((PetscObject)ksp)->options, prefix, "-ksp_view_eigenvalues", &ksp->viewerEV, &ksp->formatEV, &ksp->viewEV));
+  PetscCall(PetscOptionsDeprecated("-ksp_compute_singularvalues", "-ksp_view_singularvalues", "3.9", NULL));
   PetscCall(PetscOptionsGetViewer(comm, ((PetscObject)ksp)->options, prefix, "-ksp_view_singularvalues", &ksp->viewerSV, &ksp->formatSV, &ksp->viewSV));
+  PetscCall(PetscOptionsDeprecated("-ksp_compute_eigenvalues_explicitly", "-ksp_view_eigenvalues_explicit", "3.9", NULL));
   PetscCall(PetscOptionsGetViewer(comm, ((PetscObject)ksp)->options, prefix, "-ksp_view_eigenvalues_explicit", &ksp->viewerEVExp, &ksp->formatEVExp, &ksp->viewEVExp));
+  PetscCall(PetscOptionsDeprecated("-ksp_final_residual", "-ksp_view_final_residual", "3.9", NULL));
   PetscCall(PetscOptionsGetViewer(comm, ((PetscObject)ksp)->options, prefix, "-ksp_view_final_residual", &ksp->viewerFinalRes, &ksp->formatFinalRes, &ksp->viewFinalRes));
   PetscCall(PetscOptionsGetViewer(comm, ((PetscObject)ksp)->options, prefix, "-ksp_view_preconditioned_operator_explicit", &ksp->viewerPOpExp, &ksp->formatPOpExp, &ksp->viewPOpExp));
   PetscCall(PetscOptionsGetViewer(comm, ((PetscObject)ksp)->options, prefix, "-ksp_view_diagonal_scale", &ksp->viewerDScale, &ksp->formatDScale, &ksp->viewDScale));
 
   /* Deprecated options */
   if (!ksp->viewEV) {
-    PetscCall(PetscOptionsDeprecated("-ksp_compute_eigenvalues", NULL, "3.9", "Use -ksp_view_eigenvalues"));
-    PetscCall(PetscOptionsGetViewer(comm, ((PetscObject)ksp)->options, prefix, "-ksp_compute_eigenvalues", &ksp->viewerEV, &ksp->formatEV, &ksp->viewEV));
-  }
-  if (!ksp->viewEV) {
+    /* Cannot remove the what otherwise would be redundant call to PetscOptionsName("-ksp_plot_eigenvalues",...) below because the argument handling is different */
     PetscCall(PetscOptionsDeprecated("-ksp_plot_eigenvalues", NULL, "3.9", "Use -ksp_view_eigenvalues draw"));
     PetscCall(PetscOptionsName("-ksp_plot_eigenvalues", "[deprecated since PETSc 3.9; use -ksp_view_eigenvalues draw]", "KSPView", &ksp->viewEV));
     if (ksp->viewEV) {
@@ -556,7 +576,8 @@ PetscErrorCode KSPSetFromOptions(KSP ksp)
     }
   }
   if (!ksp->viewEV) {
-    PetscCall(PetscOptionsDeprecated("-ksp_plot_eigencontours", NULL, "3.9", "Use -ksp_view_eigenvalues draw::draw_contour"));
+    PetscCall(PetscOptionsDeprecated("-ksp_plot_eigenvalues_explicitly", NULL, "3.9", "Use -ksp_view_eigenvalues_explicit draw"));
+    /* Cannot remove the what otherwise would be redundant call to PetscOptionsName("-ksp_plot_eigencontours",...) below because the argument handling is different */
     PetscCall(PetscOptionsName("-ksp_plot_eigencontours", "[deprecated since PETSc 3.9; use -ksp_view_eigenvalues draw::draw_contour]", "KSPView", &ksp->viewEV));
     if (ksp->viewEV) {
       ksp->formatEV = PETSC_VIEWER_DRAW_CONTOUR;
@@ -565,11 +586,7 @@ PetscErrorCode KSPSetFromOptions(KSP ksp)
     }
   }
   if (!ksp->viewEVExp) {
-    PetscCall(PetscOptionsDeprecated("-ksp_compute_eigenvalues_explicitly", NULL, "3.9", "Use -ksp_view_eigenvalues_explicit"));
-    PetscCall(PetscOptionsGetViewer(comm, ((PetscObject)ksp)->options, prefix, "-ksp_compute_eigenvalues_explicitly", &ksp->viewerEVExp, &ksp->formatEVExp, &ksp->viewEVExp));
-  }
-  if (!ksp->viewEVExp) {
-    PetscCall(PetscOptionsDeprecated("-ksp_plot_eigenvalues_explicitly", NULL, "3.9", "Use -ksp_view_eigenvalues_explicit draw"));
+    /* Cannot remove the what otherwise would be redundant call to PetscOptionsName("-ksp_plot_eigencontours_explicitly",...) below because the argument handling is different */
     PetscCall(PetscOptionsName("-ksp_plot_eigenvalues_explicitly", "[deprecated since PETSc 3.9; use -ksp_view_eigenvalues_explicit draw]", "KSPView", &ksp->viewEVExp));
     if (ksp->viewEVExp) {
       ksp->formatEVExp = PETSC_VIEWER_DEFAULT;
@@ -577,14 +594,6 @@ PetscErrorCode KSPSetFromOptions(KSP ksp)
       PetscCall(PetscObjectReference((PetscObject)ksp->viewerEVExp));
     }
   }
-  if (!ksp->viewSV) {
-    PetscCall(PetscOptionsDeprecated("-ksp_compute_singularvalues", NULL, "3.9", "Use -ksp_view_singularvalues"));
-    PetscCall(PetscOptionsGetViewer(comm, ((PetscObject)ksp)->options, prefix, "-ksp_compute_singularvalues", &ksp->viewerSV, &ksp->formatSV, &ksp->viewSV));
-  }
-  if (!ksp->viewFinalRes) {
-    PetscCall(PetscOptionsDeprecated("-ksp_final_residual", NULL, "3.9", "Use -ksp_view_final_residual"));
-    PetscCall(PetscOptionsGetViewer(comm, ((PetscObject)ksp)->options, prefix, "-ksp_final_residual", &ksp->viewerFinalRes, &ksp->formatFinalRes, &ksp->viewFinalRes));
-  }
 
 #if defined(PETSC_HAVE_SAWS)
   /*
@@ -599,7 +608,6 @@ PetscErrorCode KSPSetFromOptions(KSP ksp)
   }
 #endif
 
-  /* -----------------------------------------------------------------------*/
   PetscCall(KSPSetUpNorms_Private(ksp, PETSC_FALSE, NULL, &pcside));
   PetscCall(PetscOptionsEnum("-ksp_pc_side", "KSP preconditioner side", "KSPSetPCSide", PCSides, (PetscEnum)pcside, (PetscEnum *)&pcside, &flg));
   if (flg) PetscCall(KSPSetPCSide(ksp, pcside));
@@ -634,14 +642,14 @@ skipoptions:
 }
 
 /*@
-   KSPResetFromOptions - Sets `KSP` parameters from user options ONLY if the `KSP` was previously set from options
+  KSPResetFromOptions - Sets `KSP` parameters from user options ONLY if the `KSP` was previously set from options
 
-   Collective
+  Collective
 
-   Input Parameter:
-.  ksp - the `KSP` context
+  Input Parameter:
+. ksp - the `KSP` context
 
-   Level: advanced
+  Level: advanced
 
 .seealso: [](ch_ksp), `KSPSetFromOptions()`, `KSPSetOptionsPrefix()`
 @*/
