@@ -1,4 +1,3 @@
-
 static char help[] = "Creates a matrix from quadrilateral finite elements in 2D, Laplacian \n\
   -ne <size>       : problem size in number of elements (eg, -ne 31 gives 32^2 grid)\n\
   -alpha <v>      : scaling of material coefficient in embedded circle\n\n";
@@ -7,18 +6,16 @@ static char help[] = "Creates a matrix from quadrilateral finite elements in 2D,
 
 int main(int argc, char **args)
 {
-  Mat         Amat, Pmat;
-  PetscInt    i, m, M, its, Istart, Iend, j, Ii, ix, ne = 4;
-  PetscReal   x, y, h;
-  Vec         xx, bb;
-  KSP         ksp;
-  PetscReal   soft_alpha = 1.e-3;
-  MPI_Comm    comm;
-  PetscMPIInt npe, mype;
-  PetscScalar DD[4][4], DD2[4][4];
-#if defined(PETSC_USE_LOG)
+  Mat           Amat, Pmat;
+  PetscInt      i, m, M, its, Istart, Iend, j, Ii, ix, ne = 4;
+  PetscReal     x, y, h;
+  Vec           xx, bb;
+  KSP           ksp;
+  PetscReal     soft_alpha = 1.e-3;
+  MPI_Comm      comm;
+  PetscMPIInt   npe, mype;
+  PetscScalar   DD[4][4], DD2[4][4];
   PetscLogStage stage;
-#endif
 #define DIAG_S 0.0
   PetscScalar DD1[4][4] = {
     {5.0 + DIAG_S, -2.0,         -1.0,         -2.0        },
@@ -161,19 +158,15 @@ int main(int argc, char **args)
   }
 
   /* solve */
-#if defined(PETSC_USE_LOG)
   PetscCall(PetscLogStageRegister("Solve", &stage));
   PetscCall(PetscLogStagePush(stage));
-#endif
   PetscCall(VecSet(xx, .0));
 
   PetscCall(KSPSetUp(ksp));
 
   PetscCall(KSPSolve(ksp, bb, xx));
 
-#if defined(PETSC_USE_LOG)
   PetscCall(PetscLogStagePop());
-#endif
 
   PetscCall(KSPGetIterationNumber(ksp, &its));
 
@@ -246,4 +239,9 @@ int main(int argc, char **args)
       requires: triangle
       output_file: output/ex54_0.out
 
+   test:
+      requires: !single !__float128
+      nsize: 4
+      suffix: hem
+      args: -ne 39 -ksp_type cg -pc_type gamg -pc_gamg_type agg -ksp_rtol 1e-4 -pc_gamg_square_graph 0 -ksp_monitor_short -ksp_norm_type unpreconditioned -mat_coarsen_type hem -ksp_monitor_short -pc_gamg_aggressive_coarsening 0
 TEST*/
