@@ -6,7 +6,7 @@
        forcing function f = -cos(m*pi*x)*cos(n*pi*y),
        Periodic boundary conditions
          p(x=0) = p(x=1)
-       Neuman boundary conditions
+       Neumann boundary conditions
          dp/dy = 0 for y = 0, y = 1.
 
        This example uses the DM_BOUNDARY_MIRROR to implement the Neumann boundary conditions, see the manual pages for DMBoundaryType
