@@ -1,4 +1,3 @@
-
 /*
       Defines a preconditioner that can consist of a collection of PCs
 */
@@ -98,8 +97,8 @@ static PetscErrorCode PCApplyTranspose_Composite_Multiplicative(PC pc, Vec x, Ve
 
 /*
     This is very special for a matrix of the form alpha I + R + S
-where first preconditioner is built from alpha I + S and second from
-alpha I + R
+    where first preconditioner is built from alpha I + S and second from
+    alpha I + R
 */
 static PetscErrorCode PCApply_Composite_Special(PC pc, Vec x, Vec y)
 {
@@ -176,6 +175,22 @@ static PetscErrorCode PCSetUp_Composite(PC pc)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+static PetscErrorCode PCSetUpOnBlocks_Composite(PC pc)
+{
+  PC_Composite    *jac  = (PC_Composite *)pc->data;
+  PC_CompositeLink next = jac->head;
+  PCFailedReason   reason;
+
+  PetscFunctionBegin;
+  while (next) {
+    PetscCall(PCSetUp(next->pc));
+    PetscCall(PCGetFailedReasonRank(next->pc, &reason));
+    if (reason) pc->failedreason = reason;
+    next = next->next;
+  }
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
 static PetscErrorCode PCReset_Composite(PC pc)
 {
   PC_Composite    *jac  = (PC_Composite *)pc->data;
@@ -389,20 +404,20 @@ static PetscErrorCode PCCompositeGetPC_Composite(PC pc, PetscInt n, PC *subpc)
 }
 
 /*@
-   PCCompositeSetType - Sets the type of composite preconditioner.
+  PCCompositeSetType - Sets the type of composite preconditioner.
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameters:
-+  pc - the preconditioner context
--  type - `PC_COMPOSITE_ADDITIVE` (default), `PC_COMPOSITE_MULTIPLICATIVE`, `PC_COMPOSITE_SPECIAL`
+  Input Parameters:
++ pc   - the preconditioner context
+- type - `PC_COMPOSITE_ADDITIVE` (default), `PC_COMPOSITE_MULTIPLICATIVE`, `PC_COMPOSITE_SPECIAL`
 
-   Options Database Key:
-.  -pc_composite_type <type: one of multiplicative, additive, special> - Sets composite preconditioner type
+  Options Database Key:
+. -pc_composite_type <type: one of multiplicative, additive, special> - Sets composite preconditioner type
 
-   Level: advanced
+  Level: advanced
 
-.seealso: `PCCOMPOSITE`, `PC_COMPOSITE_ADDITIVE`, `PC_COMPOSITE_MULTIPLICATIVE`, `PC_COMPOSITE_SPECIAL`, `PCCompositeType`,
+.seealso: [](ch_ksp), `PCCOMPOSITE`, `PC_COMPOSITE_ADDITIVE`, `PC_COMPOSITE_MULTIPLICATIVE`, `PC_COMPOSITE_SPECIAL`, `PCCompositeType`,
           `PCCompositeGetType()`
 @*/
 PetscErrorCode PCCompositeSetType(PC pc, PCCompositeType type)
@@ -415,19 +430,19 @@ PetscErrorCode PCCompositeSetType(PC pc, PCCompositeType type)
 }
 
 /*@
-   PCCompositeGetType - Gets the type of composite preconditioner.
+  PCCompositeGetType - Gets the type of composite preconditioner.
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameter:
-.  pc - the preconditioner context
+  Input Parameter:
+. pc - the preconditioner context
 
-   Output Parameter:
-.  type - `PC_COMPOSITE_ADDITIVE` (default), `PC_COMPOSITE_MULTIPLICATIVE`, `PC_COMPOSITE_SPECIAL`
+  Output Parameter:
+. type - `PC_COMPOSITE_ADDITIVE` (default), `PC_COMPOSITE_MULTIPLICATIVE`, `PC_COMPOSITE_SPECIAL`
 
-   Level: advanced
+  Level: advanced
 
-.seealso: `PCCOMPOSITE`, `PC_COMPOSITE_ADDITIVE`, `PC_COMPOSITE_MULTIPLICATIVE`, `PC_COMPOSITE_SPECIAL`, `PCCompositeType`,
+.seealso: [](ch_ksp), `PCCOMPOSITE`, `PC_COMPOSITE_ADDITIVE`, `PC_COMPOSITE_MULTIPLICATIVE`, `PC_COMPOSITE_SPECIAL`, `PCCompositeType`,
           `PCCompositeSetType()`
 @*/
 PetscErrorCode PCCompositeGetType(PC pc, PCCompositeType *type)
@@ -439,18 +454,18 @@ PetscErrorCode PCCompositeGetType(PC pc, PCCompositeType *type)
 }
 
 /*@
-   PCCompositeSpecialSetAlpha - Sets alpha for the special composite preconditioner, `PC_COMPOSITE_SPECIAL`,
-     for alphaI + R + S
+  PCCompositeSpecialSetAlpha - Sets alpha for the special composite preconditioner, `PC_COMPOSITE_SPECIAL`,
+  for $\alpha I + R + S$
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameters:
-+  pc - the preconditioner context
--  alpha - scale on identity
+  Input Parameters:
++ pc    - the preconditioner context
+- alpha - scale on identity
 
-   Level: Developer
+  Level: developer
 
-.seealso: `PCCOMPOSITE`, `PC_COMPOSITE_ADDITIVE`, `PC_COMPOSITE_MULTIPLICATIVE`, `PC_COMPOSITE_SPECIAL`, `PCCompositeType`,
+.seealso: [](ch_ksp), `PCCOMPOSITE`, `PC_COMPOSITE_ADDITIVE`, `PC_COMPOSITE_MULTIPLICATIVE`, `PC_COMPOSITE_SPECIAL`, `PCCompositeType`,
           `PCCompositeSetType()`, `PCCompositeGetType()`
 @*/
 PetscErrorCode PCCompositeSpecialSetAlpha(PC pc, PetscScalar alpha)
@@ -468,12 +483,12 @@ PetscErrorCode PCCompositeSpecialSetAlpha(PC pc, PetscScalar alpha)
   Collective
 
   Input Parameters:
-+ pc - the preconditioner context
++ pc   - the preconditioner context
 - type - the type of the new preconditioner
 
   Level: intermediate
 
-.seealso: `PCCOMPOSITE`, `PCCompositeAddPC()`, `PCCompositeGetNumberPC()`
+.seealso: [](ch_ksp), `PCCOMPOSITE`, `PCCompositeAddPC()`, `PCCompositeGetNumberPC()`
 @*/
 PetscErrorCode PCCompositeAddPCType(PC pc, PCType type)
 {
@@ -492,9 +507,9 @@ PetscErrorCode PCCompositeAddPCType(PC pc, PCType type)
 + pc    - the preconditioner context
 - subpc - the new preconditioner
 
-   Level: intermediate
+  Level: intermediate
 
-.seealso: `PCCOMPOSITE`, `PCCompositeAddPCType()`, `PCCompositeGetNumberPC()`
+.seealso: [](ch_ksp), `PCCOMPOSITE`, `PCCompositeAddPCType()`, `PCCompositeGetNumberPC()`
 @*/
 PetscErrorCode PCCompositeAddPC(PC pc, PC subpc)
 {
@@ -506,54 +521,54 @@ PetscErrorCode PCCompositeAddPC(PC pc, PC subpc)
 }
 
 /*@
-   PCCompositeGetNumberPC - Gets the number of `PC` objects in the composite `PC`.
+  PCCompositeGetNumberPC - Gets the number of `PC` objects in the composite `PC`.
 
-   Not Collective
+  Not Collective
 
-   Input Parameter:
-.  pc - the preconditioner context
+  Input Parameter:
+. pc - the preconditioner context
 
-   Output Parameter:
-.  num - the number of sub pcs
+  Output Parameter:
+. num - the number of sub pcs
 
-   Level: Developer
+  Level: developer
 
-.seealso: `PCCOMPOSITE`, `PCCompositeGetPC()`, `PCCompositeAddPC()`, `PCCompositeAddPCType()`
+.seealso: [](ch_ksp), `PCCOMPOSITE`, `PCCompositeGetPC()`, `PCCompositeAddPC()`, `PCCompositeAddPCType()`
 @*/
 PetscErrorCode PCCompositeGetNumberPC(PC pc, PetscInt *num)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
-  PetscValidIntPointer(num, 2);
+  PetscAssertPointer(num, 2);
   PetscUseMethod(pc, "PCCompositeGetNumberPC_C", (PC, PetscInt *), (pc, num));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-   PCCompositeGetPC - Gets one of the `PC` objects in the composite `PC`.
+  PCCompositeGetPC - Gets one of the `PC` objects in the composite `PC`.
 
-   Not Collective
+  Not Collective
 
-   Input Parameters:
-+  pc - the preconditioner context
--  n - the number of the pc requested
+  Input Parameters:
++ pc - the preconditioner context
+- n  - the number of the pc requested
 
-   Output Parameter:
-.  subpc - the PC requested
+  Output Parameter:
+. subpc - the PC requested
 
-   Level: intermediate
+  Level: intermediate
 
-    Note:
-    To use a different operator to construct one of the inner preconditioners first call `PCCompositeGetPC()`, then
-    call `PCSetOperators()` on that `PC`.
+  Note:
+  To use a different operator to construct one of the inner preconditioners first call `PCCompositeGetPC()`, then
+  call `PCSetOperators()` on that `PC`.
 
-.seealso: `PCCOMPOSITE`, `PCCompositeAddPCType()`, `PCCompositeGetNumberPC()`, `PCSetOperators()`
+.seealso: [](ch_ksp), `PCCOMPOSITE`, `PCCompositeAddPCType()`, `PCCompositeGetNumberPC()`, `PCSetOperators()`
 @*/
 PetscErrorCode PCCompositeGetPC(PC pc, PetscInt n, PC *subpc)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
-  PetscValidPointer(subpc, 3);
+  PetscAssertPointer(subpc, 3);
   PetscUseMethod(pc, "PCCompositeGetPC_C", (PC, PetscInt, PC *), (pc, n, subpc));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -563,8 +578,8 @@ PetscErrorCode PCCompositeGetPC(PC pc, PetscInt n, PC *subpc)
 
    Options Database Keys:
 +  -pc_composite_type <type: one of multiplicative, additive, symmetric_multiplicative, special> - Sets composite preconditioner type
-.  -pc_use_amat - activates `PCSetUseAmat()`
--  -pc_composite_pcs - <pc0,pc1,...> list of PCs to compose
+.  -pc_use_amat                                                                                  - activates `PCSetUseAmat()`
+-  -pc_composite_pcs                                                                             - <pc0,pc1,...> list of PCs to compose
 
    Level: intermediate
 
@@ -576,7 +591,7 @@ PetscErrorCode PCCompositeGetPC(PC pc, PetscInt n, PC *subpc)
    To use a different operator to construct one of the inner preconditioners first call `PCCompositeGetPC()`, then
    call `PCSetOperators()` on that `PC`.
 
-.seealso: `PCCreate()`, `PCSetType()`, `PCType`, `PC`,
+.seealso: [](ch_ksp), `PCCreate()`, `PCSetType()`, `PCType`, `PC`,
           `PCSHELL`, `PCKSP`, `PCCompositeSetType()`, `PCCompositeSpecialSetAlpha()`, `PCCompositeAddPCType()`,
           `PCCompositeGetPC()`, `PCSetUseAmat()`, `PCCompositeAddPC()`, `PCCompositeGetNumberPC()`
 M*/
@@ -591,6 +606,7 @@ PETSC_EXTERN PetscErrorCode PCCreate_Composite(PC pc)
   pc->ops->apply           = PCApply_Composite_Additive;
   pc->ops->applytranspose  = PCApplyTranspose_Composite_Additive;
   pc->ops->setup           = PCSetUp_Composite;
+  pc->ops->setuponblocks   = PCSetUpOnBlocks_Composite;
   pc->ops->reset           = PCReset_Composite;
   pc->ops->destroy         = PCDestroy_Composite;
   pc->ops->setfromoptions  = PCSetFromOptions_Composite;
