@@ -1,4 +1,3 @@
-
 /*
    Provides an interface to the ML smoothed Aggregation
    Note: Something non-obvious breaks -pc_mg_type ADDITIVE for parallel runs
@@ -395,7 +394,6 @@ static PetscErrorCode MatWrapML_MPIAIJ(ML_Operator *mlmat, MatReuse reuse, Mat *
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/* -------------------------------------------------------------------------- */
 /*
    PCSetCoordinates_ML
 
@@ -444,9 +442,8 @@ static PetscErrorCode PCSetCoordinates_ML(PC pc, PetscInt ndm, PetscInt a_nloc,
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/* -----------------------------------------------------------------------------*/
 extern PetscErrorCode PCReset_MG(PC);
-PetscErrorCode        PCReset_ML(PC pc)
+static PetscErrorCode PCReset_ML(PC pc)
 {
   PC_MG   *mg    = (PC_MG *)pc->data;
   PC_ML   *pc_ml = (PC_ML *)mg->innerctx;
@@ -492,7 +489,7 @@ PetscErrorCode        PCReset_ML(PC pc)
   PetscCall(PCReset_MG(pc));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
-/* -------------------------------------------------------------------------- */
+
 /*
    PCSetUp_ML - Prepares for the use of the ML preconditioner
                     by setting data structures and options.
@@ -509,7 +506,7 @@ PetscErrorCode        PCReset_ML(PC pc)
 extern PetscErrorCode PCSetFromOptions_MG(PC, PetscOptionItems *PetscOptionsObject);
 extern PetscErrorCode PCReset_MG(PC);
 
-PetscErrorCode PCSetUp_ML(PC pc)
+static PetscErrorCode PCSetUp_ML(PC pc)
 {
   PetscMPIInt      size;
   FineGridCtx     *PetscMLdata;
@@ -608,7 +605,6 @@ PetscErrorCode PCSetUp_ML(PC pc)
   }
 
   /* setup special features of PCML */
-  /*--------------------------------*/
   /* convert A to Aloc to be used by ML at fine grid */
   pc_ml->size = size;
   PetscCall(PetscObjectBaseTypeCompare((PetscObject)A, MATSEQAIJ, &isSeq));
@@ -697,11 +693,11 @@ PetscErrorCode PCSetUp_ML(PC pc)
         for (j = 0; j < mlocal; j++) nullvec[(i + !!has_const) * mlocal + j] = v[j];
         PetscCall(VecRestoreArrayRead(vecs[i], &v));
       }
-      PetscStackCallExternalVoid("ML_Aggregate_Create", PetscCall(ML_Aggregate_Set_NullSpace(agg_object, bs, nvec + !!has_const, nullvec, mlocal)));
+      PetscStackCallExternalVoid("ML_Aggregate_Create", ML_Aggregate_Set_NullSpace(agg_object, bs, nvec + !!has_const, nullvec, mlocal));
       PetscCall(PetscFree(nullvec));
     } break;
     case PCML_NULLSPACE_BLOCK:
-      PetscStackCallExternalVoid("ML_Aggregate_Set_NullSpace", PetscCall(ML_Aggregate_Set_NullSpace(agg_object, bs, bs, 0, 0)));
+      PetscStackCallExternalVoid("ML_Aggregate_Set_NullSpace", ML_Aggregate_Set_NullSpace(agg_object, bs, bs, 0, 0));
       break;
     case PCML_NULLSPACE_SCALAR:
       break;
@@ -945,7 +941,6 @@ PetscErrorCode PCSetUp_ML(PC pc)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/* -------------------------------------------------------------------------- */
 /*
    PCDestroy_ML - Destroys the private context for the ML preconditioner
    that was created with PCCreate_ML().
@@ -955,7 +950,7 @@ PetscErrorCode PCSetUp_ML(PC pc)
 
    Application Interface Routine: PCDestroy()
 */
-PetscErrorCode PCDestroy_ML(PC pc)
+static PetscErrorCode PCDestroy_ML(PC pc)
 {
   PC_MG *mg    = (PC_MG *)pc->data;
   PC_ML *pc_ml = (PC_ML *)mg->innerctx;
@@ -968,7 +963,7 @@ PetscErrorCode PCDestroy_ML(PC pc)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode PCSetFromOptions_ML(PC pc, PetscOptionItems *PetscOptionsObject)
+static PetscErrorCode PCSetFromOptions_ML(PC pc, PetscOptionItems *PetscOptionsObject)
 {
   PetscInt    indx, PrintLevel, partindx;
   const char *scheme[] = {"Uncoupled", "Coupled", "MIS", "METIS"};
@@ -1109,7 +1104,7 @@ PetscErrorCode PCSetFromOptions_ML(PC pc, PetscOptionItems *PetscOptionsObject)
    operators are computed by ML, with the matrices converted to PETSc matrices in `MATAIJ` format
    and the restriction/interpolation operators wrapped as PETSc shell matrices.
 
-.seealso: `PCCreate()`, `PCSetType()`, `PCType`, `PC`, `PCMGType`, `PCMG`, `PCHYPRE`, `PCGAMG`,
+.seealso: [](ch_ksp), `PCCreate()`, `PCSetType()`, `PCType`, `PC`, `PCMGType`, `PCMG`, `PCHYPRE`, `PCGAMG`,
           `PCMGSetLevels()`, `PCMGGetLevels()`, `PCMGSetType()`, `MPSetCycles()`, `PCMGSetDistinctSmoothUp()`,
           `PCMGGetCoarseSolve()`, `PCMGSetResidual()`, `PCMGSetInterpolation()`,
           `PCMGSetRestriction()`, `PCMGGetSmoother()`, `PCMGGetSmootherUp()`, `PCMGGetSmootherDown()`,
