@@ -1,4 +1,3 @@
-
 /***********************************gs.c***************************************
 
 Author: Henry M. Tufo III
@@ -23,7 +22,7 @@ File Description:
 #include <../src/ksp/pc/impls/tfs/tfs.h>
 
 /* default length of number of items via tree - doubles if exceeded */
-#define TREE_BUF_SZ 2048;
+#define TREE_BUF_SZ 2048
 #define GS_VEC_SZ   1
 
 /***********************************gs.c***************************************
@@ -60,7 +59,7 @@ typedef struct gather_scatter_id {
   PetscInt num_loads;
 
   /* repeats == true -> local info */
-  PetscInt  nel;  /* number of unique elememts */
+  PetscInt  nel;  /* number of unique elements */
   PetscInt *elms; /* of size nel */
   PetscInt  nel_total;
   PetscInt *local_elms; /* of size nel_total */
