@@ -1,4 +1,3 @@
-
 /**********************************ivec.c**************************************
 
 Author: Henry M. Tufo III
@@ -36,7 +35,7 @@ PetscErrorCode PCTFS_ivec_zero(PetscInt *arg1, PetscInt n)
 {
   PetscFunctionBegin;
   while (n--) *arg1++ = 0;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /***********************************ivec.c*************************************/
@@ -44,7 +43,7 @@ PetscErrorCode PCTFS_ivec_set(PetscInt *arg1, PetscInt arg2, PetscInt n)
 {
   PetscFunctionBegin;
   while (n--) *arg1++ = arg2;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /***********************************ivec.c*************************************/
@@ -56,7 +55,7 @@ PetscErrorCode PCTFS_ivec_max(PetscInt *arg1, PetscInt *arg2, PetscInt n)
     arg1++;
     arg2++;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /***********************************ivec.c*************************************/
@@ -68,7 +67,7 @@ PetscErrorCode PCTFS_ivec_min(PetscInt *arg1, PetscInt *arg2, PetscInt n)
     arg1++;
     arg2++;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /***********************************ivec.c*************************************/
@@ -76,7 +75,7 @@ PetscErrorCode PCTFS_ivec_mult(PetscInt *arg1, PetscInt *arg2, PetscInt n)
 {
   PetscFunctionBegin;
   while (n--) *arg1++ *= *arg2++;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /***********************************ivec.c*************************************/
@@ -84,7 +83,7 @@ PetscErrorCode PCTFS_ivec_add(PetscInt *arg1, PetscInt *arg2, PetscInt n)
 {
   PetscFunctionBegin;
   while (n--) *arg1++ += *arg2++;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /***********************************ivec.c*************************************/
@@ -96,7 +95,7 @@ PetscErrorCode PCTFS_ivec_lxor(PetscInt *arg1, PetscInt *arg2, PetscInt n)
     arg1++;
     arg2++;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /***********************************ivec.c*************************************/
@@ -104,7 +103,7 @@ PetscErrorCode PCTFS_ivec_xor(PetscInt *arg1, PetscInt *arg2, PetscInt n)
 {
   PetscFunctionBegin;
   while (n--) *arg1++ ^= *arg2++;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /***********************************ivec.c*************************************/
@@ -112,7 +111,7 @@ PetscErrorCode PCTFS_ivec_or(PetscInt *arg1, PetscInt *arg2, PetscInt n)
 {
   PetscFunctionBegin;
   while (n--) *arg1++ |= *arg2++;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /***********************************ivec.c*************************************/
@@ -124,7 +123,7 @@ PetscErrorCode PCTFS_ivec_lor(PetscInt *arg1, PetscInt *arg2, PetscInt n)
     arg1++;
     arg2++;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /***********************************ivec.c*************************************/
@@ -132,7 +131,7 @@ PetscErrorCode PCTFS_ivec_and(PetscInt *arg1, PetscInt *arg2, PetscInt n)
 {
   PetscFunctionBegin;
   while (n--) *arg1++ &= *arg2++;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /***********************************ivec.c*************************************/
@@ -144,7 +143,7 @@ PetscErrorCode PCTFS_ivec_land(PetscInt *arg1, PetscInt *arg2, PetscInt n)
     arg1++;
     arg2++;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /***********************************ivec.c*************************************/
@@ -152,7 +151,7 @@ PetscErrorCode PCTFS_ivec_and3(PetscInt *arg1, PetscInt *arg2, PetscInt *arg3, P
 {
   PetscFunctionBegin;
   while (n--) *arg1++ = (*arg2++ & *arg3++);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /***********************************ivec.c*************************************/
@@ -186,23 +185,23 @@ PetscErrorCode PCTFS_ivec_non_uniform(PetscInt *arg1, PetscInt *arg2, PetscInt n
     j -= i;
 
     /* call appropriate ivec function */
-    if (type == GL_MAX) PCTFS_ivec_max(arg1, arg2, j);
-    else if (type == GL_MIN) PCTFS_ivec_min(arg1, arg2, j);
-    else if (type == GL_MULT) PCTFS_ivec_mult(arg1, arg2, j);
-    else if (type == GL_ADD) PCTFS_ivec_add(arg1, arg2, j);
-    else if (type == GL_B_XOR) PCTFS_ivec_xor(arg1, arg2, j);
-    else if (type == GL_B_OR) PCTFS_ivec_or(arg1, arg2, j);
-    else if (type == GL_B_AND) PCTFS_ivec_and(arg1, arg2, j);
-    else if (type == GL_L_XOR) PCTFS_ivec_lxor(arg1, arg2, j);
-    else if (type == GL_L_OR) PCTFS_ivec_lor(arg1, arg2, j);
-    else if (type == GL_L_AND) PCTFS_ivec_land(arg1, arg2, j);
+    if (type == GL_MAX) PetscCall(PCTFS_ivec_max(arg1, arg2, j));
+    else if (type == GL_MIN) PetscCall(PCTFS_ivec_min(arg1, arg2, j));
+    else if (type == GL_MULT) PetscCall(PCTFS_ivec_mult(arg1, arg2, j));
+    else if (type == GL_ADD) PetscCall(PCTFS_ivec_add(arg1, arg2, j));
+    else if (type == GL_B_XOR) PetscCall(PCTFS_ivec_xor(arg1, arg2, j));
+    else if (type == GL_B_OR) PetscCall(PCTFS_ivec_or(arg1, arg2, j));
+    else if (type == GL_B_AND) PetscCall(PCTFS_ivec_and(arg1, arg2, j));
+    else if (type == GL_L_XOR) PetscCall(PCTFS_ivec_lxor(arg1, arg2, j));
+    else if (type == GL_L_OR) PetscCall(PCTFS_ivec_lor(arg1, arg2, j));
+    else if (type == GL_L_AND) PetscCall(PCTFS_ivec_land(arg1, arg2, j));
     else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_PLIB, "unrecognized type passed to PCTFS_ivec_non_uniform()!");
 
     arg1 += j;
     arg2 += j;
     i += j;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /***********************************ivec.c*************************************/
@@ -301,7 +300,7 @@ PetscErrorCode PCTFS_ivec_sort(PetscInt *ar, PetscInt size)
       }
 
       /* check to see if stack is exhausted ==> DONE */
-      if (top_s == bottom_s) PetscFunctionReturn(0);
+      if (top_s == bottom_s) PetscFunctionReturn(PETSC_SUCCESS);
 
       /* else pop another list from the stack */
       ar   = *(--top_a);
@@ -406,7 +405,7 @@ PetscErrorCode PCTFS_ivec_sort_companion(PetscInt *ar, PetscInt *ar2, PetscInt s
       }
 
       /* check to see if stack is exhausted ==> DONE */
-      if (top_s == bottom_s) PetscFunctionReturn(0);
+      if (top_s == bottom_s) PetscFunctionReturn(PETSC_SUCCESS);
 
       /* else pop another list from the stack */
       ar2  = *(--top_a);
@@ -511,7 +510,7 @@ PetscErrorCode PCTFS_ivec_sort_companion_hack(PetscInt *ar, PetscInt **ar2, Pets
       }
 
       /* check to see if stack is exhausted ==> DONE */
-      if (top_s == bottom_s) PetscFunctionReturn(0);
+      if (top_s == bottom_s) PetscFunctionReturn(PETSC_SUCCESS);
 
       /* else pop another list from the stack */
       ar2  = (PetscInt **)*(--top_a);
@@ -526,13 +525,13 @@ PetscErrorCode PCTFS_SMI_sort(void *ar1, void *ar2, PetscInt size, PetscInt type
 {
   PetscFunctionBegin;
   if (type == SORT_INTEGER) {
-    if (ar2) PCTFS_ivec_sort_companion((PetscInt *)ar1, (PetscInt *)ar2, size);
-    else PCTFS_ivec_sort((PetscInt *)ar1, size);
+    if (ar2) PetscCall(PCTFS_ivec_sort_companion((PetscInt *)ar1, (PetscInt *)ar2, size));
+    else PetscCall(PCTFS_ivec_sort((PetscInt *)ar1, size));
   } else if (type == SORT_INT_PTR) {
-    if (ar2) PCTFS_ivec_sort_companion_hack((PetscInt *)ar1, (PetscInt **)ar2, size);
-    else PCTFS_ivec_sort((PetscInt *)ar1, size);
+    if (ar2) PetscCall(PCTFS_ivec_sort_companion_hack((PetscInt *)ar1, (PetscInt **)ar2, size));
+    else PetscCall(PCTFS_ivec_sort((PetscInt *)ar1, size));
   } else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_PLIB, "PCTFS_SMI_sort only does SORT_INTEGER!");
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /***********************************ivec.c*************************************/
@@ -566,7 +565,7 @@ PetscErrorCode PCTFS_rvec_copy(PetscScalar *arg1, PetscScalar *arg2, PetscInt n)
 {
   PetscFunctionBegin;
   while (n--) *arg1++ = *arg2++;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*********************************ivec.c*************************************/
@@ -574,7 +573,7 @@ PetscErrorCode PCTFS_rvec_zero(PetscScalar *arg1, PetscInt n)
 {
   PetscFunctionBegin;
   while (n--) *arg1++ = 0.0;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /***********************************ivec.c*************************************/
@@ -582,7 +581,7 @@ PetscErrorCode PCTFS_rvec_one(PetscScalar *arg1, PetscInt n)
 {
   PetscFunctionBegin;
   while (n--) *arg1++ = 1.0;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /***********************************ivec.c*************************************/
@@ -590,7 +589,7 @@ PetscErrorCode PCTFS_rvec_set(PetscScalar *arg1, PetscScalar arg2, PetscInt n)
 {
   PetscFunctionBegin;
   while (n--) *arg1++ = arg2;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /***********************************ivec.c*************************************/
@@ -598,7 +597,7 @@ PetscErrorCode PCTFS_rvec_scale(PetscScalar *arg1, PetscScalar arg2, PetscInt n)
 {
   PetscFunctionBegin;
   while (n--) *arg1++ *= arg2;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*********************************ivec.c*************************************/
@@ -606,7 +605,7 @@ PetscErrorCode PCTFS_rvec_add(PetscScalar *arg1, PetscScalar *arg2, PetscInt n)
 {
   PetscFunctionBegin;
   while (n--) *arg1++ += *arg2++;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*********************************ivec.c*************************************/
@@ -614,7 +613,7 @@ PetscErrorCode PCTFS_rvec_mult(PetscScalar *arg1, PetscScalar *arg2, PetscInt n)
 {
   PetscFunctionBegin;
   while (n--) *arg1++ *= *arg2++;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*********************************ivec.c*************************************/
@@ -626,7 +625,7 @@ PetscErrorCode PCTFS_rvec_max(PetscScalar *arg1, PetscScalar *arg2, PetscInt n)
     arg1++;
     arg2++;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*********************************ivec.c*************************************/
@@ -638,7 +637,7 @@ PetscErrorCode PCTFS_rvec_max_abs(PetscScalar *arg1, PetscScalar *arg2, PetscInt
     arg1++;
     arg2++;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*********************************ivec.c*************************************/
@@ -650,7 +649,7 @@ PetscErrorCode PCTFS_rvec_min(PetscScalar *arg1, PetscScalar *arg2, PetscInt n)
     arg1++;
     arg2++;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*********************************ivec.c*************************************/
@@ -662,11 +661,11 @@ PetscErrorCode PCTFS_rvec_min_abs(PetscScalar *arg1, PetscScalar *arg2, PetscInt
     arg1++;
     arg2++;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*********************************ivec.c*************************************/
-PetscErrorCode PCTFS_rvec_exists(PetscScalar *arg1, PetscScalar *arg2, PetscInt n)
+static PetscErrorCode PCTFS_rvec_exists(PetscScalar *arg1, PetscScalar *arg2, PetscInt n)
 {
   PetscFunctionBegin;
   while (n--) {
@@ -674,11 +673,11 @@ PetscErrorCode PCTFS_rvec_exists(PetscScalar *arg1, PetscScalar *arg2, PetscInt
     arg1++;
     arg2++;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /***********************************ivec.c*************************************/
-PetscErrorCode PCTFS_rvec_non_uniform(PetscScalar *arg1, PetscScalar *arg2, PetscInt n, PetscInt *arg3)
+static PetscErrorCode PCTFS_rvec_non_uniform(PetscScalar *arg1, PetscScalar *arg2, PetscInt n, PetscInt *arg3)
 {
   PetscInt i, j, type;
 
@@ -694,20 +693,20 @@ PetscErrorCode PCTFS_rvec_non_uniform(PetscScalar *arg1, PetscScalar *arg2, Pets
     j -= i;
 
     /* call appropriate ivec function */
-    if (type == GL_MAX) PCTFS_rvec_max(arg1, arg2, j);
-    else if (type == GL_MIN) PCTFS_rvec_min(arg1, arg2, j);
-    else if (type == GL_MULT) PCTFS_rvec_mult(arg1, arg2, j);
-    else if (type == GL_ADD) PCTFS_rvec_add(arg1, arg2, j);
-    else if (type == GL_MAX_ABS) PCTFS_rvec_max_abs(arg1, arg2, j);
-    else if (type == GL_MIN_ABS) PCTFS_rvec_min_abs(arg1, arg2, j);
-    else if (type == GL_EXISTS) PCTFS_rvec_exists(arg1, arg2, j);
+    if (type == GL_MAX) PetscCall(PCTFS_rvec_max(arg1, arg2, j));
+    else if (type == GL_MIN) PetscCall(PCTFS_rvec_min(arg1, arg2, j));
+    else if (type == GL_MULT) PetscCall(PCTFS_rvec_mult(arg1, arg2, j));
+    else if (type == GL_ADD) PetscCall(PCTFS_rvec_add(arg1, arg2, j));
+    else if (type == GL_MAX_ABS) PetscCall(PCTFS_rvec_max_abs(arg1, arg2, j));
+    else if (type == GL_MIN_ABS) PetscCall(PCTFS_rvec_min_abs(arg1, arg2, j));
+    else if (type == GL_EXISTS) PetscCall(PCTFS_rvec_exists(arg1, arg2, j));
     else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_PLIB, "unrecognized type passed to PCTFS_rvec_non_uniform()!");
 
     arg1 += j;
     arg2 += j;
     i += j;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /***********************************ivec.c*************************************/
