@@ -9,8 +9,17 @@
   #define matgetvaluesnn1_             MATGETVALUESnn1
   #define matgetvaluesnnnn_            MATGETVALUESnnnn
   #define matgetvalues11_              MATGETVALUES11
-  #define matgetvalues1n_              MATGETVALUES1n
-  #define matgetvaluesn1_              MATGETVALUESn1
+  #define matgetvalues11a_             MATGETVALUES11A
+  #define matgetvalues1n_              MATGETVALUES1N
+  #define matgetvaluesn1_              MATGETVALUESN1
+  #define matgetvalueslocal_           MATGETVALUESLOCAL
+  #define matgetvalueslocal0_          MATGETVALUESLOCAL0
+  #define matgetvalueslocalnn1_        MATGETVALUESLOCALNN1
+  #define matgetvalueslocalnnnn_       MATGETVALUESLOCALNNNN
+  #define matgetvalueslocal11_         MATGETVALUESLOCAL11
+  #define matgetvalueslocal11a_        MATGETVALUESLOCAL11A
+  #define matgetvalueslocal1n_         MATGETVALUESLOCAL1N
+  #define matgetvalueslocaln1_         MATGETVALUESLOCALN1
   #define matsetvalues_                MATSETVALUES
   #define matsetvaluesnnnn_            MATSETVALUESNNNN
   #define matsetvalues0_               MATSETVALUES0
@@ -107,6 +116,7 @@
   #define matgetownershiprangecolumn_  MATGETOWNERSHIPRANGECOLUMN
   #define matviewfromoptions_          MATVIEWFROMOPTIONS
   #define matdestroy_                  MATDESTROY
+  #define matcreatefromoptions_        MATCREATEFROMOPTIONS
 #elif !defined(PETSC_HAVE_FORTRAN_UNDERSCORE)
   #define matsetvalues_                matsetvalues
   #define matsetvaluesnnnn_            matsetvaluesnnnn
@@ -198,8 +208,16 @@
   #define matgetvaluesnn1_             matgetvaluesnn1
   #define matgetvaluesnnnn_            matgetvaluesnnnn
   #define matgetvalues11_              matgetvalues11
+  #define matgetvalues11a_             matgetvalues11a
   #define matgetvalues1n_              matgetvalues1n
   #define matgetvaluesn1_              matgetvaluesn1
+  #define matgetvalueslocal_           matgetvalueslocal
+  #define matgetvalueslocal0_          matgetvalueslocal0
+  #define matgetvalueslocalnn1_        matgetvalueslocalnn1
+  #define matgetvalueslocalnnnn_       matgetvalueslocalnnnn
+  #define matgetvalueslocal11_         matgetvalueslocal11
+  #define matgetvalueslocal1n_         matgetvalueslocal1n
+  #define matgetvalueslocaln1_         matgetvalueslocaln1
   #define matsetnullspace_             matsetnullspace
   #define matgetownershiprange_        matgetownershiprange
   #define matgetownershiprange00_      matgetownershiprange00
@@ -210,8 +228,18 @@
   #define matgetownershiprangecolumn_  matgetownershiprangecolumn
   #define matviewfromoptions_          matviewfromoptions
   #define matdestroy_                  matdestroy
+  #define matcreatefromoptions_        matcreatefromoptions
 #endif
 
+PETSC_EXTERN void matcreatefromoptions_(MPI_Fint *comm, char *prefix, PetscInt *bs, PetscInt *m, PetscInt *n, PetscInt *M, PetscInt *N, Mat *A, int *ierr, PETSC_FORTRAN_CHARLEN_T len)
+{
+  char *fprefix;
+  FIXCHAR(prefix, len, fprefix);
+  *ierr = MatCreateFromOptions(MPI_Comm_f2c(*(comm)), fprefix, *bs, *m, *n, *M, *N, A);
+  if (*ierr) return;
+  FREECHAR(prefix, fprefix);
+}
+
 PETSC_EXTERN void matgetvalues_(Mat *mat, PetscInt *m, PetscInt idxm[], PetscInt *n, PetscInt idxn[], PetscScalar v[], int *ierr)
 {
   *ierr = MatGetValues(*mat, *m, idxm, *n, idxn, v);
@@ -237,6 +265,11 @@ PETSC_EXTERN void matgetvalues11_(Mat *mat, PetscInt *m, PetscInt idxm[], PetscI
   matgetvalues_(mat, m, idxm, n, idxn, v, ierr);
 }
 
+PETSC_EXTERN void matgetvalues11a_(Mat *mat, PetscInt *m, PetscInt idxm[], PetscInt *n, PetscInt idxn[], PetscScalar v[], int *ierr)
+{
+  matgetvalues_(mat, m, idxm, n, idxn, v, ierr);
+}
+
 PETSC_EXTERN void matgetvalues1n_(Mat *mat, PetscInt *m, PetscInt idxm[], PetscInt *n, PetscInt idxn[], PetscScalar v[], int *ierr)
 {
   matgetvalues_(mat, m, idxm, n, idxn, v, ierr);
@@ -247,6 +280,46 @@ PETSC_EXTERN void matgetvaluesn1_(Mat *mat, PetscInt *m, PetscInt idxm[], PetscI
   matgetvalues_(mat, m, idxm, n, idxn, v, ierr);
 }
 
+PETSC_EXTERN void matgetvalueslocal_(Mat *mat, PetscInt *m, PetscInt idxm[], PetscInt *n, PetscInt idxn[], PetscScalar v[], int *ierr)
+{
+  *ierr = MatGetValuesLocal(*mat, *m, idxm, *n, idxn, v);
+}
+
+PETSC_EXTERN void matgetvalueslocal0_(Mat *mat, PetscInt *m, PetscInt idxm[], PetscInt *n, PetscInt idxn[], PetscScalar v[], int *ierr)
+{
+  matgetvalueslocal_(mat, m, idxm, n, idxn, v, ierr);
+}
+
+PETSC_EXTERN void matgetvalueslocalnn1_(Mat *mat, PetscInt *m, PetscInt idxm[], PetscInt *n, PetscInt idxn[], PetscScalar v[], int *ierr)
+{
+  matgetvalueslocal_(mat, m, idxm, n, idxn, v, ierr);
+}
+
+PETSC_EXTERN void matgetvalueslocalnnnn_(Mat *mat, PetscInt *m, PetscInt idxm[], PetscInt *n, PetscInt idxn[], PetscScalar v[], int *ierr)
+{
+  matgetvalueslocal_(mat, m, idxm, n, idxn, v, ierr);
+}
+
+PETSC_EXTERN void matgetvalueslocal11_(Mat *mat, PetscInt *m, PetscInt idxm[], PetscInt *n, PetscInt idxn[], PetscScalar v[], int *ierr)
+{
+  matgetvalueslocal_(mat, m, idxm, n, idxn, v, ierr);
+}
+
+PETSC_EXTERN void matgetvalueslocal11a_(Mat *mat, PetscInt *m, PetscInt idxm[], PetscInt *n, PetscInt idxn[], PetscScalar v[], int *ierr)
+{
+  matgetvalueslocal_(mat, m, idxm, n, idxn, v, ierr);
+}
+
+PETSC_EXTERN void matgetvalueslocal1n_(Mat *mat, PetscInt *m, PetscInt idxm[], PetscInt *n, PetscInt idxn[], PetscScalar v[], int *ierr)
+{
+  matgetvalueslocal_(mat, m, idxm, n, idxn, v, ierr);
+}
+
+PETSC_EXTERN void matgetvalueslocaln1_(Mat *mat, PetscInt *m, PetscInt idxm[], PetscInt *n, PetscInt idxn[], PetscScalar v[], int *ierr)
+{
+  matgetvalueslocal_(mat, m, idxm, n, idxn, v, ierr);
+}
+
 PETSC_EXTERN void matgetownershiprange_(Mat *mat, PetscInt *m, PetscInt *n, int *ierr)
 {
   CHKFORTRANNULLINTEGER(m);
@@ -546,8 +619,8 @@ PETSC_EXTERN void matrestorerowij_(Mat *B, PetscInt *shift, PetscBool *sym, Pets
   at a time.
 */
 static int                matgetrowactive = 0;
-static const PetscInt    *my_ocols        = 0;
-static const PetscScalar *my_ovals        = 0;
+static const PetscInt    *my_ocols        = NULL;
+static const PetscScalar *my_ovals        = NULL;
 
 PETSC_EXTERN void matgetrow_(Mat *mat, PetscInt *row, PetscInt *ncols, PetscInt *cols, PetscScalar *vals, PetscErrorCode *ierr)
 {
@@ -820,7 +893,7 @@ PETSC_EXTERN void matsetoptionsprefix_(Mat *mat, char *prefix, PetscErrorCode *i
 
 PETSC_EXTERN void matnullspaceremove_(MatNullSpace *sp, Vec *vec, PetscErrorCode *ierr)
 {
-  CHKFORTRANNULLOBJECT(*sp)
+  CHKFORTRANNULLOBJECT(*sp);
   *ierr = MatNullSpaceRemove(*sp, *vec);
 }
 
@@ -831,17 +904,23 @@ PETSC_EXTERN void matgetinfo_(Mat *mat, MatInfoType *flag, MatInfo *info, int *i
 
 PETSC_EXTERN void matlufactor_(Mat *mat, IS *row, IS *col, const MatFactorInfo *info, int *ierr)
 {
-  *ierr = MatLUFactor(*mat, *row, *col, info);
+  CHKFORTRANNULLOBJECT(row);
+  CHKFORTRANNULLOBJECT(col);
+  *ierr = MatLUFactor(*mat, row ? *row : NULL, col ? *col : NULL, info);
 }
 
 PETSC_EXTERN void matilufactor_(Mat *mat, IS *row, IS *col, const MatFactorInfo *info, int *ierr)
 {
-  *ierr = MatILUFactor(*mat, *row, *col, info);
+  CHKFORTRANNULLOBJECT(row);
+  CHKFORTRANNULLOBJECT(col);
+  *ierr = MatILUFactor(*mat, row ? *row : NULL, col ? *col : NULL, info);
 }
 
 PETSC_EXTERN void matlufactorsymbolic_(Mat *fact, Mat *mat, IS *row, IS *col, const MatFactorInfo *info, int *ierr)
 {
-  *ierr = MatLUFactorSymbolic(*fact, *mat, *row, *col, info);
+  CHKFORTRANNULLOBJECT(row);
+  CHKFORTRANNULLOBJECT(col);
+  *ierr = MatLUFactorSymbolic(*fact, *mat, row ? *row : NULL, col ? *col : NULL, info);
 }
 
 PETSC_EXTERN void matlufactornumeric_(Mat *fact, Mat *mat, const MatFactorInfo *info, int *ierr)
@@ -851,12 +930,14 @@ PETSC_EXTERN void matlufactornumeric_(Mat *fact, Mat *mat, const MatFactorInfo *
 
 PETSC_EXTERN void matcholeskyfactor_(Mat *mat, IS *perm, const MatFactorInfo *info, int *ierr)
 {
-  *ierr = MatCholeskyFactor(*mat, *perm, info);
+  CHKFORTRANNULLOBJECT(perm);
+  *ierr = MatCholeskyFactor(*mat, perm ? *perm : NULL, info);
 }
 
 PETSC_EXTERN void matcholeskyfactorsymbolic_(Mat *fact, Mat *mat, IS *perm, const MatFactorInfo *info, int *ierr)
 {
-  *ierr = MatCholeskyFactorSymbolic(*fact, *mat, *perm, info);
+  CHKFORTRANNULLOBJECT(perm);
+  *ierr = MatCholeskyFactorSymbolic(*fact, *mat, perm ? *perm : NULL, info);
 }
 
 PETSC_EXTERN void matcholeskyfactornumeric_(Mat *fact, Mat *mat, const MatFactorInfo *info, int *ierr)
@@ -866,17 +947,21 @@ PETSC_EXTERN void matcholeskyfactornumeric_(Mat *fact, Mat *mat, const MatFactor
 
 PETSC_EXTERN void matilufactorsymbolic_(Mat *fact, Mat *mat, IS *row, IS *col, const MatFactorInfo *info, int *ierr)
 {
-  *ierr = MatILUFactorSymbolic(*fact, *mat, *row, *col, info);
+  CHKFORTRANNULLOBJECT(row);
+  CHKFORTRANNULLOBJECT(col);
+  *ierr = MatILUFactorSymbolic(*fact, *mat, row ? *row : NULL, col ? *col : NULL, info);
 }
 
 PETSC_EXTERN void maticcfactorsymbolic_(Mat *fact, Mat *mat, IS *perm, const MatFactorInfo *info, int *ierr)
 {
-  *ierr = MatICCFactorSymbolic(*fact, *mat, *perm, info);
+  CHKFORTRANNULLOBJECT(perm);
+  *ierr = MatICCFactorSymbolic(*fact, *mat, perm ? *perm : NULL, info);
 }
 
-PETSC_EXTERN void maticcfactor_(Mat *mat, IS *row, const MatFactorInfo *info, int *ierr)
+PETSC_EXTERN void maticcfactor_(Mat *mat, IS *perm, const MatFactorInfo *info, int *ierr)
 {
-  *ierr = MatICCFactor(*mat, *row, info);
+  CHKFORTRANNULLOBJECT(perm);
+  *ierr = MatICCFactor(*mat, perm ? *perm : NULL, info);
 }
 
 PETSC_EXTERN void matfactorinfoinitialize_(MatFactorInfo *info, int *ierr)
