@@ -1,4 +1,3 @@
-
 /*
    This is where the abstract matrix operations are defined that are
   used for finite difference computations of Jacobians using coloring.
@@ -69,28 +68,28 @@ static PetscErrorCode MatFDColoringView_Draw(MatFDColoring fd, PetscViewer viewe
 }
 
 /*@C
-   MatFDColoringView - Views a finite difference coloring context.
+  MatFDColoringView - Views a finite difference coloring context.
 
-   Collective
+  Collective
 
-   Input Parameters:
-+  c - the coloring context
--  viewer - visualization context
+  Input Parameters:
++ c      - the coloring context
+- viewer - visualization context
 
-   Level: intermediate
+  Level: intermediate
 
-   Notes:
-   The available visualization contexts include
+  Notes:
+  The available visualization contexts include
 +     `PETSC_VIEWER_STDOUT_SELF` - standard output (default)
 .     `PETSC_VIEWER_STDOUT_WORLD` - synchronized standard
-        output where only the first processor opens
-        the file.  All other processors send their
-        data to the first processor to print.
+  output where only the first processor opens
+  the file.  All other processors send their
+  data to the first processor to print.
 -     `PETSC_VIEWER_DRAW_WORLD` - graphical display of nonzero structure
 
-     Since PETSc uses only a small number of basic colors (currently 33), if the coloring
-   involves more than 33 then some seemingly identical colors are displayed making it look
-   like an illegal coloring. This is just a graphical artifact.
+  Since PETSc uses only a small number of basic colors (currently 33), if the coloring
+  involves more than 33 then some seemingly identical colors are displayed making it look
+  like an illegal coloring. This is just a graphical artifact.
 
 .seealso: `Mat`, `MatFDColoring`, `MatFDColoringCreate()`
 @*/
@@ -140,20 +139,20 @@ PetscErrorCode MatFDColoringView(MatFDColoring c, PetscViewer viewer)
 }
 
 /*@
-   MatFDColoringSetParameters - Sets the parameters for the sparse approximation of
-   a Jacobian matrix using finite differences.
+  MatFDColoringSetParameters - Sets the parameters for the sparse approximation of
+  a Jacobian matrix using finite differences.
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameters:
-+  matfd - the coloring context
-.  error - relative error
--  umin - minimum allowable u-value magnitude
+  Input Parameters:
++ matfd - the coloring context
+. error - relative error
+- umin  - minimum allowable u-value magnitude
 
-   Level: advanced
+  Level: advanced
 
-   Note:
-     The Jacobian is estimated with the differencing approximation
+  Note:
+  The Jacobian is estimated with the differencing approximation
 .vb
        F'(u)_{:,i} = [F(u+h*dx_{i}) - F(u)]/h where
        htype = 'ds':
@@ -179,16 +178,16 @@ PetscErrorCode MatFDColoringSetParameters(MatFDColoring matfd, PetscReal error,
 }
 
 /*@
-   MatFDColoringSetBlockSize - Sets block size for efficient inserting entries of Jacobian matrix.
+  MatFDColoringSetBlockSize - Sets block size for efficient inserting entries of Jacobian matrix.
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameters:
-+  coloring - the coloring context
-.  brows - number of rows in the block
--  bcols - number of columns in the block
+  Input Parameters:
++ matfd - the coloring context
+. brows - number of rows in the block
+- bcols - number of columns in the block
 
-   Level: intermediate
+  Level: intermediate
 
 .seealso: `Mat`, `MatFDColoring`, `MatFDColoringCreate()`, `MatFDColoringSetFromOptions()`
 @*/
@@ -204,19 +203,19 @@ PetscErrorCode MatFDColoringSetBlockSize(MatFDColoring matfd, PetscInt brows, Pe
 }
 
 /*@
-   MatFDColoringSetUp - Sets up the internal data structures of matrix coloring context for the later use.
+  MatFDColoringSetUp - Sets up the internal data structures of matrix coloring context for the later use.
 
-   Collective
+  Collective
 
-   Input Parameters:
-+  mat - the matrix containing the nonzero structure of the Jacobian
-.  iscoloring - the coloring of the matrix; usually obtained with `MatGetColoring()` or `DMCreateColoring()`
--  color - the matrix coloring context
+  Input Parameters:
++ mat        - the matrix containing the nonzero structure of the Jacobian
+. iscoloring - the coloring of the matrix; usually obtained with `MatGetColoring()` or `DMCreateColoring()`
+- color      - the matrix coloring context
 
-   Level: beginner
+  Level: beginner
 
-   Notes:
-   When the coloring type is `IS_COLORING_LOCAL` the coloring is in the local ordering of the unknowns.
+  Notes:
+  When the coloring type is `IS_COLORING_LOCAL` the coloring is in the local ordering of the unknowns.
 
 .seealso: `Mat`, `MatFDColoring`, `MatFDColoringCreate()`, `MatFDColoringDestroy()`
 @*/
@@ -240,18 +239,18 @@ PetscErrorCode MatFDColoringSetUp(Mat mat, ISColoring iscoloring, MatFDColoring
 }
 
 /*@C
-   MatFDColoringGetFunction - Gets the function to use for computing the Jacobian.
+  MatFDColoringGetFunction - Gets the function to use for computing the Jacobian.
 
-   Not Collective
+  Not Collective
 
-   Input Parameter:
-.  coloring - the coloring context
+  Input Parameter:
+. matfd - the coloring context
 
-   Output Parameters:
-+  f - the function
--  fctx - the optional user-defined function context
+  Output Parameters:
++ f    - the function
+- fctx - the optional user-defined function context
 
-   Level: intermediate
+  Level: intermediate
 
 .seealso: `Mat`, `MatFDColoring`, `MatFDColoringCreate()`, `MatFDColoringSetFunction()`, `MatFDColoringSetFromOptions()`
 @*/
@@ -265,38 +264,38 @@ PetscErrorCode MatFDColoringGetFunction(MatFDColoring matfd, PetscErrorCode (**f
 }
 
 /*@C
-   MatFDColoringSetFunction - Sets the function to use for computing the Jacobian.
+  MatFDColoringSetFunction - Sets the function to use for computing the Jacobian.
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameters:
-+  coloring - the coloring context
-.  f - the function
--  fctx - the optional user-defined function context
+  Input Parameters:
++ matfd - the coloring context
+. f     - the function
+- fctx  - the optional user-defined function context
 
-   Calling sequence with `SNES` of `f`:
-$   PetscErrorCode f(SNES snes, Vec in, Vec out, void *fctx)
-+  snes - the nonlinear solver `SNES` object
-.  in - the location where the Jacobian is to be computed
-.  out - the location to put the computed function value
--  fctx - the function context
+  Level: advanced
 
-   Calling sequence without `SNES` of `f`:
-$   PetscErrorCode f(void *dummy, Vec in, Vec out, void *fctx)
-+  dummy - an unused parameter
-.  in - the location where the Jacobian is to be computed
-.  out - the location to put the computed function value
--  fctx - the function context
+  Note:
+  `f` has two possible calling configurations\:
+$ PetscErrorCode f(SNES snes, Vec in, Vec out, void *fctx)
++ snes - the nonlinear solver `SNES` object
+. in   - the location where the Jacobian is to be computed
+. out  - the location to put the computed function value
+- fctx - the function context
 
-   Level: advanced
+  and
+$ PetscErrorCode f(void *dummy, Vec in, Vec out, void *fctx)
++ dummy - an unused parameter
+. in    - the location where the Jacobian is to be computed
+. out   - the location to put the computed function value
+- fctx  - the function context
 
-   Note:
-    This function is usually used automatically by `SNES` (when one uses `SNESSetJacobian()` with the argument
-     `SNESComputeJacobianDefaultColor()`) and only needs to be used by someone computing a matrix via coloring directly by
-     calling `MatFDColoringApply()`
+  This function is usually used automatically by `SNES` (when one uses `SNESSetJacobian()` with the argument
+  `SNESComputeJacobianDefaultColor()`) and only needs to be used by someone computing a matrix via coloring directly by
+  calling `MatFDColoringApply()`
 
-   Fortran Note:
-    In Fortran you must call `MatFDColoringSetFunction()` for a coloring object to
+  Fortran Notes:
+  In Fortran you must call `MatFDColoringSetFunction()` for a coloring object to
   be used without `SNES` or within the `SNES` solvers.
 
 .seealso: `Mat`, `MatFDColoring`, `MatFDColoringCreate()`, `MatFDColoringGetFunction()`, `MatFDColoringSetFromOptions()`
@@ -311,12 +310,12 @@ PetscErrorCode MatFDColoringSetFunction(MatFDColoring matfd, PetscErrorCode (*f)
 }
 
 /*@
-   MatFDColoringSetFromOptions - Sets coloring finite difference parameters from
-   the options database.
+  MatFDColoringSetFromOptions - Sets coloring finite difference parameters from
+  the options database.
 
-   Collective
+  Collective
 
-   The Jacobian, F'(u), is estimated with the differencing approximation
+  The Jacobian, F'(u), is estimated with the differencing approximation
 .vb
        F'(u)_{:,i} = [F(u+h*dx_{i}) - F(u)]/h where
        h = error_rel*u[i]                 if  abs(u[i]) > umin
@@ -324,18 +323,18 @@ PetscErrorCode MatFDColoringSetFunction(MatFDColoring matfd, PetscErrorCode (*f)
        dx_{i} = (0, ... 1, .... 0)
 .ve
 
-   Input Parameter:
-.  coloring - the coloring context
+  Input Parameter:
+. matfd - the coloring context
 
-   Options Database Keys:
-+  -mat_fd_coloring_err <err> - Sets <err> (square root of relative error in the function)
-.  -mat_fd_coloring_umin <umin> - Sets umin, the minimum allowable u-value magnitude
-.  -mat_fd_type - "wp" or "ds" (see MATMFFD_WP or MATMFFD_DS)
-.  -mat_fd_coloring_view - Activates basic viewing
-.  -mat_fd_coloring_view ::ascii_info - Activates viewing info
--  -mat_fd_coloring_view draw - Activates drawing
+  Options Database Keys:
++ -mat_fd_coloring_err <err>         - Sets <err> (square root of relative error in the function)
+. -mat_fd_coloring_umin <umin>       - Sets umin, the minimum allowable u-value magnitude
+. -mat_fd_type                       - "wp" or "ds" (see MATMFFD_WP or MATMFFD_DS)
+. -mat_fd_coloring_view              - Activates basic viewing
+. -mat_fd_coloring_view ::ascii_info - Activates viewing info
+- -mat_fd_coloring_view draw         - Activates drawing
 
-    Level: intermediate
+  Level: intermediate
 
 .seealso: `Mat`, `MatFDColoring`, `MatFDColoringCreate()`, `MatFDColoringView()`, `MatFDColoringSetParameters()`
 @*/
@@ -370,23 +369,23 @@ PetscErrorCode MatFDColoringSetFromOptions(MatFDColoring matfd)
 }
 
 /*@C
-   MatFDColoringSetType - Sets the approach for computing the finite difference parameter
+  MatFDColoringSetType - Sets the approach for computing the finite difference parameter
 
-   Collective
+  Collective
 
-   Input Parameters:
-+  coloring - the coloring context
--  type - either `MATMFFD_WP` or `MATMFFD_DS`
+  Input Parameters:
++ matfd - the coloring context
+- type  - either `MATMFFD_WP` or `MATMFFD_DS`
 
-   Options Database Key:
-.  -mat_fd_type - "wp" or "ds"
+  Options Database Key:
+. -mat_fd_type - "wp" or "ds"
 
-   Level: intermediate
+  Level: intermediate
 
-   Note:
-   It is goofy that the argument type is `MatMFFDType` since the `MatFDColoring` actually computes the matrix entries
-         but the process of computing the entries is the same as as with the `MATMFFD` operation so we should reuse the names instead of
-         introducing another one.
+  Note:
+  It is goofy that the argument type is `MatMFFDType` since the `MatFDColoring` actually computes the matrix entries
+  but the process of computing the entries is the same as as with the `MATMFFD` operation so we should reuse the names instead of
+  introducing another one.
 
 .seealso: `Mat`, `MatFDColoring`, `MatFDColoringCreate()`, `MatFDColoringView()`, `MatFDColoringSetParameters()`
 @*/
@@ -404,7 +403,7 @@ PetscErrorCode MatFDColoringSetType(MatFDColoring matfd, MatMFFDType type)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode MatFDColoringViewFromOptions(MatFDColoring fd, const char prefix[], const char optionname[])
+static PetscErrorCode MatFDColoringViewFromOptions(MatFDColoring fd, const char prefix[], const char optionname[])
 {
   PetscBool         flg;
   PetscViewer       viewer;
@@ -426,19 +425,19 @@ PetscErrorCode MatFDColoringViewFromOptions(MatFDColoring fd, const char prefix[
 }
 
 /*@
-   MatFDColoringCreate - Creates a matrix coloring context for finite difference
-   computation of Jacobians.
+  MatFDColoringCreate - Creates a matrix coloring context for finite difference
+  computation of Jacobians.
 
-   Collective
+  Collective
 
-   Input Parameters:
-+  mat - the matrix containing the nonzero structure of the Jacobian
--  iscoloring - the coloring of the matrix; usually obtained with `MatColoringCreate()` or `DMCreateColoring()`
+  Input Parameters:
++ mat        - the matrix containing the nonzero structure of the Jacobian
+- iscoloring - the coloring of the matrix; usually obtained with `MatColoringCreate()` or `DMCreateColoring()`
 
-    Output Parameter:
-.   color - the new coloring context
+  Output Parameter:
+. color - the new coloring context
 
-    Level: intermediate
+  Level: intermediate
 
 .seealso: `Mat`, `MatFDColoring`, `MatFDColoringDestroy()`, `SNESComputeJacobianDefaultColor()`, `ISColoringCreate()`,
           `MatFDColoringSetFunction()`, `MatFDColoringSetFromOptions()`, `MatFDColoringApply()`,
@@ -485,15 +484,15 @@ PetscErrorCode MatFDColoringCreate(Mat mat, ISColoring iscoloring, MatFDColoring
 }
 
 /*@
-    MatFDColoringDestroy - Destroys a matrix coloring context that was created
-    via `MatFDColoringCreate()`.
+  MatFDColoringDestroy - Destroys a matrix coloring context that was created
+  via `MatFDColoringCreate()`.
 
-    Collective
+  Collective
 
-    Input Parameter:
-.   c - coloring context
+  Input Parameter:
+. c - coloring context
 
-    Level: intermediate
+  Level: intermediate
 
 .seealso: `Mat`, `MatFDColoring`, `MatFDColoringCreate()`
 @*/
@@ -529,25 +528,25 @@ PetscErrorCode MatFDColoringDestroy(MatFDColoring *c)
 }
 
 /*@C
-    MatFDColoringGetPerturbedColumns - Returns the indices of the columns that
-      that are currently being perturbed.
+  MatFDColoringGetPerturbedColumns - Returns the indices of the columns that
+  that are currently being perturbed.
 
-    Not Collective
+  Not Collective
 
-    Input Parameter:
-.   coloring - coloring context created with `MatFDColoringCreate()`
+  Input Parameter:
+. coloring - coloring context created with `MatFDColoringCreate()`
 
-    Output Parameters:
-+   n - the number of local columns being perturbed
--   cols - the column indices, in global numbering
+  Output Parameters:
++ n    - the number of local columns being perturbed
+- cols - the column indices, in global numbering
 
-   Level: advanced
+  Level: advanced
 
-   Note:
-   IF the matrix type is `MATBAIJ`, then the block column indices are returned
+  Note:
+  IF the matrix type is `MATBAIJ`, then the block column indices are returned
 
-   Fortran Note:
-   This routine has a different interface for Fortran
+  Fortran Notes:
+  This routine has a different interface for Fortran
 .vb
      #include <petsc/finclude/petscmat.h>
           use petscmat
@@ -574,24 +573,24 @@ PetscErrorCode MatFDColoringGetPerturbedColumns(MatFDColoring coloring, PetscInt
 }
 
 /*@
-    MatFDColoringApply - Given a matrix for which a `MatFDColoring` context
-    has been created, computes the Jacobian for a function via finite differences.
+  MatFDColoringApply - Given a matrix for which a `MatFDColoring` context
+  has been created, computes the Jacobian for a function via finite differences.
 
-    Collective
+  Collective
 
-    Input Parameters:
-+   mat - location to store Jacobian
-.   coloring - coloring context created with `MatFDColoringCreate()`
-.   x1 - location at which Jacobian is to be computed
--   sctx - context required by function, if this is being used with the SNES solver then it is `SNES` object, otherwise it is null
+  Input Parameters:
++ J        - location to store Jacobian
+. coloring - coloring context created with `MatFDColoringCreate()`
+. x1       - location at which Jacobian is to be computed
+- sctx     - context required by function, if this is being used with the SNES solver then it is `SNES` object, otherwise it is null
 
-    Options Database Keys:
-+    -mat_fd_type - "wp" or "ds"  (see `MATMFFD_WP` or `MATMFFD_DS`)
-.    -mat_fd_coloring_view - Activates basic viewing or coloring
-.    -mat_fd_coloring_view draw - Activates drawing of coloring
--    -mat_fd_coloring_view ::ascii_info - Activates viewing of coloring info
+  Options Database Keys:
++ -mat_fd_type                       - "wp" or "ds"  (see `MATMFFD_WP` or `MATMFFD_DS`)
+. -mat_fd_coloring_view              - Activates basic viewing or coloring
+. -mat_fd_coloring_view draw         - Activates drawing of coloring
+- -mat_fd_coloring_view ::ascii_info - Activates viewing of coloring info
 
-    Level: intermediate
+  Level: intermediate
 
 .seealso: `Mat`, `MatFDColoring`, `MatFDColoringCreate()`, `MatFDColoringDestroy()`, `MatFDColoringView()`, `MatFDColoringSetFunction()`, `MatFDColoringSetValues()`
 @*/
