@@ -1,4 +1,3 @@
-
 /*
      Provides the code that allows PETSc users to register their own
   sequential matrix Ordering routines.
@@ -9,12 +8,6 @@
 PetscFunctionList MatOrderingList              = NULL;
 PetscBool         MatOrderingRegisterAllCalled = PETSC_FALSE;
 
-PetscErrorCode MatGetOrdering_Flow(Mat mat, MatOrderingType type, IS *irow, IS *icol)
-{
-  PetscFunctionBegin;
-  SETERRQ(PetscObjectComm((PetscObject)mat), PETSC_ERR_SUP, "Cannot do default flow ordering for matrix type");
-}
-
 PETSC_INTERN PetscErrorCode MatGetOrdering_Natural(Mat mat, MatOrderingType type, IS *irow, IS *icol)
 {
   PetscInt  n, i, *ii;
@@ -79,24 +72,24 @@ PETSC_INTERN PetscErrorCode MatGetOrdering_RowLength(Mat mat, MatOrderingType ty
 }
 
 /*@C
-   MatOrderingRegister - Adds a new sparse matrix ordering to the matrix package.
+  MatOrderingRegister - Adds a new sparse matrix ordering to the matrix package.
 
-   Not Collective
+  Not Collective
 
-   Input Parameters:
-+  sname - name of ordering (for example `MATORDERINGND`)
--  function - function pointer that creates the ordering
+  Input Parameters:
++ sname    - name of ordering (for example `MATORDERINGND`)
+- function - function pointer that creates the ordering
 
-   Level: developer
+  Level: developer
 
-   Sample usage:
+  Example Usage:
 .vb
    MatOrderingRegister("my_order", MyOrder);
 .ve
 
-   Then, your partitioner can be chosen with the procedural interface via
+  Then, your partitioner can be chosen with the procedural interface via
 $     MatOrderingSetType(part, "my_order)
-   or at runtime via the option
+  or at runtime via the option
 $     -pc_factor_mat_ordering_type my_order
 
 .seealso: `MatOrderingRegisterAll()`, `MatGetOrdering()`
@@ -111,14 +104,14 @@ PetscErrorCode MatOrderingRegister(const char sname[], PetscErrorCode (*function
 
 #include <../src/mat/impls/aij/mpi/mpiaij.h>
 /*@C
-   MatGetOrdering - Gets a reordering for a matrix to reduce fill or to
-   improve numerical stability of LU factorization.
+  MatGetOrdering - Gets a reordering for a matrix to reduce fill or to
+  improve numerical stability of LU factorization.
 
-   Collective
+  Collective
 
-   Input Parameters:
-+  mat - the matrix
--  type - type of reordering, one of the following
+  Input Parameters:
++ mat  - the matrix
+- type - type of reordering, one of the following
 .vb
       MATORDERINGNATURAL_OR_ND - Nested dissection unless matrix is SBAIJ then it is natural
       MATORDERINGNATURAL - Natural
@@ -129,29 +122,29 @@ PetscErrorCode MatOrderingRegister(const char sname[], PetscErrorCode (*function
       MATORDERINGEXTERNAL - Use an ordering internal to the factorzation package and do not compute or use PETSc's
 .ve
 
-   Output Parameters:
-+  rperm - row permutation indices
--  cperm - column permutation indices
+  Output Parameters:
++ rperm - row permutation indices
+- cperm - column permutation indices
 
-   Options Database Key:
-+ -mat_view_ordering draw - plots matrix nonzero structure in new ordering
+  Options Database Key:
++ -mat_view_ordering draw                      - plots matrix nonzero structure in new ordering
 - -pc_factor_mat_ordering_type <nd,natural,..> - ordering to use with `PC`s based on factorization, `MATLU`, `MATILU`, MATCHOLESKY`, `MATICC`
 
-   Level: intermediate
+  Level: intermediate
 
-   Notes:
-      This DOES NOT actually reorder the matrix; it merely returns two index sets
-   that define a reordering. This is usually not used directly, rather use the
-   options `PCFactorSetMatOrderingType()`
+  Notes:
+  This DOES NOT actually reorder the matrix; it merely returns two index sets
+  that define a reordering. This is usually not used directly, rather use the
+  options `PCFactorSetMatOrderingType()`
 
-   The user can define additional orderings; see `MatOrderingRegister()`.
+  The user can define additional orderings; see `MatOrderingRegister()`.
 
-   These are generally only implemented for sequential sparse matrices.
+  These are generally only implemented for sequential sparse matrices.
 
-   Some external packages that PETSc can use for direct factorization such as SuperLU_DIST do not accept orderings provided by
-   this call.
+  Some external packages that PETSc can use for direct factorization such as SuperLU_DIST do not accept orderings provided by
+  this call.
 
-   If `MATORDERINGEXTERNAL` is used then PETSc does not compute an ordering and utilizes one built into the factorization package
+  If `MATORDERINGEXTERNAL` is used then PETSc does not compute an ordering and utilizes one built into the factorization package
 
 .seealso: `MatOrderingRegister()`, `PCFactorSetMatOrderingType()`, `MatColoring`, `MatColoringCreate()`, `MatOrderingType`, `Mat`
 @*/
@@ -163,8 +156,8 @@ PetscErrorCode MatGetOrdering(Mat mat, MatOrderingType type, IS *rperm, IS *cper
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(mat, MAT_CLASSID, 1);
-  PetscValidPointer(rperm, 3);
-  PetscValidPointer(cperm, 4);
+  PetscAssertPointer(rperm, 3);
+  PetscAssertPointer(cperm, 4);
   PetscCheck(mat->assembled, PetscObjectComm((PetscObject)mat), PETSC_ERR_ARG_WRONGSTATE, "Not for unassembled matrix");
   PetscCheck(!mat->factortype, PetscObjectComm((PetscObject)mat), PETSC_ERR_ARG_WRONGSTATE, "Not for factored matrix");
   PetscCheck(type, PETSC_COMM_SELF, PETSC_ERR_ARG_NULL, "Ordering type cannot be null");
