@@ -1,4 +1,3 @@
-
 #include <../src/mat/impls/adj/mpi/mpiadj.h> /*I "petscmat.h" I*/
 
 EXTERN_C_BEGIN
@@ -15,22 +14,22 @@ typedef struct {
 } MatPartitioning_PTScotch;
 
 /*@
-   MatPartitioningPTScotchSetImbalance - Sets the value of the load imbalance
-   ratio to be used during strategy selection.
+  MatPartitioningPTScotchSetImbalance - Sets the value of the load imbalance
+  ratio to be used during strategy selection.
 
-   Collective
+  Collective
 
-   Input Parameters:
-+  part - the partitioning context
--  imb  - the load imbalance ratio
+  Input Parameters:
++ part - the partitioning context
+- imb  - the load imbalance ratio
 
-   Options Database Key:
-.  -mat_partitioning_ptscotch_imbalance <imb> - set load imbalance ratio
+  Options Database Key:
+. -mat_partitioning_ptscotch_imbalance <imb> - set load imbalance ratio
 
-   Note:
-   Must be in the range [0,1]. The default value is 0.01.
+  Note:
+  Must be in the range [0,1]. The default value is 0.01.
 
-   Level: advanced
+  Level: advanced
 
 .seealso: `MATPARTITIONINGSCOTCH`, `MatPartitioningPTScotchSetStrategy()`, `MatPartitioningPTScotchGetImbalance()`
 @*/
@@ -43,7 +42,7 @@ PetscErrorCode MatPartitioningPTScotchSetImbalance(MatPartitioning part, PetscRe
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode MatPartitioningPTScotchSetImbalance_PTScotch(MatPartitioning part, PetscReal imb)
+static PetscErrorCode MatPartitioningPTScotchSetImbalance_PTScotch(MatPartitioning part, PetscReal imb)
 {
   MatPartitioning_PTScotch *scotch = (MatPartitioning_PTScotch *)part->data;
 
@@ -57,18 +56,18 @@ PetscErrorCode MatPartitioningPTScotchSetImbalance_PTScotch(MatPartitioning part
 }
 
 /*@
-   MatPartitioningPTScotchGetImbalance - Gets the value of the load imbalance
-   ratio used during strategy selection.
+  MatPartitioningPTScotchGetImbalance - Gets the value of the load imbalance
+  ratio used during strategy selection.
 
-   Not Collective
+  Not Collective
 
-   Input Parameter:
-.  part - the partitioning context
+  Input Parameter:
+. part - the partitioning context
 
-   Output Parameter:
-.  imb  - the load imbalance ratio
+  Output Parameter:
+. imb - the load imbalance ratio
 
-   Level: advanced
+  Level: advanced
 
 .seealso: `MATPARTITIONINGSCOTCH`, `MatPartitioningPTScotchSetImbalance()`
 @*/
@@ -76,12 +75,12 @@ PetscErrorCode MatPartitioningPTScotchGetImbalance(MatPartitioning part, PetscRe
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(part, MAT_PARTITIONING_CLASSID, 1);
-  PetscValidRealPointer(imb, 2);
+  PetscAssertPointer(imb, 2);
   PetscUseMethod(part, "MatPartitioningPTScotchGetImbalance_C", (MatPartitioning, PetscReal *), (part, imb));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode MatPartitioningPTScotchGetImbalance_PTScotch(MatPartitioning part, PetscReal *imb)
+static PetscErrorCode MatPartitioningPTScotchGetImbalance_PTScotch(MatPartitioning part, PetscReal *imb)
 {
   MatPartitioning_PTScotch *scotch = (MatPartitioning_PTScotch *)part->data;
 
@@ -91,13 +90,13 @@ PetscErrorCode MatPartitioningPTScotchGetImbalance_PTScotch(MatPartitioning part
 }
 
 /*@
-   MatPartitioningPTScotchSetStrategy - Sets the strategy to be used in PTScotch.
+  MatPartitioningPTScotchSetStrategy - Sets the strategy to be used in PTScotch.
 
-   Collective
+  Collective
 
-   Input Parameters:
-+  part - the partitioning context
--  strategy - the strategy, one of
+  Input Parameters:
++ part     - the partitioning context
+- strategy - the strategy, one of
 .vb
      MP_PTSCOTCH_DEFAULT     - Default behavior
      MP_PTSCOTCH_QUALITY     - Prioritize quality over speed
@@ -107,13 +106,13 @@ PetscErrorCode MatPartitioningPTScotchGetImbalance_PTScotch(MatPartitioning part
      MP_PTSCOTCH_SCALABILITY - Favor scalability as much as possible
 .ve
 
-   Options Database Key:
-.  -mat_partitioning_ptscotch_strategy [quality,speed,balance,safety,scalability] - strategy
+  Options Database Key:
+. -mat_partitioning_ptscotch_strategy [quality,speed,balance,safety,scalability] - strategy
 
-   Level: advanced
+  Level: advanced
 
-   Note:
-   The default is `MP_SCOTCH_QUALITY`. See the PTScotch documentation for more information.
+  Note:
+  The default is `MP_SCOTCH_QUALITY`. See the PTScotch documentation for more information.
 
 .seealso: `MATPARTITIONINGSCOTCH`, `MatPartitioningPTScotchSetImbalance()`, `MatPartitioningPTScotchGetStrategy()`
 @*/
@@ -126,7 +125,7 @@ PetscErrorCode MatPartitioningPTScotchSetStrategy(MatPartitioning part, MPPTScot
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode MatPartitioningPTScotchSetStrategy_PTScotch(MatPartitioning part, MPPTScotchStrategyType strategy)
+static PetscErrorCode MatPartitioningPTScotchSetStrategy_PTScotch(MatPartitioning part, MPPTScotchStrategyType strategy)
 {
   MatPartitioning_PTScotch *scotch = (MatPartitioning_PTScotch *)part->data;
 
@@ -155,17 +154,17 @@ PetscErrorCode MatPartitioningPTScotchSetStrategy_PTScotch(MatPartitioning part,
 }
 
 /*@
-   MatPartitioningPTScotchGetStrategy - Gets the strategy used in PTScotch.
+  MatPartitioningPTScotchGetStrategy - Gets the strategy used in PTScotch.
 
-   Not Collective
+  Not Collective
 
-   Input Parameter:
-.  part - the partitioning context
+  Input Parameter:
+. part - the partitioning context
 
-   Output Parameter:
-.  strategy - the strategy
+  Output Parameter:
+. strategy - the strategy
 
-   Level: advanced
+  Level: advanced
 
 .seealso: `MATPARTITIONINGSCOTCH`, `MatPartitioningPTScotchSetStrategy()`
 @*/
@@ -173,12 +172,12 @@ PetscErrorCode MatPartitioningPTScotchGetStrategy(MatPartitioning part, MPPTScot
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(part, MAT_PARTITIONING_CLASSID, 1);
-  PetscValidPointer(strategy, 2);
+  PetscAssertPointer(strategy, 2);
   PetscUseMethod(part, "MatPartitioningPTScotchGetStrategy_C", (MatPartitioning, MPPTScotchStrategyType *), (part, strategy));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode MatPartitioningPTScotchGetStrategy_PTScotch(MatPartitioning part, MPPTScotchStrategyType *strategy)
+static PetscErrorCode MatPartitioningPTScotchGetStrategy_PTScotch(MatPartitioning part, MPPTScotchStrategyType *strategy)
 {
   MatPartitioning_PTScotch *scotch = (MatPartitioning_PTScotch *)part->data;
 
@@ -206,7 +205,7 @@ PetscErrorCode MatPartitioningPTScotchGetStrategy_PTScotch(MatPartitioning part,
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode MatPartitioningView_PTScotch(MatPartitioning part, PetscViewer viewer)
+static PetscErrorCode MatPartitioningView_PTScotch(MatPartitioning part, PetscViewer viewer)
 {
   MatPartitioning_PTScotch *scotch = (MatPartitioning_PTScotch *)part->data;
   PetscBool                 isascii;
@@ -241,7 +240,7 @@ PetscErrorCode MatPartitioningView_PTScotch(MatPartitioning part, PetscViewer vi
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode MatPartitioningSetFromOptions_PTScotch(MatPartitioning part, PetscOptionItems *PetscOptionsObject)
+static PetscErrorCode MatPartitioningSetFromOptions_PTScotch(MatPartitioning part, PetscOptionItems *PetscOptionsObject)
 {
   PetscBool                 flag;
   PetscReal                 r;
@@ -435,21 +434,21 @@ static PetscErrorCode MatPartitioningApply_PTScotch_Private(MatPartitioning part
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode MatPartitioningApply_PTScotch(MatPartitioning part, IS *partitioning)
+static PetscErrorCode MatPartitioningApply_PTScotch(MatPartitioning part, IS *partitioning)
 {
   PetscFunctionBegin;
   PetscCall(MatPartitioningApply_PTScotch_Private(part, PETSC_FALSE, partitioning));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode MatPartitioningApplyND_PTScotch(MatPartitioning part, IS *partitioning)
+static PetscErrorCode MatPartitioningApplyND_PTScotch(MatPartitioning part, IS *partitioning)
 {
   PetscFunctionBegin;
   PetscCall(MatPartitioningApply_PTScotch_Private(part, PETSC_TRUE, partitioning));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode MatPartitioningDestroy_PTScotch(MatPartitioning part)
+static PetscErrorCode MatPartitioningDestroy_PTScotch(MatPartitioning part)
 {
   MatPartitioning_PTScotch *scotch = (MatPartitioning_PTScotch *)part->data;
 
@@ -464,15 +463,12 @@ PetscErrorCode MatPartitioningDestroy_PTScotch(MatPartitioning part)
 }
 
 /*MC
-   MATPARTITIONINGPTSCOTCH - Creates a partitioning context that uses the external package SCOTCH.
+   MATPARTITIONINGPTSCOTCH - Creates a partitioning context that uses the external package SCOTCH <http://www.labri.fr/perso/pelegrin/scotch/>.
 
    Level: beginner
 
-   Note:
-    See http://www.labri.fr/perso/pelegrin/scotch/
-
 .seealso: `MatPartitioningSetType()`, `MatPartitioningType`, `MatPartitioningPTScotchSetImbalance()`, `MatPartitioningPTScotchGetImbalance()`,
-          `MatPartitioningPTScotchSetStrategy()`, `MatPartitioningPTScotchGetStrategy()`
+          `MatPartitioningPTScotchSetStrategy()`, `MatPartitioningPTScotchGetStrategy()`, `MatPartitioning`
 M*/
 
 PETSC_EXTERN PetscErrorCode MatPartitioningCreate_PTScotch(MatPartitioning part)
