@@ -255,17 +255,20 @@ static PetscErrorCode SNESView_NASM(SNES snes, PetscViewer viewer)
 }
 
 /*@
-   SNESNASMSetType - Set the type of subdomain update used for the nonlinear additive Schwarz solver
+  SNESNASMSetType - Set the type of subdomain update used for the nonlinear additive Schwarz solver `SNESNASM`
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameters:
-+  snes - the `SNES` context
--  type - the type of update, `PC_ASM_BASIC` or `PC_ASM_RESTRICT`
+  Input Parameters:
++ snes - the `SNES` context
+- type - the type of update, `PC_ASM_BASIC` or `PC_ASM_RESTRICT`
 
-   Level: intermediate
+  Options Database Key:
+. -snes_nasm_type <basic,restrict> - type of subdomain update used
 
-.seealso: `SNESNASM`, `SNESNASMGetType()`, `PCASMSetType()`, `PC_ASM_BASIC`, `PC_ASM_RESTRICT`, `PCASMType`
+  Level: intermediate
+
+.seealso: [](ch_snes), `SNES`, `SNESNASM`, `SNESNASMGetType()`, `PCASMSetType()`, `PC_ASM_BASIC`, `PC_ASM_RESTRICT`, `PCASMType`
 @*/
 PetscErrorCode SNESNASMSetType(SNES snes, PCASMType type)
 {
@@ -288,19 +291,19 @@ static PetscErrorCode SNESNASMSetType_NASM(SNES snes, PCASMType type)
 }
 
 /*@
-   SNESNASMGetType - Get the type of subdomain update used for the nonlinear additive Schwarz solver
+  SNESNASMGetType - Get the type of subdomain update used for the nonlinear additive Schwarz solver `SNESNASM`
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameter:
-.  snes - the `SNES` context
+  Input Parameter:
+. snes - the `SNES` context
 
-   Output Parameter:
-.  type - the type of update
+  Output Parameter:
+. type - the type of update
 
-   Level: intermediate
+  Level: intermediate
 
-.seealso: `SNESNASM`, `SNESNASMSetType()`, `PCASMGetType()`, `PC_ASM_BASIC`, `PC_ASM_RESTRICT`, `PCASMType`
+.seealso: [](ch_snes), `SNES`, `SNESNASM`, `SNESNASMSetType()`, `PCASMGetType()`, `PC_ASM_BASIC`, `PC_ASM_RESTRICT`, `PCASMType`
 @*/
 PetscErrorCode SNESNASMGetType(SNES snes, PCASMType *type)
 {
@@ -319,21 +322,21 @@ static PetscErrorCode SNESNASMGetType_NASM(SNES snes, PCASMType *type)
 }
 
 /*@
-   SNESNASMSetSubdomains - Manually Set the context required to restrict and solve subdomain problems in the nonlinear additive Schwarz solver
+  SNESNASMSetSubdomains - Manually Set the context required to restrict and solve subdomain problems in the nonlinear additive Schwarz solver
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameters:
-+  snes - the SNES context
-.  n - the number of local subdomains
-.  subsnes - solvers defined on the local subdomains
-.  iscatter - scatters into the nonoverlapping portions of the local subdomains
-.  oscatter - scatters into the overlapping portions of the local subdomains
--  gscatter - scatters into the (ghosted) local vector of the local subdomain
+  Input Parameters:
++ snes     - the `SNES` context
+. n        - the number of local subdomains
+. subsnes  - solvers defined on the local subdomains
+. iscatter - scatters into the nonoverlapping portions of the local subdomains
+. oscatter - scatters into the overlapping portions of the local subdomains
+- gscatter - scatters into the (ghosted) local vector of the local subdomain
 
-   Level: intermediate
+  Level: intermediate
 
-.seealso: `SNESNASM`, `SNESNASMGetSubdomains()`
+.seealso: [](ch_snes), `SNES`, `SNESNASM`, `SNESNASMGetSubdomains()`
 @*/
 PetscErrorCode SNESNASMSetSubdomains(SNES snes, PetscInt n, SNES subsnes[], VecScatter iscatter[], VecScatter oscatter[], VecScatter gscatter[])
 {
@@ -391,23 +394,23 @@ static PetscErrorCode SNESNASMSetSubdomains_NASM(SNES snes, PetscInt n, SNES sub
 }
 
 /*@
-   SNESNASMGetSubdomains - Get the local subdomain contexts for the nonlinear additive Schwarz solver
+  SNESNASMGetSubdomains - Get the local subdomain contexts for the nonlinear additive Schwarz solver
 
-   Not Collective but some of the objects returned will be parallel
+  Not Collective but some of the objects returned will be parallel
 
-   Input Parameter:
-.  snes - the `SNES` context
+  Input Parameter:
+. snes - the `SNES` context
 
-   Output Parameters:
-+  n - the number of local subdomains
-.  subsnes - solvers defined on the local subdomains
-.  iscatter - scatters into the nonoverlapping portions of the local subdomains
-.  oscatter - scatters into the overlapping portions of the local subdomains
--  gscatter - scatters into the (ghosted) local vector of the local subdomain
+  Output Parameters:
++ n        - the number of local subdomains
+. subsnes  - solvers defined on the local subdomains
+. iscatter - scatters into the nonoverlapping portions of the local subdomains
+. oscatter - scatters into the overlapping portions of the local subdomains
+- gscatter - scatters into the (ghosted) local vector of the local subdomain
 
-   Level: intermediate
+  Level: intermediate
 
-.seealso: `SNESNASM`, `SNESNASMSetSubdomains()`
+.seealso: [](ch_snes), `SNES`, `SNESNASM`, `SNESNASMSetSubdomains()`
 @*/
 PetscErrorCode SNESNASMGetSubdomains(SNES snes, PetscInt *n, SNES *subsnes[], VecScatter *iscatter[], VecScatter *oscatter[], VecScatter *gscatter[])
 {
@@ -433,23 +436,23 @@ static PetscErrorCode SNESNASMGetSubdomains_NASM(SNES snes, PetscInt *n, SNES *s
 }
 
 /*@
-   SNESNASMGetSubdomainVecs - Get the processor-local subdomain vectors for the nonlinear additive Schwarz solver
+  SNESNASMGetSubdomainVecs - Get the processor-local subdomain vectors for the nonlinear additive Schwarz solver
 
-   Not Collective
+  Not Collective
 
-   Input Parameter:
-.  snes - the `SNES` context
+  Input Parameter:
+. snes - the `SNES` context
 
-   Output Parameters:
-+  n - the number of local subdomains
-.  x - The subdomain solution vector
-.  y - The subdomain step vector
-.  b - The subdomain RHS vector
--  xl - The subdomain local vectors (ghosted)
+  Output Parameters:
++ n  - the number of local subdomains
+. x  - The subdomain solution vector
+. y  - The subdomain step vector
+. b  - The subdomain RHS vector
+- xl - The subdomain local vectors (ghosted)
 
-   Level: developer
+  Level: developer
 
-.seealso: `SNESNASM`, `SNESNASMGetSubdomains()`
+.seealso: [](ch_snes), `SNES`, `SNESNASM`, `SNESNASMGetSubdomains()`
 @*/
 PetscErrorCode SNESNASMGetSubdomainVecs(SNES snes, PetscInt *n, Vec **x, Vec **y, Vec **b, Vec **xl)
 {
@@ -475,22 +478,22 @@ static PetscErrorCode SNESNASMGetSubdomainVecs_NASM(SNES snes, PetscInt *n, Vec
 }
 
 /*@
-   SNESNASMSetComputeFinalJacobian - Schedules the computation of the global and subdomain Jacobians upon convergence for the
-   nonlinear additive Schwarz solver
+  SNESNASMSetComputeFinalJacobian - Schedules the computation of the global and subdomain Jacobians upon convergence for the
+  nonlinear additive Schwarz solver
 
-   Collective
+  Collective
 
-   Input Parameters:
-+  snes - the SNES context
--  flg - `PETSC_TRUE` to compute the Jacobians
+  Input Parameters:
++ snes - the SNES context
+- flg  - `PETSC_TRUE` to compute the Jacobians
 
-   Level: developer
+  Level: developer
 
-   Notes:
-   This is used almost exclusively in the implementation of `SNESASPIN`, where the converged subdomain and global Jacobian
-   is needed at each linear iteration.
+  Notes:
+  This is used almost exclusively in the implementation of `SNESASPIN`, where the converged subdomain and global Jacobian
+  is needed at each linear iteration.
 
-.seealso: `SNESNASM`, `SNESNASMGetSubdomains()`
+.seealso: [](ch_snes), `SNES`, `SNESNASM`, `SNESNASMGetSubdomains()`
 @*/
 PetscErrorCode SNESNASMSetComputeFinalJacobian(SNES snes, PetscBool flg)
 {
@@ -512,20 +515,23 @@ static PetscErrorCode SNESNASMSetComputeFinalJacobian_NASM(SNES snes, PetscBool
 }
 
 /*@
-   SNESNASMSetDamping - Sets the update damping for `SNESNASM` the nonlinear additive Schwarz solver
+  SNESNASMSetDamping - Sets the update damping for `SNESNASM` the nonlinear additive Schwarz solver
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameters:
-+  snes - the `SNES` context
--  dmp - damping
+  Input Parameters:
++ snes - the `SNES` context
+- dmp  - damping
 
-   Level: intermediate
+  Options Database Key:
+. -snes_nasm_damping <dmp> - the new solution is obtained as old solution plus `dmp` times (sum of the solutions on the subdomains)
 
-   Notes:
-    The new solution is obtained as old solution plus dmp times (sum of the solutions on the subdomains)
+  Level: intermediate
 
-.seealso: `SNESNASM`, `SNESNASMGetDamping()`
+  Note:
+  The new solution is obtained as old solution plus dmp times (sum of the solutions on the subdomains)
+
+.seealso: [](ch_snes), `SNES`, `SNESNASM`, `SNESNASMGetDamping()`
 @*/
 PetscErrorCode SNESNASMSetDamping(SNES snes, PetscReal dmp)
 {
@@ -547,19 +553,19 @@ static PetscErrorCode SNESNASMSetDamping_NASM(SNES snes, PetscReal dmp)
 }
 
 /*@
-   SNESNASMGetDamping - Gets the update damping for `SNESNASM` the nonlinear additive Schwarz solver
+  SNESNASMGetDamping - Gets the update damping for `SNESNASM` the nonlinear additive Schwarz solver
 
-   Not Collective
+  Not Collective
 
-   Input Parameter:
-.  snes - the SNES context
+  Input Parameter:
+. snes - the `SNES` context
 
-   Output Parameter:
-.  dmp - damping
+  Output Parameter:
+. dmp - damping
 
-   Level: intermediate
+  Level: intermediate
 
-.seealso: `SNESNASM`, `SNESNASMSetDamping()`
+.seealso: [](ch_snes), `SNES`, `SNESNASM`, `SNESNASMSetDamping()`
 @*/
 PetscErrorCode SNESNASMGetDamping(SNES snes, PetscReal *dmp)
 {
@@ -588,7 +594,7 @@ static PetscErrorCode SNESNASMGetDamping_NASM(SNES snes, PetscReal *dmp)
 
   TODO: All scatters should be packed into one
 */
-PetscErrorCode SNESNASMSolveLocal_Private(SNES snes, Vec B, Vec Y, Vec X)
+static PetscErrorCode SNESNASMSolveLocal_Private(SNES snes, Vec B, Vec Y, Vec X)
 {
   SNES_NASM *nasm = (SNES_NASM *)snes->data;
   SNES       subsnes;
@@ -749,15 +755,15 @@ static PetscErrorCode SNESSolve_NASM(SNES snes)
     snes->norm = fnorm;
     PetscCall(PetscObjectSAWsGrantAccess((PetscObject)snes));
     PetscCall(SNESLogConvergenceHistory(snes, snes->norm, 0));
-    PetscCall(SNESMonitor(snes, 0, snes->norm));
 
     /* test convergence */
-    PetscUseTypeMethod(snes, converged, 0, 0.0, 0.0, fnorm, &snes->reason, snes->cnvP);
+    PetscCall(SNESConverged(snes, 0, 0.0, 0.0, fnorm));
+    PetscCall(SNESMonitor(snes, 0, snes->norm));
     if (snes->reason) PetscFunctionReturn(PETSC_SUCCESS);
   } else {
     PetscCall(PetscObjectSAWsGrantAccess((PetscObject)snes));
     PetscCall(SNESLogConvergenceHistory(snes, snes->norm, 0));
-    PetscCall(SNESMonitor(snes, 0, snes->norm));
+    PetscCall(SNESMonitor(snes, snes->iter, snes->norm));
   }
 
   /* Call general purpose update function */
@@ -778,9 +784,9 @@ static PetscErrorCode SNESSolve_NASM(SNES snes)
     snes->norm = fnorm;
     PetscCall(PetscObjectSAWsGrantAccess((PetscObject)snes));
     PetscCall(SNESLogConvergenceHistory(snes, snes->norm, 0));
-    PetscCall(SNESMonitor(snes, snes->iter, snes->norm));
     /* Test for convergence */
-    if (normschedule == SNES_NORM_ALWAYS) PetscUseTypeMethod(snes, converged, snes->iter, 0.0, 0.0, fnorm, &snes->reason, snes->cnvP);
+    PetscCall(SNESConverged(snes, snes->iter, 0.0, 0.0, fnorm));
+    PetscCall(SNESMonitor(snes, snes->iter, snes->norm));
     if (snes->reason) break;
     /* Call general purpose update function */
     PetscTryTypeMethod(snes, update, snes->iter);
@@ -789,27 +795,21 @@ static PetscErrorCode SNESSolve_NASM(SNES snes)
     PetscCall(SNESNASMComputeFinalJacobian_Private(snes, X));
     SNESCheckJacobianDomainerror(snes);
   }
-  if (normschedule == SNES_NORM_ALWAYS) {
-    if (i == snes->max_its) {
-      PetscCall(PetscInfo(snes, "Maximum number of iterations has been reached: %" PetscInt_FMT "\n", snes->max_its));
-      if (!snes->reason) snes->reason = SNES_DIVERGED_MAX_IT;
-    }
-  } else if (!snes->reason) snes->reason = SNES_CONVERGED_ITS; /* NASM is meant to be used as a nonlinear preconditioner */
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
-  SNESNASM - Nonlinear Additive Schwarz solver
+  SNESNASM - Nonlinear Additive Schwarz solver {cite}`ck02`, {cite}`bruneknepleysmithtu15`
 
    Options Database Keys:
-+  -snes_nasm_log - enable logging events for the communication and solve stages
-.  -snes_nasm_type <basic,restrict> - type of subdomain update used
-.  -snes_asm_damping <dmp> - the new solution is obtained as old solution plus dmp times (sum of the solutions on the subdomains)
-.  -snes_nasm_finaljacobian - compute the local and global jacobians of the final iterate
-.  -snes_nasm_finaljacobian_type <finalinner,finalouter,initial> - pick state the jacobian is calculated at
-.  -sub_snes_ - options prefix of the subdomain nonlinear solves
-.  -sub_ksp_ - options prefix of the subdomain Krylov solver
--  -sub_pc_ - options prefix of the subdomain preconditioner
++  -snes_nasm_log                                                - enable logging events for the communication and solve stages
+.  -snes_nasm_type <basic,restrict>                              - type of subdomain update used
+.  -snes_nasm_damping <dmp>                                      - the new solution is obtained as old solution plus dmp times (sum of the solutions on the subdomains)
+.  -snes_nasm_finaljacobian                                      - compute the local and global Jacobians of the final iterate
+.  -snes_nasm_finaljacobian_type <finalinner,finalouter,initial> - pick state the Jacobian is calculated at
+.  -sub_snes_                                                    - options prefix of the subdomain nonlinear solves
+.  -sub_ksp_                                                     - options prefix of the subdomain Krylov solver
+-  -sub_pc_                                                      - options prefix of the subdomain preconditioner
 
    Level: advanced
 
@@ -819,18 +819,16 @@ static PetscErrorCode SNESSolve_NASM(SNES snes)
 
    Developer Note:
    This is a non-Newton based nonlinear solver that does not directly require a Jacobian; hence the flag snes->usesksp is set to
-       false and `SNESView()` and -snes_view do not display a `KSP` object. However, if the flag nasm->finaljacobian is set (for example, if
-       `SNESNASM` is used as a nonlinear preconditioner for  `SNESASPIN`) then `SNESSetUpMatrices()` is called to generate the
-       Jacobian (needed by `SNESASPIN`)
-       and this utilizes the inner `KSP` object for storing the matrices, but the `KSP` is never used for solving a linear system. When `SNESNASM` is
-       used by `SNESASPIN` they share the same Jacobian matrices because `SNESSetUp()` (called on the outer `SNESASPIN`) causes the inner `SNES`
-       object (in this case `SNESNASM`) to inherit the outer Jacobian matrices.
+   false and `SNESView()` and -snes_view do not display a `KSP` object. However, if the flag nasm->finaljacobian is set (for example, if
+   `SNESNASM` is used as a nonlinear preconditioner for  `SNESASPIN`) then `SNESSetUpMatrices()` is called to generate the
+   Jacobian (needed by `SNESASPIN`)
+   and this utilizes the inner `KSP` object for storing the matrices, but the `KSP` is never used for solving a linear system. When `SNESNASM` is
+   used by `SNESASPIN` they share the same Jacobian matrices because `SNESSetUp()` (called on the outer `SNESASPIN`) causes the inner `SNES`
+   object (in this case `SNESNASM`) to inherit the outer Jacobian matrices.
 
-   References:
-.  * - Peter R. Brune, Matthew G. Knepley, Barry F. Smith, and Xuemin Tu, "Composing Scalable Nonlinear Algebraic Solvers",
-   SIAM Review, 57(4), 2015
-
-.seealso: `SNESCreate()`, `SNES`, `SNESSetType()`, `SNESType`, `SNESNASMSetType()`, `SNESNASMGetType()`, `SNESNASMSetSubdomains()`, `SNESNASMGetSubdomains()`, `SNESNASMGetSubdomainVecs()`, `SNESNASMSetComputeFinalJacobian()`, `SNESNASMSetDamping()`, `SNESNASMGetDamping()`
+.seealso: [](ch_snes), `SNESCreate()`, `SNES`, `SNESSetType()`, `SNESType`, `SNESNASMSetType()`, `SNESNASMGetType()`, `SNESNASMSetSubdomains()`, `SNESNASMGetSubdomains()`,
+          `SNESNASMGetSubdomainVecs()`, `SNESNASMSetComputeFinalJacobian()`, `SNESNASMSetDamping()`, `SNESNASMGetDamping()`, `SNESNASMSetWeight()`,
+          `SNESNASMGetSNES()`, `SNESNASMGetNumber()`
 M*/
 
 PETSC_EXTERN PetscErrorCode SNESCreate_NASM(SNES snes)
@@ -891,20 +889,20 @@ PETSC_EXTERN PetscErrorCode SNESCreate_NASM(SNES snes)
 }
 
 /*@
-   SNESNASMGetSNES - Gets a subsolver
+  SNESNASMGetSNES - Gets a subsolver
 
-   Not Collective
+  Not Collective
 
-   Input Parameters:
-+  snes - the `SNES` context
--  i - the number of the subsnes to get
+  Input Parameters:
++ snes - the `SNES` context
+- i    - the number of the subsnes to get
 
-   Output Parameter:
-.  subsnes - the subsolver context
+  Output Parameter:
+. subsnes - the subsolver context
 
-   Level: intermediate
+  Level: intermediate
 
-.seealso: `SNESNASM`, `SNESNASMGetNumber()`
+.seealso: [](ch_snes), `SNESNASM`, `SNESNASMGetNumber()`
 @*/
 PetscErrorCode SNESNASMGetSNES(SNES snes, PetscInt i, SNES *subsnes)
 {
@@ -917,19 +915,19 @@ PetscErrorCode SNESNASMGetSNES(SNES snes, PetscInt i, SNES *subsnes)
 }
 
 /*@
-   SNESNASMGetNumber - Gets number of subsolvers
+  SNESNASMGetNumber - Gets number of subsolvers
 
-   Not Collective
+  Not Collective
 
-   Input Parameter:
-.  snes - the `SNES` context
+  Input Parameter:
+. snes - the `SNES` context
 
-   Output Parameter:
-.  n - the number of subsolvers
+  Output Parameter:
+. n - the number of subsolvers
 
-   Level: intermediate
+  Level: intermediate
 
-.seealso: `SNESNASM`, `SNESNASMGetSNES()`
+.seealso: [](ch_snes), `SNESNASM`, `SNESNASMGetSNES()`
 @*/
 PetscErrorCode SNESNASMGetNumber(SNES snes, PetscInt *n)
 {
@@ -941,17 +939,17 @@ PetscErrorCode SNESNASMGetNumber(SNES snes, PetscInt *n)
 }
 
 /*@
-   SNESNASMSetWeight - Sets weight to use when adding overlapping updates
+  SNESNASMSetWeight - Sets weight to use when adding overlapping updates
 
-   Collective
+  Collective
 
-   Input Parameters:
-+  snes - the `SNES` context
--  weight - the weights to use (typically 1/N for each dof, where N is the number of patches it appears in)
+  Input Parameters:
++ snes   - the `SNES` context
+- weight - the weights to use (typically 1/N for each dof, where N is the number of patches it appears in)
 
-   Level: intermediate
+  Level: intermediate
 
-.seealso: `SNESNASM`
+.seealso: [](ch_snes), `SNESNASM`
 @*/
 PetscErrorCode SNESNASMSetWeight(SNES snes, Vec weight)
 {
