@@ -57,15 +57,15 @@ static PetscErrorCode SNESTR_Converged_Private(SNES snes, PetscInt it, PetscReal
 }
 
 /*@
-  SNESNewtonTRSetFallbackType - Set the type of fallback if the solution of the trust region subproblem is outside the radius
+  SNESNewtonTRSetFallbackType - Set the type of fallback to use if the solution of the trust region subproblem is outside the radius
 
   Input Parameters:
-+ snes - the nonlinear solver object
++ snes  - the nonlinear solver object
 - ftype - the fallback type, see `SNESNewtonTRFallbackType`
 
   Level: intermediate
 
-.seealso: `SNESNEWTONTR`, `SNESNewtonTRPreCheck()`, `SNESNewtonTRGetPreCheck()`, `SNESNewtonTRSetPreCheck()`,
+.seealso: [](ch_snes), `SNESNEWTONTR`, `SNESNewtonTRPreCheck()`, `SNESNewtonTRGetPreCheck()`, `SNESNewtonTRSetPreCheck()`,
           `SNESNewtonTRSetPostCheck()`, `SNESNewtonTRGetPostCheck()`
 @*/
 PetscErrorCode SNESNewtonTRSetFallbackType(SNES snes, SNESNewtonTRFallbackType ftype)
@@ -82,22 +82,22 @@ PetscErrorCode SNESNewtonTRSetFallbackType(SNES snes, SNESNewtonTRFallbackType f
 }
 
 /*@C
-   SNESNewtonTRSetPreCheck - Sets a user function that is called before the search step has been determined.
-       Allows the user a chance to change or override the trust region decision.
+  SNESNewtonTRSetPreCheck - Sets a user function that is called before the search step has been determined.
+  Allows the user a chance to change or override the trust region decision.
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameters:
-+  snes - the nonlinear solver object
-.  func - [optional] function evaluation routine, for the calling sequence see `SNESNewtonTRPreCheck()`
--  ctx  - [optional] user-defined context for private data for the function evaluation routine (may be `NULL`)
+  Input Parameters:
++ snes - the nonlinear solver object
+. func - [optional] function evaluation routine, for the calling sequence see `SNESNewtonTRPreCheck()`
+- ctx  - [optional] user-defined context for private data for the function evaluation routine (may be `NULL`)
 
-   Level: deprecated (since 3.19)
+  Level: deprecated (since 3.19)
 
-   Note:
-   This function is called BEFORE the function evaluation within the solver.
+  Note:
+  This function is called BEFORE the function evaluation within the solver.
 
-.seealso: `SNESNEWTONTR`, `SNESNewtonTRPreCheck()`, `SNESNewtonTRGetPreCheck()`, `SNESNewtonTRSetPostCheck()`, `SNESNewtonTRGetPostCheck()`,
+.seealso: [](ch_snes), `SNESNEWTONTR`, `SNESNewtonTRPreCheck()`, `SNESNewtonTRGetPreCheck()`, `SNESNewtonTRSetPostCheck()`, `SNESNewtonTRGetPostCheck()`,
 @*/
 PetscErrorCode SNESNewtonTRSetPreCheck(SNES snes, PetscErrorCode (*func)(SNES, Vec, Vec, PetscBool *, void *), void *ctx)
 {
@@ -115,22 +115,22 @@ PetscErrorCode SNESNewtonTRSetPreCheck(SNES snes, PetscErrorCode (*func)(SNES, V
 }
 
 /*@C
-   SNESNewtonTRGetPreCheck - Gets the pre-check function
+  SNESNewtonTRGetPreCheck - Gets the pre-check function
 
-   Deprecated use `SNESNEWTONDCTRDC`
+  Deprecated use `SNESNEWTONDCTRDC`
 
-   Not Collective
+  Not Collective
 
-   Input Parameter:
-.  snes - the nonlinear solver context
+  Input Parameter:
+. snes - the nonlinear solver context
 
-   Output Parameters:
-+  func - [optional] function evaluation routine, for the calling sequence see `SNESNewtonTRPreCheck()`
--  ctx  - [optional] user-defined context for private data for the function evaluation routine (may be `NULL`)
+  Output Parameters:
++ func - [optional] function evaluation routine, for the calling sequence see `SNESNewtonTRPreCheck()`
+- ctx  - [optional] user-defined context for private data for the function evaluation routine (may be `NULL`)
 
-   Level: deprecated (since 3.19)
+  Level: deprecated (since 3.19)
 
-.seealso: `SNESNEWTONTR`, `SNESNewtonTRSetPreCheck()`, `SNESNewtonTRPreCheck()`
+.seealso: [](ch_snes), `SNESNEWTONTR`, `SNESNewtonTRSetPreCheck()`, `SNESNewtonTRPreCheck()`
 @*/
 PetscErrorCode SNESNewtonTRGetPreCheck(SNES snes, PetscErrorCode (**func)(SNES, Vec, Vec, PetscBool *, void *), void **ctx)
 {
@@ -147,23 +147,23 @@ PetscErrorCode SNESNewtonTRGetPreCheck(SNES snes, PetscErrorCode (**func)(SNES,
 }
 
 /*@C
-   SNESNewtonTRSetPostCheck - Sets a user function that is called after the search step has been determined but before the next
-       function evaluation. Allows the user a chance to change or override the internal decision of the solver
+  SNESNewtonTRSetPostCheck - Sets a user function that is called after the search step has been determined but before the next
+  function evaluation. Allows the user a chance to change or override the internal decision of the solver
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameters:
-+  snes - the nonlinear solver object
-.  func - [optional] function evaluation routine, for the calling sequence see `SNESNewtonTRPostCheck()`
--  ctx  - [optional] user-defined context for private data for the function evaluation routine (may be `NULL`)
+  Input Parameters:
++ snes - the nonlinear solver object
+. func - [optional] function evaluation routine, for the calling sequence see `SNESNewtonTRPostCheck()`
+- ctx  - [optional] user-defined context for private data for the function evaluation routine (may be `NULL`)
 
-   Level: deprecated (since 3.19)
+  Level: deprecated (since 3.19)
 
-   Note:
-   This function is called BEFORE the function evaluation within the solver while the function set in
-   `SNESLineSearchSetPostCheck()` is called AFTER the function evaluation.
+  Note:
+  This function is called BEFORE the function evaluation within the solver while the function set in
+  `SNESLineSearchSetPostCheck()` is called AFTER the function evaluation.
 
-.seealso: `SNESNEWTONTR`, `SNESNewtonTRPostCheck()`, `SNESNewtonTRGetPostCheck()`, `SNESNewtonTRSetPreCheck()`, `SNESNewtonTRGetPreCheck()`
+.seealso: [](ch_snes), `SNESNEWTONTR`, `SNESNewtonTRPostCheck()`, `SNESNewtonTRGetPostCheck()`, `SNESNewtonTRSetPreCheck()`, `SNESNewtonTRGetPreCheck()`
 @*/
 PetscErrorCode SNESNewtonTRSetPostCheck(SNES snes, PetscErrorCode (*func)(SNES, Vec, Vec, Vec, PetscBool *, PetscBool *, void *), void *ctx)
 {
@@ -181,20 +181,20 @@ PetscErrorCode SNESNewtonTRSetPostCheck(SNES snes, PetscErrorCode (*func)(SNES,
 }
 
 /*@C
-   SNESNewtonTRGetPostCheck - Gets the post-check function
+  SNESNewtonTRGetPostCheck - Gets the post-check function
 
-   Not Collective
+  Not Collective
 
-   Input Parameter:
-.  snes - the nonlinear solver context
+  Input Parameter:
+. snes - the nonlinear solver context
 
-   Output Parameters:
-+  func - [optional] function evaluation routine, for the calling sequence see `SNESNewtonTRPostCheck()`
--  ctx  - [optional] user-defined context for private data for the function evaluation routine (may be `NULL`)
+  Output Parameters:
++ func - [optional] function evaluation routine, for the calling sequence see `SNESNewtonTRPostCheck()`
+- ctx  - [optional] user-defined context for private data for the function evaluation routine (may be `NULL`)
 
-   Level: intermediate
+  Level: intermediate
 
-.seealso: `SNESNEWTONTR`, `SNESNewtonTRSetPostCheck()`, `SNESNewtonTRPostCheck()`
+.seealso: [](ch_snes), `SNESNEWTONTR`, `SNESNewtonTRSetPostCheck()`, `SNESNewtonTRPostCheck()`
 @*/
 PetscErrorCode SNESNewtonTRGetPostCheck(SNES snes, PetscErrorCode (**func)(SNES, Vec, Vec, Vec, PetscBool *, PetscBool *, void *), void **ctx)
 {
@@ -211,21 +211,21 @@ PetscErrorCode SNESNewtonTRGetPostCheck(SNES snes, PetscErrorCode (**func)(SNES,
 }
 
 /*@C
-   SNESNewtonTRPreCheck - Runs the precheck routine
+  SNESNewtonTRPreCheck - Runs the precheck routine
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameters:
-+  snes - the solver
-.  X - The last solution
--  Y - The step direction
+  Input Parameters:
++ snes - the solver
+. X    - The last solution
+- Y    - The step direction
 
-   Output Parameter:
-.  changed_Y - Indicator that the step direction `Y` has been changed.
+  Output Parameter:
+. changed_Y - Indicator that the step direction `Y` has been changed.
 
-   Level: intermediate
+  Level: intermediate
 
-.seealso: `SNESNEWTONTR`, `SNESNewtonTRSetPreCheck()`, `SNESNewtonTRGetPreCheck()`, `SNESNewtonTRPostCheck()`
+.seealso: [](ch_snes), `SNESNEWTONTR`, `SNESNewtonTRSetPreCheck()`, `SNESNewtonTRGetPreCheck()`, `SNESNewtonTRPostCheck()`
 @*/
 PetscErrorCode SNESNewtonTRPreCheck(SNES snes, Vec X, Vec Y, PetscBool *changed_Y)
 {
@@ -245,26 +245,26 @@ PetscErrorCode SNESNewtonTRPreCheck(SNES snes, Vec X, Vec Y, PetscBool *changed_
 }
 
 /*@C
-   SNESNewtonTRPostCheck - Runs the postcheck routine
+  SNESNewtonTRPostCheck - Runs the postcheck routine
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameters:
-+  snes - the solver
-.  X - The last solution
-.  Y - The full step direction
--  W - The updated solution, W = X - Y
+  Input Parameters:
++ snes - the solver
+. X    - The last solution
+. Y    - The full step direction
+- W    - The updated solution, W = X - Y
 
-   Output Parameters:
-+  changed_Y - indicator if step has been changed
--  changed_W - Indicator if the new candidate solution W has been changed.
+  Output Parameters:
++ changed_Y - indicator if step has been changed
+- changed_W - Indicator if the new candidate solution W has been changed.
 
-   Note:
-     If Y is changed then W is recomputed as X - Y
+  Note:
+  If Y is changed then W is recomputed as X - Y
 
-   Level: intermediate
+  Level: intermediate
 
-.seealso: `SNESNEWTONTR`, `SNESNewtonTRSetPostCheck()`, `SNESNewtonTRGetPostCheck()`, `SNESNewtonTRPreCheck()
+.seealso: [](ch_snes), `SNESNEWTONTR`, `SNESNewtonTRSetPostCheck()`, `SNESNewtonTRGetPostCheck()`, `SNESNewtonTRPreCheck()`
 @*/
 PetscErrorCode SNESNewtonTRPostCheck(SNES snes, Vec X, Vec Y, Vec W, PetscBool *changed_Y, PetscBool *changed_W)
 {
@@ -375,11 +375,11 @@ static PetscErrorCode SNESSolve_NEWTONTR(SNES snes)
   deltaM     = neP->deltaM;
   neP->delta = delta;
   PetscCall(SNESLogConvergenceHistory(snes, fnorm, 0));
-  PetscCall(SNESMonitor(snes, 0, fnorm));
 
   /* test convergence */
   rho_satisfied = PETSC_FALSE;
-  PetscUseTypeMethod(snes, converged, snes->iter, 0.0, 0.0, fnorm, &snes->reason, snes->cnvP);
+  PetscCall(SNESConverged(snes, 0, 0.0, 0.0, fnorm));
+  PetscCall(SNESMonitor(snes, 0, fnorm));
   if (snes->reason) PetscFunctionReturn(PETSC_SUCCESS);
 
   if (has_objective) PetscCall(SNESComputeObjective(snes, X, &fk));
@@ -553,7 +553,7 @@ static PetscErrorCode SNESSolve_NEWTONTR(SNES snes)
       PetscCall(PetscInfo(snes, "Trying again in smaller region\n"));
       /* check to see if progress is hopeless */
       PetscCall(SNESTR_Converged_Private(snes, snes->iter, xnorm, ynorm, fnorm, &snes->reason, snes->cnvP));
-      if (!snes->reason) PetscUseTypeMethod(snes, converged, snes->iter, xnorm, ynorm, fnorm, &snes->reason, snes->cnvP);
+      if (!snes->reason) PetscCall(SNESConverged(snes, snes->iter, xnorm, ynorm, fnorm));
       if (snes->reason == SNES_CONVERGED_SNORM_RELATIVE) snes->reason = SNES_DIVERGED_TR_DELTA;
       snes->numFailures++;
       /* We're not progressing, so return with the current iterate */
@@ -577,19 +577,15 @@ static PetscErrorCode SNESSolve_NEWTONTR(SNES snes)
       snes->ynorm = ynorm;
       PetscCall(PetscObjectSAWsGrantAccess((PetscObject)snes));
       PetscCall(SNESLogConvergenceHistory(snes, snes->norm, lits));
-      PetscCall(SNESMonitor(snes, snes->iter, snes->norm));
 
       /* Test for convergence, xnorm = || X || */
       PetscCall(VecNorm(X, NORM_2, &xnorm));
-      PetscUseTypeMethod(snes, converged, snes->iter, xnorm, ynorm, fnorm, &snes->reason, snes->cnvP);
+      PetscCall(SNESConverged(snes, snes->iter, xnorm, ynorm, fnorm));
+      PetscCall(SNESMonitor(snes, snes->iter, snes->norm));
       if (snes->reason) break;
     }
   }
 
-  if (snes->iter == maxits) {
-    PetscCall(PetscInfo(snes, "Maximum number of iterations has been reached: %" PetscInt_FMT "\n", maxits));
-    if (!snes->reason) snes->reason = SNES_DIVERGED_MAX_IT;
-  }
   if (clear_converged_test) {
     PetscCall(KSPGetAndClearConvergenceTest(ksp, &ctx->convtest, &ctx->convctx, &ctx->convdestroy));
     PetscCall(PetscFree(ctx));
@@ -651,25 +647,22 @@ static PetscErrorCode SNESView_NEWTONTR(SNES snes, PetscViewer viewer)
 }
 
 /*MC
-      SNESNEWTONTR - Newton based nonlinear solver that uses trust-region dogleg method with Cauchy direction
+   SNESNEWTONTR - Newton based nonlinear solver that uses trust-region dogleg method with Cauchy direction {cite}`nocedal2006numerical`
 
    Options Database Keys:
-+   -snes_tr_tol <tol> - trust region tolerance
-.   -snes_tr_eta1 <eta1> - trust region parameter 0.0 <= eta1 <= eta2, rho >= eta1 breaks out of the inner iteration (default: eta1=0.001)
-.   -snes_tr_eta2 <eta2> - trust region parameter 0.0 <= eta1 <= eta2, rho <= eta2 shrinks the trust region (default: eta2=0.25)
-.   -snes_tr_eta3 <eta3> - trust region parameter eta3 > eta2, rho >= eta3 expands the trust region (default: eta3=0.75)
-.   -snes_tr_t1 <t1> - trust region parameter, shrinking factor of trust region (default: 0.25)
-.   -snes_tr_t2 <t2> - trust region parameter, expanding factor of trust region (default: 2.0)
-.   -snes_tr_deltaM <deltaM> - trust region parameter, max size of trust region (default: MAX_REAL)
-.   -snes_tr_delta0 <delta0> - trust region parameter, initial size of trust region (default: 0.2)
--   -snes_tr_fallback_type <newton,cauchy,dogleg> - Solution strategy to test reduction when step is outside of trust region. Can use scaled Newton direction, Cauchy point (Steepest Descent direction) or dogleg method.
-
-    Reference:
-.   * - "Numerical Optimization" by Nocedal and Wright, chapter 4.
++  -snes_tr_tol <tol>                            - trust region tolerance
+.  -snes_tr_eta1 <eta1>                          - trust region parameter 0.0 <= eta1 <= eta2, rho >= eta1 breaks out of the inner iteration (default: eta1=0.001)
+.  -snes_tr_eta2 <eta2>                          - trust region parameter 0.0 <= eta1 <= eta2, rho <= eta2 shrinks the trust region (default: eta2=0.25)
+.  -snes_tr_eta3 <eta3>                          - trust region parameter eta3 > eta2, rho >= eta3 expands the trust region (default: eta3=0.75)
+.  -snes_tr_t1 <t1>                              - trust region parameter, shrinking factor of trust region (default: 0.25)
+.  -snes_tr_t2 <t2>                              - trust region parameter, expanding factor of trust region (default: 2.0)
+.  -snes_tr_deltaM <deltaM>                      - trust region parameter, max size of trust region (default: MAX_REAL)
+.  -snes_tr_delta0 <delta0>                      - trust region parameter, initial size of trust region (default: 0.2)
+-  -snes_tr_fallback_type <newton,cauchy,dogleg> - Solution strategy to test reduction when step is outside of trust region. Can use scaled Newton direction, Cauchy point (Steepest Descent direction) or dogleg method.
 
    Level: deprecated (since 3.19)
 
-.seealso: `SNESCreate()`, `SNES`, `SNESSetType()`, `SNESNEWTONLS`, `SNESSetTrustRegionTolerance()`,
+.seealso: [](ch_snes), `SNESCreate()`, `SNES`, `SNESSetType()`, `SNESNEWTONLS`, `SNESSetTrustRegionTolerance()`,
           `SNESNewtonTRPreCheck()`, `SNESNewtonTRGetPreCheck()`, `SNESNewtonTRSetPostCheck()`, `SNESNewtonTRGetPostCheck()`,
           `SNESNewtonTRSetPreCheck()`, `SNESNewtonTRSetFallbackType()`
 M*/
