@@ -1,47 +1,49 @@
-
 #include <petsc/private/snesimpl.h> /*I  "petscsnes.h"  I*/
 #include <petsc/private/vecimpl.h>  /* for Vec->ops->setvalues */
 #include <petscdm.h>
 
 /*@C
-   SNESComputeJacobianDefault - Computes the Jacobian using finite differences.
+  SNESComputeJacobianDefault - Computes the Jacobian using finite differences.
 
-   Collective
+  Collective
 
-   Input Parameters:
-+  snes - the `SNES` context
-.  x1 - compute Jacobian at this point
--  ctx - application's function context, as set with `SNESSetFunction()`
+  Input Parameters:
++ snes - the `SNES` context
+. x1   - compute Jacobian at this point
+- ctx  - application's function context, as set with `SNESSetFunction()`
 
-   Output Parameters:
-+  J - Jacobian matrix (not altered in this routine)
--  B - newly computed Jacobian matrix to use with preconditioner (generally the same as `J`)
+  Output Parameters:
++ J - Jacobian matrix (not altered in this routine)
+- B - newly computed Jacobian matrix to use with preconditioner (generally the same as `J`)
 
-   Options Database Keys:
-+  -snes_fd - Activates `SNESComputeJacobianDefault()`
-.  -snes_fd_coloring - Activates a faster computation that uses a graph coloring of the matrix
-.  -snes_test_err - Square root of function error tolerance, default square root of machine
+  Options Database Keys:
++ -snes_fd          - Activates `SNESComputeJacobianDefault()`
+. -snes_fd_coloring - Activates a faster computation that uses a graph coloring of the matrix
+. -snes_test_err    - Square root of function error tolerance, default square root of machine
                     epsilon (1.e-8 in double, 3.e-4 in single)
--  -mat_fd_type - Either wp or ds (see `MATMFFD_WP` or `MATMFFD_DS`)
+- -mat_fd_type      - Either wp or ds (see `MATMFFD_WP` or `MATMFFD_DS`)
 
-   Level: intermediate
+  Level: intermediate
 
-   Notes:
-   This routine is slow and expensive, and is not currently optimized
-   to take advantage of sparsity in the problem.  Although
-   `SNESComputeJacobianDefault()` is not recommended for general use
-   in large-scale applications, It can be useful in checking the
-   correctness of a user-provided Jacobian.
+  Notes:
+  This routine is slow and expensive, and is not currently optimized
+  to take advantage of sparsity in the problem.  Although
+  `SNESComputeJacobianDefault()` is not recommended for general use
+  in large-scale applications, It can be useful in checking the
+  correctness of a user-provided Jacobian.
 
-   An alternative routine that uses coloring to exploit matrix sparsity is
-   `SNESComputeJacobianDefaultColor()`.
+  An alternative routine that uses coloring to exploit matrix sparsity is
+  `SNESComputeJacobianDefaultColor()`.
 
-   This routine ignores the maximum number of function evaluations set with `SNESSetTolerances()` and the function
-   evaluations it performs are not counted in what is returned by of `SNESGetNumberFunctionEvals()`.
+  This routine ignores the maximum number of function evaluations set with `SNESSetTolerances()` and the function
+  evaluations it performs are not counted in what is returned by of `SNESGetNumberFunctionEvals()`.
 
-   This function can be provided to `SNESSetJacobian()` along with a dense matrix to hold the Jacobian
+  This function can be provided to `SNESSetJacobian()` along with a dense matrix to hold the Jacobian
 
-.seealso: `SNES`, `SNESSetJacobian()`, `SNESSetJacobian()`, `SNESComputeJacobianDefaultColor()`, `MatCreateSNESMF()`
+  Developer Note:
+  The function has a poorly chosen name since it does not mention the use of finite differences
+
+.seealso: [](ch_snes), `SNES`, `SNESSetJacobian()`, `SNESComputeJacobianDefaultColor()`, `MatCreateSNESMF()`
 @*/
 PetscErrorCode SNESComputeJacobianDefault(SNES snes, Vec x1, Mat J, Mat B, void *ctx)
 {
