@@ -1,25 +1,24 @@
-
 #include <petsc/private/drawimpl.h> /*I "petscdraw.h" I*/
 
 /*@
-   PetscDrawSetViewPort - Sets the portion of the window (page) to which draw
-   routines will write.
+  PetscDrawSetViewPort - Sets the portion of the window (page) to which draw
+  routines will write.
 
-   Collective
+  Collective
 
-   Input Parameters:
-+  xl - the horizontal coordinate of the lower left corner of the subwindow.
-.  yl - the vertical coordinate of the lower left corner of the subwindow.
-.  xr - the horizontal coordinate of the upper right corner of the subwindow.
-.  yr - the vertical coordinate of the upper right corner of the subwindow.
--  draw - the drawing context
+  Input Parameters:
++ xl   - the horizontal coordinate of the lower left corner of the subwindow.
+. yl   - the vertical coordinate of the lower left corner of the subwindow.
+. xr   - the horizontal coordinate of the upper right corner of the subwindow.
+. yr   - the vertical coordinate of the upper right corner of the subwindow.
+- draw - the drawing context
 
-   Level: advanced
+  Level: advanced
 
-   Notes:
-   These numbers must always be between 0.0 and 1.0.
+  Notes:
+  These numbers must always be between 0.0 and 1.0.
 
-   Lower left corner is (0,0).
+  Lower left corner is (0,0).
 
 .seealso: `PetscDrawGetViewPort()`, `PetscDraw`, `PetscDrawSplitViewPort()`, `PetscDrawViewPortsCreate()`
 @*/
@@ -37,26 +36,26 @@ PetscErrorCode PetscDrawSetViewPort(PetscDraw draw, PetscReal xl, PetscReal yl,
 }
 
 /*@
-   PetscDrawGetViewPort - Gets the portion of the window (page) to which draw
-   routines will write.
+  PetscDrawGetViewPort - Gets the portion of the window (page) to which draw
+  routines will write.
 
-   Collective
+  Collective
 
-   Input Parameter:
-.  draw - the drawing context
+  Input Parameter:
+. draw - the drawing context
 
-   Output Parameters:
-+  xl - the horizontal coordinate of the lower left corner of the subwindow.
-.  yl - the vertical coordinate of the lower left corner of the subwindow.
-.  xr - the horizontal coordinate of the upper right corner of the subwindow.
--  yr - the vertical coordinate of the upper right corner of the subwindow.
+  Output Parameters:
++ xl - the horizontal coordinate of the lower left corner of the subwindow.
+. yl - the vertical coordinate of the lower left corner of the subwindow.
+. xr - the horizontal coordinate of the upper right corner of the subwindow.
+- yr - the vertical coordinate of the upper right corner of the subwindow.
 
-   Level: advanced
+  Level: advanced
 
-   Notes:
-   These numbers must always be between 0.0 and 1.0.
+  Notes:
+  These numbers must always be between 0.0 and 1.0.
 
-   Lower left corner is (0,0).
+  Lower left corner is (0,0).
 
 .seealso: `PetscDraw`, `PetscDrawSplitViewPort()`, `PetscDrawSetViewPort()`
 @*/
@@ -64,10 +63,10 @@ PetscErrorCode PetscDrawGetViewPort(PetscDraw draw, PetscReal *xl, PetscReal *yl
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(draw, PETSC_DRAW_CLASSID, 1);
-  PetscValidRealPointer(xl, 2);
-  PetscValidRealPointer(yl, 3);
-  PetscValidRealPointer(xr, 4);
-  PetscValidRealPointer(yr, 5);
+  PetscAssertPointer(xl, 2);
+  PetscAssertPointer(yl, 3);
+  PetscAssertPointer(xr, 4);
+  PetscAssertPointer(yr, 5);
   *xl = draw->port_xl;
   *yl = draw->port_yl;
   *xr = draw->port_xr;
@@ -76,15 +75,15 @@ PetscErrorCode PetscDrawGetViewPort(PetscDraw draw, PetscReal *xl, PetscReal *yl
 }
 
 /*@
-   PetscDrawSplitViewPort - Splits a window shared by several processes into smaller
-   view ports. One for each process.
+  PetscDrawSplitViewPort - Splits a window shared by several processes into smaller
+  view ports. One for each process.
 
-   Collective
+  Collective
 
-   Input Parameter:
-.  draw - the drawing context
+  Input Parameter:
+. draw - the drawing context
 
-   Level: advanced
+  Level: advanced
 
 .seealso: `PetscDrawDivideViewPort()`, `PetscDrawSetViewPort()`
 @*/
@@ -129,21 +128,21 @@ PetscErrorCode PetscDrawSplitViewPort(PetscDraw draw)
 }
 
 /*@C
-   PetscDrawViewPortsCreate - Splits a window into smaller view ports. Each processor shares all the viewports.
+  PetscDrawViewPortsCreate - Splits a window into smaller view ports. Each processor shares all the viewports.
 
-   Collective
+  Collective
 
-   Input Parameters:
-+  draw - the drawing context
--  nports - the number of ports
+  Input Parameters:
++ draw   - the drawing context
+- nports - the number of ports
 
-   Output Parameter:
-.  ports - a `PetscDrawViewPorts` context (C structure)
+  Output Parameter:
+. newports - a `PetscDrawViewPorts` context (C structure)
 
-   Options Database Key:
-.  -draw_ports - display multiple fields in the same window with PetscDrawPorts() instead of in separate windows
+  Options Database Key:
+. -draw_ports - display multiple fields in the same window with PetscDrawPorts() instead of in separate windows
 
-   Level: advanced
+  Level: advanced
 
 .seealso: `PetscDrawSplitViewPort()`, `PetscDrawSetViewPort()`, `PetscDrawViewPortsSet()`, `PetscDrawViewPortsDestroy()`
 @*/
@@ -158,7 +157,7 @@ PetscErrorCode PetscDrawViewPortsCreate(PetscDraw draw, PetscInt nports, PetscDr
   PetscFunctionBegin;
   PetscValidHeaderSpecific(draw, PETSC_DRAW_CLASSID, 1);
   PetscCheck(nports >= 1, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Number of divisions must be positive: %" PetscInt_FMT, nports);
-  PetscValidPointer(newports, 3);
+  PetscAssertPointer(newports, 3);
   PetscCall(PetscDrawIsNull(draw, &isnull));
   if (isnull) {
     *newports = NULL;
@@ -210,21 +209,21 @@ PetscErrorCode PetscDrawViewPortsCreate(PetscDraw draw, PetscInt nports, PetscDr
 }
 
 /*@C
-   PetscDrawViewPortsCreateRect - Splits a window into smaller
-       view ports. Each processor shares all the viewports. The number
-       of views in the x- and y-directions is specified.
+  PetscDrawViewPortsCreateRect - Splits a window into smaller
+  view ports. Each processor shares all the viewports. The number
+  of views in the x- and y-directions is specified.
 
-   Collective
+  Collective
 
-   Input Parameters:
-+  draw - the drawing context
-.  nx - the number of x divisions
--  ny - the number of y divisions
+  Input Parameters:
++ draw - the drawing context
+. nx   - the number of x divisions
+- ny   - the number of y divisions
 
-   Output Parameter:
-.  ports - a `PetscDrawViewPorts` context (C structure)
+  Output Parameter:
+. newports - a `PetscDrawViewPorts` context (C structure)
 
-   Level: advanced
+  Level: advanced
 
 .seealso: `PetscDrawSplitViewPort()`, `PetscDrawSetViewPort()`, `PetscDrawViewPortsSet()`, `PetscDrawViewPortsDestroy()`, `PetscDrawViewPorts`
 @*/
@@ -239,7 +238,7 @@ PetscErrorCode PetscDrawViewPortsCreateRect(PetscDraw draw, PetscInt nx, PetscIn
   PetscFunctionBegin;
   PetscValidHeaderSpecific(draw, PETSC_DRAW_CLASSID, 1);
   PetscCheck(nx >= 1 && ny >= 1, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Number of divisions must be positive: %" PetscInt_FMT " x %" PetscInt_FMT, nx, ny);
-  PetscValidPointer(newports, 4);
+  PetscAssertPointer(newports, 4);
   PetscCall(PetscDrawIsNull(draw, &isnull));
   if (isnull) {
     *newports = NULL;
@@ -294,14 +293,14 @@ PetscErrorCode PetscDrawViewPortsCreateRect(PetscDraw draw, PetscInt nx, PetscIn
 }
 
 /*@C
-   PetscDrawViewPortsDestroy - frees a `PetscDrawViewPorts` object
+  PetscDrawViewPortsDestroy - frees a `PetscDrawViewPorts` object
 
-   Collective on the PetscDraw inside ports
+  Collective on the `PetscDraw` inside `ports`
 
-   Input Parameter:
-.  ports - the `PetscDrawViewPorts` object
+  Input Parameter:
+. ports - the `PetscDrawViewPorts` object
 
-   Level: advanced
+  Level: advanced
 
 .seealso: `PetscDrawViewPorts`, `PetscDrawSplitViewPort()`, `PetscDrawSetViewPort()`, `PetscDrawViewPortsSet()`, `PetscDrawViewPortsCreate()`
 @*/
@@ -309,7 +308,7 @@ PetscErrorCode PetscDrawViewPortsDestroy(PetscDrawViewPorts *ports)
 {
   PetscFunctionBegin;
   if (!ports) PetscFunctionReturn(PETSC_SUCCESS);
-  PetscValidPointer(ports, 1);
+  PetscAssertPointer(ports, 1);
   /* reset Drawport of Window back to previous value */
   PetscCall(PetscDrawSetViewPort(ports->draw, ports->port_xl, ports->port_yl, ports->port_xr, ports->port_yr));
   PetscCall(PetscDrawDestroy(&ports->draw));
@@ -319,15 +318,15 @@ PetscErrorCode PetscDrawViewPortsDestroy(PetscDrawViewPorts *ports)
 }
 
 /*@C
-   PetscDrawViewPortsSet - sets a draw object to use a particular subport
+  PetscDrawViewPortsSet - sets a draw object to use a particular subport
 
-   Logically Collective on the `PetscDraw` inside ports
+  Logically Collective on the `PetscDraw` inside `ports`
 
-   Input Parameters:
-+  ports - the `PetscDrawViewPorts` object
--  port - the port number, from 0 to nports-1
+  Input Parameters:
++ ports - the `PetscDrawViewPorts` object
+- port  - the port number, from 0 to nports-1
 
-   Level: advanced
+  Level: advanced
 
 .seealso: `PetscDrawViewPorts`, `PetscDrawSplitViewPort()`, `PetscDrawSetViewPort()`, `PetscDrawViewPortsDestroy()`, `PetscDrawViewPortsCreate()`
 @*/
@@ -335,7 +334,7 @@ PetscErrorCode PetscDrawViewPortsSet(PetscDrawViewPorts *ports, PetscInt port)
 {
   PetscFunctionBegin;
   if (!ports) PetscFunctionReturn(PETSC_SUCCESS);
-  PetscValidPointer(ports, 1);
+  PetscAssertPointer(ports, 1);
   PetscCheck(port >= 0 && (port <= ports->nports - 1), PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Port is out of range requested %" PetscInt_FMT " from 0 to %" PetscInt_FMT, port, ports->nports - 1);
   PetscCall(PetscDrawSetViewPort(ports->draw, ports->xl[port], ports->yl[port], ports->xr[port], ports->yr[port]));
   PetscFunctionReturn(PETSC_SUCCESS);
