@@ -99,12 +99,14 @@ static struct _PetscRandomOps PetscRandomOps_Values = {
 };
 
 /*MC
-   PETSCRANDER48 - simple portable reimplementation of basic Unix drand48() random number generator that should generate the
+   PETSCRANDER48 - simple portable reimplementation of basic Unix `drand48()` random number generator that should generate the
         exact same random numbers on any system.
 
-   Options Database Keys:
+   Options Database Key:
 . -random_type <rand,rand48,rander48,sprng> - select the random number generator at runtime
 
+  Level: beginner
+
   Notes:
     This is the default random number generate provided by `PetscRandomCreate()` if you do not set a particular implementation.
 
@@ -113,8 +115,6 @@ static struct _PetscRandomOps PetscRandomOps_Values = {
   random numbers so if you wish different `PetscRandom` objects of this type set different seeds for each one after you create them with
   `PetscRandomSetSeed()` followed by `PetscRandomSeed()`.
 
-  Level: beginner
-
 .seealso: `PetscRandomCreate()`, `PetscRandomSetType()`, `PETSCRAND`, `PETSCRAND48`, `PETSCRANDER48`, `PETSCSPRNG`, `PetscRandomSetSeed()`,
           `PetscRandomSeed()`, `PetscRandomSetFromOptions()`
 M*/
@@ -126,8 +126,8 @@ PETSC_EXTERN PetscErrorCode PetscRandomCreate_Rander48(PetscRandom r)
   PetscFunctionBegin;
   PetscCall(PetscNew(&r48));
   /* r48 does not need to be initialized because PetscRandomSeed() is always called before use and sets the needed values */
-  r->data = r48;
-  PetscCall(PetscMemcpy(r->ops, &PetscRandomOps_Values, sizeof(PetscRandomOps_Values)));
+  r->data   = r48;
+  r->ops[0] = PetscRandomOps_Values;
   PetscCall(PetscObjectChangeTypeName((PetscObject)r, PETSCRANDER48));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
