@@ -25,27 +25,27 @@ PetscErrorCode PetscDLLibraryPrintPath(PetscDLLibrary libs)
 }
 
 /*@C
-   PetscDLLibraryRetrieve - Copies a PETSc dynamic library from a remote location
-     (if it is remote), then indicates if it exits and its local name.
+  PetscDLLibraryRetrieve - Copies a PETSc dynamic library from a remote location
+  (if it is remote), then indicates if it exits and its local name.
 
-     Collective
+  Collective
 
-   Input Parameters:
-+   comm - MPI processes that will be opening the library
-.   libname - name of the library, can be a relative or absolute path and be a URL
--   llen - length of the `name` buffer
+  Input Parameters:
++ comm    - MPI processes that will be opening the library
+. libname - name of the library, can be a relative or absolute path and be a URL
+- llen    - length of the `name` buffer
 
-   Output Parameters:
-+   name - actual name of the file on local filesystem if `found`
--   found - true if the file exists
+  Output Parameters:
++ lname - actual name of the file on local filesystem if `found`
+- found - true if the file exists
 
-   Level: developer
+  Level: developer
 
-   Notes:
-   [[<http,ftp>://hostname]/directoryname/]filename[.so.1.0]
+  Notes:
+  [[<http,ftp>://hostname]/directoryname/]filename[.so.1.0]
 
    ${PETSC_ARCH}, ${PETSC_DIR}, ${PETSC_LIB_DIR}, or ${any environmental variable}
-   occurring in directoryname and filename will be replaced with appropriate values.
+  occurring in directoryname and filename will be replaced with appropriate values.
 
 .seealso: `PetscFileRetrieve()`
 @*/
@@ -97,27 +97,27 @@ PetscErrorCode PetscDLLibraryRetrieve(MPI_Comm comm, const char libname[], char
 }
 
 /*@C
-   PetscDLLibraryOpen - Opens a PETSc dynamic link library
+  PetscDLLibraryOpen - Opens a PETSc dynamic link library
 
-     Collective
+  Collective
 
-   Input Parameters:
-+   comm - MPI processes that are opening the library
--   path - name of the library, can be a relative or absolute path
+  Input Parameters:
++ comm - MPI processes that are opening the library
+- path - name of the library, can be a relative or absolute path
 
-   Output Parameter:
-.   entry - a PETSc dynamic link library entry
+  Output Parameter:
+. entry - a PETSc dynamic link library entry
 
-   Level: developer
+  Level: developer
 
-   Notes:
-   [[<http,ftp>://hostname]/directoryname/]libbasename[.so.1.0]
+  Notes:
+  [[<http,ftp>://hostname]/directoryname/]libbasename[.so.1.0]
 
-   If the library has the symbol `PetscDLLibraryRegister_basename()` in it then that function is automatically run
-   when the library is opened.
+  If the library has the symbol `PetscDLLibraryRegister_basename()` in it then that function is automatically run
+  when the library is opened.
 
    ${PETSC_ARCH} occurring in directoryname and filename
-   will be replaced with the appropriate value.
+  will be replaced with the appropriate value.
 
 .seealso: `PetscDLLibrary`, `PetscLoadDynamicLibrary()`, `PetscDLLibraryAppend()`, `PetscDLLibraryRetrieve()`, `PetscDLLibrarySym()`, `PetscDLLibraryClose()`
 @*/
@@ -131,8 +131,8 @@ PetscErrorCode PetscDLLibraryOpen(MPI_Comm comm, const char path[], PetscDLLibra
   PetscErrorCode (*func)(void) = NULL;
 
   PetscFunctionBegin;
-  PetscValidCharPointer(path, 2);
-  PetscValidPointer(entry, 3);
+  PetscAssertPointer(path, 2);
+  PetscAssertPointer(entry, 3);
 
   *entry = NULL;
 
@@ -188,26 +188,26 @@ PetscErrorCode PetscDLLibraryOpen(MPI_Comm comm, const char path[], PetscDLLibra
 }
 
 /*@C
-   PetscDLLibrarySym - Load a symbol from a list of dynamic link libraries.
+  PetscDLLibrarySym - Load a symbol from a list of dynamic link libraries.
 
-   Collective
+  Collective
 
-   Input Parameters:
-+  comm - the MPI communicator that will load the symbol
-.  outlist - list of already open libraries that may contain symbol (can be `NULL` and only the executable is searched for the function)
-.  path     - optional complete library name (if provided it checks here before checking `outlist`)
--  insymbol - name of symbol
+  Input Parameters:
++ comm     - the MPI communicator that will load the symbol
+. outlist  - list of already open libraries that may contain symbol (can be `NULL` and only the executable is searched for the function)
+. path     - optional complete library name (if provided it checks here before checking `outlist`)
+- insymbol - name of symbol
 
-   Output Parameter:
-.  value - if symbol not found then this value is set to `NULL`
+  Output Parameter:
+. value - if symbol not found then this value is set to `NULL`
 
-   Level: developer
+  Level: developer
 
-   Notes:
-   Symbol can be of the form
-        [/path/libname[.so.1.0]:]functionname[()] where items in [] denote optional
+  Notes:
+  Symbol can be of the form
+  [/path/libname[.so.1.0]:]functionname[()] where items in [] denote optional
 
-   It will attempt to (retrieve and) open the library if it is not yet been opened.
+  It will attempt to (retrieve and) open the library if it is not yet been opened.
 
 .seealso: `PetscDLLibrary`, `PetscLoadDynamicLibrary()`, `PetscDLLibraryAppend()`, `PetscDLLibraryRetrieve()`, `PetscDLLibraryOpen()`, `PetscDLLibraryClose()`
 @*/
@@ -218,10 +218,10 @@ PetscErrorCode PetscDLLibrarySym(MPI_Comm comm, PetscDLLibrary *outlist, const c
   PetscDLLibrary list = NULL, nlist, prev;
 
   PetscFunctionBegin;
-  if (outlist) PetscValidPointer(outlist, 2);
-  if (path) PetscValidCharPointer(path, 3);
-  PetscValidCharPointer(insymbol, 4);
-  PetscValidPointer(value, 5);
+  if (outlist) PetscAssertPointer(outlist, 2);
+  if (path) PetscAssertPointer(path, 3);
+  PetscAssertPointer(insymbol, 4);
+  PetscAssertPointer(value, 5);
 
   if (outlist) list = *outlist;
   *value = NULL;
@@ -290,26 +290,26 @@ PetscErrorCode PetscDLLibrarySym(MPI_Comm comm, PetscDLLibrary *outlist, const c
 }
 
 /*@C
-     PetscDLLibraryAppend - Appends another dynamic link library to the end  of the search list
+  PetscDLLibraryAppend - Appends another dynamic link library to the end  of the search list
 
-     Collective
+  Collective
 
-     Input Parameters:
-+     comm - MPI communicator
--     path - name of the library
+  Input Parameters:
++ comm - MPI communicator
+- path - name of the library
 
-     Output Parameter:
-.     outlist - list of libraries
+  Output Parameter:
+. outlist - list of libraries
 
-     Level: developer
+  Level: developer
 
-     Note:
-    if library is already in path will not add it.
+  Note:
+  if library is already in path will not add it.
 
   If the library has the symbol PetscDLLibraryRegister_basename() in it then that function is automatically run
-      when the library is opened.
+  when the library is opened.
 
-.seealso: `PetscDLLibrary`, `PetscDLLibraryOpen()`, `PetscLoadDynamicLibrary()`, `PetscDLLibraryRetrieve()`, `PetscDLLibraryOpen()`, `PetscDLLibraryPrepend()`
+.seealso: `PetscDLLibrary`, `PetscDLLibraryOpen()`, `PetscLoadDynamicLibrary()`, `PetscDLLibraryRetrieve()`, `PetscDLLibraryPrepend()`
 @*/
 PetscErrorCode PetscDLLibraryAppend(MPI_Comm comm, PetscDLLibrary *outlist, const char path[])
 {
@@ -321,7 +321,7 @@ PetscErrorCode PetscDLLibraryAppend(MPI_Comm comm, PetscDLLibrary *outlist, cons
   PetscToken     token;
 
   PetscFunctionBegin;
-  PetscValidPointer(outlist, 2);
+  PetscAssertPointer(outlist, 2);
 
   /* is path a directory? */
   PetscCall(PetscTestDirectory(path, 'r', &dir));
@@ -375,23 +375,23 @@ PetscErrorCode PetscDLLibraryAppend(MPI_Comm comm, PetscDLLibrary *outlist, cons
 }
 
 /*@C
-     PetscDLLibraryPrepend - Add another dynamic library to search for symbols to the beginning of the search list
+  PetscDLLibraryPrepend - Add another dynamic library to search for symbols to the beginning of the search list
 
-     Collective
+  Collective
 
-     Input Parameters:
-+     comm - MPI communicator
--     path - name of the library
+  Input Parameters:
++ comm - MPI communicator
+- path - name of the library
 
-     Output Parameter:
-.     outlist - list of libraries
+  Output Parameter:
+. outlist - list of libraries
 
-     Level: developer
+  Level: developer
 
-     Note:
-    If library is already in the list it will remove the old reference.
+  Note:
+  If library is already in the list it will remove the old reference.
 
-.seealso: `PetscDLLibrary`, `PetscDLLibraryOpen()`, `PetscLoadDynamicLibrary()`, `PetscDLLibraryRetrieve()`, `PetscDLLibraryOpen()`, `PetscDLLibraryAppend()`
+.seealso: `PetscDLLibrary`, `PetscDLLibraryOpen()`, `PetscLoadDynamicLibrary()`, `PetscDLLibraryRetrieve()`, `PetscDLLibraryAppend()`
 @*/
 PetscErrorCode PetscDLLibraryPrepend(MPI_Comm comm, PetscDLLibrary *outlist, const char path[])
 {
@@ -403,7 +403,7 @@ PetscErrorCode PetscDLLibraryPrepend(MPI_Comm comm, PetscDLLibrary *outlist, con
   PetscToken     token;
 
   PetscFunctionBegin;
-  PetscValidPointer(outlist, 2);
+  PetscAssertPointer(outlist, 2);
 
   /* is path a directory? */
   PetscCall(PetscTestDirectory(path, 'r', &dir));
@@ -465,16 +465,16 @@ PetscErrorCode PetscDLLibraryPrepend(MPI_Comm comm, PetscDLLibrary *outlist, con
 }
 
 /*@C
-     PetscDLLibraryClose - Destroys the search path of dynamic libraries and closes the libraries.
+  PetscDLLibraryClose - Destroys the search path of dynamic libraries and closes the libraries.
 
-    Collective
+  Collective
 
-    Input Parameter:
-.     head - library list
+  Input Parameter:
+. list - library list
 
-     Level: developer
+  Level: developer
 
-.seealso: `PetscDLLibrary`, `PetscDLLibraryOpen()`, `PetscLoadDynamicLibrary()`, `PetscDLLibraryRetrieve()`, `PetscDLLibraryOpen()`, `PetscDLLibraryAppend()`,
+.seealso: `PetscDLLibrary`, `PetscDLLibraryOpen()`, `PetscLoadDynamicLibrary()`, `PetscDLLibraryRetrieve()`, `PetscDLLibraryAppend()`,
           `PetscDLLibraryPrepend()`
 @*/
 PetscErrorCode PetscDLLibraryClose(PetscDLLibrary list)
