@@ -1,4 +1,3 @@
-
 /*
     Provides a general mechanism to allow one to register new routines in
     dynamic libraries for many of the PETSc objects (including, e.g., KSP and PC).
@@ -88,7 +87,7 @@ PETSC_INTERN PetscErrorCode PetscInitialize_DynamicLibraries(void)
     PetscCheck(found, PETSC_COMM_SELF, PETSC_ERR_FILE_OPEN, "Unable to locate PETSc dynamic library \n You cannot move the dynamic libraries!");
   #else
     PetscCall(PetscLoadDynamicLibrary("sys", &found));
-    PetscCheck(found, PETSC_COMM_SELF, PETSC_ERR_FILE_OPEN, "Unable to locate PETSc dynamic library \n You cannot move the dynamic libraries!");
+    PetscCheck(found, PETSC_COMM_SELF, PETSC_ERR_FILE_OPEN, "Unable to locate PETSc Sys dynamic library \n You cannot move the dynamic libraries!");
     PetscCall(PetscLoadDynamicLibrary("vec", &found));
     PetscCheck(found, PETSC_COMM_SELF, PETSC_ERR_FILE_OPEN, "Unable to locate PETSc Vec dynamic library \n You cannot move the dynamic libraries!");
     PetscCall(PetscLoadDynamicLibrary("mat", &found));
@@ -229,7 +228,7 @@ static PetscErrorCode PetscHMapFuncInsert_Private(PetscHMapFunc map, const char
   PetscBool     found;
 
   PetscFunctionBegin;
-  PetscValidCharPointer(name, 2);
+  PetscAssertPointer(name, 2);
   if (fnc) PetscValidFunction(fnc, 3);
   PetscCall(PetscHMapFuncFind(map, name, &it, &found));
   if (fnc) {
@@ -262,51 +261,51 @@ static PetscErrorCode PetscFunctionListCreate_Private(PetscInt size, PetscFuncti
 }
 
 /*MC
-   PetscFunctionListAdd - Given a routine and a string id, saves that routine in the
-   specified registry.
+  PetscFunctionListAdd - Given a routine and a string id, saves that routine in the
+  specified registry.
 
-   Synopsis:
-   #include <petscsys.h>
-   PetscErrorCode PetscFunctionListAdd(PetscFunctionList *flist,const char name[],void (*fptr)(void))
+  Synopsis:
+  #include <petscsys.h>
+  PetscErrorCode PetscFunctionListAdd(PetscFunctionList *flist,const char name[],void (*fptr)(void))
 
-   Not Collective
+  Not Collective
 
-   Input Parameters:
-+  flist - pointer to function list object
-.  name - string to identify routine
--  fptr - function pointer
+  Input Parameters:
++ fl   - pointer to function list object
+. name - string to identify routine
+- fptr - function pointer
 
-    Level: developer
+  Level: developer
 
-   Notes:
-   To remove a registered routine, pass in a `NULL` `fptr`.
+  Notes:
+  To remove a registered routine, pass in a `NULL` `fptr`.
 
-   Users who wish to register new classes for use by a particular PETSc
-   component (e.g., `SNES`) should generally call the registration routine
-   for that particular component (e.g., `SNESRegister()`) instead of
-   calling `PetscFunctionListAdd()` directly.
+  Users who wish to register new classes for use by a particular PETSc
+  component (e.g., `SNES`) should generally call the registration routine
+  for that particular component (e.g., `SNESRegister()`) instead of
+  calling `PetscFunctionListAdd()` directly.
 
 .seealso: `PetscFunctionListDestroy()`, `SNESRegister()`, `KSPRegister()`,`PetscFunctionListDuplicate()`
           `PCRegister()`, `TSRegister()`, `PetscFunctionList`, `PetscObjectComposeFunction()`
 M*/
-PetscErrorCode PetscFunctionListAdd_Private(PetscFunctionList *fl, const char name[], PetscVoidFunction fnc)
+PetscErrorCode PetscFunctionListAdd_Private(PetscFunctionList *fl, const char name[], PetscVoidFunction fptr)
 {
   PetscFunctionBegin;
-  PetscValidPointer(fl, 1);
-  if (name) PetscValidCharPointer(name, 2);
-  if (fnc) PetscValidFunction(fnc, 3);
+  PetscAssertPointer(fl, 1);
+  if (name) PetscAssertPointer(name, 2);
+  if (fptr) PetscValidFunction(fptr, 3);
   PetscCall(PetscFunctionListCreate_Private(0, fl));
-  PetscCall(PetscHMapFuncInsert_Private((*fl)->map, name, fnc));
+  PetscCall(PetscHMapFuncInsert_Private((*fl)->map, name, fptr));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-    PetscFunctionListDestroy - Destroys a list of registered routines.
+  PetscFunctionListDestroy - Destroys a list of registered routines.
 
-    Input Parameter:
-.   fl  - pointer to list
+  Input Parameter:
+. fl - pointer to list
 
-    Level: developer
+  Level: developer
 
 .seealso: `PetscFunctionListAdd()`, `PetscFunctionList`, `PetscFunctionListClear()`
 @*/
@@ -382,16 +381,16 @@ PetscErrorCode PetscFunctionListPrintAll(void)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*MC
-    PetscFunctionListNonEmpty - Print composed names for non `NULL` function pointers
+/*@C
+  PetscFunctionListPrintNonEmpty - Print composed names for non `NULL` function pointers
 
-    Input Parameter:
-.   flist   - pointer to list
+  Input Parameter:
+. fl - the function list
 
-    Level: developer
+  Level: developer
 
 .seealso: `PetscFunctionListAdd()`, `PetscFunctionList`, `PetscObjectQueryFunction()`
-M*/
+@*/
 PetscErrorCode PetscFunctionListPrintNonEmpty(PetscFunctionList fl)
 {
   PetscFunctionBegin;
@@ -408,43 +407,43 @@ PetscErrorCode PetscFunctionListPrintNonEmpty(PetscFunctionList fl)
 }
 
 /*MC
-    PetscFunctionListFind - Find function registered under given name
+  PetscFunctionListFind - Find function registered under given name
 
-    Synopsis:
-    #include <petscsys.h>
-    PetscErrorCode PetscFunctionListFind(PetscFunctionList flist,const char name[],void (**fptr)(void))
+  Synopsis:
+  #include <petscsys.h>
+  PetscErrorCode PetscFunctionListFind(PetscFunctionList flist,const char name[],void (**fptr)(void))
 
-    Input Parameters:
-+   flist   - pointer to list
--   name - name registered for the function
+  Input Parameters:
++ fl   - the function list
+- name - name registered for the function
 
-    Output Parameter:
-.   fptr - the function pointer if name was found, else `NULL`
+  Output Parameter:
+. fptr - the function pointer if name was found, else `NULL`
 
-    Level: developer
+  Level: developer
 
 .seealso: `PetscFunctionListAdd()`, `PetscFunctionList`, `PetscObjectQueryFunction()`, `PetscFunctionListDuplicate()`
 M*/
-PetscErrorCode PetscFunctionListFind_Private(PetscFunctionList fl, const char name[], PetscVoidFunction *r)
+PetscErrorCode PetscFunctionListFind_Private(PetscFunctionList fl, const char name[], PetscVoidFunction *fptr)
 {
   PetscFunctionBegin;
-  PetscValidCharPointer(name, 2);
-  PetscValidPointer(r, 3);
-  *r = NULL;
-  if (fl) PetscCall(PetscHMapFuncGet(fl->map, name, r));
+  PetscAssertPointer(name, 2);
+  PetscAssertPointer(fptr, 3);
+  *fptr = NULL;
+  if (fl) PetscCall(PetscHMapFuncGet(fl->map, name, fptr));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-   PetscFunctionListView - prints out contents of a `PetscFunctionList`
+  PetscFunctionListView - prints out contents of a `PetscFunctionList`
 
-   Collective
+  Collective
 
-   Input Parameters:
-+  list - the list of functions
--  viewer - the `PetscViewer` used to view the `PetscFunctionList`
+  Input Parameters:
++ list   - the list of functions
+- viewer - the `PetscViewer` used to view the `PetscFunctionList`
 
-   Level: developer
+  Level: developer
 
 .seealso: `PetscFunctionListAdd()`, `PetscFunctionListPrintTypes()`, `PetscFunctionList`
 @*/
@@ -453,7 +452,7 @@ PetscErrorCode PetscFunctionListView(PetscFunctionList list, PetscViewer viewer)
   PetscBool iascii;
 
   PetscFunctionBegin;
-  PetscValidPointer(list, 1);
+  PetscAssertPointer(list, 1);
   if (!viewer) PetscCall(PetscViewerASCIIGetStdout(PETSC_COMM_SELF, &viewer));
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 2);
 
@@ -480,23 +479,23 @@ PetscErrorCode PetscFunctionListView(PetscFunctionList list, PetscViewer viewer)
 }
 
 /*@C
-   PetscFunctionListGet - Gets an array the contains the entries in `PetscFunctionList`, this is used
-         by help etc.
+  PetscFunctionListGet - Gets an array the contains the entries in `PetscFunctionList`, this is used
+  by help etc.
 
-   Not Collective
+  Not Collective
 
-   Input Parameter:
-.  list   - list of types
+  Input Parameter:
+. list - list of types
 
-   Output Parameters:
-+  array - array of names
--  n - length of `array`
+  Output Parameters:
++ array - array of names
+- n     - length of `array`
 
-   Level: developer
+  Level: developer
 
-   Note:
-       This allocates the array so that must be freed. BUT the individual entries are
-    not copied so should not be freed.
+  Note:
+  This allocates the array so that must be freed. BUT the individual entries are
+  not copied so should not be freed.
 
 .seealso: `PetscFunctionListAdd()`, `PetscFunctionList`
 @*/
@@ -505,7 +504,7 @@ PetscErrorCode PetscFunctionListGet(PetscFunctionList list, const char ***array,
   PetscInt size = 0;
 
   PetscFunctionBegin;
-  PetscValidPointer(array, 2);
+  PetscAssertPointer(array, 2);
   *array = NULL;
   if (list) {
     const PetscHMapFunc map = list->map;
@@ -520,22 +519,22 @@ PetscErrorCode PetscFunctionListGet(PetscFunctionList list, const char ***array,
 }
 
 /*@C
-   PetscFunctionListPrintTypes - Prints the methods available in a list of functions
+  PetscFunctionListPrintTypes - Prints the methods available in a list of functions
 
-   Collective over MPI_Comm
+  Collective
 
-   Input Parameters:
-+  comm   - the communicator (usually `MPI_COMM_WORLD`)
-.  fd     - file to print to, usually `stdout`
-.  prefix - prefix to prepend to name (optional)
-.  name   - option string (for example, `-ksp_type`)
-.  text - short description of the object (for example, "Krylov solvers")
-.  man - name of manual page that discusses the object (for example, `KSPCreate`)
-.  list   - list of types
-.  def - default (current) value
--  newv - new value
+  Input Parameters:
++ comm   - the communicator (usually `MPI_COMM_WORLD`)
+. fd     - file to print to, usually `stdout`
+. prefix - prefix to prepend to name (optional)
+. name   - option string (for example, `-ksp_type`)
+. text   - short description of the object (for example, "Krylov solvers")
+. man    - name of manual page that discusses the object (for example, `KSPCreate`)
+. list   - list of types
+. def    - default (current) value
+- newv   - new value
 
-   Level: developer
+  Level: developer
 
 .seealso: `PetscFunctionListAdd()`, `PetscFunctionList`
 @*/
@@ -555,15 +554,15 @@ PetscErrorCode PetscFunctionListPrintTypes(MPI_Comm comm, FILE *fd, const char p
 }
 
 /*@
-    PetscFunctionListDuplicate - Creates a new list from a given function list `PetscFunctionList`.
+  PetscFunctionListDuplicate - Creates a new list from a given function list `PetscFunctionList`.
 
-    Input Parameter:
-.   fl   - pointer to list
+  Input Parameter:
+. fl - pointer to list
 
-    Output Parameter:
-.   nl - the new list (should point to `NULL` to start, otherwise appends)
+  Output Parameter:
+. nl - the new list (should point to `NULL` to start, otherwise appends)
 
-    Level: developer
+  Level: developer
 
 .seealso: `PetscFunctionList`, `PetscFunctionListAdd()`, `PetscFlistDestroy()`
 @*/
