@@ -193,20 +193,20 @@ PETSC_INTERN PetscBool petscsetmallocvisited;
 PetscBool              petscsetmallocvisited = PETSC_FALSE;
 
 /*@C
-   PetscMallocSet - Sets the underlying allocation routines used by `PetscMalloc()` and `PetscFree()`
+  PetscMallocSet - Sets the underlying allocation routines used by `PetscMalloc()` and `PetscFree()`
 
-   Not Collective
+  Not Collective
 
-   Input Parameters:
-+  imalloc - the routine that provides the `malloc()` implementation (also provides `calloc()`, which is used depending on the second argument)
-.  ifree - the routine that provides the `free()` implementation
--  iralloc - the routine that provides the `realloc()` implementation
+  Input Parameters:
++ imalloc - the routine that provides the `malloc()` implementation (also provides `calloc()`, which is used depending on the second argument)
+. ifree   - the routine that provides the `free()` implementation
+- iralloc - the routine that provides the `realloc()` implementation
 
-   Level: developer
+  Level: developer
 
-   Note:
-   This routine MUST be called before `PetscInitialize()` and may be
-   called only once.
+  Note:
+  This routine MUST be called before `PetscInitialize()` and may be
+  called only once.
 
 .seealso: `PetscMallocClear()`, `PetscInitialize()`, `PetscMalloc()`, `PetscFree()`
 @*/
@@ -222,18 +222,18 @@ PetscErrorCode PetscMallocSet(PetscErrorCode (*imalloc)(size_t, PetscBool, int,
 }
 
 /*@C
-   PetscMallocClear - Resets the routines used by `PetscMalloc()` and `PetscFree()`
+  PetscMallocClear - Resets the routines used by `PetscMalloc()` and `PetscFree()`
 
-   Not Collective
+  Not Collective
 
-   Level: developer
+  Level: developer
 
-   Notes:
-    In general one should never run a PETSc program with different `malloc()` and
-    `free()` settings for different parts; this is because one NEVER wants to
-    `free()` an address that was malloced by a different memory management system
+  Notes:
+  In general one should never run a PETSc program with different `malloc()` and
+  `free()` settings for different parts; this is because one NEVER wants to
+  `free()` an address that was malloced by a different memory management system
 
-    Called in `PetscFinalize()` so that if `PetscInitialize()` is called again it starts with a fresh slate of allocation information
+  Called in `PetscFinalize()` so that if `PetscInitialize()` is called again it starts with a fresh slate of allocation information
 
 .seealso: `PetscMallocSet()`, `PetscMalloc()`, `PetscFree()`
 @*/
@@ -267,18 +267,18 @@ static PetscErrorCode (*PetscTrReallocOld)(size_t, int, const char[], const char
 static PetscErrorCode (*PetscTrFreeOld)(void *, int, const char[], const char[])                       = PetscFreeAlign;
 
 /*@C
-   PetscMallocSetDRAM - Set `PetscMalloc()` to use DRAM.
-     If memkind is available, change the memkind type. Otherwise, switch the
-     current malloc and free routines to the `PetscMallocAlign()` and
-     `PetscFreeAlign()` (PETSc default).
+  PetscMallocSetDRAM - Set `PetscMalloc()` to use DRAM.
+  If memkind is available, change the memkind type. Otherwise, switch the
+  current malloc and free routines to the `PetscMallocAlign()` and
+  `PetscFreeAlign()` (PETSc default).
 
-   Not Collective
+  Not Collective
 
-   Level: developer
+  Level: developer
 
-   Note:
-     This provides a way to do the allocation on DRAM temporarily. One
-     can switch back to the previous choice by calling `PetscMallocReset()`.
+  Note:
+  This provides a way to do the allocation on DRAM temporarily. One
+  can switch back to the previous choice by calling `PetscMallocReset()`.
 
 .seealso: `PetscMallocReset()`, `PetscMalloc()`, `PetscFree()`
 @*/
@@ -303,11 +303,11 @@ PetscErrorCode PetscMallocSetDRAM(void)
 }
 
 /*@C
-   PetscMallocResetDRAM - Reset the changes made by `PetscMallocSetDRAM()`
+  PetscMallocResetDRAM - Reset the changes made by `PetscMallocSetDRAM()`
 
-   Not Collective
+  Not Collective
 
-   Level: developer
+  Level: developer
 
 .seealso: `PetscMallocSetDRAM()`
 @*/
@@ -335,24 +335,24 @@ static PetscBool petscmalloccoalesce =
 #endif
 
 /*@C
-   PetscMallocSetCoalesce - Use coalesced `PetscMalloc()` when allocating groups of objects, that is when using `PetscMallocN()`
+  PetscMallocSetCoalesce - Use coalesced `PetscMalloc()` when allocating groups of objects, that is when using `PetscMallocN()`
 
-   Not Collective
+  Not Collective
 
-   Input Parameter:
-.  coalesce - `PETSC_TRUE` to use coalesced malloc for multi-memory allocation.
+  Input Parameter:
+. coalesce - `PETSC_TRUE` to use coalesced malloc for multi-memory allocation.
 
-   Options Database Key:
-.  -malloc_coalesce - turn coalesced malloc on or off
+  Options Database Key:
+. -malloc_coalesce - turn coalesced `PetscMallocN()` on or off
 
-   Level: developer
+  Level: developer
 
-   Notes:
-   PETSc uses coalesced malloc by default for optimized builds and not for debugging builds.
+  Notes:
+  PETSc uses coalesced `PetscMallocN()` by default for optimized builds and not for debugging builds.
 
-   This default can be changed via the command-line option `-malloc_coalesce` or by calling this function.
+  This default can be changed via the command-line option `-malloc_coalesce` or by calling this function.
 
-   This function can only be called immediately after `PetscInitialize()`
+  This function can only be called immediately after `PetscInitialize()`
 
 .seealso: `PetscMallocA()`, `PetscMalloc()`, `PetscFree()`
 @*/
@@ -364,25 +364,25 @@ PetscErrorCode PetscMallocSetCoalesce(PetscBool coalesce)
 }
 
 /*@C
-   PetscMallocA - Allocate and optionally clear one or more memory locations, possibly using coalesced malloc
+  PetscMallocA - Allocate and optionally clear one or more memory locations, possibly using coalesced malloc
 
-   Not Collective
+  Not Collective
 
-   Input Parameters:
-+  n - number of objects to allocate (at least 1)
-.  clear - use `calloc()` to allocate space initialized to zero
-.  lineno - line number to attribute allocation (typically `__LINE__`)
-.  function - function to attribute allocation (typically `PETSC_FUNCTION_NAME`)
-.  filename - file name to attribute allocation (typically `__FILE__`)
--  bytes0 - first of `n` object sizes
+  Input Parameters:
++ n        - number of objects to allocate (at least 1)
+. clear    - use `calloc()` to allocate space initialized to zero
+. lineno   - line number to attribute allocation (typically `__LINE__`)
+. function - function to attribute allocation (typically `PETSC_FUNCTION_NAME`)
+. filename - file name to attribute allocation (typically `__FILE__`)
+- bytes0   - first of `n` object sizes
 
-   Output Parameter:
-.  ptr0 - first of `n` pointers to allocate
+  Output Parameter:
+. ptr0 - first of `n` pointers to allocate
 
-   Level: developer
+  Level: developer
 
-   Note:
-   This function is not normally called directly by users, but rather via the macros `PetscMalloc1()`, `PetscMalloc2()`, or `PetscCalloc1()`, etc.
+  Note:
+  This function is not normally called directly by users, but rather via the macros `PetscMalloc1()`, `PetscMalloc2()`, or `PetscCalloc1()`, etc.
 
 .seealso: `PetscMallocAlign()`, `PetscMallocSet()`, `PetscMalloc1()`, `PetscMalloc2()`, `PetscMalloc3()`, `PetscMalloc4()`, `PetscMalloc5()`, `PetscMalloc6()`, `PetscMalloc7()`,
           `PetscCalloc1()`, `PetscCalloc2()`, `PetscCalloc3()`, `PetscCalloc4()`, `PetscCalloc5()`, `PetscCalloc6()`, `PetscCalloc7()`, `PetscFreeA()`
@@ -424,23 +424,25 @@ PetscErrorCode PetscMallocA(int n, PetscBool clear, int lineno, const char *func
 }
 
 /*@C
-   PetscFreeA - Free one or more memory locations, possibly allocated using coalesced malloc
+  PetscFreeA - Free one or more memory locations, possibly allocated using coalesced `PetscMallocN()`
 
-   Not Collective
+  Not Collective
 
-   Input Parameters:
-+  n - number of objects to free (at least 1)
-.  lineno - line number to attribute deallocation (typically `__LINE__`)
-.  function - function to attribute deallocation (typically `PETSC_FUNCTION_NAME`)
-.  filename - file name to attribute deallocation (typically `__FILE__`)
--  ptr0 - first of `n` pointers to free
+  Input Parameters:
++ n        - number of objects to free (at least 1)
+. lineno   - line number to attribute deallocation (typically `__LINE__`)
+. function - function to attribute deallocation (typically `PETSC_FUNCTION_NAME`)
+. filename - file name to attribute deallocation (typically `__FILE__`)
+- ptr0     - first of `n` pointers to free
 
-   Level: developer
+  Level: developer
 
-   Notes:
-   This function is not normally called directly by users, but rather via the macros `PetscFree()`, `PetscFree2()`, etc.
+  Notes:
+  This function is not normally called directly by users, but rather via the macros `PetscFree()`, `PetscFree2()`, etc.
 
-   The pointers are zeroed to prevent users from accidentally reusing space that has been freed.
+  The pointers are zeroed to prevent users from accidentally reusing space that has been freed.
+
+  If the arguments were obtained via `PetscMallocA()`, `PetscMalloc2()`, `PetscMalloc3()`, etc., then the arguments must be passed in the same order to the corresponding `PetscFreeA()`, `PetscFree2()`, `PetscFree3()`, respectively.
 
 .seealso: `PetscMallocAlign()`, `PetscMallocSet()`, `PetscMallocA()`, `PetscFree1()`, `PetscFree2()`, `PetscFree3()`, `PetscFree4()`, `PetscFree5()`, `PetscFree6()`, `PetscFree7()`
 @*/
