@@ -29,29 +29,29 @@
 #endif
 
 /*@
-   PetscMemoryGetCurrentUsage - Returns the current resident set size (memory used)
-   for the program.
+  PetscMemoryGetCurrentUsage - Returns the current resident set size (memory used)
+  for the program.
 
-   Not Collective
+  Not Collective
 
-   Output Parameter:
-.   mem - memory usage in bytes
+  Output Parameter:
+. mem - memory usage in bytes
 
-   Options Database Key:
-+  -memory_view - Print memory usage at end of run
-.  -log_view_memory - Display memory information for each logged event
--  -malloc_log - Activate logging of memory usage
+  Options Database Key:
++ -memory_view     - Print memory usage at end of run
+. -log_view_memory - Display memory information for each logged event
+- -malloc_view     - Print usage of `PetscMalloc()` in `PetscFinalize()`
 
-   Level: intermediate
+  Level: intermediate
 
-   Notes:
-   The memory usage reported here includes all Fortran arrays
-   (that may be used in application-defined sections of code).
-   This routine thus provides a more complete picture of memory
-   usage than `PetscMallocGetCurrentUsage()` for codes that employ Fortran with
-   hardwired arrays.
+  Notes:
+  The memory usage reported here includes all Fortran arrays
+  (that may be used in application-defined sections of code).
+  This routine thus provides a more complete picture of memory
+  usage than `PetscMallocGetCurrentUsage()` for codes that employ Fortran with
+  hardwired arrays.
 
-   This value generally never decreases during a run even if the application has freed much of its memory that it allocated
+  This value generally never decreases during a run even if the application has freed much of its memory that it allocated
 
 .seealso: `PetscMallocGetMaximumUsage()`, `PetscMemoryGetMaximumUsage()`, `PetscMallocGetCurrentUsage()`, `PetscMemorySetGetMaximumUsage()`, `PetscMemoryView()`
 @*/
@@ -117,27 +117,27 @@ PetscBool      PetscMemoryCollectMaximumUsage = PETSC_FALSE;
 PetscLogDouble PetscMemoryMaximumUsage        = 0;
 
 /*@
-   PetscMemoryGetMaximumUsage - Returns the maximum resident set size (memory used)
-   for the program since it started (the high water mark).
+  PetscMemoryGetMaximumUsage - Returns the maximum resident set size (memory used)
+  for the program since it started (the high water mark).
 
-   Not Collective
+  Not Collective
 
-   Output Parameter:
-.   mem - memory usage in bytes
+  Output Parameter:
+. mem - memory usage in bytes
 
-   Options Database Key:
-+  -memory_view - Print memory usage at end of run
-.  -log_view_memory - Print memory information per event
--  -malloc_log - Activate logging of memory usage
+  Options Database Key:
++ -memory_view     - Print memory usage at end of run
+. -log_view_memory - Print memory information per event
+- -malloc_view     - Print usage of `PetscMalloc()` in `PetscFinalize()`
 
-   Level: intermediate
+  Level: intermediate
 
-   Note:
-   The memory usage reported here includes all Fortran arrays
-   (that may be used in application-defined sections of code).
-   This routine thus provides a more complete picture of memory
-   usage than `PetscMallocGetCurrentUsage()` for codes that employ Fortran with
-   hardwired arrays.
+  Note:
+  The memory usage reported here includes all Fortran arrays
+  (that may be used in application-defined sections of code).
+  This routine thus provides a more complete picture of memory
+  usage than `PetscMallocGetCurrentUsage()` for codes that employ Fortran with
+  hardwired arrays.
 
 .seealso: `PetscMallocGetMaximumUsage()`, `PetscMemoryGetCurrentUsage()`, `PetscMallocGetCurrentUsage()`,
           `PetscMemorySetGetMaximumUsage()`
@@ -151,17 +151,17 @@ PetscErrorCode PetscMemoryGetMaximumUsage(PetscLogDouble *mem)
 }
 
 /*@
-   PetscMemorySetGetMaximumUsage - Tells PETSc to monitor the maximum memory usage so that
-       `PetscMemoryGetMaximumUsage()` will work.
+  PetscMemorySetGetMaximumUsage - Tells PETSc to monitor the maximum memory usage so that
+  `PetscMemoryGetMaximumUsage()` will work.
 
-   Not Collective
+  Not Collective
 
-   Options Database Key:
-+  -memory_view - Print memory usage at end of run
-.  -log_view_memory - Print memory information per event
--  -malloc_log - Activate logging of memory usage
+  Options Database Key:
++ -memory_view     - Print memory usage at end of run
+. -log_view_memory - Print memory information per event
+- -malloc_view     - Print usage of `PetscMalloc()` in `PetscFinalize()`
 
-   Level: intermediate
+  Level: intermediate
 
 .seealso: `PetscMallocGetMaximumUsage()`, `PetscMemoryGetCurrentUsage()`, `PetscMallocGetCurrentUsage()`,
           `PetscMemoryGetMaximumUsage()`
