@@ -1,6 +1,5 @@
-
 /*
-     Interface to malloc() and free(). This code allows for logging of memory usage and some error checking
+     Logging of memory usage and some error checking
 */
 #include <petsc/private/petscimpl.h> /*I "petscsys.h" I*/
 #include <petscviewer.h>
@@ -18,7 +17,7 @@ PETSC_EXTERN PetscErrorCode PetscReallocAlign(size_t, int, const char[], const c
 #define CLASSID_VALUE ((PetscClassId)0xf0e0d0c9)
 #define ALREADY_FREED ((PetscClassId)0x0f0e0d9c)
 
-/*  this is the header put at the beginning of each malloc() using for tracking allocated space and checking of allocated space heap */
+/*  this is the header put at the beginning of each PetscTrMallocDefault() for tracking allocated space and checking of allocated space heap */
 typedef struct _trSPACE {
   size_t       size, rsize; /* Aligned size and requested size */
   int          id;
@@ -32,7 +31,7 @@ typedef struct _trSPACE {
   struct _trSPACE *next, *prev;
 } TRSPACE;
 
-/* HEADER_BYTES is the number of bytes in a PetscMalloc() header.
+/* HEADER_BYTES is the number of bytes in a PetscTrMallocDefault() header.
    It is sizeof(trSPACE) padded to be a multiple of PETSC_MEMALIGN.
 */
 #define HEADER_BYTES ((sizeof(TRSPACE) + (PETSC_MEMALIGN - 1)) & ~(PETSC_MEMALIGN - 1))
@@ -51,7 +50,7 @@ static size_t    TRallocated           = 0;
 static int       TRfrags               = 0;
 static TRSPACE  *TRhead                = NULL;
 static int       TRid                  = 0;
-static PetscBool TRdebugLevel          = PETSC_FALSE;
+static PetscBool TRdebug               = PETSC_FALSE;
 static PetscBool TRdebugIinitializenan = PETSC_FALSE;
 static PetscBool TRrequestedSize       = PETSC_FALSE;
 static size_t    TRMaxMem              = 0;
@@ -71,36 +70,30 @@ static size_t       PetscLogMallocTraceThreshold = 0;
 static PetscViewer  PetscLogMallocTraceViewer    = NULL;
 
 /*@C
-   PetscMallocValidate - Test the memory for corruption.  This can be called at any time between `PetscInitialize()` and `PetscFinalize()`
+  PetscMallocValidate - Test the memory for corruption.  This can be called at any time between `PetscInitialize()` and `PetscFinalize()`
 
-   Input Parameters:
-+  line - line number where call originated.
-.  function - name of function calling
--  file - file where function is
+  Input Parameters:
++ line     - line number where call originated.
+. function - name of function calling
+- file     - file where function is
 
-   Return value:
-   The number of errors detected.
+  Options Database Keys:
++ -malloc_test  - turns this feature on when PETSc was not configured with `--with-debugging=0`
+- -malloc_debug - turns this feature on anytime
 
-   Options Database Keys:.
-+  -malloc_test - turns this feature on when PETSc was not configured with `--with-debugging=0`
--  -malloc_debug - turns this feature on anytime
-
-   Level: advanced
-
-   Notes:
-   Error messages are written to `stdout`.
-
-   This is only run if `PetscMallocSetDebug()` has been called which is set by `-malloc_test` (if debugging is turned on) or `-malloc_debug` (any time)
+  Level: advanced
 
+  Notes:
   You should generally use `CHKMEMQ` as a short cut for calling this routine.
 
-   No output is generated if there are no problems detected.
+  Error messages are written to `stdout`.
 
-   Fortran Note:
-    The Fortran calling sequence is simply `PetscMallocValidate(ierr)`
+  This is only run if `PetscMallocSetDebug()` has been called which is set by `-malloc_test` (if debugging is turned on) or `-malloc_debug` (any time)
 
-   Developers Note:
-     Uses the flg `TRdebugLevel` (set as the first argument to `PetscMallocSetDebug()`) to determine if it should run
+  No output is generated if there are no problems detected.
+
+  Fortran Notes:
+  The Fortran calling sequence is simply `PetscMallocValidate(ierr)`
 
 .seealso: `CHKMEMQ`, `PetscMalloc()`, `PetscFree()`, `PetscMallocSetDebug()`
 @*/
@@ -110,16 +103,18 @@ PetscErrorCode PetscMallocValidate(int line, const char function[], const char f
   char         *a;
   PetscClassId *nend;
 
-  if (!TRdebugLevel) return PETSC_SUCCESS;
+  if (!TRdebug) return PETSC_SUCCESS;
   head     = TRhead;
   lasthead = NULL;
   if (head && head->prev) {
+    TRdebug = PETSC_FALSE;
     PetscCall((*PetscErrorPrintf)("PetscMallocValidate: error detected in %s() at %s:%d\n", function, file, line));
     PetscCall((*PetscErrorPrintf)("Root memory header %p has invalid back pointer %p\n", (void *)head, (void *)head->prev));
     return PETSC_ERR_MEMC;
   }
   while (head) {
     if (head->classid != CLASSID_VALUE) {
+      TRdebug = PETSC_FALSE;
       PetscCall((*PetscErrorPrintf)("PetscMallocValidate: error detected in %s() at %s:%d\n", function, file, line));
       PetscCall((*PetscErrorPrintf)("Memory at address %p is corrupted\n", (void *)head));
       PetscCall((*PetscErrorPrintf)("Probably write before beginning of or past end of array\n"));
@@ -133,6 +128,7 @@ PetscErrorCode PetscMallocValidate(int line, const char function[], const char f
     a    = (char *)(((TrSPACE *)head) + 1);
     nend = (PetscClassId *)(a + head->size);
     if (*nend != CLASSID_VALUE) {
+      TRdebug = PETSC_FALSE;
       PetscCall((*PetscErrorPrintf)("PetscMallocValidate: error detected in %s() at %s:%d\n", function, file, line));
       if (*nend == ALREADY_FREED) {
         PetscCall((*PetscErrorPrintf)("Memory [id=%d(%.0f)] at address %p already freed\n", head->id, (PetscLogDouble)head->size, a));
@@ -144,6 +140,7 @@ PetscErrorCode PetscMallocValidate(int line, const char function[], const char f
       }
     }
     if (head->prev && head->prev != lasthead) {
+      TRdebug = PETSC_FALSE;
       PetscCall((*PetscErrorPrintf)("PetscMallocValidate: error detected in %s() at %s:%d\n", function, file, line));
       PetscCall((*PetscErrorPrintf)("Backpointer %p is invalid, should be %p\n", (void *)head->prev, (void *)lasthead));
       PetscCall((*PetscErrorPrintf)("Previous memory originally allocated in %s() at %s:%d\n", lasthead->functionname, lasthead->filename, lasthead->lineno));
@@ -157,24 +154,16 @@ PetscErrorCode PetscMallocValidate(int line, const char function[], const char f
 }
 
 /*
-    PetscTrMallocDefault - Malloc with tracing.
+    PetscTrMallocDefault - Malloc with logging and error checking
 
-    Input Parameters:
-+   a   - number of bytes to allocate
-.   lineno - line number where used.  Use `__LINE__` for this
--   filename  - file name where used.  Use `__FILE__` for this
-
-    Output Parameter:
-    double aligned pointer to requested storage
- */
-PetscErrorCode PetscTrMallocDefault(size_t a, PetscBool clear, int lineno, const char function[], const char filename[], void **result)
+*/
+static PetscErrorCode PetscTrMallocDefault(size_t a, PetscBool clear, int lineno, const char function[], const char filename[], void **result)
 {
   TRSPACE *head;
   char    *inew;
   size_t   nsize;
 
   PetscFunctionBegin;
-  /* Do not try to handle empty blocks */
   if (!a) {
     *result = NULL;
     PetscFunctionReturn(PETSC_SUCCESS);
@@ -205,8 +194,7 @@ PetscErrorCode PetscTrMallocDefault(size_t a, PetscBool clear, int lineno, const
   TRallocated += TRrequestedSize ? head->rsize : head->size;
   if (TRallocated > TRMaxMem) TRMaxMem = TRallocated;
   if (PetscLogMemory) {
-    PetscInt i;
-    for (i = 0; i < NumTRMaxMems; i++) {
+    for (PetscInt i = 0; i < NumTRMaxMems; i++) {
       if (TRallocated > TRMaxMems[i]) TRMaxMems[i] = TRallocated;
     }
   }
@@ -214,11 +202,12 @@ PetscErrorCode PetscTrMallocDefault(size_t a, PetscBool clear, int lineno, const
 
 #if defined(PETSC_USE_DEBUG) && !defined(PETSC_HAVE_THREADSAFETY)
   PetscCall(PetscStackCopy(&petscstack, &head->stack));
-  /* fix the line number to where the malloc() was called, not the PetscFunctionBegin; */
+  /* fix the line number to where PetscTrMallocDefault() was called, not the PetscFunctionBegin; */
   head->stack.line[head->stack.currentsize - 2] = lineno;
+  head->stack.currentsize--;
   #if defined(PETSC_USE_REAL_SINGLE) || defined(PETSC_USE_REAL_DOUBLE)
   if (!clear && TRdebugIinitializenan) {
-    size_t     i, n = a / sizeof(PetscReal);
+    size_t     n = a / sizeof(PetscReal);
     PetscReal *s = (PetscReal *)inew;
       /* from https://www.doc.ic.ac.uk/~eedwards/compsys/float/nan.html */
     #if defined(PETSC_USE_REAL_SINGLE)
@@ -226,7 +215,7 @@ PetscErrorCode PetscTrMallocDefault(size_t a, PetscBool clear, int lineno, const
     #else
     PetscInt64 nas = 0x7FF0000000000002;
     #endif
-    for (i = 0; i < n; i++) memcpy(s + i, &nas, sizeof(PetscReal));
+    for (size_t i = 0; i < n; i++) memcpy(s + i, &nas, sizeof(PetscReal));
   }
   #endif
 #endif
@@ -256,16 +245,10 @@ PetscErrorCode PetscTrMallocDefault(size_t a, PetscBool clear, int lineno, const
 }
 
 /*
-   PetscTrFreeDefault - Free with tracing.
+   PetscTrFreeDefault - Free with logging and error checking
 
-   Input Parameters:
-+   a    - pointer to a block allocated with `PetscTrMallocDefault()`
-.   lineno - line number where used.  Use `__LINE__` for this
--   filename  - file name where used.  Use `__FILE__` for this
-
-  Level: developer
- */
-PetscErrorCode PetscTrFreeDefault(void *aa, int lineno, const char function[], const char filename[])
+*/
+static PetscErrorCode PetscTrFreeDefault(void *aa, int lineno, const char function[], const char filename[])
 {
   char         *a = (char *)aa;
   TRSPACE      *head;
@@ -274,7 +257,6 @@ PetscErrorCode PetscTrFreeDefault(void *aa, int lineno, const char function[], c
   PetscClassId *nend;
 
   PetscFunctionBegin;
-  /* Do not try to handle empty blocks */
   if (!a) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscCall(PetscMallocValidate(lineno, function, filename));
@@ -284,12 +266,14 @@ PetscErrorCode PetscTrFreeDefault(void *aa, int lineno, const char function[], c
   head  = (TRSPACE *)a;
 
   if (head->classid != CLASSID_VALUE) {
+    TRdebug = PETSC_FALSE;
     PetscCall((*PetscErrorPrintf)("PetscTrFreeDefault() called from %s() at %s:%d\n", function, filename, lineno));
     PetscCall((*PetscErrorPrintf)("Block at address %p is corrupted; cannot free;\nmay be block not allocated with PetscMalloc()\n", a));
     SETERRQ(PETSC_COMM_SELF, PETSC_ERR_MEMC, "Bad location or corrupted memory");
   }
   nend = (PetscClassId *)(ahead + head->size);
   if (*nend != CLASSID_VALUE) {
+    TRdebug = PETSC_FALSE;
     if (*nend == ALREADY_FREED) {
       PetscCall((*PetscErrorPrintf)("PetscTrFreeDefault() called from %s() at %s:%d\n", function, filename, lineno));
       PetscCall((*PetscErrorPrintf)("Block [id=%d(%.0f)] at address %p was already freed\n", head->id, (PetscLogDouble)head->size, a + sizeof(TrSPACE)));
@@ -310,9 +294,8 @@ PetscErrorCode PetscTrFreeDefault(void *aa, int lineno, const char function[], c
   if (PetscLogMallocTrace > -1 && head->rsize >= PetscLogMallocTraceThreshold) {
     PetscCall(PetscViewerASCIIPrintf(PetscLogMallocTraceViewer, "Free  %zu %s:%d (%s)\n", head->rsize, filename ? filename : "null", lineno, function ? function : "null"));
   }
-  /* Mark the location freed */
   *nend = ALREADY_FREED;
-  /* Save location where freed.  If we suspect the line number, mark as  allocated location */
+  /* Save location where freed.  If we suspect the line number, mark as allocated location */
   if (lineno > 0 && lineno < 50000) {
     head->lineno       = lineno;
     head->filename     = filename;
@@ -333,22 +316,10 @@ PetscErrorCode PetscTrFreeDefault(void *aa, int lineno, const char function[], c
 }
 
 /*
-  PetscTrReallocDefault - Realloc with tracing.
+  PetscTrReallocDefault - Realloc with logging and error checking
 
-  Input Parameters:
-+ len      - number of bytes to allocate
-. lineno   - line number where used.  Use `__LINE__` for this
-. filename - file name where used.  Use `__FILE__` for this
-- result - original memory
-
-  Output Parameter:
-. result - double aligned pointer to requested storage
-
-  Level: developer
-
-.seealso: `PetscTrMallocDefault()`, `PetscTrFreeDefault()`
 */
-PetscErrorCode PetscTrReallocDefault(size_t len, int lineno, const char function[], const char filename[], void **result)
+static PetscErrorCode PetscTrReallocDefault(size_t len, int lineno, const char function[], const char filename[], void **result)
 {
   char         *a = (char *)*result;
   TRSPACE      *head;
@@ -377,12 +348,14 @@ PetscErrorCode PetscTrReallocDefault(size_t len, int lineno, const char function
   inew  = a;
 
   if (head->classid != CLASSID_VALUE) {
+    TRdebug = PETSC_FALSE;
     PetscCall((*PetscErrorPrintf)("PetscTrReallocDefault() called from %s() at %s:%d\n", function, filename, lineno));
     PetscCall((*PetscErrorPrintf)("Block at address %p is corrupted; cannot free;\nmay be block not allocated with PetscMalloc()\n", a));
     SETERRQ(PETSC_COMM_SELF, PETSC_ERR_MEMC, "Bad location or corrupted memory");
   }
   nend = (PetscClassId *)(ahead + head->size);
   if (*nend != CLASSID_VALUE) {
+    TRdebug = PETSC_FALSE;
     if (*nend == ALREADY_FREED) {
       PetscCall((*PetscErrorPrintf)("PetscTrReallocDefault() called from %s() at %s:%d\n", function, filename, lineno));
       PetscCall((*PetscErrorPrintf)("Block [id=%d(%.0f)] at address %p was already freed\n", head->id, (PetscLogDouble)head->size, a + sizeof(TrSPACE)));
@@ -431,8 +404,7 @@ PetscErrorCode PetscTrReallocDefault(size_t len, int lineno, const char function
   TRallocated += TRrequestedSize ? head->rsize : head->size;
   if (TRallocated > TRMaxMem) TRMaxMem = TRallocated;
   if (PetscLogMemory) {
-    PetscInt i;
-    for (i = 0; i < NumTRMaxMems; i++) {
+    for (PetscInt i = 0; i < NumTRMaxMems; i++) {
       if (TRallocated > TRMaxMems[i]) TRMaxMems[i] = TRallocated;
     }
   }
@@ -468,27 +440,27 @@ PetscErrorCode PetscTrReallocDefault(size_t len, int lineno, const char function
 }
 
 /*@C
-    PetscMemoryView - Shows the amount of memory currently being used in a communicator.
+  PetscMemoryView - Shows the amount of memory currently being used in a communicator.
 
-    Collective
+  Collective
 
-    Input Parameters:
-+    viewer - the viewer to output the information on
--    message - string printed before values
+  Input Parameters:
++ viewer  - the viewer to output the information on
+- message - string printed before values
 
-    Options Database Keys:
-+    -malloc_debug - have PETSc track how much memory it has allocated
-.    -log_view_memory - print memory usage per event when `-log_view` is used
--    -memory_view - during `PetscFinalize()` have this routine called
+  Options Database Keys:
++ -malloc_debug    - have PETSc track how much memory it has allocated
+. -log_view_memory - print memory usage per event when `-log_view` is used
+- -memory_view     - during `PetscFinalize()` have this routine called
 
-    Level: intermediate
+  Level: intermediate
 
 .seealso: `PetscMallocDump()`, `PetscMemoryGetCurrentUsage()`, `PetscMemorySetGetMaximumUsage()`, `PetscMallocView()`, `PetscMalloc()`, `PetscFree()`
  @*/
 PetscErrorCode PetscMemoryView(PetscViewer viewer, const char message[])
 {
-  PetscLogDouble allocated, allocatedmax, resident, residentmax, gallocated, gallocatedmax, gresident, gresidentmax, maxgallocated, maxgallocatedmax, maxgresident, maxgresidentmax;
-  PetscLogDouble mingallocated, mingallocatedmax, mingresident, mingresidentmax;
+  PetscLogDouble allocated, allocatedmax, resident, residentmax, gallocated, gallocatedmax, gresident, gresidentmax, maxgallocated, maxgallocatedmax;
+  PetscLogDouble mingallocated, mingallocatedmax, mingresident, mingresidentmax, maxgresident, maxgresidentmax;
   MPI_Comm       comm;
 
   PetscFunctionBegin;
@@ -551,14 +523,17 @@ PetscErrorCode PetscMemoryView(PetscViewer viewer, const char message[])
 }
 
 /*@
-    PetscMallocGetCurrentUsage - gets the current amount of memory used that was allocated with `PetscMalloc()`
+  PetscMallocGetCurrentUsage - gets the current amount of memory used that was allocated with `PetscMalloc()`
 
-    Not Collective
+  Not Collective
 
-    Output Parameter:
-.   space - number of bytes currently allocated
+  Output Parameter:
+. space - number of bytes currently allocated
 
-    Level: intermediate
+  Level: intermediate
+
+  Note:
+  This only works if `-memory_view` or `-log_view_memory` have been used
 
 .seealso: `PetscMallocDump()`, `PetscMallocGetMaximumUsage()`, `PetscMemoryGetCurrentUsage()`, `PetscMalloc()`, `PetscFree()`,
           `PetscMemoryGetMaximumUsage()`
@@ -571,15 +546,18 @@ PetscErrorCode PetscMallocGetCurrentUsage(PetscLogDouble *space)
 }
 
 /*@
-    PetscMallocGetMaximumUsage - gets the maximum amount of memory used that was obtained with `PetscMalloc()` at any time
-        during this run, the high water mark.
+  PetscMallocGetMaximumUsage - gets the maximum amount of memory used that was obtained with `PetscMalloc()` at any time
+  during this run, the high water mark.
 
-    Not Collective
+  Not Collective
 
-    Output Parameter:
-.   space - maximum number of bytes ever allocated at one time
+  Output Parameter:
+. space - maximum number of bytes ever allocated at one time
 
-    Level: intermediate
+  Level: intermediate
+
+  Note:
+  This only works if `PetscMemorySetGetMaximumUsage()`, `-memory_view`, or `-log_view_memory` have been used
 
 .seealso: `PetscMallocDump()`, `PetscMallocView()`, `PetscMemoryGetCurrentUsage()`, `PetscMalloc()`, `PetscFree()`,
           `PetscMallocPushMaximumUsage()`
@@ -592,14 +570,17 @@ PetscErrorCode PetscMallocGetMaximumUsage(PetscLogDouble *space)
 }
 
 /*@
-    PetscMallocPushMaximumUsage - Adds another event to collect the maximum memory usage over an event
+  PetscMallocPushMaximumUsage - Adds another event to collect the maximum memory usage over an event
 
-    Not Collective
+  Not Collective
 
-    Input Parameter:
-.   event - an event id; this is just for error checking
+  Input Parameter:
+. event - an event id; this is just for error checking
 
-    Level: developer
+  Level: developer
+
+  Note:
+  This only does anything if `PetscMemorySetGetMaximumUsage()`, `-memory_view`, or `-log_view_memory` have been used
 
 .seealso: `PetscMallocDump()`, `PetscMallocView()`, `PetscMallocGetMaximumUsage()`, `PetscMemoryGetCurrentUsage()`, `PetscMalloc()`, `PetscFree()`,
           `PetscMallocPopMaximumUsage()`
@@ -607,24 +588,27 @@ PetscErrorCode PetscMallocGetMaximumUsage(PetscLogDouble *space)
 PetscErrorCode PetscMallocPushMaximumUsage(int event)
 {
   PetscFunctionBegin;
-  if (++NumTRMaxMems > MAXTRMAXMEMS) PetscFunctionReturn(PETSC_SUCCESS);
+  if (event < 0 || ++NumTRMaxMems > MAXTRMAXMEMS) PetscFunctionReturn(PETSC_SUCCESS);
   TRMaxMems[NumTRMaxMems - 1]       = TRallocated;
   TRMaxMemsEvents[NumTRMaxMems - 1] = event;
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-    PetscMallocPopMaximumUsage - collect the maximum memory usage over an event
+  PetscMallocPopMaximumUsage - collect the maximum memory usage over an event
 
-    Not Collective
+  Not Collective
 
-    Input Parameter:
-.   event - an event id; this is just for error checking
+  Input Parameter:
+. event - an event id; this is just for error checking
 
-    Output Parameter:
-.   mu - maximum amount of memory malloced during this event; high water mark relative to the beginning of the event
+  Output Parameter:
+. mu - maximum amount of memory malloced during this event; high water mark relative to the beginning of the event
 
-    Level: developer
+  Level: developer
+
+  Note:
+  This only does anything if `PetscMemorySetGetMaximumUsage()`, `-memory_view`, or `-log_view_memory` have been used
 
 .seealso: `PetscMallocDump()`, `PetscMallocView()`, `PetscMallocGetMaximumUsage()`, `PetscMemoryGetCurrentUsage()`, `PetscMalloc()`, `PetscFree()`,
           `PetscMallocPushMaximumUsage()`
@@ -633,24 +617,27 @@ PetscErrorCode PetscMallocPopMaximumUsage(int event, PetscLogDouble *mu)
 {
   PetscFunctionBegin;
   *mu = 0;
-  if (NumTRMaxMems-- > MAXTRMAXMEMS) PetscFunctionReturn(PETSC_SUCCESS);
+  if (event < 0 || NumTRMaxMems-- > MAXTRMAXMEMS) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCheck(TRMaxMemsEvents[NumTRMaxMems] == event, PETSC_COMM_SELF, PETSC_ERR_MEMC, "PetscMallocPush/PopMaximumUsage() are not nested");
   *mu = TRMaxMems[NumTRMaxMems];
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   PetscMallocGetStack - returns a pointer to the stack for the location in the program a call to `PetscMalloc()` was used to obtain that memory
+  PetscMallocGetStack - returns a pointer to the stack for the location in the program a call to `PetscMalloc()` was used to obtain that memory
 
-   Not Collective
+  Not Collective
 
-   Input Parameter:
-.    ptr - the memory location
+  Input Parameter:
+. ptr - the memory location
 
-   Output Parameter:
-.    stack - the stack indicating where the program allocated this memory
+  Output Parameter:
+. stack - the stack indicating where the program allocated this memory
 
-   Level: intermediate
+  Level: intermediate
+
+  Note:
+  This only does anything if `-malloc_debug` (or `-malloc_test` if PETSc was configured with debugging) has been used
 
 .seealso: `PetscMallocGetCurrentUsage()`, `PetscMallocView()`, `PetscMalloc()`, `PetscFree()`
 @*/
@@ -670,30 +657,35 @@ PetscErrorCode PetscMallocGetStack(void *ptr, PetscStack **stack)
 }
 
 /*@C
-   PetscMallocDump - Dumps the currently allocated memory blocks to a file. The information
-   printed is: size of space (in bytes), address of space, id of space,
-   file in which space was allocated, and line number at which it was
-   allocated.
+  PetscMallocDump - Dumps the currently allocated memory blocks to a file. The information
+  printed is: size of space (in bytes), address of space, id of space,
+  file in which space was allocated, and line number at which it was
+  allocated.
 
-   Not Collective
+  Not Collective
 
-   Input Parameter:
-.  fp  - file pointer.  If `fp` is `NULL`, `stdout` is assumed.
+  Input Parameter:
+. fp - file pointer.  If `fp` is `NULL`, `stdout` is assumed.
 
-   Options Database Key:
-.  -malloc_dump <optional filename> - Print summary of unfreed memory during call to `PetscFinalize()`, writing to filename if given
+  Options Database Key:
+. -malloc_dump <optional filename> - Print summary of unfreed memory during call to `PetscFinalize()`, writing to filename if given
 
-   Level: intermediate
+  Level: intermediate
 
-   Notes:
-     Uses `MPI_COMM_WORLD` to display rank, because this may be called in `PetscFinalize()` after `PETSC_COMM_WORLD` has been freed.
+  Notes:
+  Uses `MPI_COMM_WORLD` to display rank, because this may be called in `PetscFinalize()` after `PETSC_COMM_WORLD` has been freed.
 
-     When called in `PetscFinalize()` dumps only the allocations that have not been properly freed
+  When called in `PetscFinalize()` dumps only the allocations that have not been properly freed
 
-     `PetscMallocView()` prints a list of all memory ever allocated
+  `PetscMallocView()` prints a list of all memory ever allocated
 
-   Fortran Note:
-   The calling sequence is `PetscMallocDump`(PetscErrorCode ierr). A `fp` parameter is not supported.
+  This only does anything if `-malloc_debug` (or `-malloc_test` if PETSc was configured with debugging) has been used
+
+  Fortran Notes:
+  The calling sequence is `PetscMallocDump`(PetscErrorCode ierr). A `fp` parameter is not supported.
+
+  Developer Notes:
+  This should be absorbed into `PetscMallocView()`
 
 .seealso: `PetscMallocGetCurrentUsage()`, `PetscMallocView()`, `PetscMallocViewSet()`, `PetscMallocValidate()`, `PetscMalloc()`, `PetscFree()`
 @*/
@@ -718,9 +710,11 @@ PetscErrorCode PetscMallocDump(FILE *fp)
 
     PetscCall(PetscStrcmp(head->functionname, "PetscDLLibraryOpen", &isLib));
     if (!isLib) {
-      fprintf(fp, "[%2d] %.0f bytes %s() at %s:%d\n", rank, (PetscLogDouble)(TRrequestedSize ? head->rsize : head->size), head->functionname, head->filename, head->lineno);
 #if defined(PETSC_USE_DEBUG) && !defined(PETSC_HAVE_THREADSAFETY)
+      fprintf(fp, "[%2d] %.0f bytes\n", rank, (PetscLogDouble)(TRrequestedSize ? head->rsize : head->size));
       PetscCall(PetscStackPrint(&head->stack, fp));
+#else
+      fprintf(fp, "[%2d] %.0f bytes %s() at %s:%d\n", rank, (PetscLogDouble)(TRrequestedSize ? head->rsize : head->size), head->functionname, head->filename, head->lineno);
 #endif
     }
     head = head->next;
@@ -729,25 +723,25 @@ PetscErrorCode PetscMallocDump(FILE *fp)
 }
 
 /*@
-    PetscMallocViewSet - Activates logging of all calls to `PetscMalloc()` with a minimum size to view
+  PetscMallocViewSet - Activates logging of all calls to `PetscMalloc()` with a minimum size to view
 
-    Not Collective
+  Not Collective
 
-    Input Parameter:
-.   logmin - minimum allocation size to log, or `PETSC_DEFAULT` to log all memory allocations
+  Input Parameter:
+. logmin - minimum allocation size to log, or `PETSC_DEFAULT` to log all memory allocations
 
-    Options Database Keys:
-+  -malloc_view <optional filename> - Activates `PetscMallocView()` in `PetscFinalize()`
-.  -malloc_view_threshold <min> - Sets a minimum size if -malloc_view is used
--  -log_view_memory - view the memory usage also with the -log_view option
+  Options Database Keys:
++ -malloc_view <optional filename> - Activates `PetscMallocView()` in `PetscFinalize()`
+. -malloc_view_threshold <min>     - Sets a minimum size if `-malloc_view` is used
+- -log_view_memory                 - view the memory usage also with the -log_view option
 
-    Level: advanced
+  Level: advanced
 
-    Note:
-    Must be called after `PetscMallocSetDebug()`
+  Note:
+  Must be called after `PetscMallocSetDebug()`
 
-    Developer Note:
-    Uses `MPI_COMM_WORLD` to determine rank because PETSc communicators may not be available
+  Developer Notes:
+  Uses `MPI_COMM_WORLD` to determine rank because PETSc communicators may not be available
 
 .seealso: `PetscMallocViewGet()`, `PetscMallocDump()`, `PetscMallocView()`, `PetscMallocTraceSet()`, `PetscMallocValidate()`, `PetscMalloc()`, `PetscFree()`
 @*/
@@ -762,17 +756,17 @@ PetscErrorCode PetscMallocViewSet(PetscLogDouble logmin)
 }
 
 /*@
-    PetscMallocViewGet - Determine whether calls to `PetscMalloc()` are being logged
+  PetscMallocViewGet - Determine whether calls to `PetscMalloc()` are being logged
 
-    Not Collective
+  Not Collective
 
-    Output Parameter
-.   logging - `PETSC_TRUE` if logging is active
+  Output Parameter:
+. logging - `PETSC_TRUE` if logging is active
 
-    Options Database Key:
-.  -malloc_view <optional filename> - Activates `PetscMallocView()`
+  Options Database Key:
+. -malloc_view <optional filename> - Activates `PetscMallocView()`
 
-    Level: advanced
+  Level: advanced
 
 .seealso: `PetscMallocViewSet()`, `PetscMallocDump()`, `PetscMallocView()`, `PetscMallocTraceGet()`, `PetscMalloc()`, `PetscFree()`
 @*/
@@ -784,7 +778,7 @@ PetscErrorCode PetscMallocViewGet(PetscBool *logging)
 }
 
 /*@
-  PetscMallocTraceSet - Trace all calls to `PetscMalloc()`
+  PetscMallocTraceSet - Trace all calls to `PetscMalloc()`. That is print each `PetscMalloc()` and `PetscFree()` call to a viewer.
 
   Not Collective
 
@@ -798,6 +792,8 @@ PetscErrorCode PetscMallocViewGet(PetscBool *logging)
   Note:
   The viewer should not be collective.
 
+  This only does anything if `-malloc_debug` (or `-malloc_test` if PETSc was configured with debugging) has been used
+
 .seealso: `PetscMallocTraceGet()`, `PetscMallocViewGet()`, `PetscMallocDump()`, `PetscMallocView()`, `PetscMalloc()`, `PetscFree()`
 @*/
 PetscErrorCode PetscMallocTraceSet(PetscViewer viewer, PetscBool active, PetscLogDouble logmin)
@@ -830,6 +826,8 @@ PetscErrorCode PetscMallocTraceSet(PetscViewer viewer, PetscBool active, PetscLo
 
   Level: advanced
 
+  This only does anything if `-malloc_debug` (or `-malloc_test` if PETSc was configured with debugging) has been used
+
 .seealso: `PetscMallocTraceSet()`, `PetscMallocViewGet()`, `PetscMallocDump()`, `PetscMallocView()`, `PetscMalloc()`, `PetscFree()`
 @*/
 PetscErrorCode PetscMallocTraceGet(PetscBool *logging)
@@ -840,32 +838,31 @@ PetscErrorCode PetscMallocTraceGet(PetscBool *logging)
 }
 
 /*@C
-    PetscMallocView - Saves the log of all calls to `PetscMalloc()`; also calls
-       `PetscMemoryGetMaximumUsage()`
+  PetscMallocView - Saves the log of all calls to `PetscMalloc()`; also calls `PetscMemoryGetMaximumUsage()`
 
-    Not Collective
+  Not Collective
 
-    Input Parameter:
-.   fp - file pointer; or `NULL`
+  Input Parameter:
+. fp - file pointer; or `NULL`
 
-    Options Database Key:
-.  -malloc_view <optional filename> - Activates `PetscMallocView()` in `PetscFinalize()`
+  Options Database Key:
+. -malloc_view <optional filename> - Activates `PetscMallocView()` in `PetscFinalize()`
 
-    Level: advanced
+  Level: advanced
 
-   Notes:
-     `PetscMallocDump()` dumps only the currently unfreed memory, this dumps all memory ever allocated
+  Notes:
+  `PetscMallocDump()` dumps only the currently unfreed memory, this dumps all memory ever allocated
 
-     `PetscMemoryView()` gives a brief summary of current memory usage
+  `PetscMemoryView()` gives a brief summary of current memory usage
 
-   Fortran Notes:
-   The calling sequence in Fortran is `PetscMallocView`(integer ierr)
+  Fortran Notes:
+  The calling sequence in Fortran is `PetscMallocView`(integer ierr)
 
 .seealso: `PetscMallocGetCurrentUsage()`, `PetscMallocDump()`, `PetscMallocViewSet()`, `PetscMemoryView()`, `PetscMalloc()`, `PetscFree()`
 @*/
 PetscErrorCode PetscMallocView(FILE *fp)
 {
-  PetscInt       i, j, n, *perm;
+  PetscInt       n, *perm;
   size_t        *shortlength;
   int           *shortcount;
   PetscMPIInt    rank;
@@ -893,8 +890,9 @@ PetscErrorCode PetscMallocView(FILE *fp)
     PetscCheck(shortlength, PETSC_COMM_SELF, PETSC_ERR_MEM, "Out of memory");
     shortfunction = (const char **)malloc(PetscLogMalloc * sizeof(char *));
     PetscCheck(shortfunction, PETSC_COMM_SELF, PETSC_ERR_MEM, "Out of memory");
-    for (i = 0, n = 0; i < PetscLogMalloc; i++) {
-      for (j = 0; j < n; j++) {
+    n = 0;
+    for (PetscInt i = 0; i < PetscLogMalloc; i++) {
+      for (PetscInt j = 0; j < n; j++) {
         PetscCall(PetscStrcmp(shortfunction[j], PetscLogMallocFunction[i], &match));
         if (match) {
           shortlength[j] += PetscLogMallocLength[i];
@@ -911,11 +909,11 @@ PetscErrorCode PetscMallocView(FILE *fp)
 
     perm = (PetscInt *)malloc(n * sizeof(PetscInt));
     PetscCheck(perm, PETSC_COMM_SELF, PETSC_ERR_MEM, "Out of memory");
-    for (i = 0; i < n; i++) perm[i] = i;
+    for (PetscInt i = 0; i < n; i++) perm[i] = i;
     PetscCall(PetscSortStrWithPermutation(n, (const char **)shortfunction, perm));
 
     (void)fprintf(fp, "[%d] Memory usage sorted by function\n", rank);
-    for (i = 0; i < n; i++) (void)fprintf(fp, "[%d] %d %.0f %s()\n", rank, shortcount[perm[i]], (PetscLogDouble)shortlength[perm[i]], shortfunction[perm[i]]);
+    for (PetscInt i = 0; i < n; i++) (void)fprintf(fp, "[%d] %d %.0f %s()\n", rank, shortcount[perm[i]], (PetscLogDouble)shortlength[perm[i]], shortfunction[perm[i]]);
     free(perm);
     free(shortlength);
     free(shortcount);
@@ -926,28 +924,26 @@ PetscErrorCode PetscMallocView(FILE *fp)
 }
 
 /*@
-    PetscMallocSetDebug - Set's PETSc memory debugging
+  PetscMallocSetDebug - Set's PETSc memory debugging
 
-    Not Collective
+  Not Collective
 
-    Input Parameters:
-+   eachcall - checks the entire heap of allocated memory for issues on each call to `PetscMalloc()` and `PetscFree()`, slow
--   initializenan - initializes all memory with `NaN` to catch use of uninitialized floating point arrays
+  Input Parameters:
++ eachcall      - checks the entire heap of allocated memory for issues on each call to `PetscMalloc()` and `PetscFree()`, slow
+- initializenan - initializes all memory with `NaN` to catch use of uninitialized floating point arrays
 
-    Options Database Keys:
-+   -malloc_debug <true or false> - turns on or off debugging
-.   -malloc_test - turns on all debugging if PETSc was configured with debugging including `-malloc_dump`, otherwise ignored
-.   -malloc_view_threshold t - log only allocations larger than t
-.   -malloc_dump <filename> - print a list of all memory that has not been freed
-.   -malloc no - (deprecated) same as `-malloc_debug no`
--   -malloc_log - (deprecated) same as `-malloc_view`
+  Options Database Keys:
++ -malloc_debug <true or false> - turns on or off debugging
+. -malloc_test                  - turns on all debugging if PETSc was configured with debugging including `-malloc_dump`, otherwise ignored
+. -malloc_view_threshold t      - log only allocations larger than t
+- -malloc_dump <filename>       - print a list of all memory that has not been freed, in `PetscFinalize()`
 
-   Level: developer
+  Level: developer
 
-    Note:
-    This is called in `PetscInitialize()` and should not be called elsewhere
+  Note:
+  This is called in `PetscInitialize()` and should not be called elsewhere
 
-.seealso: `CHKMEMQ()`, `PetscMallocValidate()`, `PetscMallocGetDebug()`, `PetscMalloc()`, `PetscFree()`
+.seealso: `CHKMEMQ`, `PetscMallocValidate()`, `PetscMallocGetDebug()`, `PetscMalloc()`, `PetscFree()`
 @*/
 PetscErrorCode PetscMallocSetDebug(PetscBool eachcall, PetscBool initializenan)
 {
@@ -959,7 +955,7 @@ PetscErrorCode PetscMallocSetDebug(PetscBool eachcall, PetscBool initializenan)
   TRfrags               = 0;
   TRhead                = NULL;
   TRid                  = 0;
-  TRdebugLevel          = eachcall;
+  TRdebug               = eachcall;
   TRMaxMem              = 0;
   PetscLogMallocMax     = 10000;
   PetscLogMalloc        = -1;
@@ -968,27 +964,27 @@ PetscErrorCode PetscMallocSetDebug(PetscBool eachcall, PetscBool initializenan)
 }
 
 /*@
-    PetscMallocGetDebug - Indicates what PETSc memory debugging it is doing.
+  PetscMallocGetDebug - Indicates what PETSc memory debugging it is doing.
 
-    Not Collective
+  Not Collective
 
-    Output Parameters:
-+    basic - doing basic debugging
-.    eachcall - checks the entire memory heap at each `PetscMalloc()`/`PetscFree()`
--    initializenan - initializes memory with `NaN`
+  Output Parameters:
++ basic         - doing basic debugging
+. eachcall      - checks the entire memory heap at each `PetscMalloc()`/`PetscFree()`
+- initializenan - initializes memory with `NaN`
 
-   Level: intermediate
+  Level: intermediate
 
-   Note:
-     By default, the debug version always does some debugging unless you run with `-malloc_debug no`
+  Note:
+  By default, the debug configuration of PETSc always does some debugging unless you run with `-malloc_debug no`
 
-.seealso: `CHKMEMQ()`, `PetscMallocValidate()`, `PetscMallocSetDebug()`, `PetscMalloc()`, `PetscFree()`
+.seealso: `CHKMEMQ`, `PetscMallocValidate()`, `PetscMallocSetDebug()`, `PetscMalloc()`, `PetscFree()`
 @*/
 PetscErrorCode PetscMallocGetDebug(PetscBool *basic, PetscBool *eachcall, PetscBool *initializenan)
 {
   PetscFunctionBegin;
   if (basic) *basic = (PetscTrMalloc == PetscTrMallocDefault) ? PETSC_TRUE : PETSC_FALSE;
-  if (eachcall) *eachcall = TRdebugLevel;
+  if (eachcall) *eachcall = TRdebug;
   if (initializenan) *initializenan = TRdebugIinitializenan;
   PetscFunctionReturn(PETSC_SUCCESS);
 }
