@@ -1,5 +1,6 @@
 #include "sycldevice.hpp"
 #include <CL/sycl.hpp>
+#include <Kokkos_Core.hpp>
 
 namespace Petsc
 {
@@ -15,13 +16,16 @@ namespace impl
 
 class DeviceContext {
 public:
-  struct PetscDeviceContext_IMPLS {
+  struct PetscDeviceContext_SYCL {
     ::sycl::event event;
-    ::sycl::event begin; // timer-only
-    ::sycl::event end;   // timer-only
+    ::sycl::event begin;   // timer-only
+    ::sycl::event end;     // timer-only
+    Kokkos::Timer timer{}; // use cpu time since sycl events are return value of queue submission and we have no infrastructure to store them
+    double        timeBegin{};
 #if PetscDefined(USE_DEBUG)
-    PetscBool timerInUse;
+    PetscBool timerInUse{};
 #endif
+    ::sycl::queue queue;
   };
 
 private:
@@ -34,7 +38,7 @@ private:
     PetscFunctionReturn(PETSC_SUCCESS);
   }
 
-  static PetscErrorCode initialize_(PetscInt id, DeviceContext *dci) noexcept
+  static PetscErrorCode initialize_(PetscInt id, PetscDeviceContext dctx) noexcept
   {
     PetscFunctionBegin;
     PetscCall(PetscDeviceCheckDeviceCount_Internal(id));
@@ -56,20 +60,82 @@ public:
   static PetscErrorCode destroy(PetscDeviceContext dctx) noexcept
   {
     PetscFunctionBegin;
-    delete static_cast<PetscDeviceContext_IMPLS *>(dctx->data);
+    delete static_cast<PetscDeviceContext_SYCL *>(dctx->data);
     dctx->data = nullptr;
     PetscFunctionReturn(PETSC_SUCCESS);
   };
+
+  static PetscErrorCode setUp(PetscDeviceContext dctx) noexcept
+  {
+    PetscFunctionBegin;
+#if PetscDefined(USE_DEBUG)
+    static_cast<PetscDeviceContext_SYCL *>(dctx->data)->timerInUse = PETSC_FALSE;
+#endif
+    // petsc/sycl currently only uses Kokkos's default execution space (and its queue),
+    // so in some sense, we have only one petsc device context.
+    PetscCall(PetscKokkosInitializeCheck());
+    static_cast<PetscDeviceContext_SYCL *>(dctx->data)->queue = Kokkos::DefaultExecutionSpace().sycl_queue();
+    PetscFunctionReturn(PETSC_SUCCESS);
+  };
+
+  static PetscErrorCode query(PetscDeviceContext dctx, PetscBool *idle) noexcept
+  {
+    PetscFunctionBegin;
+    // available in future, https://github.com/intel/llvm/blob/sycl/sycl/doc/extensions/supported/sycl_ext_oneapi_queue_empty.asciidoc
+    // *idle = static_cast<PetscDeviceContext_SYCL*>(dctx->data)->queue.empty() ? PETSC_TRUE : PETSC_FALSE;
+    *idle = PETSC_FALSE;
+    PetscFunctionReturn(PETSC_SUCCESS);
+  };
+
+  static PetscErrorCode synchronize(PetscDeviceContext dctx) noexcept
+  {
+    PetscBool  idle = PETSC_TRUE;
+    const auto dci  = static_cast<PetscDeviceContext_SYCL *>(dctx->data);
+
+    PetscFunctionBegin;
+    PetscCall(query(dctx, &idle));
+    if (!idle) PetscCallCXX(dci->queue.wait());
+    PetscFunctionReturn(PETSC_SUCCESS);
+  };
+
+  static PetscErrorCode getStreamHandle(PetscDeviceContext dctx, void **handle) noexcept
+  {
+    PetscFunctionBegin;
+    *reinterpret_cast<::sycl::queue **>(handle) = &(static_cast<PetscDeviceContext_SYCL *>(dctx->data)->queue);
+    PetscFunctionReturn(PETSC_SUCCESS);
+  };
+
+  static PetscErrorCode beginTimer(PetscDeviceContext dctx) noexcept
+  {
+    const auto dci = static_cast<PetscDeviceContext_SYCL *>(dctx->data);
+
+    PetscFunctionBegin;
+#if PetscDefined(USE_DEBUG)
+    PetscCheck(!dci->timerInUse, PETSC_COMM_SELF, PETSC_ERR_PLIB, "Forgot to call PetscLogGpuTimeEnd()?");
+    dci->timerInUse = PETSC_TRUE;
+#endif
+    PetscCallCXX(dci->timeBegin = dci->timer.seconds());
+    PetscFunctionReturn(PETSC_SUCCESS);
+  };
+
+  static PetscErrorCode endTimer(PetscDeviceContext dctx, PetscLogDouble *elapsed) noexcept
+  {
+    const auto dci = static_cast<PetscDeviceContext_SYCL *>(dctx->data);
+
+    PetscFunctionBegin;
+#if PetscDefined(USE_DEBUG)
+    PetscCheck(dci->timerInUse, PETSC_COMM_SELF, PETSC_ERR_PLIB, "Forgot to call PetscLogGpuTimeBegin()?");
+    dci->timerInUse = PETSC_FALSE;
+#endif
+    PetscCallCXX(dci->queue.wait());
+    PetscCallCXX(*elapsed = dci->timer.seconds() - dci->timeBegin);
+    PetscFunctionReturn(PETSC_SUCCESS);
+  };
+
   static PetscErrorCode changeStreamType(PetscDeviceContext, PetscStreamType) noexcept { SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP, "Not implemented"); };
-  static PetscErrorCode setUp(PetscDeviceContext) noexcept { return PETSC_SUCCESS; }; // Nothing to setup
-  static PetscErrorCode query(PetscDeviceContext, PetscBool *) noexcept { SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP, "Not implemented"); };
   static PetscErrorCode waitForContext(PetscDeviceContext, PetscDeviceContext) noexcept { SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP, "Not implemented"); };
-  static PetscErrorCode synchronize(PetscDeviceContext) noexcept { SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP, "Not implemented"); };
   static PetscErrorCode getBlasHandle(PetscDeviceContext, void *) noexcept { SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP, "Not implemented"); };
   static PetscErrorCode getSolverHandle(PetscDeviceContext, void *) noexcept { SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP, "Not implemented"); };
-  static PetscErrorCode getStreamHandle(PetscDeviceContext, void *) noexcept { SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP, "Not implemented"); };
-  static PetscErrorCode beginTimer(PetscDeviceContext) noexcept { SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP, "Not implemented"); };
-  static PetscErrorCode endTimer(PetscDeviceContext, PetscLogDouble *) noexcept { SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP, "Not implemented"); };
 };
 
 } // namespace impl
@@ -87,7 +153,7 @@ PetscErrorCode PetscDeviceContextCreate_SYCL(PetscDeviceContext dctx)
   static const DeviceContext syclctx;
 
   PetscFunctionBegin;
-  dctx->data = new DeviceContext::PetscDeviceContext_IMPLS();
-  PetscCall(PetscMemcpy(dctx->ops, &syclctx.ops, sizeof(syclctx.ops)));
+  PetscCallCXX(dctx->data = new DeviceContext::PetscDeviceContext_SYCL());
+  dctx->ops[0] = syclctx.ops;
   PetscFunctionReturn(PETSC_SUCCESS);
 }
