@@ -1,21 +1,19 @@
-
 #include <petsc/private/petscimpl.h> /*I    "petscsys.h"   I*/
 
 /*@C
-   PetscObjectGetName - Gets a string name associated with a PETSc object.
+  PetscObjectGetName - Gets a string name associated with a PETSc object.
 
-   Not Collective unless object has not been named yet
+  Not Collective unless `obj` has not yet been named
 
-   Input Parameters:
-+  obj - the Petsc variable
-         Thus must be cast with a (`PetscObject`), for example,
+  Input Parameters:
++ obj  - the PETSc variable. It must be cast with a (`PetscObject`), for example,
          `PetscObjectGetName`((`PetscObject`)mat,&name);
--  name - the name associated with obj
+- name - the name associated with `obj`
 
-   Note:
-    Calls `PetscObjectName()` if a name has not yet been provided to the object.
+  Level: intermediate
 
-   Level: intermediate
+  Note:
+  Calls `PetscObjectName()` if a name has not yet been provided to the object.
 
 .seealso: `PetscObjectSetName()`, `PetscObjectName()`, `PetscObject`, `PetscObjectGetId()`
 @*/
@@ -23,7 +21,7 @@ PetscErrorCode PetscObjectGetName(PetscObject obj, const char *name[])
 {
   PetscFunctionBegin;
   PetscValidHeader(obj, 1);
-  PetscValidPointer(name, 2);
+  PetscAssertPointer(name, 2);
   PetscCall(PetscObjectName(obj));
   *name = obj->name;
   PetscFunctionReturn(PETSC_SUCCESS);
