@@ -1,4 +1,3 @@
-
 #include <petscsys.h> /*I  "petscsys.h"  I*/
 #include <petsc/private/mpiutils.h>
 
@@ -15,7 +14,7 @@
              Optionally `NULL`.
 
   Output Parameter:
-. nrecvs    - number of messages received
+. nrecvs - number of messages received
 
   Level: developer
 
@@ -64,15 +63,15 @@ PetscErrorCode PetscGatherNumberOfMessages(MPI_Comm comm, const PetscMPIInt ifla
   Collective
 
   Input Parameters:
-+ comm      - Communicator
-. nsends    - number of messages that are to be sent.
-. nrecvs    - number of messages being received
-- ilengths  - an array of integers of length sizeof(comm)
++ comm     - Communicator
+. nsends   - number of messages that are to be sent.
+. nrecvs   - number of messages being received
+- ilengths - an array of integers of length sizeof(comm)
               a non zero `ilengths`[i] represent a message to i of length `ilengths`[i]
 
   Output Parameters:
-+ onodes    - list of ranks from which messages are expected
-- olengths  - corresponding message lengths
++ onodes   - list of ranks from which messages are expected
+- olengths - corresponding message lengths
 
   Level: developer
 
@@ -99,7 +98,7 @@ PetscErrorCode PetscGatherMessageLengths(MPI_Comm comm, PetscMPIInt nsends, Pets
 
   /* cannot use PetscMalloc3() here because in the call to MPI_Waitall() they MUST be contiguous */
   PetscCall(PetscMalloc2(nrecvs + nsends, &r_waits, nrecvs + nsends, &w_status));
-  s_waits = r_waits + nrecvs;
+  if (nrecvs + nsends) s_waits = r_waits + nrecvs;
 
   /* Post the Irecv to get the message length-info */
   PetscCall(PetscMalloc1(nrecvs, olengths));
@@ -121,8 +120,8 @@ PetscErrorCode PetscGatherMessageLengths(MPI_Comm comm, PetscMPIInt nsends, Pets
   for (i = 0; i < nrecvs; ++i) {
     (*onodes)[i] = w_status[i].MPI_SOURCE;
 #if defined(PETSC_HAVE_OMPI_MAJOR_VERSION)
-    /* This line is a workaround for a bug in OpenMPI-2.1.1 distributed by Ubuntu-18.04.2 LTS.
-       It happens in self-to-self MPI_Send/Recv using MPI_ANY_SOURCE for message matching. OpenMPI
+    /* This line is a workaround for a bug in Open MPI 2.1.1 distributed by Ubuntu-18.04.2 LTS.
+       It happens in self-to-self MPI_Send/Recv using MPI_ANY_SOURCE for message matching. Open MPI
        does not put correct value in recv buffer. See also
        https://lists.mcs.anl.gov/pipermail/petsc-dev/2019-July/024803.html
        https://www.mail-archive.com/users@lists.open-mpi.org//msg33383.html
@@ -177,7 +176,7 @@ PetscErrorCode PetscGatherMessageLengths_Private(MPI_Comm comm, PetscMPIInt nsen
 
   /* cannot use PetscMalloc3() here because in the call to MPI_Waitall() they MUST be contiguous */
   PetscCall(PetscMalloc2(nrecvs + nsends, &r_waits, nrecvs + nsends, &w_status));
-  s_waits = r_waits + nrecvs;
+  if (r_waits) s_waits = r_waits + nrecvs;
 
   /* Post the Irecv to get the message length-info */
   PetscCall(PetscMalloc1(nrecvs, olengths));
