@@ -1,4 +1,3 @@
-
 /*
     Code for tracing mistakes in MPI usage. For example, sends that are never received,
   nonblocking messages that are not correctly waited for, etc.
@@ -9,18 +8,18 @@
 #if defined(PETSC_USE_LOG) && !defined(PETSC_HAVE_MPIUNI)
 
 /*@C
-   PetscMPIDump - Dumps a listing of incomplete MPI operations, such as sends that
-   have never been received, etc.
+  PetscMPIDump - Dumps a listing of incomplete MPI operations, such as sends that
+  have never been received, etc.
 
-   Collective on `PETSC_COMM_WORLD`
+  Collective on `PETSC_COMM_WORLD`
 
-   Input Parameter:
-.  fp - file pointer.  If fp is NULL, stdout is assumed.
+  Input Parameter:
+. fd - file pointer.  If fp is `NULL`, `stdout` is assumed.
 
-   Options Database Key:
-.  -mpidump - Dumps MPI incompleteness during call to PetscFinalize()
+  Options Database Key:
+. -mpidump - Dumps MPI incompleteness during call to PetscFinalize()
 
-    Level: developer
+  Level: developer
 
 .seealso: `PetscMallocDump()`
  @*/
@@ -28,7 +27,6 @@ PetscErrorCode PetscMPIDump(FILE *fd)
 {
   PetscMPIInt rank;
   double      tsends, trecvs, work;
-  int         err;
 
   PetscFunctionBegin;
   PetscCallMPI(MPI_Comm_rank(PETSC_COMM_WORLD, &rank));
@@ -39,8 +37,7 @@ PetscErrorCode PetscMPIDump(FILE *fd)
   if (petsc_irecv_ct + petsc_isend_ct != petsc_sum_of_waits_ct) {
     PetscCall(PetscFPrintf(PETSC_COMM_SELF, fd, "[%d]You have not waited on all non-blocking sends and receives", rank));
     PetscCall(PetscFPrintf(PETSC_COMM_SELF, fd, "[%d]Number non-blocking sends %g receives %g number of waits %g\n", rank, petsc_isend_ct, petsc_irecv_ct, petsc_sum_of_waits_ct));
-    err = fflush(fd);
-    PetscCheck(!err, PETSC_COMM_SELF, PETSC_ERR_SYS, "fflush() failed on file");
+    PetscCall(PetscFFlush(fd));
   }
   PetscCall(PetscSequentialPhaseEnd(PETSC_COMM_WORLD, 1));
   /* Did we receive all the messages that we sent? */
@@ -50,10 +47,9 @@ PetscErrorCode PetscMPIDump(FILE *fd)
   PetscCallMPI(MPI_Reduce(&work, &tsends, 1, MPI_DOUBLE, MPI_SUM, 0, PETSC_COMM_WORLD));
   if (rank == 0 && tsends != trecvs) {
     PetscCall(PetscFPrintf(PETSC_COMM_SELF, fd, "Total number sends %g not equal receives %g\n", tsends, trecvs));
-    err = fflush(fd);
-    PetscCheck(!err, PETSC_COMM_SELF, PETSC_ERR_SYS, "fflush() failed on file");
+    PetscCall(PetscFFlush(fd));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #else
@@ -61,14 +57,14 @@ PetscErrorCode PetscMPIDump(FILE *fd)
 PetscErrorCode PetscMPIDump(FILE *fd)
 {
   PetscFunctionBegin;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #endif
 
 #if defined(PETSC_HAVE_MPI_PROCESS_SHARED_MEMORY)
 /*
-    OpenMPI version of MPI_Win_allocate_shared() does not provide __float128 alignment so we provide
+    Open MPI version of MPI_Win_allocate_shared() does not provide __float128 alignment so we provide
     a utility that insures alignment up to data item size.
 */
 PetscErrorCode MPIU_Win_allocate_shared(MPI_Aint sz, PetscMPIInt szind, MPI_Info info, MPI_Comm comm, void *ptr, MPI_Win *win)
@@ -79,7 +75,7 @@ PetscErrorCode MPIU_Win_allocate_shared(MPI_Aint sz, PetscMPIInt szind, MPI_Info
   PetscCallMPI(MPI_Win_allocate_shared(16 + sz, szind, info, comm, &tmp, win));
   tmp += ((size_t)tmp) % szind ? szind / 4 - ((((size_t)tmp) % szind) / 4) : 0;
   *(void **)ptr = (void *)tmp;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PETSC_EXTERN PetscErrorCode MPIU_Win_shared_query(MPI_Win win, PetscMPIInt rank, MPI_Aint *sz, PetscMPIInt *szind, void *ptr)
@@ -91,7 +87,7 @@ PETSC_EXTERN PetscErrorCode MPIU_Win_shared_query(MPI_Win win, PetscMPIInt rank,
   PetscCheck(*szind > 0, PETSC_COMM_SELF, PETSC_ERR_LIB, "szkind %d must be positive", *szind);
   tmp += ((size_t)tmp) % *szind ? *szind / 4 - ((((size_t)tmp) % *szind) / 4) : 0;
   *(void **)ptr = (void *)tmp;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #endif
