@@ -1,8 +1,6 @@
 #include <petsc/private/taolinesearchimpl.h>
 #include <../src/tao/linesearch/impls/gpcglinesearch/gpcglinesearch.h>
 
-/* ---------------------------------------------------------- */
-
 static PetscErrorCode TaoLineSearchDestroy_GPCG(TaoLineSearch ls)
 {
   TaoLineSearch_GPCG *ctx = (TaoLineSearch_GPCG *)ls->data;
@@ -16,7 +14,6 @@ static PetscErrorCode TaoLineSearchDestroy_GPCG(TaoLineSearch ls)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*------------------------------------------------------------*/
 static PetscErrorCode TaoLineSearchView_GPCG(TaoLineSearch ls, PetscViewer viewer)
 {
   PetscBool isascii;
@@ -27,7 +24,6 @@ static PetscErrorCode TaoLineSearchView_GPCG(TaoLineSearch ls, PetscViewer viewe
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*------------------------------------------------------------*/
 static PetscErrorCode TaoLineSearchApply_GPCG(TaoLineSearch ls, Vec x, PetscReal *f, Vec g, Vec s)
 {
   TaoLineSearch_GPCG *neP = (TaoLineSearch_GPCG *)ls->data;
@@ -179,15 +175,13 @@ static PetscErrorCode TaoLineSearchApply_GPCG(TaoLineSearch ls, Vec x, PetscReal
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/* ---------------------------------------------------------- */
-
 /*MC
-   TAOLINESEARCHGPCG - Special line-search method for the Gradient-Projected Conjugate Gradient (TAOGPCG) algorithm.
+   TAOLINESEARCHGPCG - Special line-search method for the Gradient-Projected Conjugate Gradient (`TAOGPCG`) algorithm.
    Should not be used with any other algorithm.
 
    Level: developer
 
-.keywords: Tao, linesearch
+  .seealso: `TAOGPCG`, `TaoLineSearch`, `Tao`
 M*/
 PETSC_EXTERN PetscErrorCode TaoLineSearchCreate_GPCG(TaoLineSearch ls)
 {
