@@ -1,4 +1,3 @@
-
 #include <petsc/private/characteristicimpl.h> /*I "petsccharacteristic.h" I*/
 #include <petscdmda.h>
 #include <petscviewer.h>
@@ -13,14 +12,13 @@ PetscLogEvent CHARACTERISTIC_FullTimeLocal, CHARACTERISTIC_FullTimeRemote, CHARA
 PetscFunctionList CharacteristicList              = NULL;
 PetscBool         CharacteristicRegisterAllCalled = PETSC_FALSE;
 
-PetscErrorCode DMDAGetNeighborsRank(DM, PetscMPIInt[]);
-PetscInt       DMDAGetNeighborRelative(DM, PetscReal, PetscReal);
-PetscErrorCode DMDAMapToPeriodicDomain(DM, PetscScalar[]);
+static PetscErrorCode DMDAGetNeighborsRank(DM, PetscMPIInt[]);
+static PetscInt       DMDAGetNeighborRelative(DM, PetscReal, PetscReal);
 
-PetscErrorCode CharacteristicHeapSort(Characteristic, Queue, PetscInt);
-PetscErrorCode CharacteristicSiftDown(Characteristic, Queue, PetscInt, PetscInt);
+static PetscErrorCode CharacteristicHeapSort(Characteristic, Queue, PetscInt);
+static PetscErrorCode CharacteristicSiftDown(Characteristic, Queue, PetscInt, PetscInt);
 
-PetscErrorCode CharacteristicView(Characteristic c, PetscViewer viewer)
+static PetscErrorCode CharacteristicView(Characteristic c, PetscViewer viewer)
 {
   PetscBool iascii;
 
@@ -63,7 +61,7 @@ PetscErrorCode CharacteristicCreate(MPI_Comm comm, Characteristic *c)
   Characteristic newC;
 
   PetscFunctionBegin;
-  PetscValidPointer(c, 2);
+  PetscAssertPointer(c, 2);
   *c = NULL;
   PetscCall(CharacteristicInitializePackage());
 
@@ -109,22 +107,22 @@ PetscErrorCode CharacteristicCreate(MPI_Comm comm, Characteristic *c)
 }
 
 /*@C
-   CharacteristicSetType - Builds Characteristic for a particular solver.
+  CharacteristicSetType - Builds Characteristic for a particular solver.
 
-   Logically Collective
+  Logically Collective
 
-   Input Parameters:
-+  c    - the method of characteristics context
--  type - a known method
+  Input Parameters:
++ c    - the method of characteristics context
+- type - a known method
 
-   Options Database Key:
-.  -characteristic_type <method> - Sets the method; use -help for a list
+  Options Database Key:
+. -characteristic_type <method> - Sets the method; use -help for a list
     of available methods
 
   Level: intermediate
 
-   Notes:
-   See "include/petsccharacteristic.h" for available methods
+  Notes:
+  See "include/petsccharacteristic.h" for available methods
 
   Normally, it is best to use the CharacteristicSetFromOptions() command and
   then set the Characteristic type from the options database rather than by using
@@ -147,7 +145,7 @@ PetscErrorCode CharacteristicSetType(Characteristic c, CharacteristicType type)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(c, CHARACTERISTIC_CLASSID, 1);
-  PetscValidCharPointer(type, 2);
+  PetscAssertPointer(type, 2);
 
   PetscCall(PetscObjectTypeCompare((PetscObject)c, type, &match));
   if (match) PetscFunctionReturn(PETSC_SUCCESS);
@@ -160,7 +158,7 @@ PetscErrorCode CharacteristicSetType(Characteristic c, CharacteristicType type)
   }
 
   PetscCall(PetscFunctionListFind(CharacteristicList, type, &r));
-  PetscCheck(r, PETSC_COMM_SELF, PETSC_ERR_ARG_UNKNOWN_TYPE, "Unknown Characteristic type given: %s", type);
+  PetscCheck(r, PetscObjectComm((PetscObject)c), PETSC_ERR_ARG_UNKNOWN_TYPE, "Unknown Characteristic type given: %s", type);
   c->setupcalled = 0;
   PetscCall((*r)(c));
   PetscCall(PetscObjectChangeTypeName((PetscObject)c, type));
@@ -168,15 +166,15 @@ PetscErrorCode CharacteristicSetType(Characteristic c, CharacteristicType type)
 }
 
 /*@
-   CharacteristicSetUp - Sets up the internal data structures for the
-   later use of an iterative solver.
+  CharacteristicSetUp - Sets up the internal data structures for the
+  later use of an iterative solver.
 
-   Collective
+  Collective
 
-   Input Parameter:
-.  ksp   - iterative context obtained from CharacteristicCreate()
+  Input Parameter:
+. c - iterative context obtained from CharacteristicCreate()
 
-   Level: developer
+  Level: developer
 
 .seealso: [](ch_ts), `CharacteristicCreate()`, `CharacteristicSolve()`, `CharacteristicDestroy()`
 @*/
@@ -199,15 +197,15 @@ PetscErrorCode CharacteristicSetUp(Characteristic c)
 /*@C
   CharacteristicRegister -  Adds a solver to the method of characteristics package.
 
-   Not Collective
+  Not Collective
 
-   Input Parameters:
-+  sname - name of a new user-defined solver
--  function - routine to create method context
+  Input Parameters:
++ sname    - name of a new user-defined solver
+- function - routine to create method context
 
   Level: advanced
 
-  Sample usage:
+  Example Usage:
 .vb
     CharacteristicRegister("my_char", MyCharCreate);
 .ve
@@ -217,13 +215,13 @@ PetscErrorCode CharacteristicSetUp(Characteristic c)
     CharacteristicCreate(MPI_Comm, Characteristic* &char);
     CharacteristicSetType(char,"my_char");
 .ve
-   or at runtime via the option
+  or at runtime via the option
 .vb
     -characteristic_type my_char
 .ve
 
-   Notes:
-   CharacteristicRegister() may be called multiple times to add several user-defined solvers.
+  Notes:
+  CharacteristicRegister() may be called multiple times to add several user-defined solvers.
 
 .seealso: [](ch_ts), `CharacteristicRegisterAll()`, `CharacteristicRegisterDestroy()`
 @*/
@@ -332,9 +330,9 @@ PetscErrorCode CharacteristicSolve(Characteristic c, PetscReal dt, Vec solution)
   PetscCall(PetscMalloc1(c->numFieldComp, &fieldValues));
   PetscCall(PetscLogEventBegin(CHARACTERISTIC_Solve, NULL, NULL, NULL, NULL));
 
-  /* -----------------------------------------------------------------------
+  /*
      PART 1, AT t-dt/2
-     -----------------------------------------------------------------------*/
+    */
   PetscCall(PetscLogEventBegin(CHARACTERISTIC_QueueSetup, NULL, NULL, NULL, NULL));
   /* GET POSITION AT HALF TIME IN THE PAST */
   if (c->velocityInterpLocal) {
@@ -427,9 +425,9 @@ PetscErrorCode CharacteristicSolve(Characteristic c, PetscReal dt, Vec solution)
   }
   PetscCall(PetscLogEventEnd(CHARACTERISTIC_HalfTimeExchange, NULL, NULL, NULL, NULL));
 
-  /* -----------------------------------------------------------------------
+  /*
      PART 2, AT t-dt
-     -----------------------------------------------------------------------*/
+  */
 
   /* GET POSITION AT t_n (local values) */
   PetscCall(PetscLogEventBegin(CHARACTERISTIC_FullTimeLocal, NULL, NULL, NULL, NULL));
@@ -628,12 +626,10 @@ PetscErrorCode CharacteristicGetValuesEnd(Characteristic c)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*---------------------------------------------------------------------*/
 /*
   Based on code from http://linux.wku.edu/~lamonml/algor/sort/heap.html
 */
-PetscErrorCode CharacteristicHeapSort(Characteristic c, Queue queue, PetscInt size)
-/*---------------------------------------------------------------------*/
+static PetscErrorCode CharacteristicHeapSort(Characteristic c, Queue queue, PetscInt size)
 {
   CharacteristicPointDA2D temp;
   PetscInt                n;
@@ -659,12 +655,10 @@ PetscErrorCode CharacteristicHeapSort(Characteristic c, Queue queue, PetscInt si
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*---------------------------------------------------------------------*/
 /*
   Based on code from http://linux.wku.edu/~lamonml/algor/sort/heap.html
 */
-PetscErrorCode CharacteristicSiftDown(Characteristic c, Queue queue, PetscInt root, PetscInt bottom)
-/*---------------------------------------------------------------------*/
+static PetscErrorCode CharacteristicSiftDown(Characteristic c, Queue queue, PetscInt root, PetscInt bottom)
 {
   PetscBool               done = PETSC_FALSE;
   PetscInt                maxChild;
@@ -687,7 +681,7 @@ PetscErrorCode CharacteristicSiftDown(Characteristic c, Queue queue, PetscInt ro
 }
 
 /* [center, left, top-left, top, top-right, right, bottom-right, bottom, bottom-left] */
-PetscErrorCode DMDAGetNeighborsRank(DM da, PetscMPIInt neighbors[])
+static PetscErrorCode DMDAGetNeighborsRank(DM da, PetscMPIInt neighbors[])
 {
   DMBoundaryType bx, by;
   PetscBool      IPeriodic = PETSC_FALSE, JPeriodic = PETSC_FALSE;
@@ -756,7 +750,7 @@ PetscErrorCode DMDAGetNeighborsRank(DM da, PetscMPIInt neighbors[])
     8 | 7 | 6
       |   |
 */
-PetscInt DMDAGetNeighborRelative(DM da, PetscReal ir, PetscReal jr)
+static PetscInt DMDAGetNeighborRelative(DM da, PetscReal ir, PetscReal jr)
 {
   DMDALocalInfo info;
   PetscReal     is, ie, js, je;
