@@ -1,4 +1,3 @@
-
 #include <petsc/private/tsimpl.h> /*I   "petscts.h"   I*/
 #include <petscdm.h>
 
@@ -387,8 +386,8 @@ static PetscErrorCode TSView_EIMEX(TS ts, PetscViewer viewer)
   Logically Collective
 
   Input Parameters:
-+  ts - timestepping context
--  nrows - maximum number of rows
++ ts    - timestepping context
+- nrows - maximum number of rows
 
   Level: intermediate
 
@@ -408,9 +407,9 @@ PetscErrorCode TSEIMEXSetMaxRows(TS ts, PetscInt nrows)
   Logically Collective
 
   Input Parameters:
-+  ts - timestepping context
-.  row - the row
--  col - the column
++ ts  - timestepping context
+. row - the row
+- col - the column
 
   Level: intermediate
 
@@ -430,12 +429,12 @@ PetscErrorCode TSEIMEXSetRowCol(TS ts, PetscInt row, PetscInt col)
   Logically Collective
 
   Input Parameters:
-+  ts - timestepping context
--  tindex - index in the T table
++ ts  - timestepping context
+- flg - index in the T table
 
   Level: intermediate
 
-.seealso: [](ch_ts), `TSEIMEXSetRowCol()`, `TSEIMEXSetOrdAdapt()`, `TSEIMEX`
+.seealso: [](ch_ts), `TSEIMEXSetRowCol()`, `TSEIMEX`
 @*/
 PetscErrorCode TSEIMEXSetOrdAdapt(TS ts, PetscBool flg)
 {
@@ -483,7 +482,7 @@ static PetscErrorCode TSEIMEXSetOrdAdapt_EIMEX(TS ts, PetscBool flg)
 }
 
 /*MC
-      TSEIMEX - Time stepping with Extrapolated IMEX methods.
+   TSEIMEX - Time stepping with Extrapolated IMEX methods {cite}`constantinescu_a2010a`.
 
    These methods are intended for problems with well-separated time scales, especially when a slow scale is strongly nonlinear such that it
    is expensive to solve with a fully implicit method. The user should provide the stiff part of the equation using `TSSetIFunction()` and the
@@ -494,11 +493,13 @@ static PetscErrorCode TSEIMEXSetOrdAdapt_EIMEX(TS ts, PetscBool flg)
   Notes:
   The default is a 3-stage scheme, it can be changed with `TSEIMEXSetMaxRows()` or -ts_eimex_max_rows
 
-  This method currently only works with ODE, for which the stiff part G(t,X,Xdot) has the form Xdot + Ghat(t,X).
+  This method currently only works with ODE, for which the stiff part $ G(t,X,Xdot) $  has the form $ Xdot + Ghat(t,X)$.
 
   The general system is written as
 
+  $$
   G(t,X,Xdot) = F(t,X)
+  $$
 
   where G represents the stiff part and F represents the non-stiff part. The user should provide the stiff part
   of the equation using TSSetIFunction() and the non-stiff part with `TSSetRHSFunction()`.
@@ -506,14 +507,15 @@ static PetscErrorCode TSEIMEXSetOrdAdapt_EIMEX(TS ts, PetscBool flg)
 
   Another common form for the system is
 
+  $$
   y'=f(x)+g(x)
+  $$
 
   The relationship between F,G and f,g is
 
+  $$
   G = y'-g(x), F = f(x)
-
- Reference:
-. [1] -  E. Constantinescu and A. Sandu, Extrapolated implicit-explicit time stepping, SIAM Journal on Scientific Computing, 31 (2010), pp. 4452-4477.
+  $$
 
 .seealso: [](ch_ts), `TSCreate()`, `TS`, `TSSetType()`, `TSEIMEXSetMaxRows()`, `TSEIMEXSetRowCol()`, `TSEIMEXSetOrdAdapt()`, `TSType`
  M*/
