@@ -80,11 +80,11 @@ PetscErrorCode TSBasicSymplecticRegisterAll(void)
 }
 
 /*@C
-   TSBasicSymplecticRegisterDestroy - Frees the list of schemes that were registered by `TSBasicSymplecticRegister()`.
+  TSBasicSymplecticRegisterDestroy - Frees the list of schemes that were registered by `TSBasicSymplecticRegister()`.
 
-   Not Collective
+  Not Collective
 
-   Level: advanced
+  Level: advanced
 
 .seealso: [](ch_ts), `TSBasicSymplecticRegister()`, `TSBasicSymplecticRegisterAll()`, `TSBASICSYMPLECTIC`
 @*/
@@ -139,21 +139,21 @@ PetscErrorCode TSBasicSymplecticFinalizePackage(void)
 }
 
 /*@C
-   TSBasicSymplecticRegister - register a basic symplectic integration scheme by providing the coefficients.
+  TSBasicSymplecticRegister - register a basic symplectic integration scheme by providing the coefficients.
 
-   Not Collective, but the same schemes should be registered on all processes on which they will be used
+  Not Collective, but the same schemes should be registered on all processes on which they will be used
 
-   Input Parameters:
-+  name - identifier for method
-.  order - approximation order of method
-.  s - number of stages, this is the dimension of the matrices below
-.  c - coefficients for updating generalized position (dimension s)
--  d - coefficients for updating generalized momentum (dimension s)
+  Input Parameters:
++ name  - identifier for method
+. order - approximation order of method
+. s     - number of stages, this is the dimension of the matrices below
+. c     - coefficients for updating generalized position (dimension s)
+- d     - coefficients for updating generalized momentum (dimension s)
 
-   Level: advanced
+  Level: advanced
 
-   Notes:
-   Several symplectic methods are provided, this function is only needed to create new methods.
+  Note:
+  Several symplectic methods are provided, this function is only needed to create new methods.
 
 .seealso: [](ch_ts), `TSBASICSYMPLECTIC`
 @*/
@@ -163,9 +163,9 @@ PetscErrorCode TSBasicSymplecticRegister(TSRosWType name, PetscInt order, PetscI
   BasicSymplecticScheme     scheme;
 
   PetscFunctionBegin;
-  PetscValidCharPointer(name, 1);
-  PetscValidRealPointer(c, 4);
-  PetscValidRealPointer(d, 5);
+  PetscAssertPointer(name, 1);
+  PetscAssertPointer(c, 4);
+  PetscAssertPointer(d, 5);
 
   PetscCall(TSBasicSymplecticInitializePackage());
   PetscCall(PetscNew(&link));
@@ -370,19 +370,20 @@ static PetscErrorCode TSComputeLinearStability_BasicSymplectic(TS ts, PetscReal
   Logically Collective
 
   Input Parameters:
-+  ts - timestepping context
--  bsymptype - type of the symplectic scheme
++ ts        - timestepping context
+- bsymptype - type of the symplectic scheme
 
   Options Database Key:
-.  -ts_basicsymplectic_type <scheme> - select the scheme
+. -ts_basicsymplectic_type <scheme> - select the scheme
 
   Level: intermediate
 
   Note:
-    The symplectic solver always expects a two-way splitting with the split names being "position" and "momentum". Each split is associated with an `IS` object and a sub-`TS`
-    that is intended to store the user-provided RHS function.
+  The symplectic solver always expects a two-way splitting with the split names being "position" and "momentum".
+  Each split is associated with an `IS` object and a sub-`TS`
+  that is intended to store the user-provided RHS function.
 
-.seealso: [](ch_ts), `TSBASICSYMPLECTIC`, `TSBasicSymplecticType`, `TSBasicSymplecticSetType()`
+.seealso: [](ch_ts), `TSBASICSYMPLECTIC`, `TSBasicSymplecticType`
 @*/
 PetscErrorCode TSBasicSymplecticSetType(TS ts, TSBasicSymplecticType bsymptype)
 {
@@ -398,8 +399,8 @@ PetscErrorCode TSBasicSymplecticSetType(TS ts, TSBasicSymplecticType bsymptype)
   Logically Collective
 
   Input Parameters:
-+  ts - timestepping context
--  bsymptype - type of the basic symplectic scheme
++ ts        - timestepping context
+- bsymptype - type of the basic symplectic scheme
 
   Level: intermediate
 
@@ -444,32 +445,42 @@ static PetscErrorCode TSBasicSymplecticGetType_BasicSymplectic(TS ts, TSBasicSym
 }
 
 /*MC
-  TSBASICSYMPLECTIC - ODE solver using basic symplectic integration schemes
+  TSBASICSYMPLECTIC - ODE solver using basic symplectic integration schemes <https://en.wikipedia.org/wiki/Symplectic_integrator>
 
   These methods are intended for separable Hamiltonian systems
-.vb
-  qdot = dH(q,p,t)/dp
+
+  $$
+  \begin{align*}
+  qdot = dH(q,p,t)/dp   \\
   pdot = -dH(q,p,t)/dq
-.ve
+  \end{align*}
+  $$
 
   where the Hamiltonian can be split into the sum of kinetic energy and potential energy
-.vb
-  H(q,p,t) = T(p,t) + V(q,t).
-.ve
 
-  As a result, the system can be genearlly represented by
-.vb
-  qdot = f(p,t) = dT(p,t)/dp
+  $$
+  H(q,p,t) = T(p,t) + V(q,t).
+  $$
+
+  As a result, the system can be generally represented by
+
+  $$
+  \begin{align*}
+  qdot = f(p,t) = dT(p,t)/dp \\
   pdot = g(q,t) = -dV(q,t)/dq
-.ve
+  \end{align*}
+  $$
 
   and solved iteratively with
-.vb
-  q_new = q_old + d_i*h*f(p_old,t_old)
-  t_new = t_old + d_i*h
-  p_new = p_old + c_i*h*g(p_new,t_new)
-  i=0,1,...,n.
-.ve
+
+  $$
+  \begin{align*}
+  q_new = q_old + d_i*h*f(p_old,t_old) \\
+  t_new = t_old + d_i*h \\
+  p_new = p_old + c_i*h*g(p_new,t_new) \\
+  i     = 0,1,...,n.
+  \end{align*}
+  $$
 
   The solution vector should contain both q and p, which correspond to (generalized) position and momentum respectively. Note that the momentum component
   could simply be velocity in some representations. The symplectic solver always expects a two-way splitting with the split names being "position" and "momentum".
@@ -477,9 +488,6 @@ static PetscErrorCode TSBasicSymplecticGetType_BasicSymplectic(TS ts, TSBasicSym
 
   Level: beginner
 
-  Reference:
-. * -  wikipedia (https://en.wikipedia.org/wiki/Symplectic_integrator)
-
 .seealso: [](ch_ts), `TSCreate()`, `TSSetType()`, `TSRHSSplitSetIS()`, `TSRHSSplitSetRHSFunction()`, `TSType`
 M*/
 PETSC_EXTERN PetscErrorCode TSCreate_BasicSymplectic(TS ts)
