@@ -113,7 +113,7 @@ PetscErrorCode dq2ri(PetscScalar Fd, PetscScalar Fq, PetscScalar delta, PetscSca
   PetscFunctionBegin;
   *Fr = Fd * PetscSinScalar(delta) + Fq * PetscCosScalar(delta);
   *Fi = -Fd * PetscCosScalar(delta) + Fq * PetscSinScalar(delta);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* Converts from network frame ([phase a real,imag) to machine (dq) reference frame */
@@ -122,7 +122,7 @@ PetscErrorCode ri2dq(PetscScalar Fr, PetscScalar Fi, PetscScalar delta, PetscSca
   PetscFunctionBegin;
   *Fd = Fr * PetscSinScalar(delta) - Fi * PetscCosScalar(delta);
   *Fq = Fr * PetscCosScalar(delta) + Fi * PetscSinScalar(delta);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* Saves the solution at each time to a matrix */
@@ -147,7 +147,7 @@ PetscErrorCode SaveSolution(TS ts)
   PetscCall(MatDenseRestoreArray(user->Sol, &mat));
   PetscCall(VecRestoreArrayRead(X, &x));
   user->stepnum++;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode SetInitialGuess(Vec X, Userctx *user)
@@ -235,7 +235,7 @@ PetscErrorCode SetInitialGuess(Vec X, Userctx *user)
   /* PetscCall(VecView(Xgen,0)); */
   PetscCall(DMCompositeGather(user->dmpgrid, INSERT_VALUES, X, Xgen, Xnet));
   PetscCall(DMCompositeRestoreLocalVectors(user->dmpgrid, &Xgen, &Xnet));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode InitialGuess(Vec X, Userctx *user, const PetscScalar PGv[])
@@ -319,7 +319,7 @@ PetscErrorCode InitialGuess(Vec X, Userctx *user, const PetscScalar PGv[])
   /* PetscCall(VecView(Xgen,0)); */
   PetscCall(DMCompositeGather(user->dmpgrid, INSERT_VALUES, X, Xgen, Xnet));
   PetscCall(DMCompositeRestoreLocalVectors(user->dmpgrid, &Xgen, &Xnet));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode DICDPFiniteDifference(Vec X, Vec *DICDP, Userctx *user)
@@ -343,7 +343,7 @@ PetscErrorCode DICDPFiniteDifference(Vec X, Vec *DICDP, Userctx *user)
     PetscCall(VecCopy(Y, DICDP[i]));
   }
   PetscCall(VecDestroy(&Y));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* Computes F = [-f(x,y);g(x,y)] */
@@ -463,7 +463,7 @@ PetscErrorCode ResidualFunction(SNES snes, Vec X, Vec F, Userctx *user)
   PetscCall(DMCompositeGather(user->dmpgrid, INSERT_VALUES, F, Fgen, Fnet));
   PetscCall(DMCompositeRestoreLocalVectors(user->dmpgrid, &Xgen, &Xnet));
   PetscCall(DMCompositeRestoreLocalVectors(user->dmpgrid, &Fgen, &Fnet));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* \dot{x} - f(x,y)
@@ -494,7 +494,7 @@ PetscErrorCode IFunction(TS ts, PetscReal t, Vec X, Vec Xdot, Vec F, Userctx *us
   }
   PetscCall(VecRestoreArray(F, &f));
   PetscCall(VecRestoreArrayRead(Xdot, &xdot));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* This function is used for solving the algebraic system only during fault on and
@@ -521,7 +521,7 @@ PetscErrorCode AlgFunction(SNES snes, Vec X, Vec F, void *ctx)
     f[9 * i + 8] = 0;
   }
   PetscCall(VecRestoreArray(F, &f));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PreallocateJacobian(Mat J, Userctx *user)
@@ -562,7 +562,7 @@ PetscErrorCode PreallocateJacobian(Mat J, Userctx *user)
 
   PetscCall(MatSeqAIJSetPreallocation(J, 0, d_nnz));
   PetscCall(PetscFree(d_nnz));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -852,7 +852,7 @@ PetscErrorCode ResidualJacobian(SNES snes, Vec X, Mat J, Mat B, void *ctx)
 
   PetscCall(MatAssemblyBegin(J, MAT_FINAL_ASSEMBLY));
   PetscCall(MatAssemblyEnd(J, MAT_FINAL_ASSEMBLY));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -867,7 +867,7 @@ PetscErrorCode AlgJacobian(SNES snes, Vec X, Mat A, Mat B, void *ctx)
   PetscCall(ResidualJacobian(snes, X, A, B, ctx));
   PetscCall(MatSetOption(A, MAT_KEEP_NONZERO_PATTERN, PETSC_TRUE));
   PetscCall(MatZeroRowsIS(A, user->is_diff, 1.0, NULL, NULL));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -904,7 +904,7 @@ PetscErrorCode IJacobian(TS ts, PetscReal t, Vec X, Vec Xdot, PetscReal a, Mat A
   }
   PetscCall(MatAssemblyBegin(A, MAT_FINAL_ASSEMBLY));
   PetscCall(MatAssemblyEnd(A, MAT_FINAL_ASSEMBLY));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* Matrix JacobianP is constant so that it only needs to be evaluated once */
@@ -930,7 +930,7 @@ static PetscErrorCode RHSJacobianP(TS ts, PetscReal t, Vec X, Mat A, void *ctx0)
     PetscCall(MatAssemblyBegin(A, MAT_FINAL_ASSEMBLY));
     PetscCall(MatAssemblyEnd(A, MAT_FINAL_ASSEMBLY));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode CostIntegrand(TS ts, PetscReal t, Vec U, Vec R, Userctx *user)
@@ -958,7 +958,7 @@ static PetscErrorCode CostIntegrand(TS ts, PetscReal t, Vec U, Vec R, Userctx *u
   PetscCall(VecRestoreArrayRead(U, &u));
   PetscCall(VecRestoreArray(R, &r));
   PetscCall(DMCompositeRestoreLocalVectors(user->dmpgrid, &Xgen, &Xnet));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DRDUJacobianTranspose(TS ts, PetscReal t, Vec U, Mat DRDU, Mat B, Userctx *user)
@@ -998,13 +998,13 @@ static PetscErrorCode DRDUJacobianTranspose(TS ts, PetscReal t, Vec U, Mat DRDU,
   PetscCall(VecResetArray(drdu_col));
   PetscCall(MatDenseRestoreColumn(DRDU, &xarr));
   PetscCall(VecDestroy(&drdu_col));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DRDPJacobianTranspose(TS ts, PetscReal t, Vec U, Mat drdp, Userctx *user)
 {
   PetscFunctionBegin;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode ComputeSensiP(Vec lambda, Vec mu, Vec *DICDP, Userctx *user)
@@ -1023,7 +1023,7 @@ PetscErrorCode ComputeSensiP(Vec lambda, Vec mu, Vec *DICDP, Userctx *user)
     y[i] = sensip;
   }
   PetscCall(VecRestoreArray(mu, &y));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 int main(int argc, char **argv)
@@ -1449,7 +1449,7 @@ PetscErrorCode FormFunctionGradient(Tao tao, Vec P, PetscReal *f, Vec G, void *c
   PetscCall(VecDestroy(&X));
   PetscCall(TSDestroy(&ts));
   for (i = 0; i < 3; i++) PetscCall(VecDestroy(&DICDP[i]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*TEST
