@@ -1,4 +1,3 @@
-
 #include <../src/vec/pf/pfimpl.h> /*I "petscpf.h" I*/
 
 /*
@@ -36,22 +35,25 @@ static PetscErrorCode PFSetFromOptions_String(PF pf, PetscOptionItems *PetscOpti
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*
-    PFStringSetFunction - Creates a function from a string
+/*@C
+  PFStringSetFunction - Creates a function from a string
 
-   Collective
+  Collective
 
   Input Parameters:
-+    pf - the function object
--    string - the string that defines the function
++ pf     - the function object
+- string - the string that defines the function
+
+  Level: intermediate
 
   Developer Notes:
-  Currently this can be used only ONCE in a running code. It needs to be fixed to generate a new library name for each new function added.
+  Currently this can be used only ONCE in a running code. It needs to be fixed to generate a
+  new library name for each new function added.
 
   Requires `PETSC_HAVE_POPEN` `PETSC_USE_SHARED_LIBRARIES` `PETSC_HAVE_DYNAMIC_LIBRARIES` to use
 
 .seealso: `PFSetFromOptions()`
-*/
+@*/
 PetscErrorCode PFStringSetFunction(PF pf, const char *string)
 {
   char      task[1024], tmp[PETSC_MAX_PATH_LEN], lib[PETSC_MAX_PATH_LEN];
@@ -95,7 +97,7 @@ PetscErrorCode PFStringSetFunction(PF pf, const char *string)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PETSC_EXTERN PetscErrorCode PFCreate_String(PF pf, void *value)
+PETSC_INTERN PetscErrorCode PFCreate_String(PF pf, void *value)
 {
   PetscFunctionBegin;
   PetscCall(PFStringSetFunction(pf, (const char *)value));
