@@ -1,4 +1,3 @@
-
 /*
       Split phase global vector reductions with support for combining the
    communication portion of several operations. Using MPI-1.1 support only
@@ -97,18 +96,19 @@ PETSC_EXTERN void MPIAPI PetscSplitReduction_Local(void *in, void *out, PetscMPI
 }
 
 /*@
-   PetscCommSplitReductionBegin - Begin an asynchronous split-mode reduction
+  PetscCommSplitReductionBegin - Begin an asynchronous split-mode reduction
 
-   Collective but not synchronizing
+  Collective but not synchronizing
 
-   Input Parameter:
-   comm - communicator on which split reduction has been queued
+  Input Parameter:
+. comm - communicator on which split reduction has been queued
 
-   Level: advanced
+  Level: advanced
 
-   Note:
-   Calling this function is optional when using split-mode reduction. On supporting hardware, calling this after all
-   VecXxxBegin() allows the reduction to make asynchronous progress before the result is needed (in VecXxxEnd()).
+  Note:
+  Calling this function is optional when using split-mode reduction. On supporting hardware,
+  calling this after all VecXxxBegin() allows the reduction to make asynchronous progress
+  before the result is needed (in VecXxxEnd()).
 
 .seealso: `VecNormBegin()`, `VecNormEnd()`, `VecDotBegin()`, `VecDotEnd()`, `VecTDotBegin()`, `VecTDotEnd()`, `VecMDotBegin()`, `VecMDotEnd()`, `VecMTDotBegin()`, `VecMTDotEnd()`
 @*/
@@ -117,6 +117,7 @@ PetscErrorCode PetscCommSplitReductionBegin(MPI_Comm comm)
   PetscSplitReduction *sr;
 
   PetscFunctionBegin;
+  if (PetscDefined(HAVE_THREADSAFETY)) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscSplitReductionGet(comm, &sr));
   PetscCheck(sr->numopsend <= 0, PETSC_COMM_SELF, PETSC_ERR_ORDER, "Cannot call this after VecxxxEnd() has been called");
   if (sr->async) { /* Bad reuse, setup code copied from PetscSplitReductionApply(). */
@@ -263,7 +264,7 @@ PetscErrorCode PetscSplitReductionExtend(PetscSplitReduction *sr)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode PetscSplitReductionDestroy(PetscSplitReduction *sr)
+static PetscErrorCode PetscSplitReductionDestroy(PetscSplitReduction *sr)
 {
   PetscFunctionBegin;
   PetscCall(PetscFree6(sr->lvalues, sr->gvalues, sr->reducetype, sr->invecs, sr->lvalues_mix, sr->gvalues_mix));
@@ -280,7 +281,7 @@ PetscMPIInt Petsc_Reduction_keyval = MPI_KEYVAL_INVALID;
   The binding for the first argument changed from MPI 1.0 to 1.1; in 1.0
   it was MPI_Comm *comm.
 */
-PETSC_EXTERN PetscMPIInt MPIAPI Petsc_DelReduction(MPI_Comm comm, PetscMPIInt keyval, void *attr_val, void *extra_state)
+static PetscMPIInt MPIAPI Petsc_DelReduction(MPI_Comm comm, PETSC_UNUSED PetscMPIInt keyval, void *attr_val, PETSC_UNUSED void *extra_state)
 {
   PetscFunctionBegin;
   PetscCallMPI(PetscInfo(0, "Deleting reduction data in an MPI_Comm %ld\n", (long)comm));
@@ -298,6 +299,7 @@ PetscErrorCode PetscSplitReductionGet(MPI_Comm comm, PetscSplitReduction **sr)
   PetscMPIInt flag;
 
   PetscFunctionBegin;
+  PetscCheck(!PetscDefined(HAVE_THREADSAFETY), comm, PETSC_ERR_SUP, "PetscSplitReductionGet() is not thread-safe");
   if (Petsc_Reduction_keyval == MPI_KEYVAL_INVALID) {
     /*
        The calling sequence of the 2nd argument to this function changed
@@ -320,17 +322,17 @@ PetscErrorCode PetscSplitReductionGet(MPI_Comm comm, PetscSplitReduction **sr)
 /* ----------------------------------------------------------------------------------------------------*/
 
 /*@
-   VecDotBegin - Starts a split phase dot product computation.
+  VecDotBegin - Starts a split phase dot product computation.
 
-   Input Parameters:
-+   x - the first vector
-.   y - the second vector
--   result - where the result will go (can be NULL)
+  Input Parameters:
++ x      - the first vector
+. y      - the second vector
+- result - where the result will go (can be NULL)
 
-   Level: advanced
+  Level: advanced
 
-   Notes:
-   Each call to `VecDotBegin()` should be paired with a call to `VecDotEnd()`.
+  Notes:
+  Each call to `VecDotBegin()` should be paired with a call to `VecDotEnd()`.
 
 .seealso: `VecDotEnd()`, `VecNormBegin()`, `VecNormEnd()`, `VecNorm()`, `VecDot()`, `VecMDot()`,
           `VecTDotBegin()`, `VecTDotEnd()`, `PetscCommSplitReductionBegin()`
@@ -344,6 +346,11 @@ PetscErrorCode VecDotBegin(Vec x, Vec y, PetscScalar *result)
   PetscValidHeaderSpecific(x, VEC_CLASSID, 1);
   PetscValidHeaderSpecific(y, VEC_CLASSID, 2);
   PetscCall(PetscObjectGetComm((PetscObject)x, &comm));
+  if (PetscDefined(HAVE_THREADSAFETY)) {
+    PetscCheck(result, comm, PETSC_ERR_ARG_NULL, "result cannot be NULL when configuring --with-threadsafety");
+    PetscCall(VecDot(x, y, result));
+    PetscFunctionReturn(PETSC_SUCCESS);
+  }
   PetscCall(PetscSplitReductionGet(comm, &sr));
   PetscCheck(sr->state == STATE_BEGIN, PETSC_COMM_SELF, PETSC_ERR_ORDER, "Called before all VecxxxEnd() called");
   if (sr->numopsbegin >= sr->maxops) PetscCall(PetscSplitReductionExtend(sr));
@@ -356,17 +363,17 @@ PetscErrorCode VecDotBegin(Vec x, Vec y, PetscScalar *result)
 }
 
 /*@
-   VecDotEnd - Ends a split phase dot product computation.
+  VecDotEnd - Ends a split phase dot product computation.
 
-   Input Parameters:
-+  x - the first vector (can be `NULL`)
-.  y - the second vector (can be `NULL`)
--  result - where the result will go
+  Input Parameters:
++ x      - the first vector (can be `NULL`)
+. y      - the second vector (can be `NULL`)
+- result - where the result will go
 
-   Level: advanced
+  Level: advanced
 
-   Notes:
-   Each call to `VecDotBegin()` should be paired with a call to `VecDotEnd()`.
+  Notes:
+  Each call to `VecDotBegin()` should be paired with a call to `VecDotEnd()`.
 
 .seealso: `VecDotBegin()`, `VecNormBegin()`, `VecNormEnd()`, `VecNorm()`, `VecDot()`, `VecMDot()`,
           `VecTDotBegin()`, `VecTDotEnd()`, `PetscCommSplitReductionBegin()`
@@ -377,6 +384,7 @@ PetscErrorCode VecDotEnd(Vec x, Vec y, PetscScalar *result)
   MPI_Comm             comm;
 
   PetscFunctionBegin;
+  if (PetscDefined(HAVE_THREADSAFETY)) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscObjectGetComm((PetscObject)x, &comm));
   PetscCall(PetscSplitReductionGet(comm, &sr));
   PetscCall(PetscSplitReductionEnd(sr));
@@ -399,17 +407,17 @@ PetscErrorCode VecDotEnd(Vec x, Vec y, PetscScalar *result)
 }
 
 /*@
-   VecTDotBegin - Starts a split phase transpose dot product computation.
+  VecTDotBegin - Starts a split phase transpose dot product computation.
 
-   Input Parameters:
-+  x - the first vector
-.  y - the second vector
--  result - where the result will go (can be `NULL`)
+  Input Parameters:
++ x      - the first vector
+. y      - the second vector
+- result - where the result will go (can be `NULL`)
 
-   Level: advanced
+  Level: advanced
 
-   Notes:
-   Each call to `VecTDotBegin()` should be paired with a call to `VecTDotEnd()`.
+  Notes:
+  Each call to `VecTDotBegin()` should be paired with a call to `VecTDotEnd()`.
 
 .seealso: `VecTDotEnd()`, `VecNormBegin()`, `VecNormEnd()`, `VecNorm()`, `VecDot()`, `VecMDot()`,
           `VecDotBegin()`, `VecDotEnd()`, `PetscCommSplitReductionBegin()`
@@ -421,6 +429,11 @@ PetscErrorCode VecTDotBegin(Vec x, Vec y, PetscScalar *result)
 
   PetscFunctionBegin;
   PetscCall(PetscObjectGetComm((PetscObject)x, &comm));
+  if (PetscDefined(HAVE_THREADSAFETY)) {
+    PetscCheck(result, comm, PETSC_ERR_ARG_NULL, "result cannot be NULL when configuring --with-threadsafety");
+    PetscCall(VecTDot(x, y, result));
+    PetscFunctionReturn(PETSC_SUCCESS);
+  }
   PetscCall(PetscSplitReductionGet(comm, &sr));
   PetscCheck(sr->state == STATE_BEGIN, PETSC_COMM_SELF, PETSC_ERR_ORDER, "Called before all VecxxxEnd() called");
   if (sr->numopsbegin >= sr->maxops) PetscCall(PetscSplitReductionExtend(sr));
@@ -433,17 +446,17 @@ PetscErrorCode VecTDotBegin(Vec x, Vec y, PetscScalar *result)
 }
 
 /*@
-   VecTDotEnd - Ends a split phase transpose dot product computation.
+  VecTDotEnd - Ends a split phase transpose dot product computation.
 
-   Input Parameters:
-+  x - the first vector (can be `NULL`)
-.  y - the second vector (can be `NULL`)
--  result - where the result will go
+  Input Parameters:
++ x      - the first vector (can be `NULL`)
+. y      - the second vector (can be `NULL`)
+- result - where the result will go
 
-   Level: advanced
+  Level: advanced
 
-   Notes:
-   Each call to `VecTDotBegin()` should be paired with a call to `VecTDotEnd()`.
+  Notes:
+  Each call to `VecTDotBegin()` should be paired with a call to `VecTDotEnd()`.
 
 .seealso: `VecTDotBegin()`, `VecNormBegin()`, `VecNormEnd()`, `VecNorm()`, `VecDot()`, `VecMDot()`,
           `VecDotBegin()`, `VecDotEnd()`
@@ -461,17 +474,17 @@ PetscErrorCode VecTDotEnd(Vec x, Vec y, PetscScalar *result)
 /* -------------------------------------------------------------------------*/
 
 /*@
-   VecNormBegin - Starts a split phase norm computation.
+  VecNormBegin - Starts a split phase norm computation.
 
-   Input Parameters:
-+  x - the first vector
-.  ntype - norm type, one of `NORM_1`, `NORM_2`, `NORM_MAX`, `NORM_1_AND_2`
--  result - where the result will go (can be `NULL`)
+  Input Parameters:
++ x      - the first vector
+. ntype  - norm type, one of `NORM_1`, `NORM_2`, `NORM_MAX`, `NORM_1_AND_2`
+- result - where the result will go (can be `NULL`)
 
-   Level: advanced
+  Level: advanced
 
-   Notes:
-   Each call to `VecNormBegin()` should be paired with a call to `VecNormEnd()`.
+  Notes:
+  Each call to `VecNormBegin()` should be paired with a call to `VecNormEnd()`.
 
 .seealso: `VecNormEnd()`, `VecNorm()`, `VecDot()`, `VecMDot()`, `VecDotBegin()`, `VecDotEnd()`, `PetscCommSplitReductionBegin()`
 @*/
@@ -484,6 +497,12 @@ PetscErrorCode VecNormBegin(Vec x, NormType ntype, PetscReal *result)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(x, VEC_CLASSID, 1);
   PetscCall(PetscObjectGetComm((PetscObject)x, &comm));
+  if (PetscDefined(HAVE_THREADSAFETY)) {
+    PetscCheck(result, comm, PETSC_ERR_ARG_NULL, "result cannot be NULL when configuring --with-threadsafety");
+    PetscCall(PetscObjectStateIncrease((PetscObject)x)); // increase PetscObjectState to invalidate cached norms
+    PetscCall(VecNorm(x, ntype, result));
+    PetscFunctionReturn(PETSC_SUCCESS);
+  }
   PetscCall(PetscSplitReductionGet(comm, &sr));
   PetscCheck(sr->state == STATE_BEGIN, PETSC_COMM_SELF, PETSC_ERR_ORDER, "Called before all VecxxxEnd() called");
   if (sr->numopsbegin >= sr->maxops || (sr->numopsbegin == sr->maxops - 1 && ntype == NORM_1_AND_2)) PetscCall(PetscSplitReductionExtend(sr));
@@ -505,19 +524,19 @@ PetscErrorCode VecNormBegin(Vec x, NormType ntype, PetscReal *result)
 }
 
 /*@
-   VecNormEnd - Ends a split phase norm computation.
+  VecNormEnd - Ends a split phase norm computation.
 
-   Input Parameters:
-+  x - the first vector
-.  ntype - norm type, one of `NORM_1`, `NORM_2`, `NORM_MAX`, `NORM_1_AND_2`
--  result - where the result will go
+  Input Parameters:
++ x      - the first vector
+. ntype  - norm type, one of `NORM_1`, `NORM_2`, `NORM_MAX`, `NORM_1_AND_2`
+- result - where the result will go
 
-   Level: advanced
+  Level: advanced
 
-   Notes:
-   Each call to `VecNormBegin()` should be paired with a call to `VecNormEnd()`.
+  Notes:
+  Each call to `VecNormBegin()` should be paired with a call to `VecNormEnd()`.
 
-   The `x` vector is not allowed to be `NULL`, otherwise the vector would not have its correctly cached norm value
+  The `x` vector is not allowed to be `NULL`, otherwise the vector would not have its correctly cached norm value
 
 .seealso: `VecNormBegin()`, `VecNorm()`, `VecDot()`, `VecMDot()`, `VecDotBegin()`, `VecDotEnd()`, `PetscCommSplitReductionBegin()`
 @*/
@@ -527,6 +546,7 @@ PetscErrorCode VecNormEnd(Vec x, NormType ntype, PetscReal *result)
   MPI_Comm             comm;
 
   PetscFunctionBegin;
+  if (PetscDefined(HAVE_THREADSAFETY)) PetscFunctionReturn(PETSC_SUCCESS);
   PetscValidHeaderSpecific(x, VEC_CLASSID, 1);
   PetscCall(PetscObjectGetComm((PetscObject)x, &comm));
   PetscCall(PetscSplitReductionGet(comm, &sr));
@@ -562,18 +582,18 @@ PetscErrorCode VecNormEnd(Vec x, NormType ntype, PetscReal *result)
 */
 
 /*@
-   VecMDotBegin - Starts a split phase multiple dot product computation.
+  VecMDotBegin - Starts a split phase multiple dot product computation.
 
-   Input Parameters:
-+   x - the first vector
-.   nv - number of vectors
-.   y - array of vectors
--   result - where the result will go (can be `NULL`)
+  Input Parameters:
++ x      - the first vector
+. nv     - number of vectors
+. y      - array of vectors
+- result - where the result will go (can be `NULL`)
 
-   Level: advanced
+  Level: advanced
 
-   Notes:
-   Each call to `VecMDotBegin()` should be paired with a call to `VecMDotEnd()`.
+  Notes:
+  Each call to `VecMDotBegin()` should be paired with a call to `VecMDotEnd()`.
 
 .seealso: `VecMDotEnd()`, `VecNormBegin()`, `VecNormEnd()`, `VecNorm()`, `VecDot()`, `VecMDot()`,
           `VecTDotBegin()`, `VecTDotEnd()`, `VecMTDotBegin()`, `VecMTDotEnd()`, `PetscCommSplitReductionBegin()`
@@ -586,6 +606,11 @@ PetscErrorCode VecMDotBegin(Vec x, PetscInt nv, const Vec y[], PetscScalar resul
 
   PetscFunctionBegin;
   PetscCall(PetscObjectGetComm((PetscObject)x, &comm));
+  if (PetscDefined(HAVE_THREADSAFETY)) {
+    PetscCheck(result, comm, PETSC_ERR_ARG_NULL, "result cannot be NULL when configuring --with-threadsafety");
+    PetscCall(VecMDot(x, nv, y, result));
+    PetscFunctionReturn(PETSC_SUCCESS);
+  }
   PetscCall(PetscSplitReductionGet(comm, &sr));
   PetscCheck(sr->state == STATE_BEGIN, PETSC_COMM_SELF, PETSC_ERR_ORDER, "Called before all VecxxxEnd() called");
   for (i = 0; i < nv; i++) {
@@ -601,20 +626,20 @@ PetscErrorCode VecMDotBegin(Vec x, PetscInt nv, const Vec y[], PetscScalar resul
 }
 
 /*@
-   VecMDotEnd - Ends a split phase multiple dot product computation.
+  VecMDotEnd - Ends a split phase multiple dot product computation.
 
-   Input Parameters:
-+   x - the first vector (can be `NULL`)
-.   nv - number of vectors
--   y - array of vectors (can be `NULL`)
+  Input Parameters:
++ x  - the first vector (can be `NULL`)
+. nv - number of vectors
+- y  - array of vectors (can be `NULL`)
 
-   Output Parameter:
-.   result - where the result will go
+  Output Parameter:
+. result - where the result will go
 
-   Level: advanced
+  Level: advanced
 
-   Notes:
-   Each call to `VecMDotBegin()` should be paired with a call to `VecMDotEnd()`.
+  Notes:
+  Each call to `VecMDotBegin()` should be paired with a call to `VecMDotEnd()`.
 
 .seealso: `VecMDotBegin()`, `VecNormBegin()`, `VecNormEnd()`, `VecNorm()`, `VecDot()`, `VecMDot()`,
           `VecTDotBegin()`, `VecTDotEnd()`, `VecMTDotBegin()`, `VecMTDotEnd()`, `PetscCommSplitReductionBegin()`
@@ -626,6 +651,7 @@ PetscErrorCode VecMDotEnd(Vec x, PetscInt nv, const Vec y[], PetscScalar result[
   PetscInt             i;
 
   PetscFunctionBegin;
+  if (PetscDefined(HAVE_THREADSAFETY)) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscObjectGetComm((PetscObject)x, &comm));
   PetscCall(PetscSplitReductionGet(comm, &sr));
   PetscCall(PetscSplitReductionEnd(sr));
@@ -647,18 +673,18 @@ PetscErrorCode VecMDotEnd(Vec x, PetscInt nv, const Vec y[], PetscScalar result[
 }
 
 /*@
-   VecMTDotBegin - Starts a split phase transpose multiple dot product computation.
+  VecMTDotBegin - Starts a split phase transpose multiple dot product computation.
 
-   Input Parameters:
-+  x - the first vector
-.  nv - number of vectors
-.  y - array of  vectors
--  result - where the result will go (can be `NULL`)
+  Input Parameters:
++ x      - the first vector
+. nv     - number of vectors
+. y      - array of  vectors
+- result - where the result will go (can be `NULL`)
 
-   Level: advanced
+  Level: advanced
 
-   Notes:
-   Each call to `VecMTDotBegin()` should be paired with a call to `VecMTDotEnd()`.
+  Notes:
+  Each call to `VecMTDotBegin()` should be paired with a call to `VecMTDotEnd()`.
 
 .seealso: `VecMTDotEnd()`, `VecNormBegin()`, `VecNormEnd()`, `VecNorm()`, `VecDot()`, `VecMDot()`,
           `VecDotBegin()`, `VecDotEnd()`, `VecMDotBegin()`, `VecMDotEnd()`, `PetscCommSplitReductionBegin()`
@@ -671,6 +697,11 @@ PetscErrorCode VecMTDotBegin(Vec x, PetscInt nv, const Vec y[], PetscScalar resu
 
   PetscFunctionBegin;
   PetscCall(PetscObjectGetComm((PetscObject)x, &comm));
+  if (PetscDefined(HAVE_THREADSAFETY)) {
+    PetscCheck(result, comm, PETSC_ERR_ARG_NULL, "result cannot be NULL when configuring --with-threadsafety");
+    PetscCall(VecMTDot(x, nv, y, result));
+    PetscFunctionReturn(PETSC_SUCCESS);
+  }
   PetscCall(PetscSplitReductionGet(comm, &sr));
   PetscCheck(sr->state == STATE_BEGIN, PETSC_COMM_SELF, PETSC_ERR_ORDER, "Called before all VecxxxEnd() called");
   for (i = 0; i < nv; i++) {
@@ -686,20 +717,20 @@ PetscErrorCode VecMTDotBegin(Vec x, PetscInt nv, const Vec y[], PetscScalar resu
 }
 
 /*@
-   VecMTDotEnd - Ends a split phase transpose multiple dot product computation.
+  VecMTDotEnd - Ends a split phase transpose multiple dot product computation.
 
-   Input Parameters:
-+  x - the first vector (can be `NULL`)
-.  nv - number of vectors
--  y - array of  vectors (can be `NULL`)
+  Input Parameters:
++ x  - the first vector (can be `NULL`)
+. nv - number of vectors
+- y  - array of  vectors (can be `NULL`)
 
-   Output Parameter:
-.  result - where the result will go
+  Output Parameter:
+. result - where the result will go
 
-   Level: advanced
+  Level: advanced
 
-   Notes:
-   Each call to `VecTDotBegin()` should be paired with a call to `VecTDotEnd()`.
+  Notes:
+  Each call to `VecTDotBegin()` should be paired with a call to `VecTDotEnd()`.
 
 .seealso: `VecMTDotBegin()`, `VecNormBegin()`, `VecNormEnd()`, `VecNorm()`, `VecDot()`, `VecMDot()`,
           `VecDotBegin()`, `VecDotEnd()`, `VecMDotBegin()`, `VecMDotEnd()`, `PetscCommSplitReductionBegin()`
